{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "SoS"
   },
   "source": [
    "## Benefits and Pitfalls"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "SoS"
   },
   "source": [
    "<p style=\"text-align:justify;\">\n",
    "The conventional inversion recovery experiment is considered the gold standard T<sub>1</sub> mapping technique for several reasons. A typical protocol has a long TR value and a sufficient number of inversion times for stable fitting (typically 5 or more) covering the range [0, TR]. It offers a wide dynamic range of signals (up to [-<i>k</i>M<sub>0</sub>, <i>k</i>M<sub>0</sub>]), allowing a number of inversion times where high SNR is available to sample the signal recovery curve (Fukushima 1981). T<sub>1</sub> maps produced by inversion recovery are largely insensitive to inaccuracies in excitation flip angles and imperfect spoiling (Stikov et al. 2015), as all parameters except TI are constant for each measurement and only a single acquisition is performed (at TI) during each TR. One important pulse sequence design consideration is to avoid acquiring at inversion times where the signal for T<sub>1</sub> values of the tissue-of-interest is nulled, as the magnitude images at this TI time will be dominated by Rician noise which can negatively impact the fit under low SNR circumstances (Figure 6). Inversion recovery can also often be acquired using commonly available standard pulse sequences available on most MRI scanners by setting up a customized acquisition protocol, and does not require any additional calibration measurements.\n",
    "</p>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "SoS"
   },
   "source": [
    "<p style=\"text-align:justify;\">\n",
    "<b>\n",
    "Figure 6. Monte Carlo simulations (mean and standard deviation (STD), blue markers) and fitted T<sub>1</sub> values (mean and STD, red and green respectively) generated for a T<sub>1</sub> value of 900 ms and 5 TI values linearly spaced across the TR (ranging from 1 to 5 s). A bump in T<sub>1</sub> STD occurs near TR = 3000 ms, which coincides with the TR where the second TI is located near a null point for this T<sub>1</sub> value. \n",
    "</b>\n",
    "</p>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "kernel": "Octave",
    "tags": [
     "hide_input"
    ]
   },
   "outputs": [],
   "source": [
    "%use octave\n",
    "\n",
    "% Verbosity level 0 overrides the disp function and supresses warnings.\n",
    "% Once executed, they cannot be restored in this session\n",
    "% (kernel needs to be restarted or a new notebook opened.)\n",
    "VERBOSITY_LEVEL = 0;\n",
    "\n",
    "if VERBOSITY_LEVEL==0\n",
    "    % This hack was used to supress outputs from external tools\n",
    "    % in the Jupyter Book.\n",
    "    function disp(x)\n",
    "    end\n",
    "    warning('off','all')\n",
    "end\n",
    "\n",
    "try\n",
    "    cd qMRLab\n",
    "catch\n",
    "    try\n",
    "        cd ../../../qMRLab\n",
    "    catch\n",
    "        cd ../qMRLab\n",
    "    end\n",
    "end\n",
    "\n",
    "startup\n",
    "clear all\n",
    "\n",
    "%% Setup parameters\n",
    "% All times are in seconds\n",
    "% All flip angles are in degrees\n",
    "\n",
    "TR_range = 1000:100:5000; % in seconds\n",
    "\n",
    "x = struct;\n",
    "x.T1 = 900; % in seconds\n",
    "\n",
    "Opt.SNR = 25;\n",
    "Opt.M0 = 1;\n",
    "Opt.FAexcite = 90; % Excitation flip angle\n",
    "Opt.FAinv = 180;   % Inversion flip angle\n",
    "\n",
    "%% Monte Carlo data simulation\n",
    "% Simulate noisy signal data 1,000 time, fit the data, then calculate the means and standard deviations of the data and fitted T1\n",
    "% Data is calculated by calculating the a and b values of Eq. 4 from the full analytical equations (Eq. 1)\n",
    "\n",
    "Model = inversion_recovery; \n",
    "\n",
    "for ii = 1:length(TR_range)\n",
    "    Opt.TR = TR_range(ii);\n",
    "    Opt.T1 = x.T1;\n",
    "    TI_lowres(ii,:) = linspace(0.05, Opt.TR, 6)';\n",
    "    Model.Prot.IRData.Mat = [TI_lowres(ii,:)];\n",
    "    [ra,rb] = Model.ComputeRaRb(x,Opt);\n",
    "    x.rb = rb;\n",
    "    x.ra = ra;\n",
    "    for jj = 1:1000\n",
    "        [FitResult{ii,jj}, noisyData{ii,jj}] = Model.Sim_Single_Voxel_Curve(x,Opt,0); \n",
    "        fittedT1(ii,jj) = FitResult{ii,jj}.T1;\n",
    "        noisyData_array(ii,jj,:) = noisyData{ii,jj}.IRData;\n",
    "    end\n",
    "        \n",
    "    for kk=1:length(TI_lowres(ii,:))\n",
    "        data_mean(ii,kk) = mean(noisyData_array(ii,:,kk));\n",
    "        data_std(ii,kk) = std(noisyData_array(ii,:,kk));\n",
    "    end\n",
    "    \n",
    "    T1_mean(ii) = mean(fittedT1(ii,:));\n",
    "    T1_std(ii) = std(fittedT1(ii,:));\n",
    "end\n",
    "\n",
    "%% Calculate the noiseless data at a higher TI resolution to plot the ideal signal curve.\n",
    "%\n",
    "\n",
    "for ii = 1:length(TR_range)\n",
    "    TI_highres(ii,:) = linspace(0.05, TR_range(ii), 500);\n",
    "    Model.Prot.IRData.Mat = [TI_highres(ii,:)];\n",
    "    Opt.TR = TR_range(ii);\n",
    "    Opt.T1 = x.T1;\n",
    "    [ra,rb] = Model.ComputeRaRb(x,Opt);\n",
    "    x.rb = rb;\n",
    "    x.ra = ra;\n",
    "\n",
    "    data_noiseless(ii,:) = Model.equation(x);\n",
    "end"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "kernel": "SoS",
    "tags": [
     "hide_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script><script>requirejs.config({paths: { 'plotly': ['https://cdn.plot.ly/plotly-latest.min']},});if(!window._Plotly) {require(['plotly'],function(plotly) {window._Plotly=plotly;});}</script>"
      ],
      "text/vnd.plotly.v1+html": [
       "<script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script><script>requirejs.config({paths: { 'plotly': ['https://cdn.plot.ly/plotly-latest.min']},});if(!window._Plotly) {require(['plotly'],function(plotly) {window._Plotly=plotly;});}</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<html><head><meta charset=\"utf-8\" /></head><body><script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script><script type=\"text/javascript\">/**\n",
       "* plotly.js v1.44.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;z-index:1001;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;margin-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;margin-left:0px;margin-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":694}],2:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1159}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":842}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":854}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":864}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":569}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":873}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":892}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":906}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":914}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":929}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":940}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":673}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1160}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1161}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":952}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":961}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":973}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":980}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":984}],22:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./pie\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./sankey\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":3,\"./bar\":4,\"./barpolar\":5,\"./box\":6,\"./calendars\":7,\"./candlestick\":8,\"./carpet\":9,\"./choropleth\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./filter\":15,\"./groupby\":16,\"./heatmap\":17,\"./heatmapgl\":18,\"./histogram\":19,\"./histogram2d\":20,\"./histogram2dcontour\":21,\"./isosurface\":23,\"./mesh3d\":24,\"./ohlc\":25,\"./parcats\":26,\"./parcoords\":27,\"./pie\":28,\"./pointcloud\":29,\"./sankey\":30,\"./scatter3d\":31,\"./scattercarpet\":32,\"./scattergeo\":33,\"./scattergl\":34,\"./scattermapbox\":35,\"./scatterpolar\":36,\"./scatterpolargl\":37,\"./scatterternary\":38,\"./sort\":39,\"./splom\":40,\"./streamtube\":41,\"./surface\":42,\"./table\":43,\"./violin\":44}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":989}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":994}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":999}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1008}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1017}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1028}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1037}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1043}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1079}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1085}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1092}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1100}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1106}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1113}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1117}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1123}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1163}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1128}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1133}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1138}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1146}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1154}],45:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,tick:function(){var e=n(),r=this.delay;c.idle(e-r),c.flush(e-(100+2*r));var i=e-2*r;c.recalcMatrix(i);for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){return c.setMode(t),c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1});var g=0,v=0,m={shift:!1,control:!1,alt:!1,meta:!1};function y(e,r,i,a){var o=1/t.clientHeight,s=o*(r-g),l=o*(i-v),u=d.flipX?1:-1,h=d.flipY?1:-1,p=Math.PI*d.rotateSpeed,y=n();if(1&e)a.shift?c.rotate(y,0,0,-s*p):c.rotate(y,u*p*s,-h*p*l,0);else if(2&e)c.pan(y,-d.translateSpeed*s*f,d.translateSpeed*l*f,0);else if(4&e){var x=d.zoomSpeed*l/window.innerHeight*(y-c.lastT())*50;c.pan(y,0,0,f*(Math.exp(x)-1))}g=r,v=i,m=a}return a(t,y),t.addEventListener(\"touchstart\",function(e){var r=s(e.changedTouches[0],t);y(0,r[0],r[1],m),y(1,r[0],r[1],m),e.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(e){var r=s(e.changedTouches[0],t);y(1,r[0],r[1],m),e.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(e){s(e.changedTouches[0],t),y(0,g,v,m),e.preventDefault()},!!l&&{passive:!1}),o(t,function(t,e,r){var i=d.flipX?1:-1,a=d.flipY?1:-1,o=n();if(Math.abs(t)>Math.abs(e))c.rotate(o,0,0,-t*i*Math.PI*d.rotateSpeed/window.innerWidth);else{var s=d.zoomSpeed*a*e/window.innerHeight*(o-c.lastT())/100;c.pan(o,0,0,f*(Math.exp(s)-1))}},!0),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":46,\"has-passive-events\":397,\"mouse-change\":421,\"mouse-event-offset\":422,\"mouse-wheel\":424,\"right-now\":482}],46:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),f=i(),h=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),new o({turntable:u,orbit:f,matrix:h},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":419,\"orbit-camera-controller\":442,\"turntable-camera-controller\":520}],47:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";t.sankey=function(){var t={},i=24,a=8,o=[1,1],s=[],l=[],c=2/3;function u(){function t(t,e){return t.source.y-e.source.y||t.originalIndex-e.originalIndex}function e(t,e){return t.target.y-e.target.y||t.originalIndex-e.originalIndex}s.forEach(function(r){r.sourceLinks.sort(e),r.targetLinks.sort(t)}),s.forEach(function(t){var e=0,r=0;t.sourceLinks.forEach(function(t){t.sy=e,e+=t.dy}),t.targetLinks.forEach(function(t){t.ty=r,r+=t.dy})})}function f(t){return t.y+t.dy/2}function h(t){return t.value}return t.nodeWidth=function(e){return arguments.length?(i=+e,t):i},t.nodePadding=function(e){return arguments.length?(a=+e,t):a},t.nodes=function(e){return arguments.length?(s=e,t):s},t.links=function(e){return arguments.length?(l=e,t):l},t.size=function(e){return arguments.length?(o=e,t):o},t.layout=function(n){return s.forEach(function(t){t.sourceLinks=[],t.targetLinks=[]}),l.forEach(function(t,e){var r=t.source,n=t.target;\"number\"==typeof r&&(r=t.source=s[t.source]),\"number\"==typeof n&&(n=t.target=s[t.target]),t.originalIndex=e,r.sourceLinks.push(t),n.targetLinks.push(t)}),s.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,h),e.sum(t.targetLinks,h))}),function(){for(var t,e,r=s,n=0;r.length;)t=[],r.forEach(function(e){e.x=n,e.dx=i,e.sourceLinks.forEach(function(e){t.indexOf(e.target)<0&&t.push(e.target)})}),r=t,++n;(function(t){s.forEach(function(e){e.sourceLinks.length||(e.x=t-1)})})(n),e=(o[0]-i)/(n-1),s.forEach(function(t){t.x*=e})}(),function(t){var n=r.nest().key(function(t){return t.x}).sortKeys(e.ascending).entries(s).map(function(t){return t.values});(function(){var t=e.max(n,function(t){return t.length}),r=c*o[1]/(t-1);a>r&&(a=r);var i=e.min(n,function(t){return(o[1]-(t.length-1)*a)/e.sum(t,h)});n.forEach(function(t){t.forEach(function(t,e){t.y=e,t.dy=t.value*i})}),l.forEach(function(t){t.dy=t.value*i})})(),d();for(var i=1;t>0;--t)p(i*=.99),d(),u(i),d();function u(t){function r(t){return f(t.source)*t.value}n.forEach(function(n){n.forEach(function(n){if(n.targetLinks.length){var i=e.sum(n.targetLinks,r)/e.sum(n.targetLinks,h);n.y+=(i-f(n))*t}})})}function p(t){function r(t){return f(t.target)*t.value}n.slice().reverse().forEach(function(n){n.forEach(function(n){if(n.sourceLinks.length){var i=e.sum(n.sourceLinks,r)/e.sum(n.sourceLinks,h);n.y+=(i-f(n))*t}})})}function d(){n.forEach(function(t){var e,r,n,i=0,s=t.length;for(t.sort(g),n=0;n<s;++n)e=t[n],(r=i-e.y)>0&&(e.y+=r),i=e.y+e.dy+a;if((r=i-a-o[1])>0)for(i=e.y-=r,n=s-2;n>=0;--n)e=t[n],(r=e.y+e.dy+a-i)>0&&(e.y-=r),i=e.y})}function g(t,e){return t.y-e.y}}(n),u(),t},t.relayout=function(){return u(),t},t.link=function(){var t=.5;function e(e){var r=e.source.x+e.source.dx,i=e.target.x,a=n.interpolateNumber(r,i),o=a(t),s=a(1-t),l=e.source.y+e.sy,c=l+e.dy,u=e.target.y+e.ty,f=u+e.dy;return\"M\"+r+\",\"+l+\"C\"+o+\",\"+l+\" \"+s+\",\"+u+\" \"+i+\",\"+u+\"L\"+i+\",\"+f+\"C\"+s+\",\"+f+\" \"+o+\",\"+c+\" \"+r+\",\"+c+\"Z\"}return e.curvature=function(r){return arguments.length?(t=+r,e):t},e},t},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-interpolate\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":141,\"d3-collection\":142,\"d3-interpolate\":146}],48:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":231,\"gl-vao\":313,\"weak-map\":530}],49:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],50:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":443}],51:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":488}],52:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:103,\"delaunay-triangulate\":151}],53:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":52,\"simplicial-complex-boundary\":495}],54:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],55:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":54}],56:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],57:[function(t,e,r){(function(r){\"use strict\";function n(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function i(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var a=t(\"util/\"),o=Object.prototype.hasOwnProperty,s=Array.prototype.slice,l=\"foo\"===function(){}.name;function c(t){return Object.prototype.toString.call(t)}function u(t){return!i(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=m,h=/\\s*function\\s+([^\\(\\s]*)\\s*/;function p(t){if(a.isFunction(t)){if(l)return t.name;var e=t.toString().match(h);return e&&e[1]}}function d(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function g(t){if(l||!a.isFunction(t))return a.inspect(t);var e=p(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function m(t,e){t||v(t,!0,e,\"==\",f.ok)}function y(t,e,r,o){if(t===e)return!0;if(i(t)&&i(e))return 0===n(t,e);if(a.isDate(t)&&a.isDate(e))return t.getTime()===e.getTime();if(a.isRegExp(t)&&a.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(u(t)&&u(e)&&c(t)===c(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===n(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(i(t)!==i(e))return!1;var l=(o=o||{actual:[],expected:[]}).actual.indexOf(t);return-1!==l&&l===o.expected.indexOf(e)||(o.actual.push(t),o.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(a.isPrimitive(t)||a.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=x(t),o=x(e);if(i&&!o||!i&&o)return!1;if(i)return t=s.call(t),e=s.call(e),y(t,e,r);var l,c,u=w(t),f=w(e);if(u.length!==f.length)return!1;for(u.sort(),f.sort(),c=u.length-1;c>=0;c--)if(u[c]!==f[c])return!1;for(c=u.length-1;c>=0;c--)if(l=u[c],!y(t[l],e[l],r,n))return!1;return!0}(t,e,r,o))}return r?t===e:t==e}function x(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function b(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function _(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&v(i,r,\"Missing expected exception\"+n);var o=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&a.isError(i)&&o&&b(i,r)||s)&&v(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!b(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=d(g((e=this).actual),128)+\" \"+e.operator+\" \"+d(g(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=p(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},a.inherits(f.AssertionError,Error),f.fail=v,f.ok=m,f.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){y(t,e,!1)||v(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){y(t,e,!0)||v(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){y(t,e,!1)&&v(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){y(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){_(!0,t,e,r)},f.doesNotThrow=function(t,e,r){_(!1,t,e,r)},f.ifError=function(t){if(t)throw t};var w=Object.keys||function(t){var e=[];for(var r in t)o.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"util/\":60}],58:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],59:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],60:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return f(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return f(e)}var c,b=\"\",M=!1,A=[\"{\",\"}\"];(p(e)&&(M=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+f(e)),0!==o.length||M&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=M?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(h(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(h(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return h(t,e,n,s,r,M)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function f(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function h(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===M(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===M(t)}function w(t){return b(t)&&(\"[object Error]\"===M(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function M(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var T=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),T[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":59,_process:468,inherits:58}],61:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],62:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),f=i(u[r+1]);0===f&&(f=1);for(var h=new Array(r+1),o=0;o<=r;++o)h[o]=i(u[o])/f;return h};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":487}],63:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,f=0;f<u;f+=4)e=i[t.charCodeAt(f)]<<18|i[t.charCodeAt(f+1)]<<12|i[t.charCodeAt(f+2)]<<6|i[t.charCodeAt(f+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(f)]<<2|i[t.charCodeAt(f+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(f)]<<10|i[t.charCodeAt(f+1)]<<4|i[t.charCodeAt(f+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],64:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":74}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":74}],67:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,f;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),f=r[0].clone();else if(i(r))f=r.clone();else if(\"string\"==typeof r)f=o(r);else if(r)if(r===Math.floor(r))f=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;f=a(r)}else f=a(1);c>0?u=u.ushln(c):c<0&&(f=f.ushln(-c));return s(u,f)}},{\"./div\":66,\"./is-rat\":68,\"./lib/is-bn\":72,\"./lib/num-to-bn\":73,\"./lib/rationalize\":74,\"./lib/str-to-bn\":75}],68:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":72}],69:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":83}],70:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":69}],71:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":81,\"double-bits\":153}],72:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":83}],73:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":83,\"double-bits\":153}],74:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":69,\"./num-to-bn\":73}],75:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":83}],76:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":74}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":69}],78:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":74}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,f=n(l.ushln(u).divRound(r));return c*(s+f*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53,f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):(f*=Math.pow(2,-1023),c*f*Math.pow(2,1023-h))}},{\"./lib/bn-to-num\":70,\"./lib/ctz\":71}],80:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],81:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],82:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,f,h,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(f=(h=t).getContext(\"2d\"),r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t.canvas,f=t,r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),M=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,M,k),a(b,r,o,_,w,M,k);var T=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)T[d]=n(1-((x[d]-b[d])/m+v),0,1);return T};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:104}],83:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var f=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)f*=e;this.imuln(f),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function h(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,f=67108863&l,h=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=h;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+f)/67108864|0,f=67108863&o}r.words[c]=0|f,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var h=u[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[h-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],f=8191&u,h=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,M=w>>>13,A=0|o[5],T=8191&A,S=A>>>13,C=0|o[6],E=8191&C,L=C>>>13,z=0|o[7],O=8191&z,I=z>>>13,D=0|o[8],P=8191&D,R=D>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],V=8191&j,U=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,W=0|s[2],Y=8191&W,X=W>>>13,Z=0|s[3],$=8191&Z,J=Z>>>13,K=0|s[4],Q=8191&K,tt=K>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ft=8191&ut,ht=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(f,V))|0)+((8191&(i=(i=Math.imul(f,U))+Math.imul(h,V)|0))<<13)|0;c=((a=Math.imul(h,U))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,V),i=(i=Math.imul(d,U))+Math.imul(g,V)|0,a=Math.imul(g,U);var mt=(c+(n=n+Math.imul(f,H)|0)|0)+((8191&(i=(i=i+Math.imul(f,G)|0)+Math.imul(h,H)|0))<<13)|0;c=((a=a+Math.imul(h,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,V),i=(i=Math.imul(m,U))+Math.imul(y,V)|0,a=Math.imul(y,U),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(f,Y)|0)|0)+((8191&(i=(i=i+Math.imul(f,X)|0)+Math.imul(h,Y)|0))<<13)|0;c=((a=a+Math.imul(h,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,V),i=(i=Math.imul(b,U))+Math.imul(_,V)|0,a=Math.imul(_,U),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,Y)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,Y)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(f,$)|0)|0)+((8191&(i=(i=i+Math.imul(f,J)|0)+Math.imul(h,$)|0))<<13)|0;c=((a=a+Math.imul(h,J)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,V),i=(i=Math.imul(k,U))+Math.imul(M,V)|0,a=Math.imul(M,U),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,Y)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,Y)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,J)|0)+Math.imul(g,$)|0,a=a+Math.imul(g,J)|0;var bt=(c+(n=n+Math.imul(f,Q)|0)|0)+((8191&(i=(i=i+Math.imul(f,tt)|0)+Math.imul(h,Q)|0))<<13)|0;c=((a=a+Math.imul(h,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(T,V),i=(i=Math.imul(T,U))+Math.imul(S,V)|0,a=Math.imul(S,U),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(M,H)|0,a=a+Math.imul(M,G)|0,n=n+Math.imul(b,Y)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,Y)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,$)|0,i=(i=i+Math.imul(m,J)|0)+Math.imul(y,$)|0,a=a+Math.imul(y,J)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(f,rt)|0)|0)+((8191&(i=(i=i+Math.imul(f,nt)|0)+Math.imul(h,rt)|0))<<13)|0;c=((a=a+Math.imul(h,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(E,V),i=(i=Math.imul(E,U))+Math.imul(L,V)|0,a=Math.imul(L,U),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,Y)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(M,Y)|0,a=a+Math.imul(M,X)|0,n=n+Math.imul(b,$)|0,i=(i=i+Math.imul(b,J)|0)+Math.imul(_,$)|0,a=a+Math.imul(_,J)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(f,at)|0)|0)+((8191&(i=(i=i+Math.imul(f,ot)|0)+Math.imul(h,at)|0))<<13)|0;c=((a=a+Math.imul(h,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,V),i=(i=Math.imul(O,U))+Math.imul(I,V)|0,a=Math.imul(I,U),n=n+Math.imul(E,H)|0,i=(i=i+Math.imul(E,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(T,Y)|0,i=(i=i+Math.imul(T,X)|0)+Math.imul(S,Y)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,$)|0,i=(i=i+Math.imul(k,J)|0)+Math.imul(M,$)|0,a=a+Math.imul(M,J)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(f,lt)|0)|0)+((8191&(i=(i=i+Math.imul(f,ct)|0)+Math.imul(h,lt)|0))<<13)|0;c=((a=a+Math.imul(h,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(P,V),i=(i=Math.imul(P,U))+Math.imul(R,V)|0,a=Math.imul(R,U),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(I,H)|0,a=a+Math.imul(I,G)|0,n=n+Math.imul(E,Y)|0,i=(i=i+Math.imul(E,X)|0)+Math.imul(L,Y)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,J)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,J)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(M,Q)|0,a=a+Math.imul(M,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Mt=(c+(n=n+Math.imul(f,ft)|0)|0)+((8191&(i=(i=i+Math.imul(f,ht)|0)+Math.imul(h,ft)|0))<<13)|0;c=((a=a+Math.imul(h,ht)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,V),i=(i=Math.imul(B,U))+Math.imul(N,V)|0,a=Math.imul(N,U),n=n+Math.imul(P,H)|0,i=(i=i+Math.imul(P,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,Y)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(I,Y)|0,a=a+Math.imul(I,X)|0,n=n+Math.imul(E,$)|0,i=(i=i+Math.imul(E,J)|0)+Math.imul(L,$)|0,a=a+Math.imul(L,J)|0,n=n+Math.imul(T,Q)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(M,rt)|0,a=a+Math.imul(M,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ft)|0,i=(i=i+Math.imul(d,ht)|0)+Math.imul(g,ft)|0,a=a+Math.imul(g,ht)|0;var At=(c+(n=n+Math.imul(f,dt)|0)|0)+((8191&(i=(i=i+Math.imul(f,gt)|0)+Math.imul(h,dt)|0))<<13)|0;c=((a=a+Math.imul(h,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(P,Y)|0,i=(i=i+Math.imul(P,X)|0)+Math.imul(R,Y)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,$)|0,i=(i=i+Math.imul(O,J)|0)+Math.imul(I,$)|0,a=a+Math.imul(I,J)|0,n=n+Math.imul(E,Q)|0,i=(i=i+Math.imul(E,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(M,at)|0,a=a+Math.imul(M,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ft)|0,i=(i=i+Math.imul(m,ht)|0)+Math.imul(y,ft)|0,a=a+Math.imul(y,ht)|0;var Tt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,Y),i=(i=Math.imul(B,X))+Math.imul(N,Y)|0,a=Math.imul(N,X),n=n+Math.imul(P,$)|0,i=(i=i+Math.imul(P,J)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,J)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(I,Q)|0,a=a+Math.imul(I,tt)|0,n=n+Math.imul(E,rt)|0,i=(i=i+Math.imul(E,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(M,lt)|0,a=a+Math.imul(M,ct)|0,n=n+Math.imul(b,ft)|0,i=(i=i+Math.imul(b,ht)|0)+Math.imul(_,ft)|0,a=a+Math.imul(_,ht)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,J))+Math.imul(N,$)|0,a=Math.imul(N,J),n=n+Math.imul(P,Q)|0,i=(i=i+Math.imul(P,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(I,rt)|0,a=a+Math.imul(I,nt)|0,n=n+Math.imul(E,at)|0,i=(i=i+Math.imul(E,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ft)|0,i=(i=i+Math.imul(k,ht)|0)+Math.imul(M,ft)|0,a=a+Math.imul(M,ht)|0;var Ct=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(P,rt)|0,i=(i=i+Math.imul(P,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(I,at)|0,a=a+Math.imul(I,ot)|0,n=n+Math.imul(E,lt)|0,i=(i=i+Math.imul(E,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(T,ft)|0,i=(i=i+Math.imul(T,ht)|0)+Math.imul(S,ft)|0,a=a+Math.imul(S,ht)|0;var Et=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(M,dt)|0))<<13)|0;c=((a=a+Math.imul(M,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(P,at)|0,i=(i=i+Math.imul(P,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(I,lt)|0,a=a+Math.imul(I,ct)|0,n=n+Math.imul(E,ft)|0,i=(i=i+Math.imul(E,ht)|0)+Math.imul(L,ft)|0,a=a+Math.imul(L,ht)|0;var Lt=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(P,lt)|0,i=(i=i+Math.imul(P,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ft)|0,i=(i=i+Math.imul(O,ht)|0)+Math.imul(I,ft)|0,a=a+Math.imul(I,ht)|0;var zt=(c+(n=n+Math.imul(E,dt)|0)|0)+((8191&(i=(i=i+Math.imul(E,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(P,ft)|0,i=(i=i+Math.imul(P,ht)|0)+Math.imul(R,ft)|0,a=a+Math.imul(R,ht)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(I,dt)|0))<<13)|0;c=((a=a+Math.imul(I,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ft),i=(i=Math.imul(B,ht))+Math.imul(N,ft)|0,a=Math.imul(N,ht);var It=(c+(n=n+Math.imul(P,dt)|0)|0)+((8191&(i=(i=i+Math.imul(P,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863;var Dt=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(Dt>>>26)|0,Dt&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Mt,l[9]=At,l[10]=Tt,l[11]=St,l[12]=Ct,l[13]=Et,l[14]=Lt,l[15]=zt,l[16]=Ot,l[17]=It,l[18]=Dt,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=h),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?h(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,f=(0|t.words[u])*(0|e.words[c]),h=67108863&f;s=67108863&(h=h+s|0),i+=(o=(o=o+(f/67108864|0)|0)+(h>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var f=l,h=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=f*v-h*m;m=f*m+h*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*f-c*h,h=l*h+c*f,f=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),f=new Array(n),h=r.words;h.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,f,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*f[p];l[p]=s[p]*f[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,h,a,n,i),this.conjugate(h,a,n),this.normalize13b(h,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var f=0|this.words[c];this.words[c]=u<<26-a|f>>>a,u=f&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var f=l-1;f>=0;f--){var h=67108864*(0|n.words[i.length+f])+(0|n.words[i.length+f-1]);for(h=Math.min(h/o|0,67108863),n._ishlnsubmul(i,h,f);0!==n.negative;)h--,n.negative=0,n._ishlnsubmul(i,1,f),n.isZero()||(n.negative^=1);s&&(s.words[f]=h)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),f=e.clone();!e.isZero();){for(var h=0,p=1;0==(e.words[0]&p)&&h<26;++h,p<<=1);if(h>0)for(e.iushrn(h);h-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(f)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(f)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var f=0,h=1;0==(r.words[0]&h)&&f<26;++f,h<<=1);if(f>0)for(r.iushrn(f);f-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var f=this.pow(u,i),h=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(f,new a(1).iushln(d-v-1));h=h.redMul(m),f=m.redSqr(),p=p.redMul(f),d=v}return h},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var f=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==f||0!==o?(o<<=1,o|=f,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:92}],84:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),f=0;for(n=0;n<c;++n)n!==r&&(u[f++]=l[n]);if(1&r){var h=u[1];u[1]=u[0],u[0]=h}}}return o}},{}],85:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var f,h=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,h,p))>0){if(1===u&&n)a.init(s),f=a.sweepComplete(u,r,0,s,h,p,0,s,h,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),f=1===u?a.sweepBipartite(u,r,0,s,h,p,0,c,d,g):o(u,r,n,s,h,p,c,d,g),i.free(d),i.free(g))}i.free(h),i.free(p)}return f}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":87,\"./lib/sweep\":91,\"typedarray-pool\":523}],86:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",f=\"ri\",h=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,f,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+h+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+h+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+h+\"],x1=\"+u+\"[\"+i+\"+\"+h+\"+\"+n+\"],xi=\"+f+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+h+\"],r1=\"+u+\"[k+\"+n+\"+\"+h+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var M=r.join(\"\")+w.join(\"\");return new Function(M)()}r.partial=_(!1),r.full=_(!0)},{}],87:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,C,E,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+C);var z,O=0,I=2*t;M(O++,0,0,a,0,C,r?16:0,-1/0,1/0),r||M(O++,0,0,C,0,a,1,-1/0,1/0);for(;O>0;){var D=(O-=1)*b,P=w[D],R=w[D+1],F=w[D+2],B=w[D+3],N=w[D+4],j=w[D+5],V=O*_,U=k[V],q=k[V+1],H=1&j,G=!!(16&j),W=u,Y=S,X=E,Z=L;if(H&&(W=E,Y=L,X=u,Z=S),!(2&j&&(F=v(t,P,R,F,W,Y,q),R>=F)||4&j&&(R=m(t,P,R,F,W,Y,U))>=F)){var $=F-R,J=N-B;if(G){if(t*$*($+J)<p){if(void 0!==(z=l.scanComplete(t,P,e,R,F,W,Y,B,N,X,Z)))return z;continue}}else{if(t*Math.min($,J)<f){if(void 0!==(z=o(t,P,e,H,R,F,W,Y,B,N,X,Z)))return z;continue}if(t*$*J<h){if(void 0!==(z=l.scanBipartite(t,P,e,H,R,F,W,Y,B,N,X,Z)))return z;continue}}var K=d(t,P,R,F,W,Y,U,q);if(R<K)if(t*(K-R)<f){if(void 0!==(z=s(t,P+1,e,R,K,W,Y,B,N,X,Z)))return z}else if(P===t-2){if(void 0!==(z=H?l.sweepBipartite(t,e,B,N,X,Z,R,K,W,Y):l.sweepBipartite(t,e,R,K,W,Y,B,N,X,Z)))return z}else M(O++,P+1,R,K,B,N,H,-1/0,1/0),M(O++,P+1,B,N,R,K,1^H,-1/0,1/0);if(K<F){var Q=c(t,P,B,N,X,Z),tt=X[I*Q+P],et=g(t,P,Q,N,X,Z,tt);if(et<N&&M(O++,P,K,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&M(O++,P,K,F,B,Q,(2|H)+(G?16:0),U,tt),Q+1===et){if(void 0!==(z=G?T(t,P,e,K,F,W,Y,Q,X,Z[Q]):A(t,P,e,H,K,F,W,Y,Q,X,Z[Q])))return z}else if(Q<et){var rt;if(G){if(rt=y(t,P,K,F,W,Y,tt),K<rt){var nt=g(t,P,K,rt,W,Y,tt);if(P===t-2){if(K<nt&&void 0!==(z=l.sweepComplete(t,e,K,nt,W,Y,Q,et,X,Z)))return z;if(nt<rt&&void 0!==(z=l.sweepBipartite(t,e,nt,rt,W,Y,Q,et,X,Z)))return z}else K<nt&&M(O++,P+1,K,nt,Q,et,16,-1/0,1/0),nt<rt&&(M(O++,P+1,nt,rt,Q,et,0,-1/0,1/0),M(O++,P+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,P,K,F,W,Y,tt):y(t,P,K,F,W,Y,tt),K<rt&&(P===t-2?z=H?l.sweepBipartite(t,e,Q,et,X,Z,K,rt,W,Y):l.sweepBipartite(t,e,K,rt,W,Y,Q,et,X,Z):(M(O++,P+1,K,rt,Q,et,H,-1/0,1/0),M(O++,P+1,Q,et,K,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),f=128,h=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function M(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var f=2*t,h=l*f,p=c[h+e];t:for(var d=i,g=i*f;d<a;++d,g+=f){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[h+b],w=c[h+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function T(t,e,r,n,i,a,o,s,l,c){var u=2*t,f=s*u,h=l[f+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(h<v||m<h)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[f+y],b=l[f+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":86,\"./median\":88,\"./partition\":89,\"./sweep\":91,\"bit-twiddle\":81,\"typedarray-pool\":523}],88:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,f=o+r>>>1,h=2*t,p=f,d=s[h*f+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[h*f+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[h*v+e],y=Math.random()*g+c|0,x=s[h*y+e],b=Math.random()*g+c|0,_=s[h*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=h*(u-1),k=h*p,M=0;M<h;++M,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var T=l[u-1];l[u-1]=l[p],l[p]=T,p=n(t,e,c,u-1,s,l,d);for(var w=h*(u-1),k=h*p,M=0;M<h;++M,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var T=l[u-1];if(l[u-1]=l[p],l[p]=T,f<p){for(u=p-1;c<u&&s[h*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<f))break;for(c=p+1;c<u&&s[h*c+e]===d;)c+=1}}return n(t,e,r,f,s,l,s[h*f+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,f=o*(l-1);u>r&&i[f+e]>c;--u,f-=o){for(var h=f,p=f+o,d=0;d<o;++d,++h,++p){var g=i[h];i[h]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":89}],89:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],90:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,f){var h=(r-e+1)/6|0,p=e+h,d=r-h,g=e+r>>1,v=g-h,m=g+h,y=p,x=v,b=g,_=m,w=d,k=e+1,M=r-1,A=0;c(y,x,f)&&(A=y,y=x,x=A);c(_,w,f)&&(A=_,_=w,w=A);c(y,b,f)&&(A=y,y=b,b=A);c(x,b,f)&&(A=x,x=b,b=A);c(y,_,f)&&(A=y,y=_,_=A);c(b,_,f)&&(A=b,b=_,_=A);c(x,w,f)&&(A=x,x=w,w=A);c(x,b,f)&&(A=x,x=b,b=A);c(_,w,f)&&(A=_,_=w,w=A);var T=f[2*x];var S=f[2*x+1];var C=f[2*_];var E=f[2*_+1];var L=2*y;var z=2*b;var O=2*w;var I=2*p;var D=2*g;var P=2*d;for(var R=0;R<2;++R){var F=f[L+R],B=f[z+R],N=f[O+R];f[I+R]=F,f[D+R]=B,f[P+R]=N}o(v,e,f);o(m,r,f);for(var j=k;j<=M;++j)if(u(j,T,S,f))j!==k&&a(j,k,f),++k;else if(!u(j,C,E,f))for(;;){if(u(M,C,E,f)){u(M,T,S,f)?(s(j,k,M,f),++k,--M):(a(j,M,f),--M);break}if(--M<j)break}l(e,k-1,T,S,f);l(r,M+1,C,E,f);k-2-e<=n?i(e,k-2,f):t(e,k-2,f);r-(M+2)<=n?i(M+2,r,f):t(M+2,r,f);M-k<=n?i(k,M,f):t(k,M,f)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],91:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,f,h,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var M=f[k],A=b*k;p[x++]=i[A+_],p[x++]=-(M+1),p[x++]=i[A+w],p[x++]=M}for(var k=h;k<v;++k){var M=y[k]+o,T=b*k;p[x++]=m[T+_],p[x++]=-M,p[x++]=m[T+w],p[x++]=M}var S=x>>>1;a(p,S);for(var C=0,E=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,E--,L=L-o|0);else if(L>=0)d(s,l,C--,L);else if(L<=-o){L=-L-o|0;for(var z=0;z<C;++z){var O=e(s[z],L);if(void 0!==O)return O}g(c,u,E++,L)}else{L=-L-1|0;for(var z=0;z<E;++z){var O=e(L,c[z]);if(void 0!==O)return O}g(s,l,C++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,M=r;M<n;++M){var A=o[M]+1<<1,T=_*M;p[b++]=i[T+w],p[b++]=-A,p[b++]=i[T+k],p[b++]=A}for(var M=v;M<m;++M){var A=x[M]+1<<1,S=_*M;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var C=b>>>1;a(p,C);for(var E=0,L=0,z=0,M=0;M<C;++M){var O=0|p[2*M+1],I=1&O;if(M<C-1&&O>>1==p[2*M+3]>>1&&(I=2,M+=1),O<0){for(var D=-(O>>1)-1,P=0;P<z;++P){var R=e(f[P],D);if(void 0!==R)return R}if(0!==I)for(var P=0;P<E;++P){var R=e(s[P],D);if(void 0!==R)return R}if(1!==I)for(var P=0;P<L;++P){var R=e(c[P],D);if(void 0!==R)return R}0===I?g(s,l,E++,D):1===I?g(c,u,L++,D):2===I&&g(f,h,z++,D)}else{var D=(O>>1)-1;0===I?d(s,l,E--,D):1===I?d(c,u,L--,D):2===I&&d(f,h,z--,D)}}},scanBipartite:function(t,e,r,n,i,c,u,f,h,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,M=1;n?M=o:k=o;for(var A=i;A<c;++A){var T=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-T,p[x++]=u[S+w],p[x++]=T}for(var A=h;A<v;++A){var T=A+M,C=b*A;p[x++]=m[C+_],p[x++]=-T}var E=x>>>1;a(p,E);for(var L=0,A=0;A<E;++A){var z=0|p[2*A+1];if(z<0){var T=-z,O=!1;if(T>=o?(O=!n,T-=o):(O=!!n,T-=1),O)g(s,l,L++,T);else{var I=y[T],D=b*T,P=m[D+e+1],R=m[D+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<P)){for(var j=e+2;j<t;++j)if(m[D+j+t]<u[N+j]||u[N+j+t]<m[D+j])continue t;var V,U=f[B];if(void 0!==(V=n?r(I,U):r(U,I)))return V}}}}else d(s,l,L--,z-k)}},scanComplete:function(t,e,r,n,i,l,c,u,f,h,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<f;++x){var b=x+1,w=v*x;p[g++]=h[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var M=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[M++]=b-o;else{var T=d[b-=1],S=v*b,C=h[S+e+1],E=h[S+e+1+t];t:for(var L=0;L<M;++L){var z=s[L],O=c[z];if(O===T)break;var I=v*z;if(!(E<l[I+e+1]||l[I+e+1+t]<C)){for(var D=e+2;D<t;++D)if(h[S+D+t]<l[I+D]||l[I+D+t]<h[S+D])continue t;var P=r(O,T);if(void 0!==P)return P}}}}else{for(var b=A-o,L=M-1;L>=0;--L)if(s[L]===b){for(var D=L+1;D<M;++D)s[D-1]=s[D];break}--M}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),f=n.mallocInt32(1024),h=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":90,\"bit-twiddle\":81,\"typedarray-pool\":523}],92:[function(t,e,r){},{}],93:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function f(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function h(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(h,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return f(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return f(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],94:[function(t,e,r){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=s,r.SlowBuffer=function(t){+t!=t&&(t=0);return s.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return e.__proto__=s.prototype,e}function s(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return u(t)}return l(t,e,r)}function l(t,e,r){if(\"string\"==typeof t)return function(t,e){\"string\"==typeof e&&\"\"!==e||(e=\"utf8\");if(!s.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|p(t,e),n=o(r),i=n.write(t,e);i!==r&&(n=n.slice(0,i));return n}(t,e);if(ArrayBuffer.isView(t))return f(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(j(t,ArrayBuffer)||t&&j(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r);return n.__proto__=s.prototype,n}(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return s.from(n,e,r);var i=function(t){if(s.isBuffer(t)){var e=0|h(t.length),r=o(e);return 0===r.length?r:(t.copy(r,0,0,e),r)}if(void 0!==t.length)return\"number\"!=typeof t.length||V(t.length)?o(0):f(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return f(t.data)}(t);if(i)return i;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return s.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function c(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function u(t){return c(t),o(t<0?0:0|h(t))}function f(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function p(t,e){if(s.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||j(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return F(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return B(t).length;default:if(i)return n?-1:F(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function d(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function g(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),V(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=s.from(e,n)),s.isBuffer(e))return 0===e.length?-1:v(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):v(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function v(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var f=!0,h=0;h<l;h++)if(c(t,a+h)!==c(e,h)){f=!1;break}if(f)return a}return-1}function m(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(V(s))return o;t[r+o]=s}return o}function y(t,e,r,n){return N(F(e,t.length-r),t,r,n)}function x(t,e,r,n){return N(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function b(t,e,r,n){return x(t,e,r,n)}function _(t,e,r,n){return N(B(e),t,r,n)}function w(t,e,r,n){return N(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function k(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function M(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=r)switch(f){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,f=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=f}return function(t){var e=t.length;if(e<=A)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=A));return r}(n)}r.kMaxLength=a,s.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),s.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(s.prototype,\"parent\",{enumerable:!0,get:function(){if(s.isBuffer(this))return this.buffer}}),Object.defineProperty(s.prototype,\"offset\",{enumerable:!0,get:function(){if(s.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&s[Symbol.species]===s&&Object.defineProperty(s,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),s.poolSize=8192,s.from=function(t,e,r){return l(t,e,r)},s.prototype.__proto__=Uint8Array.prototype,s.__proto__=Uint8Array,s.alloc=function(t,e,r){return function(t,e,r){return c(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},s.allocUnsafe=function(t){return u(t)},s.allocUnsafeSlow=function(t){return u(t)},s.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==s.prototype},s.compare=function(t,e){if(j(t,Uint8Array)&&(t=s.from(t,t.offset,t.byteLength)),j(e,Uint8Array)&&(e=s.from(e,e.offset,e.byteLength)),!s.isBuffer(t)||!s.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},s.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},s.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return s.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=s.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var a=t[r];if(j(a,Uint8Array)&&(a=s.from(a)),!s.isBuffer(a))throw new TypeError('\"list\" argument must be an Array of Buffers');a.copy(n,i),i+=a.length}return n},s.byteLength=p,s.prototype._isBuffer=!0,s.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)d(this,e,e+1);return this},s.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)d(this,e,e+3),d(this,e+1,e+2);return this},s.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)d(this,e,e+7),d(this,e+1,e+6),d(this,e+2,e+5),d(this,e+3,e+4);return this},s.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?M(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return C(this,e,r);case\"utf8\":case\"utf-8\":return M(this,e,r);case\"ascii\":return T(this,e,r);case\"latin1\":case\"binary\":return S(this,e,r);case\"base64\":return k(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},s.prototype.toLocaleString=s.prototype.toString,s.prototype.equals=function(t){if(!s.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===s.compare(this,t)},s.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},s.prototype.compare=function(t,e,r,n,i){if(j(t,Uint8Array)&&(t=s.from(t,t.offset,t.byteLength)),!s.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var a=(i>>>=0)-(n>>>=0),o=(r>>>=0)-(e>>>=0),l=Math.min(a,o),c=this.slice(n,i),u=t.slice(e,r),f=0;f<l;++f)if(c[f]!==u[f]){a=c[f],o=u[f];break}return a<o?-1:o<a?1:0},s.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},s.prototype.indexOf=function(t,e,r){return g(this,t,e,r,!0)},s.prototype.lastIndexOf=function(t,e,r){return g(this,t,e,r,!1)},s.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return m(this,t,e,r);case\"utf8\":case\"utf-8\":return y(this,t,e,r);case\"ascii\":return x(this,t,e,r);case\"latin1\":case\"binary\":return b(this,t,e,r);case\"base64\":return _(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return w(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},s.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var A=4096;function T(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function S(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function C(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=R(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function L(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function z(t,e,r,n,i,a){if(!s.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<a)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function I(t,e,r,n,a){return e=+e,r>>>=0,a||O(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function D(t,e,r,n,a){return e=+e,r>>>=0,a||O(t,0,r,8),i.write(t,e,r,n,52,8),r+8}s.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return n.__proto__=s.prototype,n},s.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||L(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},s.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||L(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},s.prototype.readUInt8=function(t,e){return t>>>=0,e||L(t,1,this.length),this[t]},s.prototype.readUInt16LE=function(t,e){return t>>>=0,e||L(t,2,this.length),this[t]|this[t+1]<<8},s.prototype.readUInt16BE=function(t,e){return t>>>=0,e||L(t,2,this.length),this[t]<<8|this[t+1]},s.prototype.readUInt32LE=function(t,e){return t>>>=0,e||L(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},s.prototype.readUInt32BE=function(t,e){return t>>>=0,e||L(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},s.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||L(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},s.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||L(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},s.prototype.readInt8=function(t,e){return t>>>=0,e||L(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},s.prototype.readInt16LE=function(t,e){t>>>=0,e||L(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},s.prototype.readInt16BE=function(t,e){t>>>=0,e||L(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},s.prototype.readInt32LE=function(t,e){return t>>>=0,e||L(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},s.prototype.readInt32BE=function(t,e){return t>>>=0,e||L(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},s.prototype.readFloatLE=function(t,e){return t>>>=0,e||L(t,4,this.length),i.read(this,t,!0,23,4)},s.prototype.readFloatBE=function(t,e){return t>>>=0,e||L(t,4,this.length),i.read(this,t,!1,23,4)},s.prototype.readDoubleLE=function(t,e){return t>>>=0,e||L(t,8,this.length),i.read(this,t,!0,52,8)},s.prototype.readDoubleBE=function(t,e){return t>>>=0,e||L(t,8,this.length),i.read(this,t,!1,52,8)},s.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||z(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},s.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||z(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},s.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,1,255,0),this[e]=255&t,e+1},s.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},s.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},s.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},s.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},s.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);z(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},s.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);z(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},s.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},s.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},s.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},s.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},s.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||z(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},s.prototype.writeFloatLE=function(t,e,r){return I(this,t,e,!0,r)},s.prototype.writeFloatBE=function(t,e,r){return I(this,t,e,!1,r)},s.prototype.writeDoubleLE=function(t,e,r){return D(this,t,e,!0,r)},s.prototype.writeDoubleBE=function(t,e,r){return D(this,t,e,!1,r)},s.prototype.copy=function(t,e,r,n){if(!s.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var a=i-1;a>=0;--a)t[a+e]=this[a+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return i},s.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!s.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var a;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(a=e;a<r;++a)this[a]=t;else{var o=s.isBuffer(t)?t:s.from(t,n),l=o.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(a=0;a<r-e;++a)this[a+e]=o[a%l]}return this};var P=/[^+\\/0-9A-Za-z-_]/g;function R(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function F(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function B(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(P,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function N(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function j(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function V(t){return t!=t}},{\"base64-js\":63,ieee754:398}],95:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),f=!!c(r,\"interior\",!0),h=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!f&&!h||0===t.length)return[];var d=n(t,e);if(u||f!==h||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),h?f?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":96,\"./lib/filter\":97,\"./lib/monotone\":98,\"./lib/triangulation\":99}],96:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var f=l[c-1],h=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){h=l[p];break}h<0||n(t[s],t[u],t[f],t[h])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),f=-1,h=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?h=v:v===u&&(f=g)}f<0||h<0||(n(t[s],t[u],t[f],t[h])>=0||(e.flip(s,u),i(t,e,r,f,s,h),i(t,e,r,s,h,f),i(t,e,r,h,u,f),i(t,e,r,u,f,h)))}}},{\"binary-search-bounds\":100,\"robust-in-sphere\":486}],97:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var f=new Array(n),i=0;i<f.length;++i)f[i]=0;var h=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,f,h,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(h.push(i),f[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,f=n.constraint,h=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=h[3*p+d];g>=0&&0===c[g]&&(f[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":100}],98:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function f(t,e){return i(t.a,t.b,e)}function h(t,e,r,a,o){for(var s=n.lt(e,a,f),l=n.gt(e,a,f),c=s;c<l;++c){for(var u=e[c],h=u.lowerIds,p=h.length;p>1&&i(r[h[p-2]],r[h[p-1]],a)>0;)t.push([h[p-1],h[p-2],o]),p-=1;h.length=p,h.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],f=0;f<r;++f)i.push(new c(t[f],null,a,f));for(var f=0;f<n;++f){var p=e[f],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,f),new c(m,v,o,f)):v[0]>m[0]&&i.push(new c(m,v,s,f),new c(v,m,o,f))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],f=0,_=i.length;f<_;++f){var w=i[f],k=w.type;k===a?h(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":100,\"robust-orientation\":488}],99:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":100}],100:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],102:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,f=c[e+1];for(s=0;s<f.length;++s)u+=f[s];var h=new Array(e);for(s=0;s<e;++s){f=c[s];var p=0;for(l=0;l<f.length;++l)p+=f[l];h[s]=p/u}return h}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:156,\"robust-linear-solve\":487}],103:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:102}],104:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],105:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),f=t(\"./lib/rat-seg-intersect\");function h(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],f=h(c[0]),p=h(c[1]);s.push([u(f[0],-1/0),u(p[0],-1/0),u(f[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),h=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],f=t[s[1]];a(l,c,u,f)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,h=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=f(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),h.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=h[t[1]],n=h[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var M=b;b=_,_=M}x[0]=b;var A,T=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,C=(S=n[--a])[1];i?e.push([T,C,A]):e.push([T,C]),T=C}i?e.push([T,_,A]):e.push([T,_])}return h}(t,e,h,v,r));return m(e,y,r),!!y||(h.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":106,\"big-rat\":67,\"big-rat/cmp\":65,\"big-rat/to-float\":79,\"box-intersect\":85,nextafter:437,\"rat-vec\":472,\"robust-segment-intersect\":491,\"union-find\":524}],106:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),f=s(n,r),h=u(a,f);if(0===o(h))return null;var p=s(t,r),d=u(f,p),g=i(d,h),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":66,\"big-rat/mul\":76,\"big-rat/sign\":77,\"big-rat/sub\":78,\"rat-vec/add\":471,\"rat-vec/muls\":473,\"rat-vec/sub\":474}],107:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:104}],108:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],109:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:104,\"color-rgba\":111,dtype:155}],110:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),f=u.length,h=f<=4;c=1,h?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===f&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===f&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],u=p.replace(/a$/,\"\");s=u;var f=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===f?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=void 0===l[f]?1:l[f],l=l.slice(0,f)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var d=a(t.r,t.red,t.R,null);null!==d?(s=\"rgb\",l=[d,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":108,defined:150,\"is-plain-obj\":408}],111:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:104,\"color-parse\":110,\"color-space/hsl\":112}],112:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":113}],113:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],114:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],115:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,f,h,p,d,g;t||(t={});p=(t.nshades||72)-1,h=t.format||\"hex\",(f=t.colormap)||(f=\"jet\");if(\"string\"==typeof f){if(f=f.toLowerCase(),!n[f])throw Error(f+\" not a supported colorscale\");u=n[f]}else{if(!Array.isArray(f))throw Error(\"unsupported colormap option\",f);u=f.slice()}if(u.length>p)throw new Error(f+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===h?m=m.map(o):\"rgbaString\"===h?m=m.map(s):\"float\"===h&&(m=m.map(a));return m}},{\"./colorScale\":114,lerp:411}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),f=l(t,e,a);return u===f?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);if(h>0)return o>0&&n(t,e,a)>0?1:-1;if(h<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":488,\"robust-product\":489,\"robust-sum\":493,signum:494,\"two-sum\":522}],117:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],f=t[1],h=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+f+h+p-(d+g+v+m)||n(u,f,h,p)-n(d,g,v,m,d)||n(u+f,u+h,u+p,f+h,f+p,h+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+f+h,u+f+p,u+h+p,f+h+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],118:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":101,\"compare-cell\":117}],119:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":120,\"./lib/ch2d\":121,\"./lib/chnd\":122}],120:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],121:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":420}],122:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":51,\"incremental-convex-hull\":399}],123:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],124:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],125:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],126:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],127:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],128:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":130,\"./stringify\":131}],129:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":124}],130:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=h;var f=h.cache={};function h(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(f[t])return f[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return f[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},h=c(t,/\\s+/);e=h.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),f[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===h[0]&&(h.shift(),r.lineHeight=p(h.shift())),!h.length)throw new Error(\"Missing required font-family.\");return r.family=c(h.join(\" \"),/\\s*,\\s*/).map(n),f[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":129,\"css-font-stretch-keywords\":125,\"css-font-style-keywords\":126,\"css-font-weight-keywords\":127,\"css-global-keywords\":132,\"css-system-font-keywords\":133,\"string-split-by\":507,unquote:526}],131:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},f={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},h=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=h),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return f[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":129,\"css-font-stretch-keywords\":125,\"css-font-style-keywords\":126,\"css-font-weight-keywords\":127,\"css-global-keywords\":132,\"css-system-font-keywords\":133,\"pick-by-alias\":451}],132:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],133:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],134:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,f=s*(3-2*i),h=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+f*r[p]+h*n[p];return a}return c*t+u*e+f*r+h*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],135:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":137}],136:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,f=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)f=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",f,\"*t\",i,\"p\",f,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(f=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",f,\"]-=s\",f].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var f=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[f].array,c=\"+q\"+f;case\"array\":c=\"p\"+u+c;var h=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):(i.push([\"var \",h,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\"[\",c,\"]=\",h].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],f=[],h=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(f.push(0),h.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(f.push(t.arrayBlockIndices[l]),h.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)f[l]<=o[l][g]&&o[l][g]<h[l]&&d.push(o[l][g]-f[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",f[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);M<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var f=[\"offset\"+u],h=t;h<a;++h)f.push([\"j\",h,\"*t\",u,\"p\",e[h]].join(\"\"));c.push([\"p\",u,\"=(\",f.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(M,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",M,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:525}],137:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var f=t.arrayArgs[u];r.push([\"t\",f,\"=array\",f,\".dtype,\",\"r\",f,\"=array\",f,\".order\"].join(\"\")),a.push(\"t\"+f),a.push(\"r\"+f),o.push(\"t\"+f),o.push(\"r\"+f+\".join()\"),s.push(\"array\"+f+\".data\"),s.push(\"array\"+f+\".stride\"),s.push(\"array\"+f+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+f+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+f+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":136}],138:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":135}],139:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,f=Object.defineProperty,h=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&h.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),f(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":175,\"es5-ext/object/map\":184,\"es5-ext/object/normalize-options\":185,\"es5-ext/object/valid-callable\":189,\"es5-ext/object/valid-value\":191}],140:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":172,\"es5-ext/object/is-callable\":178,\"es5-ext/object/normalize-options\":185,\"es5-ext/string/#/contains\":192}],141:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var f=Array.prototype,h=f.slice,p=f.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function M(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=M(t,T),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function T(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],f=c[1],h=r(l,u,f);Array.isArray(h)||(h=_(u,f,h),h=v(Math.ceil(u/h)*h,f,h));for(var p=h.length;h[0]<=u;)h.shift(),--p;for(;h[p-1]>f;)h.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?h[a-1]:u,d.x1=a<p?h[a]:f;for(a=0;a<s;++a)u<=(o=l[a])&&o<=f&&g[i(h,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(h.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=M,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],142:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,f,h=-1,p=n.length,d=l[i++],g=r(),v=a();++h<p;)(f=g.get(s=d(c=n[h])+\"\"))?f.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],143:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=f.exec(t))?y(e[1],e[2],e[3],e[4]):(e=h.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function M(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function T(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,M,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(T(t>=240?t-240:t+120,i,n),T(t,i,n),T(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,C=180/Math.PI,E=.96422,L=1,z=.82521,O=4/29,I=6/29,D=3*I*I,P=I*I*I;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=U(t.r),a=U(t.g),o=U(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/E),n=N((.0139322*i+.0971045*a+.7141733*o)/z)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>P?Math.pow(t,1/3):t/D+O}function j(t){return t>I?t*t*t:D*(t-O)}function V(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*C;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(V(3.1338561*(e=E*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=z*j(r))),V(-.9787684*e+1.9161415*t+.033454*r),V(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var W=-.14861,Y=1.78277,X=-.29227,Z=-.90649,$=1.97294,J=$*Z,K=$*Y,Q=Y*X-Z*W;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+J*e-K*r)/(Q+J-K),a=n-i,o=($*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/($*i*(1-i)),l=s?Math.atan2(o,a)*C-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(W*n+Y*i)),255*(e+r*(X*n+Z*i)),255*(e+r*($*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=M,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],144:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],145:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function f(t){return t.x}function h(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,h,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(f),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,h=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>h+c||n<h-c||r>p+c||a<p-c;if(s.index>u.index){var f=h-s.x-s.vx,v=p-s.y-s.vy,m=f*f+v*v;m<c*c&&(0===f&&(m+=(f=o())*f),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(f*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=f*(c=1-c),s.vy-=v*c)}}}function f(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function h(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,h()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),h(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,f=c,h=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,f,h,p,g,v=0;v<a;++v)c=(s=t[v]).source,f=(u=s.target).x+u.vx-c.x-c.vx||o(),h=u.y+u.vy-c.y-c.vy||o(),f*=p=((p=Math.sqrt(f*f+h*h))-n[v])/p*r*e[v],h*=p,u.vx-=f*(g=l[v]),u.vy-=h*g,c.vx+=f*(g=1-g),c.vy+=h*g}function v(){if(i){var a,o,c=i.length,h=t.length,p=r.map(i,f);for(a=0,s=new Array(c);a<h;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(h);a<h;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(h),m(),n=new Array(h),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+h(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(f=t,g):f},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(h=\"function\"==typeof t?t:a(+t),m(),g):h},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,f,h).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var f=t.x-r.x,h=t.y-r.y,p=s-e,d=f*f+h*h;if(p*p/u<d)return d<c&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)),r.vx+=f*t.value*n/d,r.vy+=h*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=f*p,r.vy+=h*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,f=Math.sqrt(c*c+u*u),h=(o[a]-f)*i[a]*t/f;l.vx+=c*h,l.vy+=u*h}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),f=i.timer(g),h=n.dispatch(\"tick\",\"end\");function g(){v(),h.call(\"tick\",e),a<o&&(f.stop(),h.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return f.restart(g),e},stop:function(){return f.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(h.on(t,r),e):h.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":142,\"d3-dispatch\":144,\"d3-quadtree\":147,\"d3-timer\":148}],146:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function f(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var h=f(n),p=f(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,M,A,T=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function C(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*T,skewX:Math.atan(l)*T,scaleX:o,scaleY:s}}function E(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=E(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,M=document.defaultView),w.style.transform=t,t=M.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),C(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),z=E(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?C((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,I=2,D=4,P=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var V=j(s),U=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<P)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*f,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+D*h)/(2*o*I*p),g=(c*c-o*o-D*h)/(2*c*I*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(I*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*f,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=h,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=V,t.interpolateHclLong=U,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":143}],147:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,f,h,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[f=u<<1|c]))return i[f]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[f]=d:t._root=d,t;do{i=i?i[f]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((f=u<<1|c)==(h=(l>=o)<<1|s>=a));return i[h]=p,i[f]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,f=-1/0,h=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>f&&(f=i),a<u&&(u=a),a>h&&(h=a));for(f<c&&(c=this._x0,f=this._x1),h<u&&(u=this._y0,h=this._y1),this.cover(c,u).cover(f,h),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,f=this._x0,h=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,f,h,p,d)),null==n?n=1/0:(f=t-n,h=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<f||(l=c.y1)<h))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);f=t-w,h=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,f,h,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[f=u<<1|c]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(r=e,h=f)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[f]=i:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[h]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,f=(a+s)/2;(n=c[3])&&l.push(new r(n,u,f,o,s)),(n=c[2])&&l.push(new r(n,i,f,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,f)),(n=c[0])&&l.push(new r(n,i,a,u,f))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,f=(s+c)/2,h=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,f,h)),(o=a[1])&&n.push(new r(o,f,l,c,h)),(o=a[2])&&n.push(new r(o,s,h,f,u)),(o=a[3])&&n.push(new r(o,f,h,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],148:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,f=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function h(){return l||(f(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){h(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,f(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?h():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=h,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?h():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],149:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,f=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){f.call(this,t,e+\"\",r)}}function h(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=h,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(h),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(h);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return h(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function M(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function T(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(M(e));return t}function C(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function z(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function I(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=D.length;r<n;++r){var i=D[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:T,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:M(e),value:this._[e]});return t},size:C,empty:E,forEach:function(t){for(var e in this._)t.call(this,M(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,f,h=-1,p=a.length,d=i[s++],g=new b;++h<p;)(f=g.get(l=d(c=a[h])))?f.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:T,values:S,size:C,empty:E,forEach:function(t){for(var e in this._)t.call(this,M(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var D=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function P(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(V,\"\\\\$&\")};var V=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return U(t,Y),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},W=function(t,e){var r=t.matches||t[I(t,\"matchesSelector\")];return(W=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,W=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var Y=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}Y.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},Y.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var $=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:$,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===$&&t.documentElement.namespaceURI===$?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return W(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ft(t){return U(t,ht),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},Y.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},Y.remove=function(){return this.each(st)},Y.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,f=Math.min(o,u),h=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(h[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<f;)i=t[n],a=r[n],i?(i.__data__=a,h[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=h,p.parentNode=h.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(h),c.push(d)}var s=ft([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Y.sort=function(t){t=function(t){arguments.length||(t=h);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},Y.size=function(){var t=0;return ut(this,function(){++t}),t};var ht=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?P:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ft,t.selection.enter.prototype=ht,ht.append=Y.append,ht.empty=Y.empty,ht.node=Y.node,ht.call=Y.call,ht.size=Y.size,ht.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ht.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&I(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(P,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,z,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,f=e.of(this,arguments),h=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],h|=t|e,m=r,f({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(h),f({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],f({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Mt=kt*kt,At=Math.PI,Tt=2*At,St=Tt-kt,Ct=At/2,Et=At/180,Lt=180/At;function zt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function It(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Ct:t<-1?-Ct:Math.asin(t)}function Pt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<Mt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*f,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Pt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*f,o*s/Pt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,f,h={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,z).on(Nt+\".zoom\",I).on(\"dblclick.zoom\",D).on(b,O)}function k(t){return[(t[0]-h.x)/h.k,(t[1]-h.y)/h.k]}function M(t){h.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*h.k+h.x,t[1]*h.k+h.y]}(e),h.x+=t[0]-e[0],h.y+=t[1]-e[1]}function T(e,n,i,a){e.__chart__={x:h.x,y:h.y,k:h.k},M(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-h.x)/h.k}).map(l.invert)),f&&f.domain(u.range().map(function(t){return(t-h.y)/h.k}).map(u.invert))}function C(t){v++||t({type:\"zoomstart\"})}function E(t){S(),t({type:\"zoom\",scale:h.k,translate:[h.x,h.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function z(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),E(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);fs.call(e),C(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],f=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=h.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,f=n.length;o<f;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];T(r,m,i[m.identifier],Math.floor(Math.log(h.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,f=t.touches(r);fs.call(r);for(var h=0,p=f.length;h<p;++h,u=null)if(c=f[h],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],M(g*e)}s=null,A(o,l),E(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),f.on(m,z).on(b,O),p(),L(n)}g(),C(n),f.on(m,null).on(b,g)}function I(){var i=_.of(this,arguments);a?clearTimeout(a):(fs.call(this),e=k(r=n||t.mouse(this)),C(i)),a=setTimeout(function(){a=null,L(i)},50),B(),M(Math.pow(2,.002*Bt())*h.k),A(r,e),E(i)}function D(){var e=t.mouse(this),r=Math.log(h.k)/Math.LN2;T(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=h;ds?t.select(this).transition().each(\"start.zoom\",function(){h=this.__chart__||{x:0,y:0,k:1},C(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-h.x)/h.k,(s-h.y)/h.k,i/h.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=h={x:o-r[0]*n,y:s-r[1]*n,k:n},E(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=h,C(e),E(e),L(e))})},w.translate=function(t){return arguments.length?(h={x:+t[0],y:+t[1],k:h.k},S(),w):[h.x,h.y]},w.scale=function(t){return arguments.length?(h={x:h.x,y:h.y,k:null},M(+t),S(),w):h.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),h={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(f=t,u=t.copy(),h={x:0,y:0,k:1},w):f},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Vt(){}function Ut(t,e,r){return this instanceof Ut?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Ut?new Ut(t.h,t.s,t.l):ue(\"\"+t,fe,Ut):new Ut(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Ut;var qt=Ut.prototype=new Vt;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=he((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Ut(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Ut(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Wt=Gt.prototype=new Vt;function Yt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Et)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Yt(t.h,t.c,t.l):he((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Wt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Wt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Wt.rgb=function(){return Yt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,$t=.95047,Jt=1,Kt=1.08883,Qt=Xt.prototype=new Vt;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*$t)-1.5371385*(n=re(n)*Jt)-.4985314*(a=re(a)*Kt)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Vt;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function fe(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Ut(n,i,l)}function he(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/$t),i=ne((.2126729*t+.7151522*e+.072175*r)/Jt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/Kt)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return fe(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function f(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=f:c.onreadystatechange=function(){c.readyState>3&&f()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(z),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function f(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=f())!==o;){for(var h=[];r!==a&&r!==o;)h.push(r),r=f();e&&null==(h=e(h,u++))||s.push(h)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[I(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Me(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Te(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Te(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ce(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Me.apply(this,arguments)},t.timer.flush=function(){Te(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ee=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ce(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ee[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,ze=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ce(e,r))).toFixed(Math.max(0,Math.min(20,Ce(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var Ie=t.time={},De=Date;function Pe(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Pe.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new De(r-1)),1),r}function a(t,r){return e(t=new De(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{De=Pe;var n=new Pe;return n._=t,o(n,e,r)}finally{De=Date}},t}function Be(t){return function(e,r){try{De=Pe;var n=new Pe;return n._=e,t(n,r)._}finally{De=Date}}}Ie.year=Fe(function(t){return(t=Ie.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),Ie.years=Ie.year.range,Ie.years.utc=Ie.year.utc.range,Ie.day=Fe(function(t){var e=new De(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),Ie.days=Ie.day.range,Ie.days.utc=Ie.day.utc.range,Ie.dayOfYear=function(t){var e=Ie.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=Ie[t]=Fe(function(t){return(t=Ie.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});Ie[t+\"s\"]=r.range,Ie[t+\"s\"].utc=r.utc.range,Ie[t+\"OfYear\"]=function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)}}),Ie.week=Ie.sunday,Ie.weeks=Ie.sunday.range,Ie.weeks.utc=Ie.sunday.utc.range,Ie.weekOfYear=Ie.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ve=/^%/;function Ue(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function $e(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Je(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ue(n,\"0\",2)+Ue(i,\"0\",2)}function ar(t,e,r){Ve.lastIndex=0;var n=Ve.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:z;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],f=+n[6],h=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":h=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=ze.get(d)||Oe;var b=u&&h;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var M=x?e.lastIndexOf(\"e\"):-1;M<0?(_=e,w=\"\"):(_=e.substring(0,M),w=e.substring(M))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&h&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),T=A<f?new Array(A=f-A+1).join(i):\"\";return b&&(_=o(T+_,T.length?f-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+T:\">\"===s?T+a+e:\"^\"===s?T.substring(0,A>>=1)+a+e+T.substring(A):a+(b?e:T+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(f(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&De!==Pe,i=new(n?Pe:De);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function f(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(De=Pe);return r._=t,e(r)}finally{De=Date}}return r.parse=function(t){try{De=Pe;var r=e.parse(t);return r&&r._}finally{De=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var h=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){h.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ue(t.getDate(),e,2)},e:function(t,e){return Ue(t.getDate(),e,2)},H:function(t,e){return Ue(t.getHours(),e,2)},I:function(t,e){return Ue(t.getHours()%12||12,e,2)},j:function(t,e){return Ue(1+Ie.dayOfYear(t),e,3)},L:function(t,e){return Ue(t.getMilliseconds(),e,3)},m:function(t,e){return Ue(t.getMonth()+1,e,2)},M:function(t,e){return Ue(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ue(t.getSeconds(),e,2)},U:function(t,e){return Ue(Ie.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ue(Ie.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ue(t.getFullYear()%100,e,2)},Y:function(t,e){return Ue(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return f(t,_.c.toString(),e,r)},d:Ke,e:Ke,H:tr,I:tr,j:Qe,L:nr,m:Je,M:er,p:function(t,e,r){var n=h.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:We,w:Ge,W:Ye,x:function(t,e,r){return f(t,_.x.toString(),e,r)},X:function(t,e,r){return f(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:$e,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function fr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&hr.hasOwnProperty(t.type)?hr[t.type](t,e):fr(t,e)};var hr={Feature:function(t,e){fr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)fr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)fr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Er),vr};var vr,mr,yr,xr,br,_r,wr,kr,Mr,Ar,Tr,Sr,Cr=new lr,Er={sphere:function(){vr+=4*At},point:P,lineStart:P,lineEnd:P,polygonStart:function(){Cr.reset(),Er.lineStart=Lr},polygonEnd:function(){var t=2*Cr;vr+=t<0?4*At+t:t,Er.lineStart=Er.lineEnd=Er.point=P}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Et/2+At/4;var a=(t*=Et)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,f=n*l+u*Math.cos(s),h=u*o*Math.sin(s);Cr.add(Math.atan2(h,f)),r=t,n=l,i=c}Er.point=function(o,s){Er.point=a,r=(t=o)*Et,n=Math.cos(s=(e=s)*Et/2+At/4),i=Math.sin(s)},Er.lineEnd=function(){a(t,e)}}function zr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function Ir(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Dr(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Pr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,f,h={point:p,lineStart:g,lineEnd:v,polygonStart:function(){h.point=m,h.lineStart=x,h.lineEnd=b,c=0,Er.polygonStart()},polygonEnd:function(){Er.polygonEnd(),h.point=p,h.lineStart=g,h.lineEnd=v,Cr<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),f[0]=e,f[1]=n}};function p(t,a){u.push(f=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=zr([t*Et,o*Et]);if(l){var c=Ir(l,s),u=Ir([c[1],-c[0],0],c);Rr(u),u=Fr(u);var f=t-a,h=f>0?1:-1,d=u[0]*Lt*h,g=y(f)>180;if(g^(h*a<d&&d<h*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(h*a<(d=(d+360)%360-180)&&d<h*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){h.point=d}function v(){f[0]=e,f[1]=n,h.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Er.point(t,e),d(t,e)}function x(){Er.lineStart()}function b(){m(o,s),Er.lineEnd(),y(c)>kt&&(e=-(n=180)),f[0]=e,f[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,h),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=f=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Mr=Ar=Tr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Tr,i=Sr,a=r*r+n*n+i*i;return a<Mt&&(r=wr,n=kr,i=Mr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,Dt(i/Math.sqrt(a))*Lt]};var Nr={sphere:P,point:jr,lineStart:Ur,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Ur}};function jr(t,e){t*=Et;var r=Math.cos(e*=Et);Vr(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Vr(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Ur(){var t,e,r;function n(n,i){n*=Et;var a=Math.cos(i*=Et),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Mr+=c*(r+(r=l)),Vr(t,e,r)}Nr.point=function(i,a){i*=Et;var o=Math.cos(a*=Et);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Vr(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Et;var a=Math.cos(e*=Et),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,f=r*s-n*o,h=Math.sqrt(c*c+u*u+f*f),p=r*o+n*s+i*l,d=h&&-It(p)/h,g=Math.atan2(h,p);Ar+=d*c,Tr+=d*u,Sr+=d*f,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Mr+=g*(i+(i=l)),Vr(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Et;var l=Math.cos(s*=Et);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Vr(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Wr(){return!0}function Yr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,f,h=a[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((f=u[s])[0],f[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((f=u[s])[0],f[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function $r(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:f,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=f,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Cr.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var f=c[0],h=f[0],p=f[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-h,w=_>=0?1:-1,k=w*_,M=k>At,A=d*x;if(Cr.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=M?_+w*Tt:_,M^h>=r^m>=r){var T=Ir(zr(f),zr(t));Rr(T);var S=Ir(i,T);Rr(S);var C=(M^_>=0?-1:1)*Dt(S[2]);(n>C||n===C&&(T[0]||T[1]))&&(o+=M^_>=0?1:-1)}if(!v++)break;h=m,d=x,g=b,f=t}}return(a<-kt||a<kt&&Cr<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Yr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function f(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function h(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=h,l.lineStart()}function d(){u.point=f,l.lineEnd()}var g,v,m=Kr(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Jr))}return u}}function Jr(t){return t.length>1}function Kr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:P,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Ct-kt:Ct-t[1])-((e=e.x)[0]<0?e[1]-Ct-kt:Ct-e[1])}var tn=$r(Wr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Ct:-Ct),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Ct,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,f=1,h=s.x-l,p=s.y-c;if(a=t-l,h||!(a>0)){if(a/=h,h<0){if(a<u)return;a<f&&(f=a)}else if(h>0){if(a>f)return;a>u&&(u=a)}if(a=r-l,h||!(a<0)){if(a/=h,h<0){if(a>f)return;a>u&&(u=a)}else if(h>0){if(a<u)return;a<f&&(f=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<f&&(f=a)}else if(p>0){if(a>f)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>f)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<f&&(f=a)}return u>0&&(i.a={x:l+u*h,y:c+u*p}),f<1&&(i.b={x:l+f*h,y:c+f*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,f,h,p,d,g,v,m,y,x,b=l,_=Kr(),w=en(e,r,n,i),k={point:T,lineStart:function(){k.point=S,u&&u.push(f=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(h,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=T,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),M(null,null,1,l),l.lineEnd()),a&&Yr(c,o,r,M,l),l.polygonEnd()),c=u=f=null}};function M(t,o,l,c){var u=0,f=0;if(null==t||(u=a(t,l))!==(f=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==f);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function T(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&f.push([t,e]),y)h=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=En(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,Dt((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],f=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,f-.238*e],[u+.455*e,f+.238*e]]).stream(l).point,n=o.translate([u-.307*e,f+.201*e]).clipExtent([[u-.425*e+kt,f+.12*e+kt],[u-.214*e-kt,f+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,f+.212*e]).clipExtent([[u-.214*e+kt,f+.166*e+kt],[u-.115*e-kt,f+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,fn,hn,pn={point:P,lineStart:P,lineEnd:P,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=P,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>fn&&(fn=t);e<un&&(un=e);e>hn&&(hn=e)},lineStart:P,lineEnd:P,polygonStart:P,polygonEnd:P};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Mr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Mr+=o,Ar+=(o=n*t-r*e)*(r+t),Tr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Mn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:P};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Tt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Et),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,f,h,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){f=NaN,v.point=x,e.lineStart()}function x(r,i){var o=zr([r,i]),s=t(r,i);a(f,h,u,p,d,g,f=s[0],h=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(f,h)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=f,o=h,s=p,l=d,c=g,v.point=x}function k(){a(f,h,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,f,h,p,d,g,v,m){var x=u-n,b=f-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,M=c+g,A=Math.sqrt(w*w+k*k+M*M),T=Math.asin(M/=A),S=y(y(M)-1)<kt||y(o-h)<kt?(o+h)/2:Math.atan2(k,w),C=t(S,T),E=C[0],L=C[1],z=E-n,O=L-i,I=b*z-x*O;(I*I/_>e||y((x*z+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,E,L,S,w/=A,k/=A,M,v,m),m.point(E,L),a(E,L,S,w,k,M,u,f,h,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Tn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return En(function(){return t})()}function En(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,f=250,h=0,p=0,d=0,g=0,v=0,m=tn,x=z,b=null,_=null;function w(t){return[(t=i(t[0]*Et,t[1]*Et))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function M(){i=Gr(n=In(d,g,v),r);var t=r(h,p);return a=u-t[0]*c,o=f+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return $r(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(f,h){var p,d=[f,h],g=i(f,h),v=r?g?0:o(f,h):g?o(f+(f<0?At:-At),h):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Et),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=Ir(zr(t),zr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,f=Ir(i,a),h=Pr(i,c);Dr(h,Pr(a,u));var p=f,d=Or(h,p),g=Or(p,p),v=d*d-g*(Or(h,h)-1);if(!(v<0)){var m=Math.sqrt(v),x=Pr(p,(-d-m)/g);if(Dr(x,h),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],M=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,T=y(A-At)<kt;if(!T&&M<k&&(b=k,k=M,M=b),T||A<kt?T?k+M>0^x[1]<(y(x[0]-_)<kt?k:M):k<=x[1]&&x[1]<=M:A>At^(_<=x[0]&&x[0]<=w)){var S=Pr(p,(-d+m)/g);return Dr(S,h),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Et),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):z,A()):_},w.scale=function(t){return arguments.length?(c=+t,M()):c},w.translate=function(t){return arguments.length?(u=+t[0],f=+t[1],M()):[u,f]},w.center=function(t){return arguments.length?(h=t[0]%360*Et,p=t[1]%360*Et,M()):[h*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Et,g=t[1]%360*Et,v=t.length>2?t[2]%360*Et:0,M()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,M()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Et,r*Et)})}function zn(t,e){return[t,e]}function On(t,e){return[t>At?t-Tt:t<-At?t+Tt:t,e]}function In(t,e,r){return t?e||r?Gr(Pn(t),Rn(e,r)):Pn(t):e||r?Rn(e,r):On}function Dn(t){return function(e,r){return[(e+=t)>At?e-Tt:e<-At?e+Tt:e,r]}}function Pn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),Dt(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),Dt(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Tt)):(i=t+o*Tt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=zr(e);r[0]-=t,Rr(r);var n=It(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Vn(t){return t.source}function Un(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Mr=Ar=Tr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Tr/Sr]:Mr?[wr/Mr,kr/Mr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return fn=hn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[fn,hn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):z,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Mn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Tn(e);for(var n in t)r[n]=t[n];return r}}},Tn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=En,(t.geo.equirectangular=function(){return Cn(zn)}).raw=zn.invert=zn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Et,e[1]*Et))[0]*=Lt,e[1]*=Lt,e}return t=In(t[0]%360*Et,t[1]*Et,t.length>2?t[2]*Et:0),e.invert=function(e){return(e=t.invert(e[0]*Et,e[1]*Et))[0]*=Lt,e[1]*=Lt,e},e},On.invert=zn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=In(-t[0]*Et,-t[1]*Et,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Et,n*Et),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Et,(n=+r)*Et),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Et,i=t[1]*Et,a=e[1]*Et,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),f=Math.cos(a);return Math.atan2(Math.sqrt((r=f*o)*r+(r=c*u-l*f*s)*r),l*u+c*f*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,f,h,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(f).concat(t.range(Math.ceil(l/v)*v,s,v).map(h)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[f(i).concat(h(s).slice(1),f(n).reverse().slice(1),h(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),f=Nn(l,s,90),h=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,i=Un;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Et,n=t[1]*Et,i=e[0]*Et,a=e[1]*Et,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),f=o*Math.sin(r),h=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*h,i=r*f+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,f,h,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:P,point:P,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Et),o=Math.cos(i),s=y((n*=Et)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Et,e=Math.sin(a*=Et),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=P}},lineEnd:P,polygonStart:P,polygonEnd:P};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return Cn(Gn)}).raw=Gn;var Wn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},z);function Yn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return $n;function o(t,e){a>0?e<-Ct+kt&&(e=-Ct+kt):e>Ct-kt&&(e=Ct-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=zt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Ct]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return zn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-zt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return Cn(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Yn)}).raw=Yn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function $n(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Jn(t){var e,r=Cn(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Zn)}).raw=Zn,$n.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ct]},(t.geo.mercator=function(){return Jn($n)}).raw=$n;var Kn=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return Cn(Kn)}).raw=Kn;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ct]},(t.geo.transverseMercator=function(){var t=Jn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),f=u[0]===c[0],h=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+f;n<u.length-h;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,f=n[1]-c,h=(s*(l-c)-f*(i-a))/(f*o-s*u);return[i+h*o,l+h*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,fi,hi,pi,di=[],gi=[];function vi(){Di(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),fi.remove(t),di.push(t),Di(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,f=s.length;for(u=1;u<f;++u)c=s[u],l=s[u-1],zi(c.edge,l.site,c.site,i);l=s[0],(c=s[f-1]).edge=Li(l.site,c.site,null,i),Ti(l),Ti(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=fi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(fi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),fi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Ti(e),void Ti(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,f=c.y,h=t.x-u,p=t.y-f,d=r.site,g=d.x-u,v=d.y-f,m=2*(h*v-p*g),y=h*h+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(h*x-g*y)/m+f};zi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Ti(e),Ti(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,f=1/a-1/c,h=u/c;return f?(-h+Math.sqrt(h*h-2*f*(u*u/(-2*c)-l+c/2+i-a/2)))/f+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Mi(t,e){return e.angle-t.angle}function Ai(){Di(this),this.x=this.y=this.arc=this.site=this.cy=null}function Ti(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,f=2*(l*(v=a.y-s)-c*u);if(!(f>=-Mt)){var h=l*l+c*c,p=u*u+v*v,d=(v*h-c*p)/f,g=(l*p-u*h)/f,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(hi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(hi=e.N),pi.remove(e),gi.push(e),Di(e),t.circle=null)}function Ci(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,f=t.r,h=u.x,p=u.y,d=f.x,g=f.y,v=(h+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(h>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(h-d)/(g-p))*v,n<-1||n>1)if(h>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ei(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ei(t,e);return ci.push(i),r&&zi(i,t,e,r),n&&zi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function zi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function Ii(){this._=null}function Di(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Pi(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),fi=new Ii,pi=new Ii;;)if(i=hi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ci(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-f)<kt&&d-i>kt?{x:f,y:y(e-f)<kt?r:d}:y(i-d)<kt&&h-n>kt?{x:y(r-d)<kt?e:h,y:d}:y(n-h)<kt&&i-p>kt?{x:h,y:y(e-h)<kt?r:p}:y(i-p)<kt&&n-f>kt?{x:y(r-p)<kt?e:f,y:p}:null,_=void 0,_=new Ei(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return fi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Mi),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Ii.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Pi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Pi(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Pi(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Pi(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Pi(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Mi),u=-1,f=c.length,h=c[f-1].edge,p=h.l===l?h.r:h.l;++u<f;)h,i=p,p=(h=c[u].edge).l===l?h.r:h.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Vi(t){return t.x}function Ui(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Wi(t,e){var r,n,i,a=Yi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Yi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Vi,s=Ui,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,f,h,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],h=t.length,a)for(f=0;f<h;++f)(l=t[f]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(f=0;f<h;++f){var b=+m(l=t[f],f),_=+x(l,f);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function M(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,f=n>=c,h=f<<1|u;t.leaf=!1,u?i=l:o=l,f?a=c:s=c,M(t=t.nodes[h]||(t.nodes[h]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){M(T,t,+m(t,++f),+x(t,f),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var T={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){M(T,t,+m(t,++f),+x(t,f),p,d,g,v)}};if(T.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,T,p,d,g,v)},T.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,f,h,p){if(!(u>a||f>o||h<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+h),_=.5*(f+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,f,b,_);break;case 1:t(c,b,f,h,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,h,p)}}}(t,n,i,a,o),s}(T,t[0],t[1],p,d,g,v)},f=-1,null==e){for(;++f<h;)M(T,t[f],c[f],u[f],p,d,g,v);--f}else t.forEach(T.add);return c=u=t=l=null,T}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Wi;var Yi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Yi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function $i(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Wi:e instanceof Vt?qi:Array.isArray(e)?$i:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=$i;var Ji=function(){return z},Ki=t.map({linear:Ji,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Tt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Tt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:z,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Ct)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=ha(i),s=fa(i,a),l=ha(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function fa(t,e){return t[0]*e[0]+t[1]*e[1]}function ha(t){var e=Math.sqrt(fa(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=Ki.get(i)||Ji,a=Qi.get(a)||z,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Yt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,h,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Tt-c*i)/l,u=0,p=-1;++p<i;){for(h=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:h,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var M=g[p+\"-\"+d],A=g[d+\"-\"+p];(M.value||A.value)&&e.push(M.value<A.value?{source:A,target:M}:{source:M,target:A})}s&&f()}function f(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&f(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,f=Ma,h=Aa,p=-30,d=Ta,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,f,h,d,v,b,_,w,k=m.length,M=y.length;for(s=0;s<M;++s)h=(f=y[s]).source,(v=(_=(d=f.target).x-h.x)*_+(w=d.y-h.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=h.weight+d.weight?h.weight/(h.weight+d.weight):.5),d.y-=w*b,h.x+=_*(b=1-b),h.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(f=m[s]).x+=(_-f.x)*b,f.y+=(w-f.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(f=m[s]).fixed||r.visit(x(f));for(s=-1;++s<k;)(f=m[s]).fixed?(f.x=f.px,f.y=f.py):(f.x-=(f.px-(f.px=f.x))*u,f.y-=(f.py-(f.py=f.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Me(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(z).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ma=20,Aa=1,Ta=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Ia,e}function Ca(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ea(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function za(t){return t.value}function Oa(t,e){return e.value-t.value}function Ia(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=za;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ea(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ca(t,function(t){t.children&&(t.value=0)}),Ea(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Da,n=0,i=Tt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),f=+(\"function\"==typeof n?n.apply(this,arguments):n),h=(\"function\"==typeof i?i.apply(this,arguments):i)-f,p=Math.min(Math.abs(h)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(h<0?-1:1),g=t.sum(u),v=g?(h-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Da?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:f,endAngle:f+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Da={};function Pa(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=z,r=ja,n=Va,i=Fa,a=Pa,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),f=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),h=r.call(s,f,c);u=t.permute(u,h),f=t.permute(f,h);var p,d,g,v,m=n.call(s,f,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],f[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=f[d-1][g][1],f[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Va,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Ua),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],f=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],f.push(n));return f.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,f=t[0],h=f.length,p=[];for(p[0]=l=c=0,r=1;r<h;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=f[r][0]-f[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<h;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Va});function ja(e){return t.range(e.length)}function Va(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Ua(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Wa(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Wa(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Ya(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function $a(t,e){t._pack_next=e,e._pack_prev=t}function Ja(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function Ka(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,f=1/0,h=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ja(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ja(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?$a(r,n=o):$a(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(f+h)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),f=Math.min(t.y-t.r,f),h=Math.max(t.y+t.r,h)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function fo(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function ho(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Ya,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),f=n.call(this,u,o),h=i.call(this,f,u,o),p=(o=-1,u.length),d=h.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=h[o+1]-(s.x=h[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=f[0]&&l<=f[1]&&((s=c[t.bisect(h,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Wa(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ea(s,function(t){t.r=+u(t.value)}),Ea(s,Ka),n){var f=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ea(s,function(t){t.r+=f}),Ea(s,Ka),Ea(s,function(t){t.r-=f})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],f=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ea(f,o),f.parent.m=-f.z,Ca(f,s),i)Ca(u,l);else{var h=u,p=u,d=u;Ca(u,function(t){t.x<h.x&&(h=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(h,p)/2-h.x,v=n[0]/(p.x+r(p,h)/2+g),m=n[1]/(d.depth||1);Ca(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+f-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=f-u),a&&!no(l)&&(l.t=a,l.m+=c-h,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ea(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var f=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),h=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=f.x-r(f,h)/2,d=h.x+r(h,f)/2;return Ea(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function f(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),h=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=h?(c.pop(),h=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,h=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(f)}}function h(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(h)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?h:f)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:z,ceil:z};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return ho(t,po(xo(t,e)[2])),ho(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:fo,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=ho(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),f=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var h=1;h<f;h++)e.push(s(c)*h);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var h=f-1;h>0;h--)e.push(s(c)*h);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return Mo;arguments.length<2?r=Mo:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Mo=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function To(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=To(r),a=To(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=To(r=t),a=To(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=(f-u)/(r.length-e+2*i);return a=l(u+h*i,h),c&&a.reverse(),o=h*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=Math.floor((f-u)/(r.length-e+2*i));return a=l(u+Math.round((f-u-(r.length-e)*h)/2),h),c&&a.reverse(),o=Math.round(h*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Co)},t.scale.category20b=function(){return t.scale.ordinal().range(Eo)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Co=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Eo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function zo(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(h),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=Io,e=Do,r=zo,n=Oo,i=Po,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Ct,f=a.apply(this,arguments)-Ct,h=Math.abs(f-u),p=u>f?0:1;if(c<s&&(d=c,c=s,s=d),h>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,M,A,T=0,S=0,C=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(v/c*Math.sin(m))),s&&(T=Dt(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(f-S),_=c*Math.sin(f-S);var E=Math.abs(f-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^E){var L=(u+f)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(f-T),k=s*Math.sin(f-T),M=s*Math.cos(u+T),A=s*Math.sin(u+T);var z=Math.abs(u-f+2*T)<=At?0:1;if(T&&Bo(w,k,M,A)===1-p^z){var O=(u+f)/2;w=s*Math.cos(O),k=s*Math.sin(O),M=A=null}}else w=k=0;if(h>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var I=d,D=d;if(h<At){var P=null==M?[w,k]:null==b?[y,x]:si([y,x],[M,A],[b,_],[w,k]),R=y-P[0],F=x-P[1],B=b-P[0],N=_-P[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),V=Math.sqrt(P[0]*P[0]+P[1]*P[1]);D=Math.min(d,(s-V)/(j-1)),I=Math.min(d,(c-V)/(j+1))}if(null!=b){var U=No(null==M?[w,k]:[M,A],[y,x],c,I,p),q=No([b,_],[w,k],c,I,p);d===I?C.push(\"M\",U[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",U[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(U[1][0],U[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",q[0]):C.push(\"M\",U[0],\"A\",I,\",\",I,\" 0 1,\",g,\" \",q[0])}else C.push(\"M\",y,\",\",x);if(null!=M){var H=No([y,x],[M,A],s,-D,p),G=No([w,k],null==b?[y,x]:[b,_],s,-D,p);d===D?C.push(\"L\",G[0],\"A\",D,\",\",D,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",D,\",\",D,\" 0 0,\",g,\" \",H[0]):C.push(\"L\",G[0],\"A\",D,\",\",D,\" 0 0,\",g,\" \",H[0])}else C.push(\"L\",w,\",\",k)}else C.push(\"M\",y,\",\",x),null!=b&&C.push(\"A\",c,\",\",c,\" 0 \",E,\",\",p,\" \",b,\",\",_),C.push(\"L\",w,\",\",k),null!=M&&C.push(\"A\",s,\",\",s,\" 0 \",z,\",\",1-p,\" \",M,\",\",A);return C.push(\"Z\"),C.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Ct;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function Io(t){return t.innerRadius}function Do(t){return t.outerRadius}function Po(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,f=t[1]+c,h=e[0]+l,p=e[1]+c,d=(u+h)/2,g=(f+p)/2,v=h-u,m=p-f,y=v*v+m*m,x=r-n,b=u*p-h*f,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,M=(b*m+v*_)/y,A=(-b*v+m*_)/y,T=w-d,S=k-g,C=M-d,E=A-g;return T*T+S*S>C*C+E*E&&(w=M,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Wr,i=Uo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,f=a.length,h=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<f;)n.call(this,s=a[u],u)?c.push([+h.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Vo.get(t)||Uo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(z)};var Vo=t.map({linear:Uo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Uo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo(Ko,a)+\",\"+Zo(Ko,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo(Ko,o),\",\",Zo(Ko,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Uo(t):t[0]+Wo(t,Yo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Uo(t):t[1]+Wo(t.slice(1,-1),Yo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Wo((t.push(t[0]),t),Yo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Uo(t):t[0]+Wo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Uo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Wo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Uo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Yo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Uo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo(Ko,o),\",\",Zo(Ko,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Vo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var $o=[0,2/3,1/3,0],Jo=[0,1/3,2/3,0],Ko=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo($o,e),\",\",Zo($o,r),\",\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Ct,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Wr,o=Uo,s=o.key,l=o,c=\"L\",u=.7;function f(s){var f,h,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return h}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,f=s[m],m)?(g.push([h=+x.call(this,f,m),p=+b.call(this,f,m)]),v.push([+_.call(this,f,m),+w.call(this,f,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return f.x=function(t){return arguments.length?(e=r=t,f):r},f.x0=function(t){return arguments.length?(e=t,f):e},f.x1=function(t){return arguments.length?(r=t,f):r},f.y=function(t){return arguments.length?(n=i=t,f):i},f.y0=function(t){return arguments.length?(n=t,f):n},f.y1=function(t){return arguments.length?(i=t,f):i},f.defined=function(t){return arguments.length?(a=t,f):a},f.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Vo.get(t)||Uo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",f):s},f.tension=function(t){return arguments.length?(u=t,f):u},f}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(z)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=Un,r=ns,n=Po,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Ct,u=i.call(t,s,o)-Ct;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Vn,e=Un,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Ct;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Et);Y.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},Y.interrupt=function(t){return this.each(null==t?fs:hs(bs(t)))};var fs=hs(bs());function hs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return U(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),f=u[n];function h(r){var i=u.active,h=u[i];for(var d in h&&(h.timer.c=null,h.timer.t=NaN,--u.count,delete u[i],h.event&&h.event.interrupt.call(t,t.__data__,h.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Me(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,f.event&&f.event.start.call(t,t.__data__,e),c=[],f.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=f.ease,s=f.duration}function p(i){for(var a=i/s,o=l(a),h=c.length;h>0;)c[--h].call(t,o);if(a>=1)return f.event&&f.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}f||(a=i.time,o=Me(function(t){var e=f.delay;if(o.t=e+a,e<=t)return h(t-e);o.c=h},0,a),f=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=Y.call,vs.empty=Y.empty,vs.node=Y.node,vs.size=Y.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var f=this[c],h=-1,p=f.length;++h<p;)if(n=f[h]){a=n[s][o],r=t.call(n,n.__data__,h,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,f=(c=this[s]).length;u<f;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),f=this.__chart__||r,h=this.__chart__=r.copy(),p=null==c?h.ticks?h.ticks.apply(h,l):h.domain():c,d=null==e?h.tickFormat?h.tickFormat.apply(h,l):z:e,g=u.selectAll(\".tick\").data(p,h),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(h),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,M,A,T,S=v.select(\"line\"),C=y.select(\"line\"),E=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),I=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ms,k=\"x\",A=\"y\",M=\"x2\",T=\"y2\",E.attr(\"dy\",I<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+I*o+\"V0H\"+b[1]+\"V\"+I*o)):(n=As,k=\"y\",A=\"x\",M=\"y2\",T=\"x2\",E.attr(\"dy\",\".32em\").style(\"text-anchor\",I<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+I*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+I*o)),S.attr(T,I*a),L.attr(A,I*x),C.attr(M,0).attr(T,I*a),O.attr(k,0).attr(A,I*x),h.rangeBand){var D=h,P=D.rangeBand()/2;f=h=function(t){return D(t)+P}}else f.rangeBand?f=h:m.call(n,h,f);v.call(n,f,h),y.call(n,h,h)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ms(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(h,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,f=Ss[0];function h(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(f,z);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ts[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",h.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var f,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,M=y.classed(\"extent\"),A=xt(m),T=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(M||(f=null,T[0]-=s[1],T[1]-=l[1],M=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==M&&(T[0]+=s[1],T[1]+=l[1],M=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),M)T[0]=s[0]-T[0],T[1]=l[0]-T[1];else if(_){var C=+/w$/.test(_),E=+/^n/.test(_);v=[s[1-C]-T[0],l[1-E]-T[1]],T[0]=s[C],T[1]=l[E]}else t.event.altKey&&(f=T.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),M||(t.event.altKey?(f||(f=[(s[0]+s[1])/2,(l[0]+l[1])/2]),T[0]=s[+(e[0]<f[0])],T[1]=l[+(e[1]<f[1])]):f=null),w&&z(e,i,0)&&(d(b),r=!0),k&&z(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:M?\"move\":\"resize\"}))}function z(t,n,i){var a,o,h=uo(n),p=h[0],d=h[1],g=T[i],v=i?l:s,m=v[1]-v[0];if(M&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],M?o=(a+=g)+m:(f&&(g=Math.max(p,Math.min(d,2*f[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",h.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return h.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=$i(s,a.x),n=$i(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},h.x=function(t){return arguments.length?(f=Ss[!(i=t)<<1|!a],h):i},h.y=function(t){return arguments.length?(f=Ss[!i<<1|!(a=t)],h):a},h.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),h):i&&a?[c,u]:i?c:a?u:null},h.extent=function(t){var n,o,c,u,f;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(f=n,n=o,o=f),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(f=c,c=u,u=f),c==l[0]&&u==l[1]||(l=[c,u])),h):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(f=n,n=o,o=f))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(f=c,c=u,u=f))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},h.clear=function(){return h.empty()||(s=[0,0],l=[0,0],e=r=null),h},h.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(h,n,\"on\")};var Ts={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Cs=Ie.format=sr.timeFormat,Es=Cs.utc,Ls=Es(\"%Y-%m-%dT%H:%M:%S.%LZ\");function zs(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Ds,i);return a==Ds.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Ds[a-1]<Ds[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return Is(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(Is)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,Is(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(ho(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Is(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Is(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Is(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function Is(t){return new Date(t)}Cs.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?zs:Ls,zs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},zs.toString=Ls.toString,Ie.second=Fe(function(t){return new De(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),Ie.seconds=Ie.second.range,Ie.seconds.utc=Ie.second.utc.range,Ie.minute=Fe(function(t){return new De(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),Ie.minutes=Ie.minute.range,Ie.minutes.utc=Ie.minute.utc.range,Ie.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new De(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),Ie.hours=Ie.hour.range,Ie.hours.utc=Ie.hour.utc.range,Ie.month=Fe(function(t){return(t=Ie.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),Ie.months=Ie.month.range,Ie.months.utc=Ie.month.utc.range;var Ds=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ps=[[Ie.second,1],[Ie.second,5],[Ie.second,15],[Ie.second,30],[Ie.minute,1],[Ie.minute,5],[Ie.minute,15],[Ie.minute,30],[Ie.hour,1],[Ie.hour,3],[Ie.hour,6],[Ie.hour,12],[Ie.day,1],[Ie.day,2],[Ie.week,1],[Ie.month,1],[Ie.month,3],[Ie.year,1]],Rs=Cs.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Wr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Is)},floor:z,ceil:z};Ps.year=Ie.year,Ie.scale=function(){return Os(t.scale.linear(),Ps,Rs)};var Bs=Ps.map(function(t){return[t[0].utc,t[1]]}),Ns=Es.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Wr]]);function js(t){return JSON.parse(t.responseText)}function Vs(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=Ie.year.utc,Ie.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Vs,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],150:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],151:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var f=t[u],h=new Array(s+1),p=0,d=0;d<s;++d){var g=f[d];h[d]=g,p+=g*g}h[s]=p,l[u]=new a(h,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var h=x.slice();h[u]=1,v[u+1]=h,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],h=b[0];b[0]=b[1],b[1]=h}return _}},{\"incremental-convex-hull\":399,uniq:525}],152:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],f=n.measureText(u[0]).width+n.measureText(u[1]).width,h=n.measureText(u).width;if(Math.abs(f-h)>s*l){var p=(h-f)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],153:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:94}],154:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":49,\"normalize-svg-path\":438}],155:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],156:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],157:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(f),o=0;o<p.length;o++)h(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,f,h){if(t){!h&&f&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,f);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,f?l(t,n,i,f):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){h?1===h?o(t=c(t,e,r),e,r,n,i,f,2):2===h&&u(t,e,r,n,i,f):o(a(t),e,r,n,i,f,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=p(s,l,e,r,n),h=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=f&&v&&v.z<=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=h;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function f(t,e){return t.x-e.x}function h(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,f=r.y,h=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<h||l===h&&n.x>r.x)&&b(n,t)&&(r=n,h=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{e.x<r.x&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new M(t.i,t.x,t.y),n=new M(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new M(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function M(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],158:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:525}],159:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":191}],160:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":161,\"./shim\":162}],161:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],162:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),f=Array.isArray,h=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],M=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(f(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!f(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?h.call(k,M,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?h.call(k,M,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?h.call(k,M,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":163,\"../../function/is-function\":164,\"../../number/to-pos-integer\":170,\"../../object/is-value\":180,\"../../object/valid-callable\":189,\"../../object/valid-value\":191,\"../../string/is-string\":195,\"es6-symbol\":205}],163:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],164:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":165}],165:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],166:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":167,\"./shim\":168}],167:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],168:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],169:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":166}],170:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":169}],171:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,f=arguments[2],h=arguments[3];return r=Object(i(r)),n(c),u=s(r),h&&u.sort(\"function\"==typeof h?a.call(h,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,f,r[t],t,r,n):e})}}},{\"./valid-callable\":189,\"./valid-value\":191}],172:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":173,\"./shim\":174}],173:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],174:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":181,\"../valid-value\":191}],175:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":160,\"./assign\":172,\"./valid-value\":191}],176:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":187,\"./set-prototype-of/shim\":188}],177:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":171}],178:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],179:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":180}],180:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":165}],181:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":182,\"./shim\":183}],182:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":177,\"./valid-callable\":189}],185:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":180}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],188:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,f={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",f),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":176,\"../is-object\":179,\"../valid-value\":191}],189:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],190:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":179}],191:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":180}],192:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":193,\"./shim\":194}],193:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],194:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],195:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],196:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],197:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":200,d:140,\"es5-ext/object/set-prototype-of\":186,\"es5-ext/string/#/contains\":192,\"es6-symbol\":205}],198:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,f,h,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),f=function(){h=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,f),h)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,f),!h);++p);else c.call(t,function(t){return l.call(e,m,t,f),h})}},{\"./get\":199,\"es5-ext/function/is-arguments\":163,\"es5-ext/object/valid-callable\":189,\"es5-ext/string/is-string\":195}],199:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":197,\"./string\":202,\"./valid-iterable\":203,\"es5-ext/function/is-arguments\":163,\"es5-ext/string/is-string\":195,\"es6-symbol\":205}],200:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),f=Object.defineProperty,h=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");h(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,h(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):f(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),f(n.prototype,u.iterator,l(function(){return this}))},{d:140,\"d/auto-bind\":139,\"es5-ext/array/#/clear\":159,\"es5-ext/object/assign\":172,\"es5-ext/object/valid-callable\":189,\"es5-ext/object/valid-value\":191,\"es6-symbol\":205}],201:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":163,\"es5-ext/object/is-value\":180,\"es5-ext/string/is-string\":195,\"es6-symbol\":205}],202:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":200,d:140,\"es5-ext/object/set-prototype-of\":186,\"es6-symbol\":205}],203:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":201}],204:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},f=u.MutationObserver||u.WebKitMutationObserver,h=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[M]&&U(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}h?_=function(){return n.nextTick(v)}:f?(y=0,x=new f(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var M=Math.random().toString(36).substring(16);function A(){}var T=void 0,S=1,C=2,E=new B;function L(t){try{return t.then}catch(t){return E.error=t,E}}function z(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?D(t,e._result):e._state===C?P(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return P(t,e)})}(t,r):n===E?P(t,E.error):void 0===n?D(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):D(t,r))},function(e){n||(n=!0,P(t,e))},t._label);!n&&i&&(n=!0,P(t,i))},t)}(t,r,n):D(t,r)}function O(t,e){var r;t===e?P(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?z(t,e,L(e)):D(t,e)}function I(t){t._onerror&&t._onerror(t._result),F(t)}function D(t,e){t._state===T&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function P(t,e){t._state===T&&(t._state=C,t._result=e,l(I,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+C]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void P(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==T||(a&&l?O(r,o):c?P(r,s):t===S?D(r,o):t===C&&P(r,o))}var V=0;function U(t){t[M]=V++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[M]||U(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?D(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&D(this.promise,this._result))):P(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[M]=V++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){P(t,e)})}catch(e){P(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===T&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==T)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);z(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===T&&(this._remaining--,t===C?P(n,r):this._result[e]=r),0===this._remaining&&D(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(C,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return P(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:468}],205:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":206,\"./polyfill\":208}],206:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],207:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],208:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,f=Object.defineProperty,h=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,f(h,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,f(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),f(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),f(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),f(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),f(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":209,d:140}],209:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":207}],210:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":211,\"./polyfill\":213}],211:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],212:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],213:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/object/valid-object\"),o=t(\"es5-ext/object/valid-value\"),s=t(\"es5-ext/string/random-uniq\"),l=t(\"d\"),c=t(\"es6-iterator/get\"),u=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,h=t(\"./is-native-implemented\"),p=Array.isArray,d=Object.defineProperty,g=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=h&&i&&WeakMap!==n?i(new WeakMap,v(this)):this,null!=e&&(p(e)||(e=c(e))),d(t,\"__weakMapData__\",l(\"c\",\"$weakMap$\"+s())),e?(u(e,function(e){o(e),t.set(e[0],e[1])}),t):t},h&&(i&&i(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:l(n)})),Object.defineProperties(n.prototype,{delete:l(function(t){return!!g.call(a(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:l(function(t){if(g.call(a(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:l(function(t){return g.call(a(t),this.__weakMapData__)}),set:l(function(t,e){return d(a(t),this.__weakMapData__,l(\"c\",e)),this}),toString:l(function(){return\"[object WeakMap]\"})}),d(n.prototype,f,l(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":212,d:140,\"es5-ext/object/set-prototype-of\":186,\"es5-ext/object/valid-object\":190,\"es5-ext/object/valid-value\":191,\"es5-ext/string/random-uniq\":196,\"es6-iterator/for-of\":198,\"es6-iterator/get\":199,\"es6-symbol\":205}],214:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],215:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":409}],216:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,f=this.bounds;if(o<0)for(var h=u-1,p=0;p<u;++p,--h)s[p]=l[h];else if(o>=r-1){h=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--h)s[p]=l[h]+d*c[h]}else{h=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--h)m[p]=l[h],x[p]=c[h]*v,y[p]=l[h+u],b[p]=c[h+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=f[0],k=f[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,f=(e[r-1],0);f<c;++f,--u)o[f]=l[u];else{u=c*(a+1)-1;var h=e[a],p=e[a+1]-h||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(f=0;f<c;++f,--u)d[f]=s[u],v[f]=l[u]*p,g[f]=s[u+c],m[f]=l[u+c]*p,y=y&&d[f]===g[f]&&v[f]===m[f]&&0===v[f];if(y)for(f=0;f<c;++f)o[f]=0;else{n.derivative(d,v,g,m,(t-h)/p,o);for(f=0;f<c;++f)o[f]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var f=0;f<r;++f)n.push(n[o++]),i.push(0);this._time.push(t);for(f=r;f>0;--f)n.push(a(l[f-1],c[f-1],arguments[f])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],f=s>1e-6?1/s:0;this._time.push(t);for(var h=r;h>0;--h){var p=a(c[h-1],u[h-1],arguments[h]);n.push(p),i.push((p-n[o++])*f)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,f=u>1e-6?1/u:0;this._time.push(t);for(var h=r;h>0;--h){var p=arguments[h];n.push(a(l[h-1],c[h-1],n[o++]+p)),i.push(p*f)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var f=r-1;f>=0;--f)n.push(a(l[f],c[f],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":80,\"cubic-hermite\":134}],217:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var f=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new f(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new f(t):(e=new f(t.length+r)).set(t,r)}return e}},{dtype:155}],218:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var f=r.getContext(\"2d\");f.fillStyle=\"#000\",f.fillRect(0,0,r.width,r.height),f.font=a,f.textAlign=\"center\",f.textBaseline=\"middle\",f.fillStyle=\"#fff\";for(var h=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)f.fillText(s[c],h,p),(h+=o[0])>e[0]-o[0]/2&&(h=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":131}],219:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,f=u.getContext(\"2d\"),h={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,f.font=t;var d={top:0};f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillStyle=\"black\",f.fillText(\"H\",0,0);var g=a(f.getImageData(0,0,p,p));f.clearRect(0,0,p,p),f.textBaseline=\"bottom\",f.fillText(\"H\",0,p);var v=a(f.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,f.clearRect(0,0,p,p),f.textBaseline=\"alphabetic\",f.fillText(\"H\",0,p);var m=p-a(f.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,f.clearRect(0,0,p,p),f.textBaseline=\"middle\",f.fillText(\"H\",0,.5*p);var y=a(f.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"hanging\",f.fillText(\"H\",0,.5*p);var x=a(f.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"ideographic\",f.fillText(\"H\",0,p);var b=a(f.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,h.upper&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.upper,0,0),d.upper=a(f.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),h.lower&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.lower,0,0),d.lower=a(f.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),h.tittle&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.tittle,0,0),d.tittle=a(f.getImageData(0,0,p,p))),h.ascent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.ascent,0,0),d.ascent=a(f.getImageData(0,0,p,p))),h.descent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.descent,0,0),d.descent=o(f.getImageData(0,0,p,p))),h.overshoot){f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.overshoot,0,0);var _=o(f.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],220:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function f(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],f=[];o;){var h=r(t,o.key);u.push(o),f.push(h),o=h<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];f[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new f(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new f(this,t)}}),u.at=function(t){if(t<0)return new f(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new f(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new f(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new f(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new f(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new f(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new f(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new f(this,n);r=i<=0?r.left:r.right}return new f(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var h=f.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(h,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(h,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),h.clone=function(){return new f(this.tree,this._stack.slice())},h.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var f=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var h=e[f-1];e.push(new a(r._color,h.key,h.value,r.left,r.right,r._count)),e[f-1].key=r.key,e[f-1].value=r.value;for(u=e.length-2;u>=f;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[f-1].left=e[f]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((f=t[u-2]).left===r?f.left=a:f.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((f=t[u-2]).left===r?f.left=c:f.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((f=t[u-2]).left===r?f.left=a:f.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((f=t[u-2]).right===r?f.right=a:f.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((f=t[u-2]).right===r?f.right=c:f.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var f;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((f=t[u-2]).right===r?f.right=a:f.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(h,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(h,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(h,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),h.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(h,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),h.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},h.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(h,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],221:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],222:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],223:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this._tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var f=u.prototype;function h(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}f.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,f=!1;if(\"bounds\"in t)for(var h=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)h[p][d]!==this.bounds[p][d]&&(f=!0),this.bounds[p][d]=h[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new h,new h,new h];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var f=a,h=s,p=o,d=l;c&1<<u&&(f=s,h=a,p=l,d=o),f[u]=r[0][u],h[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l};f.isOpaque=function(){return!0},f.isTransparent=function(){return!1},f.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];f.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=o(r,n,i,a),u=s.cubeEdges,f=s.axis,h=n[12],b=n[13],_=n[14],w=n[15],k=this.pixelRatio*(i[3]*h+i[7]*b+i[11]*_+i[15]*w)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=u[M],this.lastCubeProps.axis[M]=f[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,u,f);e=this.gl;var T,S=g;for(M=0;M<3;++M)this.backgroundEnable[M]?S[M]=f[M]:S[M]=0;this._background.draw(r,n,i,a,S,this.backgroundColor),this._lines.bind(r,n,i,this);for(M=0;M<3;++M){var C=[0,0,0];f[M]>0?C[M]=a[1][M]:C[M]=a[0][M];for(var E=0;E<2;++E){var L=(M+1+E)%3,z=(M+1+(1^E))%3;this.gridEnable[L]&&this._lines.drawGrid(L,z,this.bounds,C,this.gridColor[L],this.gridWidth[L]*this.pixelRatio)}for(E=0;E<2;++E){L=(M+1+E)%3,z=(M+1+(1^E))%3;this.zeroEnable[z]&&Math.min(a[0][z],a[1][z])<=0&&Math.max(a[0][z],a[1][z])>=0&&this._lines.drawZero(L,z,this.bounds,C,this.zeroLineColor[z],this.zeroLineWidth[z]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var O=c(m,A[M].primalMinor),I=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(E=0;E<3;++E){var P=k/r[5*E];O[E]*=D[E]*P,I[E]*=D[E]*P}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,I,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var R,F;function B(t){(F=[0,0,0])[t]=1}function N(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?B(n):a>0&&l<0?B(n):a<0&&l>0?B(n):a<0&&l<0?B(n):o>0&&s>0?B(i):o>0&&s<0?B(i):o<0&&s>0?B(i):o<0&&s<0&&B(i)}for(M=0;M<3;++M){var j=A[M].primalMinor,V=A[M].mirrorMinor,U=c(x,A[M].primalOffset);for(E=0;E<3;++E)this.lineTickEnable[M]&&(U[E]+=k*j[E]*Math.max(this.lineTickLength[E],0)/r[5*E]);var q=[0,0,0];if(q[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this._tickAlign[M]=\"auto\"):this._tickAlign[M]=-1,R=1,\"auto\"===(T=[this._tickAlign[M],.5,R])[0]?T[0]=0:T[0]=parseInt(\"\"+T[0]),F=[0,0,0],N(M,j,V);for(E=0;E<3;++E)U[E]+=k*j[E]*this.tickPad[E]/r[5*E];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],U,this.tickColor[M],q,F,T)}if(this.labelEnable[M]){R=0,F=[0,0,0],this.labels[M].length>4&&(B(M),R=1),\"auto\"===(T=[this.labelAlign[M],.5,R])[0]?T[0]=0:T[0]=parseInt(\"\"+T[0]);for(E=0;E<3;++E)U[E]+=k*j[E]*this.labelPad[E]/r[5*E];U[M]+=.5*(a[0][M]+a[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],U,this.labelColor[M],[0,0,0],F,T)}}this._text.unbind()},f.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":224,\"./lib/cube.js\":225,\"./lib/lines.js\":226,\"./lib/text.js\":228,\"./lib/ticks.js\":229}],224:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,f=[0,0,0],h=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),f[l]=p,h[l]=p;for(var d=-1;d<=1;d+=2){f[c]=d;for(var g=-1;g<=1;g+=2)f[u]=g,e.push(f[0],f[1],f[2],h[0],h[1],h[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":227,\"gl-buffer\":231,\"gl-vao\":313}],225:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){i(s,e,t),i(s,r,s);for(var p=0,y=0;y<2;++y){u[2]=a[y][2];for(var x=0;x<2;++x){u[1]=a[x][1];for(var b=0;b<2;++b)u[0]=a[b][0],h(l[p],u,s),p+=1}}for(var _=-1,y=0;y<8;++y){for(var w=l[y][3],k=0;k<3;++k)c[y][k]=l[y][k]/w;w<0&&(_<0?_=y:c[y][2]<c[_][2]&&(_=y))}if(_<0){_=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,T=(M+1)%3,S=-1,C=-1,E=0;E<2;++E){var L=E<<M,z=L+(E<<A)+(1-E<<T),O=L+(1-E<<A)+(E<<T);o(c[L],c[z],c[O],f)<0||(E?S=1:C=1)}if(S<0||C<0)C>S&&(_|=1<<M);else{for(var E=0;E<2;++E){var L=E<<M,z=L+(E<<A)+(1-E<<T),O=L+(1-E<<A)+(E<<T),I=d([l[L],l[z],l[O],l[L+(1<<A)+(1<<T)]]);E?S=I:C=I}C>S&&(_|=1<<M)}}}for(var D=7^_,P=-1,y=0;y<8;++y)y!==_&&y!==D&&(P<0?P=y:c[P][1]>c[y][1]&&(P=y));for(var R=-1,y=0;y<3;++y){var F=P^1<<y;if(F!==_&&F!==D){R<0&&(R=F);var T=c[F];T[0]<c[R][0]&&(R=F)}}for(var B=-1,y=0;y<3;++y){var F=P^1<<y;if(F!==_&&F!==D&&F!==R){B<0&&(B=F);var T=c[F];T[0]>c[B][0]&&(B=F)}}var N=g;N[0]=N[1]=N[2]=0,N[n.log2(R^P)]=P&R,N[n.log2(P^B)]=P&B;var j=7^B;j===_||j===D?(j=7^R,N[n.log2(B^j)]=j&B):N[n.log2(R^j)]=j&R;for(var V=v,U=_,M=0;M<3;++M)V[M]=U&1<<M?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),f=[0,0,0];function h(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,f=l[0]/l[3]-n,h=l[1]/l[3]-i;o+=Math.abs(c*h-u*f)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":81,\"gl-mat4/multiply\":258,\"robust-orientation\":488,\"split-polygon\":505}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var f=0;f<3;++f){for(var h=o.length/3|0,d=0;d<r[f].length;++d){var g=+r[f][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[f]=h,l[f]=v-h;for(var h=o.length/3|0,m=0;m<r[f].length;++m){var g=+r[f][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[f]=h,u[f]=v-h}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function f(t){return t[0]=t[1]=t[2]=0,t}function h(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=f(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=h(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=f(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=f(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=f(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=f(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=f(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=h(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=f(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=f(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=f(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=h(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=f(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":227,\"gl-buffer\":231,\"gl-vao\":313}],227:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"#define GLSLIFY 1\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"#define GLSLIFY 1\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision mediump float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"#define GLSLIFY 1\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":290,glslify:395}],228:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),f=i(t,[{buffer:u,size:3}]),h=o(t);h.attributes.position.location=0;var p=new c(t,h,u,f);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,f=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,h=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=h[v[m]];o.push(f*y[0],-f*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],f=[0,0,0],h=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){f[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),h[d]=(o.length/3|0)-f[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=f,this.labelCount=h},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":227,_process:468,\"gl-buffer\":231,\"gl-vao\":313,\"vectorize-text\":528}],229:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var f=\"\"+c;f.length<i;)f=\"0\"+f;return u+\".\"+f}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,f){var h=e.model||c,p=e.view||c,m=e.projection||c,y=t.bounds,x=(f=f||a(h,p,m,y)).axis;f.edges;o(u,p,h),o(u,m,u);for(var b=g,_=0;_<3;++_)b[_].lo=1/0,b[_].hi=-1/0,b[_].pixelsPerDataUnit=1/0;var w=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,T=v;t:for(var _=0;_<2;++_){var S=[];if(x[k]<0!=!!_){T[k]=y[_][k];for(var C=0;C<2;++C){T[M]=y[C^_][M];for(var E=0;E<2;++E)T[A]=y[E^C^_][A],S.push(T.slice())}for(var C=4;4===C;++C){if(0===S.length)continue t;S=i.positive(S,w[C])}for(var C=0;C<S.length;++C)for(var A=S[C],L=d(v,u,A,r,l),E=0;E<3;++E)b[E].lo=Math.min(b[E].lo,A[E]),b[E].hi=Math.max(b[E].hi,A[E]),E!==k&&(b[E].pixelsPerDataUnit=Math.min(b[E].pixelsPerDataUnit,Math.abs(L[E])))}}}return b};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function f(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var h=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=h,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,f=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+f*f)}return t}var g=[new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":225,\"extract-frustum-planes\":214,\"gl-mat4/multiply\":258,\"gl-mat4/transpose\":266,\"gl-vec4/transformMat4\":384,\"split-polygon\":505}],231:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var f;f=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?f:f.subarray(0,t.length),e),n.free(f)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:436,\"ndarray-ops\":430,\"typedarray-pool\":523}],232:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=(t(\"gl-vec4\"),function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r}),a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],f=t[2],h=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],f),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,h-1),y=s(y,0,h-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=h||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(f-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var M=m*h*p,A=b*h*p,T=v*h,S=x*h,C=g,E=y,L=e[T+M+C],z=e[T+M+E],O=e[S+M+C],I=e[S+M+E],D=e[T+A+C],P=e[T+A+E],R=e[S+A+C],F=e[S+A+E],B=n.create();return n.lerp(B,L,z,_),n.lerp(a,O,I,_),n.lerp(B,B,a,w),n.lerp(a,D,P,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,f=1/0,h=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),f=Math.min(_[1],f),h=Math.max(_[1],h),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,f,p],k=[u,h,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var M=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),T=t.coneSize||.5;t.absoluteConeSize&&(T=t.absoluteConeSize*M),o.coneScale=T;x=0;for(var S=0;x<r.length;x++)for(var C=(_=r[x])[0],E=_[1],L=_[2],z=m[x],O=n.length(z)*M,I=0;I<8;I++){o.positions.push([C,E,L,S++]),o.positions.push([C,E,L,S++]),o.positions.push([C,E,L,S++]),o.positions.push([C,E,L,S++]),o.positions.push([C,E,L,S++]),o.positions.push([C,E,L,S++]),o.vectors.push(z),o.vectors.push(z),o.vectors.push(z),o.vectors.push(z),o.vectors.push(z),o.vectors.push(z),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var D=o.positions.length;o.cells.push([D-6,D-5,D-4],[D-3,D-2,D-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":234,\"gl-vec3\":332,\"gl-vec4\":368}],233:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var f=0,h=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<h&&(h=p,f=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[f,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:62,\"polytope-closest-point/lib/closest_point_2d.js\":467}],234:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=(t(\"./closest-point\"),d.meshShader),v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,v,y,x,b,_,w,k,M,A,T,S,C){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleVectors=c,this.triangleColors=f,this.triangleNormals=p,this.triangleUVs=h,this.triangleIds=u,this.triangleVAO=d,this.triangleCount=0,this.lineWidth=1,this.edgePositions=g,this.edgeColors=y,this.edgeUVs=x,this.edgeIds=v,this.edgeVAO=b,this.edgeCount=0,this.pointPositions=_,this.pointColors=k,this.pointUVs=M,this.pointSizes=A,this.pointIds=w,this.pointVAO=T,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=S,this.contourVAO=C,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],v=i[f],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=f({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],h=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var M=t.vertexNormals,A=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||M||(M=s.vertexNormals(r,n,T));var C=t.vertexColors,E=t.cellColors,L=t.meshColor||[1,1,1,1],z=t.vertexUVs,O=t.vertexIntensity,I=t.cellUVs,D=t.cellIntensity,P=1/0,R=-1/0;if(!z&&!I)if(O)if(t.vertexIntensityBounds)P=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];P=Math.min(P,B),R=Math.max(R,B)}else if(D)for(F=0;F<D.length;++F){B=D[F];P=Math.min(P,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];P=Math.min(P,B),R=Math.max(R,B)}this.intensity=O||(D?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,D):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var V=n[F],U=0;U<3;++U)!isNaN(V[U])&&isFinite(V[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],V[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],V[U]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var W=r[F];switch(W.length){case 1:for(V=n[X=W[0]],U=0;U<3;++U)if(isNaN(V[U])||!isFinite(V[U]))continue t;x.push(V[0],V[1],V[2],V[3]),3===(Z=C?C[X]:E?E[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),$=z?z[X]:O?[(O[X]-P)/(R-P),0]:I?I[F]:D?[(D[F]-P)/(R-P),0]:[(V[2]-P)/(R-P),0],_.push($[0],$[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(U=0;U<2;++U){V=n[X=W[U]];for(var Y=0;Y<3;++Y)if(isNaN(V[Y])||!isFinite(V[Y]))continue t}for(U=0;U<2;++U){V=n[X=W[U]];g.push(V[0],V[1],V[2]),3===(Z=C?C[X]:E?E[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),$=z?z[X]:O?[(O[X]-P)/(R-P),0]:I?I[F]:D?[(D[F]-P)/(R-P),0]:[(V[2]-P)/(R-P),0],m.push($[0],$[1]),y.push(F)}H+=1;break;case 3:for(U=0;U<3;++U)for(V=n[X=W[U]],Y=0;Y<3;++Y)if(isNaN(V[Y])||!isFinite(V[Y]))continue t;for(U=0;U<3;++U){var X;V=n[X=W[U]];a.push(V[0],V[1],V[2],V[3]);var Z,$,J,K=i[X];l.push(K[0],K[1],K[2]),3===(Z=C?C[X]:E?E[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),$=z?z[X]:O?[(O[X]-P)/(R-P),0]:I?I[F]:D?[(D[F]-P)/(R-P),0]:[(V[2]-P)/(R-P),0],p.push($[0],$[1]),J=M?M[X]:A[F],h.push(J[0],J[1],J[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(h),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),f=i(t),h=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:h,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:f,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),T=i(t),S=i(t),C=i(t),E=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:E,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:C,type:t.FLOAT,size:1}]),z=i(t),O=new y(t,l,r,null,null,s,null,null,c,f,v,h,p,d,m,x,k,_,w,M,A,E,T,S,C,L,z,a(t,[{buffer:z,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./closest-point\":233,\"./shaders\":235,colormap:115,\"gl-buffer\":231,\"gl-mat4/invert\":256,\"gl-mat4/multiply\":258,\"gl-shader\":290,\"gl-texture2d\":308,\"gl-vao\":313,ndarray:436,normals:439,\"simplicial-complex-contour\":496,\"typedarray-pool\":523}],235:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nfloat inverse(float m) {\\n  return 1.0 / m;\\n}\\n\\nmat2 inverse(mat2 m) {\\n  return mat2(m[1][1],-m[0][1],\\n             -m[1][0], m[0][0]) / (m[0][0]*m[1][1] - m[0][1]*m[1][0]);\\n}\\n\\nmat3 inverse(mat3 m) {\\n  float a00 = m[0][0], a01 = m[0][1], a02 = m[0][2];\\n  float a10 = m[1][0], a11 = m[1][1], a12 = m[1][2];\\n  float a20 = m[2][0], a21 = m[2][1], a22 = m[2][2];\\n\\n  float b01 = a22 * a11 - a12 * a21;\\n  float b11 = -a22 * a10 + a12 * a20;\\n  float b21 = a21 * a10 - a11 * a20;\\n\\n  float det = a00 * b01 + a01 * b11 + a02 * b21;\\n\\n  return mat3(b01, (-a22 * a01 + a02 * a21), (a12 * a01 - a02 * a11),\\n              b11, (a22 * a00 - a02 * a20), (-a12 * a00 + a02 * a10),\\n              b21, (-a21 * a00 + a01 * a20), (a11 * a00 - a01 * a10)) / det;\\n}\\n\\nmat4 inverse(mat4 m) {\\n  float\\n      a00 = m[0][0], a01 = m[0][1], a02 = m[0][2], a03 = m[0][3],\\n      a10 = m[1][0], a11 = m[1][1], a12 = m[1][2], a13 = m[1][3],\\n      a20 = m[2][0], a21 = m[2][1], a22 = m[2][2], a23 = m[2][3],\\n      a30 = m[3][0], a31 = m[3][1], a32 = m[3][2], a33 = m[3][3],\\n\\n      b00 = a00 * a11 - a01 * a10,\\n      b01 = a00 * a12 - a02 * a10,\\n      b02 = a00 * a13 - a03 * a10,\\n      b03 = a01 * a12 - a02 * a11,\\n      b04 = a01 * a13 - a03 * a11,\\n      b05 = a02 * a13 - a03 * a12,\\n      b06 = a20 * a31 - a21 * a30,\\n      b07 = a20 * a32 - a22 * a30,\\n      b08 = a20 * a33 - a23 * a30,\\n      b09 = a21 * a32 - a22 * a31,\\n      b10 = a21 * a33 - a23 * a31,\\n      b11 = a22 * a33 - a23 * a32,\\n\\n      det = b00 * b11 - b01 * b10 + b02 * b09 + b03 * b08 - b04 * b07 + b05 * b06;\\n\\n  return mat4(\\n      a11 * b11 - a12 * b10 + a13 * b09,\\n      a02 * b10 - a01 * b11 - a03 * b09,\\n      a31 * b05 - a32 * b04 + a33 * b03,\\n      a22 * b04 - a21 * b05 - a23 * b03,\\n      a12 * b08 - a10 * b11 - a13 * b07,\\n      a00 * b11 - a02 * b08 + a03 * b07,\\n      a32 * b02 - a30 * b05 - a33 * b01,\\n      a20 * b05 - a22 * b02 + a23 * b01,\\n      a10 * b10 - a11 * b08 + a13 * b06,\\n      a01 * b08 - a00 * b10 - a03 * b06,\\n      a30 * b04 - a31 * b02 + a33 * b00,\\n      a21 * b02 - a20 * b04 - a23 * b00,\\n      a11 * b07 - a10 * b09 - a12 * b06,\\n      a00 * b09 - a01 * b07 + a02 * b06,\\n      a31 * b01 - a30 * b03 - a32 * b00,\\n      a20 * b03 - a21 * b01 + a22 * b00) / det;\\n}\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float index, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  index = mod(index, segmentCount * 6.0);\\n\\n  float segment = floor(index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex == 3.0) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  // angle = 2pi * ((segment + ((segmentIndex == 1.0 || segmentIndex == 5.0) ? 1.0 : 0.0)) / segmentCount)\\n  float nextAngle = float(segmentIndex == 1.0 || segmentIndex == 5.0);\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex <= 2.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  normal = normalize(normal * inverse(mat3(model)));\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n  f_color          = color; //vec4(position.w, color.r, 0, 0);\\n  f_normal         = normal;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_eyeDirection   = eyePosition   - conePosition.xyz;\\n  f_lightDirection = lightPosition - conePosition.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(!gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = cookTorranceSpecular(L, V, N, roughness, fresnel);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor =  texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float index, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  index = mod(index, segmentCount * 6.0);\\n\\n  float segment = floor(index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex == 3.0) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  // angle = 2pi * ((segment + ((segmentIndex == 1.0 || segmentIndex == 5.0) ? 1.0 : 0.0)) / segmentCount)\\n  float nextAngle = float(segmentIndex == 1.0 || segmentIndex == 5.0);\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex <= 2.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:395}],236:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],237:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":236}],238:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return this.opacity>=1},l.isTransparent=function(){return this.opacity<1},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var f=0;f<3;++f)e.lineWidth(this.lineWidth[f]),r.capSize=this.capSize[f]*u,this.lineCount[f]&&e.drawArrays(e.LINES,this.lineOffset[f],this.lineCount[f]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function f(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),\"opacity\"in t&&(this.opacity=t.opacity);var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],h=0;h<3;++h)if(isNaN(u[h])||!isFinite(u[h]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length&&(d=[d[0],d[1],d[2],1]),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":239,\"gl-buffer\":231,\"gl-vao\":313}],239:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], fragPosition)) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":290,glslify:395}],240:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var f=1;if(\"color\"in(n=n||{})){if((f=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(f>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(f>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+f+\" draw buffers\")}}var h=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&f>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");h=t.FLOAT}else n.preferFloat&&f>0&&p&&(h=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,h,f,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function f(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function h(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=h(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=h(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=h(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),f(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),f(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":308}],241:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),f=t.split(\"\\n\"),h={},p=0;p<f.length;p++){var d=f[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));h[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(h[p+3]||h[p+2]||h[p+1]){var m=v[p];if(c+=m+\"\\n\",h[p+1]){var y=h[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":50,\"gl-constants/lookup\":237,\"glsl-shader-name\":387,\"sprintf-js\":506}],242:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),f=s(r),h=s(r),p=new c(t,n,i,a,u,f,h);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,f=c.prototype,h=[0,0,1,0,0,1,1,0,1,1,0,1];f.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var f=e.uniforms;f.viewTransform=u,f.shape=this.shape;var h=e.attributes;this.positionBuffer.bind(),h.position.pointer(),this.weightBuffer.bind(),h.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),h.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),f.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],f=l[2]-l[0],h=l[3]-l[1];t[0]=2*c/f,t[4]=2*u/h,t[6]=2*(a[0]-l[0])/f-1,t[7]=2*(a[1]-l[1])/h-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),f.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},f.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,f=this.bounds,p=f[0]=r[0],d=f[1]=o[0],g=1/((f[2]=r[r.length-1])-p),v=1/((f[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(h.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),M=0,A=0;A<y-1;++A)for(var T=v*(o[A]-d),S=v*(o[A+1]-d),C=0;C<m-1;++C)for(var E=g*(r[C]-p),L=g*(r[C+1]-p),z=0;z<h.length;z+=2){var O,I,D,P,R=h[z],F=h[z+1],B=s[(A+F)*m+(C+R)],N=n.le(l,B);if(N<0)O=c[0],I=c[1],D=c[2],P=c[3];else if(N===u-1)O=c[4*u-4],I=c[4*u-3],D=c[4*u-2],P=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),V=1-j,U=4*N,q=4*(N+1);O=V*c[U]+j*c[q],I=V*c[U+1]+j*c[q+1],D=V*c[U+2]+j*c[q+2],P=V*c[U+3]+j*c[q+3]}b[4*M]=255*O,b[4*M+1]=255*I,b[4*M+2]=255*D,b[4*M+3]=255*P,_[2*M]=.5*E+.5*L,_[2*M+1]=.5*T+.5*S,w[2*M]=R,w[2*M+1]=F,k[M]=A*m+C,M+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},f.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":243,\"binary-search-bounds\":244,\"gl-buffer\":231,\"gl-shader\":290,\"iota-array\":402,\"typedarray-pool\":523}],243:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:395}],244:[function(t,e,r){arguments[4][100][0].apply(r,arguments)},{dup:100}],245:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":290,glslify:395}],246:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=f(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),h=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)h.data[p]=255;var d=a(e,h);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,f=c.createPickShader,h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.opacity<1},m.isOpaque=function(){return this.opacity>=1},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||h,view:t.view||h,projection:t.projection||h,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||h,view:t.view||h,projection:t.projection||h,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),\"opacity\"in t&&(this.opacity=+t.opacity);var i=[],a=[],o=[],c=0,u=0,f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],h=t.position||t.positions;if(h){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<h.length;++e){var m,y,x,b=h[e-1],_=h[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}f[0][r]=Math.min(f[0][r],b[r],_[r]),f[1][r]=Math.max(f[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(h[h.length-1].slice()),this.bounds=f,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var M=t.dashes.slice();for(M.unshift(0),e=1;e<M.length;++e)M[e]=M[e-1]+M[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(M,M[M.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var f=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,f,this.points[f])}},{\"./lib/shaders\":245,\"binary-search-bounds\":247,\"gl-buffer\":231,\"gl-texture2d\":308,\"gl-vao\":313,\"glsl-read-float\":386,ndarray:436}],247:[function(t,e,r){arguments[4][100][0].apply(r,arguments)},{dup:100}],248:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],249:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=u*o-s*c,h=-u*a+s*l,p=c*a-o*l,d=r*f+n*h+i*p;return d?(d=1/d,t[0]=f*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=h*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],250:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],251:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],252:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],f=t[10],h=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(f*v-h*g)-(e*s-n*a)*(u*v-h*d)+(e*l-i*a)*(u*g-f*d)+(r*s-n*o)*(c*v-h*p)-(r*l-i*o)*(c*g-f*p)+(n*l-i*s)*(c*d-u*p)}},{}],253:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,f=n*s,h=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-f-d,t[1]=u+m,t[2]=h-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=h+v,t[9]=p-g,t[10]=1-c-f,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],254:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,f=n*l,h=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=f+y,t[2]=h-m,t[3]=0,t[4]=f-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=h+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],255:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],256:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,M=u*g-f*d,A=u*v-h*d,T=u*m-p*d,S=f*v-h*g,C=f*m-p*g,E=h*m-p*v,L=y*E-x*C+b*S+_*T-w*A+k*M;if(!L)return null;return L=1/L,t[0]=(s*E-l*C+c*S)*L,t[1]=(i*C-n*E-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(h*w-f*k-p*_)*L,t[4]=(l*T-o*E-c*A)*L,t[5]=(r*E-i*T+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-h*b+p*x)*L,t[8]=(o*C-s*T+c*M)*L,t[9]=(n*T-r*C-a*M)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*M)*L,t[13]=(r*S-n*A+i*M)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-f*x+h*y)*L,t}},{}],257:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);f=g-_,h=v-w,p=m-k,d=1/Math.sqrt(f*f+h*h+p*p),a=x*(p*=d)-b*(h*=d),o=b*(f*=d)-y*p,s=y*h-x*f,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=h*s-p*o,c=p*a-f*s,u=f*o-h*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=f,t[3]=0,t[4]=o,t[5]=c,t[6]=h,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(f*g+h*v+p*m),t[15]=1,t}},{\"./identity\":255}],258:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*g,t[5]=x*i+b*l+_*h+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*g,t[9]=x*i+b*l+_*h+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*g,t[13]=x*i+b*l+_*h+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],259:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],260:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p,d,g,v,m,y,x,b,_,w,k,M,A,T,S,C=n[0],E=n[1],L=n[2],z=Math.sqrt(C*C+E*E+L*L);if(Math.abs(z)<1e-6)return null;C*=z=1/z,E*=z,L*=z,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],f=e[4],h=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=C*C*o+a,b=E*C*o+L*i,_=L*C*o-E*i,w=C*E*o-L*i,k=E*E*o+a,M=L*E*o+C*i,A=C*L*o+E*i,T=E*L*o-C*i,S=L*L*o+a,t[0]=s*x+f*b+g*_,t[1]=l*x+h*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+f*k+g*M,t[5]=l*w+h*k+v*M,t[6]=c*w+p*k+m*M,t[7]=u*w+d*k+y*M,t[8]=s*A+f*T+g*S,t[9]=l*A+h*T+v*S,t[10]=c*A+p*T+m*S,t[11]=u*A+d*T+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],261:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t}},{}],262:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-f*n,t[3]=l*i-h*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+f*i,t[11]=l*n+h*i,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t}},{}],264:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],265:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*v+f*m+e[12],t[13]=i*g+l*v+h*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],266:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],267:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":248,\"gl-mat3/invert\":249,\"gl-mat4/invert\":256}],268:[function(t,e,r){arguments[4][233][0].apply(r,arguments)},{barycentric:62,dup:233,\"polytope-closest-point/lib/closest_point_2d.js\":467}],269:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision mediump float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(cookTorranceSpecular(L, V, N, roughness, fresnel), 0.);\\n  //float specular = max(beckmann(L, V, N, roughness), 0.); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5,0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),f=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),h=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor,1);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:h,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:395}],270:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,v,m,y,x,b,_,k,M,A,T,S){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=h,this.triangleUVs=f,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=M,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=T,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var M=k.prototype;function A(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function T(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function S(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}M.isOpaque=function(){return this.opacity>=1},M.isTransparent=function(){return this.opacity<1},M.pickSlots=1,M.setPickBase=function(t){this.pickId=t},M.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],v=i[f],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},M.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=f({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],h=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,A)),k||w||(w=s.vertexNormals(r,n,M));var T=t.vertexColors,S=t.cellColors,C=t.meshColor||[1,1,1,1],E=t.vertexUVs,L=t.vertexIntensity,z=t.cellUVs,O=t.cellIntensity,I=1/0,D=-1/0;if(!E&&!z)if(L)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var P=0;P<L.length;++P){var R=L[P];I=Math.min(I,R),D=Math.max(D,R)}else if(O)for(P=0;P<O.length;++P){R=O[P];I=Math.min(I,R),D=Math.max(D,R)}else for(P=0;P<n.length;++P){R=n[P][2];I=Math.min(I,R),D=Math.max(D,R)}this.intensity=L||(O?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,O):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var F=t.pointSizes,B=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(P=0;P<n.length;++P)for(var N=n[P],j=0;j<3;++j)!isNaN(N[j])&&isFinite(N[j])&&(this.bounds[0][j]=Math.min(this.bounds[0][j],N[j]),this.bounds[1][j]=Math.max(this.bounds[1][j],N[j]));var V=0,U=0,q=0;t:for(P=0;P<r.length;++P){var H=r[P];switch(H.length){case 1:for(N=n[W=H[0]],j=0;j<3;++j)if(isNaN(N[j])||!isFinite(N[j]))continue t;m.push(N[0],N[1],N[2]),3===(Y=T?T[W]:S?S[P]:C).length?y.push(Y[0],Y[1],Y[2],1):y.push(Y[0],Y[1],Y[2],Y[3]),X=E?E[W]:L?[(L[W]-I)/(D-I),0]:z?z[P]:O?[(O[P]-I)/(D-I),0]:[(N[2]-I)/(D-I),0],x.push(X[0],X[1]),F?b.push(F[W]):b.push(B),_.push(P),q+=1;break;case 2:for(j=0;j<2;++j){N=n[W=H[j]];for(var G=0;G<3;++G)if(isNaN(N[G])||!isFinite(N[G]))continue t}for(j=0;j<2;++j){N=n[W=H[j]];p.push(N[0],N[1],N[2]),3===(Y=T?T[W]:S?S[P]:C).length?d.push(Y[0],Y[1],Y[2],1):d.push(Y[0],Y[1],Y[2],Y[3]),X=E?E[W]:L?[(L[W]-I)/(D-I),0]:z?z[P]:O?[(O[P]-I)/(D-I),0]:[(N[2]-I)/(D-I),0],g.push(X[0],X[1]),v.push(P)}U+=1;break;case 3:for(j=0;j<3;++j)for(N=n[W=H[j]],G=0;G<3;++G)if(isNaN(N[G])||!isFinite(N[G]))continue t;for(j=0;j<3;++j){var W,Y,X,Z;N=n[W=H[2-j]];i.push(N[0],N[1],N[2]),3===(Y=T?T[W]:S?S[P]:C).length?a.push(Y[0],Y[1],Y[2],1):a.push(Y[0],Y[1],Y[2],Y[3]),X=E?E[W]:L?[(L[W]-I)/(D-I),0]:z?z[P]:O?[(O[P]-I)/(D-I),0]:[(N[2]-I)/(D-I),0],c.push(X[0],X[1]),Z=w?w[W]:k[P],l.push(Z[0],Z[1],Z[2]),h.push(P)}V+=1}}this.pointCount=q,this.edgeCount=U,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(h))}},M.drawTransparent=M.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},M.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},M.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},M.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=A(t),c=T(t),f=S(t),h=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),M=i(t),E=i(t),L=i(t),z=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:E,type:t.FLOAT,size:2}]),O=i(t),I=i(t),D=i(t),P=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:I,type:t.FLOAT,size:4},{buffer:D,type:t.FLOAT,size:2},{buffer:P,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,f,h,d,b,g,y,x,_,w,L,M,E,z,O,R,I,D,P,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":268,\"./lib/shaders\":269,colormap:115,\"gl-buffer\":231,\"gl-mat4/invert\":256,\"gl-mat4/multiply\":258,\"gl-shader\":290,\"gl-texture2d\":308,\"gl-vao\":313,ndarray:436,normals:439,\"simplicial-complex-contour\":496,\"typedarray-pool\":523}],271:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":274,\"gl-buffer\":231,\"gl-shader\":290}],272:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,f,h,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],f=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,h=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){f[0]=f[1]=0,f[g]=1,r.uniforms.dataAxis=f,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=h[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,f=this.ticks,h=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],M=p[w+2]-k,A=.5*(d[w+2]+d[w]),T=d[w+2]-d[w];e[w]=2*M/T,t[w]=2*(k-A)/T}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var C=s.tickMarkLength,E=s.tickMarkWidth,L=s.tickMarkColor,z=6*f[0].length,O=Math.min(a.ge(f[0],(d[0]-p[0])/(p[2]-p[0]),l),f[0].length),I=Math.min(a.gt(f[0],(d[2]-p[0])/(p[2]-p[0]),l),f[0].length),D=0+6*O,P=6*Math.max(0,I-O),R=Math.min(a.ge(f[1],(d[1]-p[1])/(p[3]-p[1]),l),f[1].length),F=Math.min(a.gt(f[1],(d[3]-p[1])/(p[3]-p[1]),l),f[1].length),B=z+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-C[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=C[1]*v/y,o[1]=E[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-C[0])/x-1,o[0]=E[0]*v/y,o[1]=C[0]*v/x,P&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,D,P)),i[0]=2*(g[2]+C[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=C[3]*v/y,o[1]=E[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+C[2])/x-1,o[0]=E[2]*v/y,o[1]=C[2]*v/x,P&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,D,P))}}(),d.update=(h=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],f=0;f<l.length;++f){var d=(l[f].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=h[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":274,\"binary-search-bounds\":276,\"gl-buffer\":231,\"gl-shader\":290}],273:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":274,\"gl-buffer\":231,\"gl-shader\":290}],274:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:395}],275:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,f,h,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],f=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,h=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],M=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(h[2+t]-h[t])-1;var T=2/h[2+(1^t)]-h[1^t];u[1^t]=T*s[1^t]-1,d[t]&&(u[1^t]-=T*p*g[t],M<A&&i[A]>i[M]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[M],i[A]-i[M]))),y[t]&&k&&(u[1^t]-=T*p*x[t],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=T*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=T*p*g[t+2],M<A&&i[A]>i[M]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[M],i[A]-i[M]))),y[t+2]&&k&&(u[1^t]+=T*p*x[t+2],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(h=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],f=a[o],g=a[o+2]-f,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,h[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=h,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],f=[-1/0],h=l[o];for(e=0;e<h.length;++e){var p=h[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),f.push(d)}this.tickOffset[o]=u,this.tickX[o]=f}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":274,\"binary-search-bounds\":276,\"gl-buffer\":231,\"gl-shader\":290,\"text-cache\":514}],276:[function(t,e,r){arguments[4][100][0].apply(r,arguments)},{dup:100}],277:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function f(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var f=this.zeroLineEnable,h=this.zeroLineColor,p=this.zeroLineWidth;if(f[0]||f[1]){o.bind();for(var d=0;d<2;++d)if(f[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],h[d]):o.drawLine(e[0],g,e[2],g,p[d],h[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var f=c[u].pick(a,o,l);if(f)return f}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(f),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":271,\"./lib/grid\":272,\"./lib/line\":273,\"./lib/text\":275,\"gl-select-static\":289}],278:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":290,glslify:395}],279:[function(t,e,r){\"use strict\";e.exports=function(t){var e=!1,r=((t=t||{}).pixelRatio||parseFloat(window.devicePixelRatio),t.canvas);if(!r)if(r=document.createElement(\"canvas\"),t.container){var m=t.container;m.appendChild(r)}else document.body.appendChild(r);var y=t.gl;y||(y=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(r,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:p}));if(!y)throw new Error(\"webgl not supported\");var x=t.bounds||[[-10,-10,-10],[10,10,10]],b=new d,_=l(y,[y.drawingBufferWidth,y.drawingBufferHeight],{preferFloat:!p}),w=h(y),k=t.camera||{eye:[2,0,0],center:[0,0,0],up:[0,1,0],zoomMin:.1,zoomMax:100,mode:\"turntable\"},M=t.axes||{},A=i(y,M);A.enable=!M.disable;var T=t.spikes||{},S=o(y,T),C=[],E=[],L=[],z=[],O=!0,I=!0,D=new Array(16),P=new Array(16),R={view:null,projection:D,model:P},I=!0,F=[y.drawingBufferWidth,y.drawingBufferHeight],B={gl:y,contextLost:!1,pixelRatio:t.pixelRatio||parseFloat(window.devicePixelRatio),canvas:r,selection:b,camera:n(r,k),axes:A,axesPixels:null,spikes:S,bounds:x,objects:C,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null},N=[y.drawingBufferWidth/B.pixelRatio|0,y.drawingBufferHeight/B.pixelRatio|0];function j(){if(!e&&B.autoResize){var t=r.parentNode,n=1,i=1;t&&t!==document.body?(n=t.clientWidth,i=t.clientHeight):(n=window.innerWidth,i=window.innerHeight);var a=0|Math.ceil(n*B.pixelRatio),o=0|Math.ceil(i*B.pixelRatio);if(a!==r.width||o!==r.height){r.width=a,r.height=o;var s=r.style;s.position=s.position||\"absolute\",s.left=\"0px\",s.top=\"0px\",s.width=n+\"px\",s.height=i+\"px\",O=!0}}}B.autoResize&&j();function V(){for(var t=C.length,e=z.length,r=0;r<e;++r)L[r]=0;t:for(var r=0;r<t;++r){var n=C[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(L[a]+i<255){E[r]=a,n.setPickBase(L[a]+1),L[a]+=i;continue t}var o=s(y,F);E[r]=e,z.push(o),L.push(i),n.setPickBase(1),e+=1}else E[r]=-1}for(;e>0&&0===L[e-1];)L.pop(),z.pop().dispose()}window.addEventListener(\"resize\",j),B.update=function(t){e||(t=t||{},O=!0,I=!0)},B.add=function(t){e||(t.axes=A,C.push(t),E.push(-1),O=!0,I=!0,V())},B.remove=function(t){if(!e){var r=C.indexOf(t);r<0||(C.splice(r,1),E.pop(),O=!0,I=!0,V())}},B.dispose=function(){if(!e&&(e=!0,window.removeEventListener(\"resize\",j),r.removeEventListener(\"webglcontextlost\",H),B.mouseListener.enabled=!1,!B.contextLost)){A.dispose(),S.dispose();for(var t=0;t<C.length;++t)C[t].dispose();_.dispose();for(var t=0;t<z.length;++t)z[t].dispose();w.dispose(),y=null,A=null,S=null,C=[]}};var U=!1,q=0;function H(){if(B.contextLost)return!0;y.isContextLost()&&(B.contextLost=!0,B.mouseListener.enabled=!1,B.selection.object=null,B.oncontextloss&&B.oncontextloss())}B.mouseListener=u(r,function(t,r,n){if(!e){var i=z.length,a=C.length,o=b.object;b.distance=1/0,b.mouse[0]=r,b.mouse[1]=n,b.object=null,b.screen=null,b.dataCoordinate=b.dataPosition=null;var s=!1;if(t&&q)U=!0;else{U&&(I=!0),U=!1;for(var l=0;l<i;++l){var c=z[l].query(r,N[1]-n-1,B.pickRadius);if(c){if(c.distance>b.distance)continue;for(var u=0;u<a;++u){var f=C[u];if(E[u]===l){var h=f.pick(c);h&&(b.buttons=t,b.screen=c.coord,b.distance=c.distance,b.object=f,b.index=h.distance,b.dataPosition=h.position,b.dataCoordinate=h.dataCoordinate,b.data=h,s=!0)}}}}}o&&o!==b.object&&(o.highlight&&o.highlight(null),O=!0),b.object&&(b.object.highlight&&b.object.highlight(b.data),O=!0),(s=s||b.object!==o)&&B.onselect&&B.onselect(b),1&t&&!(1&q)&&B.onclick&&B.onclick(b),q=t}}),r.addEventListener(\"webglcontextlost\",H);var G=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[G[0].slice(),G[1].slice()];function Y(){if(!H()){j();var t=B.camera.tick();R.view=B.camera.matrix,O=O||t,I=I||t,A.pixelRatio=B.pixelRatio,S.pixelRatio=B.pixelRatio;var e=C.length,r=G[0],n=G[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=C[i];o.pixelRatio=B.pixelRatio,o.axes=B.axes,O=O||!!o.dirty,I=I||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var p=B.bounds;if(B.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var d=.05*(n[h]-r[h]);r[h]=r[h]-d,n[h]=n[h]+d}p[0][h]=r[h],p[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==p[0][h]||W[1][h]!==p[1][h],W[0][h]=p[0][h],W[1][h]=p[1][h];if(I=I||v,O=O||v){if(v){for(var m=[0,0,0],i=0;i<3;++i)m[i]=g((p[1][i]-p[0][i])/10);A.autoTicks?A.update({bounds:p,tickSpacing:m}):A.update({bounds:p})}var x=y.drawingBufferWidth,k=y.drawingBufferHeight;F[0]=x,F[1]=k,N[0]=0|Math.max(x/B.pixelRatio,1),N[1]=0|Math.max(k/B.pixelRatio,1),f(D,B.fovy,x/k,B.zNear,B.zFar);for(var i=0;i<16;++i)P[i]=0;P[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,p[1][i]-p[0][i]);for(var i=0;i<3;++i)B.autoScale?P[5*i]=B.aspect[i]/(p[1][i]-p[0][i]):P[5*i]=1/M,B.autoCenter&&(P[12+i]=.5*-P[5*i]*(p[0][i]+p[1][i]));for(var i=0;i<e;++i){var o=C[i];o.axesBounds=p,B.clipToBounds&&(o.clipBounds=p)}b.object&&(B.snapToData?S.position=b.dataCoordinate:S.position=b.dataPosition,S.bounds=p),I&&(I=!1,function(){if(H())return;y.colorMask(!0,!0,!0,!0),y.depthMask(!0),y.disable(y.BLEND),y.enable(y.DEPTH_TEST);for(var t=C.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=N,n.begin();for(var i=0;i<t;++i)if(E[i]===r){var a=C[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(R))}n.end()}}()),B.axesPixels=a(B.axes,R,x,k),B.onrender&&B.onrender(),y.bindFramebuffer(y.FRAMEBUFFER,null),y.viewport(0,0,x,k);var T=B.clearColor;y.clearColor(T[0],T[1],T[2],T[3]),y.clear(y.COLOR_BUFFER_BIT|y.DEPTH_BUFFER_BIT),y.depthMask(!0),y.colorMask(!0,!0,!0,!0),y.enable(y.DEPTH_TEST),y.depthFunc(y.LEQUAL),y.disable(y.BLEND),y.disable(y.CULL_FACE);var L=!1;A.enable&&(L=L||A.isTransparent(),A.draw(R)),S.axes=A,b.object&&S.draw(R),y.disable(y.CULL_FACE);for(var i=0;i<e;++i){var o=C[i];o.axes=A,o.pixelRatio=B.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(R),o.isTransparent&&o.isTransparent()&&(L=!0)}if(L){_.shape=F,_.bind(),y.clear(y.DEPTH_BUFFER_BIT),y.colorMask(!1,!1,!1,!1),y.depthMask(!0),y.depthFunc(y.LESS),A.enable&&A.isTransparent()&&A.drawTransparent(R);for(var i=0;i<e;++i){var o=C[i];o.isOpaque&&o.isOpaque()&&o.draw(R)}y.enable(y.BLEND),y.blendEquation(y.FUNC_ADD),y.blendFunc(y.ONE,y.ONE_MINUS_SRC_ALPHA),y.colorMask(!0,!0,!0,!0),y.depthMask(!1),y.clearColor(0,0,0,0),y.clear(y.COLOR_BUFFER_BIT),A.isTransparent()&&A.drawTransparent(R);for(var i=0;i<e;++i){var o=C[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(R)}y.bindFramebuffer(y.FRAMEBUFFER,null),y.blendFunc(y.ONE,y.ONE_MINUS_SRC_ALPHA),y.disable(y.DEPTH_TEST),w.bind(),_.color[0].bind(0),w.uniforms.accumBuffer=0,c(y),y.disable(y.BLEND)}O=!1;for(var i=0;i<e;++i)C[i].dirty=!1}}}return function t(){e||B.contextLost||(Y(),requestAnimationFrame(t))}(),B.redraw=function(){e||(O=!0,Y())},B};var n=t(\"3d-view-controls\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),f=t(\"gl-mat4/perspective\"),h=t(\"./lib/shader\"),p=t(\"is-mobile\")({tablet:!0});function d(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function g(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}},{\"./lib/shader\":278,\"3d-view-controls\":45,\"a-big-triangle\":48,\"gl-axes3d\":223,\"gl-axes3d/properties\":230,\"gl-fbo\":240,\"gl-mat4/perspective\":259,\"gl-select-static\":289,\"gl-spikes3d\":299,\"is-mobile\":406,\"mouse-change\":421}],280:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:395}],281:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),f=new s(t,a,l,c,u);return f.update(e),t.addObject(f),f};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var f=n.getParameter(n.BLEND),h=n.getParameter(n.DITHER);return f&&!this.blend&&n.disable(n.BLEND),h&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),f&&!this.blend&&n.enable(n.BLEND),h&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":280,\"gl-buffer\":231,\"gl-shader\":290,\"typedarray-pool\":523}],282:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],f=e[2],h=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+f*g+h*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*f+l*g,t[3]=s*h+l*v,t}},{}],283:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],284:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e){var r=i[e];r||(r=i[e]={});if(t in r)return r[t];var a={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},o=n(t,a);a.triangles=!1;for(var s=n(t,a),l=[[1/0,1/0],[-1/0,-1/0]],c=s.positions.length,u=0;u<c;++u)for(var f=s.positions[u],h=0;h<2;++h)l[0][h]=Math.min(l[0][h],f[h]),l[1][h]=Math.max(l[1][h],f[h]);return r[t]=[o,s,l]};var i={}},{\"vectorize-text\":528}],285:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],f={vertex:a,fragment:l,attributes:u},h={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,f)},r.createOrtho=function(t){return m(t,h)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":290,glslify:395}],286:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return h(n,n),h(n,n),h(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),f=i(e),h=i(e),p=i(e),d=i(e),g=a(e,[{buffer:f,size:3,type:e.FLOAT},{buffer:h,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new m(e,r,n,o,f,h,p,d,g,s,c,u);return v.update(t),v};var g=1;function v(t){return!0===t?g:t>g?g:t}function m(t,e,r,n,i,a,o,s,l,c,u,f){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=g,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[g,g,g],this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=f,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}var y=m.prototype;y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.isTransparent=function(){if(this.opacity<g)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectOpacity[t]<g)return!0;return!1},y.isOpaque=function(){if(this.opacity>=g)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectOpacity[t]>=g)return!0;return!1};var x=[0,0],b=[0,0,0],_=[0,0,0],w=[0,0,0,1],k=[0,0,0,1],M=f.slice(),A=[0,0,0],T=[[0,0,0],[0,0,0]];function S(t){return t[0]=t[1]=t[2]=0,t}function C(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function L(t,e,r){var n,i=e.axesProject,a=e.gl,o=t.uniforms,l=r.model||f,c=r.view||f,u=r.projection||f,h=e.axesBounds,d=function(t){for(var e=T,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);n=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],x[0]=2/a.drawingBufferWidth,x[1]=2/a.drawingBufferHeight,t.bind(),o.view=c,o.projection=u,o.screenSize=x,o.highlightId=e.highlightId,o.highlightScale=e.highlightScale,o.clipBounds=d,o.pickGroup=e.pickId/255,o.pixelRatio=e.pixelRatio;for(var g=0;g<3;++g)if(i[g]){o.scale=e.projectScale[g],o.opacity=e.projectOpacity[g];for(var v=M,m=0;m<16;++m)v[m]=0;for(m=0;m<4;++m)v[5*m]=1;v[5*g]=0,n[g]<0?v[12+g]=h[0][g]:v[12+g]=h[1][g],s(v,l,v),o.model=v;var y=(g+1)%3,L=(g+2)%3,z=S(b),O=S(_);z[y]=1,O[L]=1;var I=p(0,0,0,C(w,z)),D=p(0,0,0,C(k,O));if(Math.abs(I[1])>Math.abs(D[1])){var P=I;I=D,D=P,P=z,z=O,O=P;var R=y;y=L,L=R}I[0]<0&&(z[y]=-1),D[1]>0&&(O[L]=-1);var F=0,B=0;for(m=0;m<4;++m)F+=Math.pow(l[4*y+m],2),B+=Math.pow(l[4*L+m],2);z[y]/=Math.sqrt(F),O[L]/=Math.sqrt(B),o.axes[0]=z,o.axes[1]=O,o.fragClipBounds[0]=E(A,d[0],g,-1e8),o.fragClipBounds[1]=E(A,d[1],g,1e8),e.vao.bind(),e.vao.draw(a.TRIANGLES,e.vertexCount),e.lineWidth>0&&(a.lineWidth(e.lineWidth),e.vao.draw(a.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var z=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function O(t,e,r,n,i,a){var o=r.gl;if((i===r.projectOpacity<g||a)&&L(e,r,n),i===r.opacity<g||a){t.bind();var s=t.uniforms;s.model=n.model||f,s.view=n.view||f,s.projection=n.projection||f,x[0]=2/o.drawingBufferWidth,x[1]=2/o.drawingBufferHeight,s.screenSize=x,s.highlightId=r.highlightId,s.highlightScale=r.highlightScale,s.fragClipBounds=z,s.clipBounds=r.axes.bounds,s.opacity=r.opacity,s.pickGroup=r.pickId/255,s.pixelRatio=r.pixelRatio,r.vao.bind(),r.vao.draw(o.TRIANGLES,r.vertexCount),r.lineWidth>0&&(o.lineWidth(r.lineWidth),r.vao.draw(o.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function I(t,e,r){var i;i=Array.isArray(t)?e<t.length?t[e]:void 0:t,i=u(i);var a=!0;n(i)&&(i=\"\\u25bc\",a=!1);var o=c(i,r);return{mesh:o[0],lines:o[1],bounds:o[2],visible:a}}y.draw=function(t){O(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,!1,!1)},y.drawTransparent=function(t){O(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,!0,!1)},y.drawPick=function(t){O(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,!0,!0)},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},y.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},y.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=v(this.projectOpacity[n])}\"opacity\"in t&&(this.opacity=v(t.opacity)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],f=[-1/0,-1/0,-1/0],h=t.glyph,p=t.color,d=t.size,g=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var M=(N=I(h,n,l)).mesh,A=N.lines,T=N.bounds;x+=3*M.cells.length,b+=2*A.edges.length}}var S=x+b,C=o.mallocFloat(3*S),E=o.mallocFloat(4*S),L=o.mallocFloat(2*S),z=o.mallocUint32(S);if(S>0){var O=0,D=x,P=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;f[k]=Math.max(f[k],w[k]),u[k]=Math.min(u[k],w[k])}M=(N=I(h,n,l)).mesh,A=N.lines,T=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(V=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)P[k]=V[k];P[3]=1}else if(4===V.length)for(k=0;k<4;++k)P[k]=V[k]}else P[0]=P[1]=P[2]=0,P[3]=1;else P=[1,1,1,0];if(j)if(Array.isArray(m)){var V;if(3===(V=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=V[k];R[k]=1}else if(4===V.length)for(k=0;k<4;++k)R[k]=V[k]}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var U=.5;j?Array.isArray(d)?U=n<d.length?+d[n]:12:d?U=+d:this.useOrtho&&(U=12):U=0;var q=0;Array.isArray(g)?q=n<g.length?+g[n]:0:g&&(q=+g);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)f[k]=Math.max(f[k],w[k]),u[k]=Math.min(u[k],w[k]);var W=i,Y=a;W=0;Array.isArray(i)?W=n<i.length?i[n]:0:i&&(W=i);Y=0;Array.isArray(a)?Y=n<a.length?a[n]:0:a&&(Y=a);var X=[W*=W>0?1-T[0][0]:W<0?1+T[1][0]:1,Y*=Y>0?1-T[0][1]:Y<0?1+T[1][1]:1],Z=M.cells||[],$=M.positions||[];for(k=0;k<Z.length;++k)for(var J=Z[k],K=0;K<3;++K){for(var Q=0;Q<3;++Q)C[3*O+Q]=w[Q];for(Q=0;Q<4;++Q)E[4*O+Q]=P[Q];z[O]=y;var tt=$[J[K]];L[2*O]=U*(H*tt[0]-G*tt[1]+X[0]),L[2*O+1]=U*(G*tt[0]+H*tt[1]+X[1]),O+=1}for(Z=A.edges,$=A.positions,k=0;k<Z.length;++k)for(J=Z[k],K=0;K<2;++K){for(Q=0;Q<3;++Q)C[3*D+Q]=w[Q];for(Q=0;Q<4;++Q)E[4*D+Q]=R[Q];z[D]=y;tt=$[J[K]];L[2*D]=U*(H*tt[0]-G*tt[1]+X[0]),L[2*D+1]=U*(G*tt[0]+H*tt[1]+X[1]),D+=1}}}this.bounds=[u,f],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(C),this.colorBuffer.update(E),this.glyphBuffer.update(L),this.idBuffer.update(z),o.free(C),o.free(E),o.free(L),o.free(z)},y.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":283,\"./lib/glyphs\":284,\"./lib/shaders\":285,\"gl-buffer\":231,\"gl-mat4/multiply\":258,\"gl-vao\":313,\"is-string-blank\":409,\"typedarray-pool\":523}],287:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:395}],288:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,f=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],h=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(f=Math.max(f,c[0]),h=Math.max(h,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<f||d<h)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,h,i),o.drawBox(0,h,f,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,h,g,d,i)),this.innerFill&&o.drawBox(f,h,p,d,n),r>0){var m=r*u;o.drawBox(f-m,h-m,p+m,h+m,a),o.drawBox(f-m,d-m,p+m,d+m,a),o.drawBox(f-m,h-m,f+m,d+m,a),o.drawBox(p-m,h-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":287,\"gl-buffer\":231,\"gl-shader\":290}],289:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var f=[o-i,u-c],h=a(this.buffer,[f[0],f[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(h.hi(f[0],f[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,h.get(d,g,0),[h.get(d,g,1),h.get(d,g,2),h.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":81,\"cwise/lib/wrapper\":138,\"gl-fbo\":240,ndarray:436,\"typedarray-pool\":523}],290:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function f(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var h=this,p=h.gl,d=h._vref;h._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),h.vertShader=h._vref.shader;var g=this._fref;if(h._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),h.fragShader=h._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,h.fragShader),p.attachShader(v,h.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(f);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),M=new Array(k),A=0;A<k;++A)M[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:M})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var T=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(T)>=0;)T+=1;_[y]=T}var S=new Array(r.length);function C(){h.program=o.program(p,h._vref,h._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(h.program,r[t].name)}C(),h._relink=C,h.types={uniforms:a(r),attributes:a(c)},h.attributes=i(p,h,x,_),Object.defineProperty(h,\"uniforms\",n(p,h,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":291,\"./lib/create-attributes\":292,\"./lib/create-uniforms\":293,\"./lib/reflect\":294,\"./lib/runtime-reflect\":295,\"./lib/shader-cache\":296}],291:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],292:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],f=u.name,h=u.type,p=u.locations;switch(h){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,f);break;default:if(h.indexOf(\"vec\")>=0){var d=h.charCodeAt(h.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);o(t,e,p[0],i,d,a,f)}else{if(!(h.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+f+\": \"+h);var d=h.charCodeAt(h.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);s(t,e,p,i,d,a,f)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var f=Function.apply(null,l),h=new i(t,e,r,n,a,f);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),f(t,n[r],e),e},get:function(){return h},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var f=new Array(i),h=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))h.call(t,o,e[a]);else{for(var s=0;s<i;++s)f[s]=e[i*a+s];h.call(t,o,f)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":291}],293:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var f=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return f(t,s)}function u(n,l,u){if(\"object\"==typeof u){var h=f(u);Object.defineProperty(n,l,{get:a(h),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function f(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var h=n(r,!0);return{get:a(f(h)),set:c(h),enumerable:!0,configurable:!0}}},{\"./GLError\":291,\"./reflect\":294}],294:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],295:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],296:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":291,\"gl-format-compiler-error\":241,\"weakmap-shim\":533}],297:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":290,glslify:395}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var f=new s(t,l,c,u);return f.update(e),f};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],f=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var h=c,p=u,d=0;d<3;++d)i&&i[d]<0?(h[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(h[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);f[0]=e.drawingBufferWidth,f[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,h,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=f;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":298,\"gl-buffer\":231,\"gl-vao\":313}],300:[function(t,e,r){arguments[4][233][0].apply(r,arguments)},{barycentric:62,dup:233,\"polytope-closest-point/lib/closest_point_2d.js\":467}],301:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nfloat inverse(float m) {\\n  return 1.0 / m;\\n}\\n\\nmat2 inverse(mat2 m) {\\n  return mat2(m[1][1],-m[0][1],\\n             -m[1][0], m[0][0]) / (m[0][0]*m[1][1] - m[0][1]*m[1][0]);\\n}\\n\\nmat3 inverse(mat3 m) {\\n  float a00 = m[0][0], a01 = m[0][1], a02 = m[0][2];\\n  float a10 = m[1][0], a11 = m[1][1], a12 = m[1][2];\\n  float a20 = m[2][0], a21 = m[2][1], a22 = m[2][2];\\n\\n  float b01 = a22 * a11 - a12 * a21;\\n  float b11 = -a22 * a10 + a12 * a20;\\n  float b21 = a21 * a10 - a11 * a20;\\n\\n  float det = a00 * b01 + a01 * b11 + a02 * b21;\\n\\n  return mat3(b01, (-a22 * a01 + a02 * a21), (a12 * a01 - a02 * a11),\\n              b11, (a22 * a00 - a02 * a20), (-a12 * a00 + a02 * a10),\\n              b21, (-a21 * a00 + a01 * a20), (a11 * a00 - a01 * a10)) / det;\\n}\\n\\nmat4 inverse(mat4 m) {\\n  float\\n      a00 = m[0][0], a01 = m[0][1], a02 = m[0][2], a03 = m[0][3],\\n      a10 = m[1][0], a11 = m[1][1], a12 = m[1][2], a13 = m[1][3],\\n      a20 = m[2][0], a21 = m[2][1], a22 = m[2][2], a23 = m[2][3],\\n      a30 = m[3][0], a31 = m[3][1], a32 = m[3][2], a33 = m[3][3],\\n\\n      b00 = a00 * a11 - a01 * a10,\\n      b01 = a00 * a12 - a02 * a10,\\n      b02 = a00 * a13 - a03 * a10,\\n      b03 = a01 * a12 - a02 * a11,\\n      b04 = a01 * a13 - a03 * a11,\\n      b05 = a02 * a13 - a03 * a12,\\n      b06 = a20 * a31 - a21 * a30,\\n      b07 = a20 * a32 - a22 * a30,\\n      b08 = a20 * a33 - a23 * a30,\\n      b09 = a21 * a32 - a22 * a31,\\n      b10 = a21 * a33 - a23 * a31,\\n      b11 = a22 * a33 - a23 * a32,\\n\\n      det = b00 * b11 - b01 * b10 + b02 * b09 + b03 * b08 - b04 * b07 + b05 * b06;\\n\\n  return mat4(\\n      a11 * b11 - a12 * b10 + a13 * b09,\\n      a02 * b10 - a01 * b11 - a03 * b09,\\n      a31 * b05 - a32 * b04 + a33 * b03,\\n      a22 * b04 - a21 * b05 - a23 * b03,\\n      a12 * b08 - a10 * b11 - a13 * b07,\\n      a00 * b11 - a02 * b08 + a03 * b07,\\n      a32 * b02 - a30 * b05 - a33 * b01,\\n      a20 * b05 - a22 * b02 + a23 * b01,\\n      a10 * b10 - a11 * b08 + a13 * b06,\\n      a01 * b08 - a00 * b10 - a03 * b06,\\n      a30 * b04 - a31 * b02 + a33 * b00,\\n      a21 * b02 - a20 * b04 - a23 * b00,\\n      a11 * b07 - a10 * b09 - a12 * b06,\\n      a00 * b09 - a01 * b07 + a02 * b06,\\n      a31 * b01 - a30 * b03 - a32 * b00,\\n      a20 * b03 - a21 * b01 + a22 * b00) / det;\\n}\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  normal = normalize(normal * inverse(mat3(model)));\\n\\n  gl_Position      = projection * view * tubePosition;\\n  f_color          = color;\\n  f_normal         = normal;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_eyeDirection   = eyePosition   - tubePosition.xyz;\\n  f_lightDirection = lightPosition - tubePosition.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(!gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = cookTorranceSpecular(L, V, N, roughness, fresnel);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor =  texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:395}],302:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=(t(\"./closest-point\"),d.meshShader),v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,v,y,x,b,_,w,k,M,A,T,S,C){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleVectors=c,this.triangleColors=f,this.triangleNormals=p,this.triangleUVs=h,this.triangleIds=u,this.triangleVAO=d,this.triangleCount=0,this.lineWidth=1,this.edgePositions=g,this.edgeColors=y,this.edgeUVs=x,this.edgeIds=v,this.edgeVAO=b,this.edgeCount=0,this.pointPositions=_,this.pointColors=k,this.pointUVs=M,this.pointSizes=A,this.pointIds=w,this.pointVAO=T,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=S,this.contourVAO=C,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],v=i[f],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=f({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],h=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var M=t.vertexNormals,A=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||M||(M=s.vertexNormals(r,n,T));var C=t.vertexColors,E=t.cellColors,L=t.meshColor||[1,1,1,1],z=t.vertexUVs,O=t.vertexIntensity,I=t.cellUVs,D=t.cellIntensity,P=1/0,R=-1/0;if(!z&&!I)if(O)if(t.vertexIntensityBounds)P=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];P=Math.min(P,B),R=Math.max(R,B)}else if(D)for(F=0;F<D.length;++F){B=D[F];P=Math.min(P,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];P=Math.min(P,B),R=Math.max(R,B)}this.intensity=O||(D?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,D):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var V=n[F],U=0;U<3;++U)!isNaN(V[U])&&isFinite(V[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],V[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],V[U]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var W=r[F];switch(W.length){case 1:for(V=n[X=W[0]],U=0;U<3;++U)if(isNaN(V[U])||!isFinite(V[U]))continue t;x.push(V[0],V[1],V[2],V[3]),3===(Z=C?C[X]:E?E[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),$=z?z[X]:O?[(O[X]-P)/(R-P),0]:I?I[F]:D?[(D[F]-P)/(R-P),0]:[(V[2]-P)/(R-P),0],_.push($[0],$[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(U=0;U<2;++U){V=n[X=W[U]];for(var Y=0;Y<3;++Y)if(isNaN(V[Y])||!isFinite(V[Y]))continue t}for(U=0;U<2;++U){V=n[X=W[U]];g.push(V[0],V[1],V[2]),3===(Z=C?C[X]:E?E[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),$=z?z[X]:O?[(O[X]-P)/(R-P),0]:I?I[F]:D?[(D[F]-P)/(R-P),0]:[(V[2]-P)/(R-P),0],m.push($[0],$[1]),y.push(F)}H+=1;break;case 3:for(U=0;U<3;++U)for(V=n[X=W[U]],Y=0;Y<3;++Y)if(isNaN(V[Y])||!isFinite(V[Y]))continue t;for(U=0;U<3;++U){var X;V=n[X=W[U]];a.push(V[0],V[1],V[2],V[3]);var Z,$,J,K=i[X];l.push(K[0],K[1],K[2],K[3]),3===(Z=C?C[X]:E?E[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),$=z?z[X]:O?[(O[X]-P)/(R-P),0]:I?I[F]:D?[(D[F]-P)/(R-P),0]:[(V[2]-P)/(R-P),0],p.push($[0],$[1]),J=M?M[X]:A[F],h.push(J[0],J[1],J[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(h),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),f=i(t),h=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:h,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:f,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),T=i(t),S=i(t),C=i(t),E=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:E,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:C,type:t.FLOAT,size:1}]),z=i(t),O=new y(t,l,r,null,null,s,null,null,c,f,v,h,p,d,m,x,k,_,w,M,A,E,T,S,C,L,z,a(t,[{buffer:z,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./closest-point\":300,\"./shaders\":301,colormap:115,\"gl-buffer\":231,\"gl-mat4/invert\":256,\"gl-mat4/multiply\":258,\"gl-shader\":290,\"gl-texture2d\":308,\"gl-vao\":313,ndarray:436,normals:439,\"simplicial-complex-contour\":496,\"typedarray-pool\":523}],303:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var f=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,f=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var h=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=f[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var M=(k+1)%8;h.push(g[k],v[k],v[M],v[M],g[M],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([h.length-6,h.length-5,h.length-4],[h.length-3,h.length-2,h.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:h,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),h=[],p=[],d=[],g=[];for(s=0;s<f.length;s++){var v=f[s],m=h.length;h=h.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:h,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return h(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),f=function(t,e,r){return t<e?e:t>r?r:t},h=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],h=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=f(g,0,h-1),y=f(y,0,h-1),v=f(v,0,p-1),x=f(x,0,p-1),m=f(m,0,d-1),b=f(b,0,d-1)),g<0||v<0||m<0||y>=h||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var M=m*h*p,A=b*h*p,T=v*h,S=x*h,C=g,E=y,L=e[T+M+C],z=e[T+M+E],O=e[S+M+C],I=e[S+M+E],D=e[T+A+C],P=e[T+A+E],R=e[S+A+C],F=e[S+A+E],B=n.create();return n.lerp(B,L,z,_),n.lerp(c,O,I,_),n.lerp(B,B,c,w),n.lerp(c,D,P,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],f=e[0][0],h=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=f&&r<=g&&n>=h&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],f=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[f]||(n.push(f),o[f]=!0)}var h=p(e),d=p(r),g=p(n),v=Math.min(h,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var M=n.create();n.copy(M,r[k]);var A=[M],T=[],S=t.getVelocity(M),C=M;T.push(S);var E=[],L=t.getDivergence(M,S);(D=n.length(L))>w&&!isNaN(D)&&isFinite(D)&&(w=D),E.push(D),u.push({points:A,velocities:T,divergences:E});for(var z=0;z<100*i&&A.length<i&&y(0,M);){z++;var O=n.clone(S),I=n.squaredLength(O);if(0===I)break;if(I>b&&n.scale(O,O,x/Math.sqrt(I)),n.add(O,O,M),S=t.getVelocity(O),n.squaredDistance(C,O)-b>-1e-4*b){A.push(O),C=O,T.push(S);L=t.getDivergence(O,S);(D=n.length(L))>w&&!isNaN(D)&&isFinite(D)&&(w=D),E.push(D)}M=O}}for(k=0;k<E.length;k++){var D=E[k];!isNaN(D)&&isFinite(D)||(E[k]=w)}var P=a(u,t.colormap,w,_);return c?P.tubeScale=c:(0===w&&(w=1),P.tubeScale=.5*l*_/w),P},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":302,\"gl-vec3\":332,\"gl-vec4\":368}],304:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":290,glslify:395}],305:[function(t,e,r){arguments[4][100][0].apply(r,arguments)},{dup:100}],306:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),f=i(e),h=a(e,[{buffer:f,size:4,stride:20,offset:0},{buffer:f,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new C(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,f,h,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),f=t(\"ndarray\"),h=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],M=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function T(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function C(t,e,r,n,i,a,o,l,c,u,h,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=h,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new T([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var E=C.prototype;E.isTransparent=function(){return this.opacity<1},E.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},E.pickSlots=1,E.setPickBase=function(t){this.pickId=t};var L=[0,0,0],z={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=z.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=z.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return z.showSurface=o,z.showContour=s,z}var I={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},D=k.slice(),P=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=I;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=P,n.vertexColor=this.vertexColor;var s=D;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var f=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,f.bind(),f.uniforms=n;var h=this._contourVAO;for(h.bind(),i=0;i<3;++i)for(f.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(f.uniforms.contourColor=this.highlightColor[i],f.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(f.uniforms.contourColor=this.contourColor[i],f.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(f.uniforms.height=this.contourLevels[i][o],h.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(f.uniforms.model=u.projections[i],f.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){f.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(f.uniforms.contourColor=this.highlightColor[o],f.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(f.uniforms.contourColor=this.contourColor[o],f.uniforms.contourTint=this.contourTint[o]),f.uniforms.height=this.contourLevels[o][g],h.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g])}for(h.unbind(),(h=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(f.uniforms.model=n.model,f.uniforms.clipBounds=n.clipBounds,f.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]),f.uniforms.contourColor=this.dynamicColor[i],f.uniforms.contourTint=this.dynamicTint[i],f.uniforms.height=this.dynamicLevel[i],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(f.uniforms.model=u.projections[o],f.uniforms.clipBounds=u.clipBounds[o],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));h.unbind()}}E.draw=function(t){return R.call(this,t,!1)},E.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}E.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=P;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},E.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var f=u?a:1-a,h=0;h<2;++h)for(var p=i+u,d=s+h,v=f*(h?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},E.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},E.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=f(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=f(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=f(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=f(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=f(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),T=w.get(0,o,b,1),C=w.get(1,o,b,0),E=w.get(1,o,b,1),L=w.get(2,o,b,0),z=w.get(2,o,b,1),O=C*z-E*L,I=L*T-z*A,D=A*E-T*C,P=Math.sqrt(O*O+I*I+D*D);P<1e-8?(P=Math.max(Math.abs(O),Math.abs(I),Math.abs(D)))<1e-8?(D=1,I=O=0,P=1):P=1/P:P=1/Math.sqrt(P),k.set(o,b,0,O*P),k.set(o,b,1,I*P),k.set(o,b,2,D*P)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,V=-1/0,U=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*U)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var W=0;W<2;++W)for(var Y=0;Y<2;++Y)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+W,1+b+Y);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var $=o+M[X][0],J=b+M[X][1],K=this._field[0].get($+1,J+1),Q=this._field[1].get($+1,J+1);Z=this._field[2].get($+1,J+1),O=k.get($+1,J+1,0),I=k.get($+1,J+1,1),D=k.get($+1,J+1,2),t.intensity&&(tt=t.intensity.get($,J));var tt=t.intensity?t.intensity.get($,J):Z+this.objectOffset[2];q[H++]=$,q[H++]=J,q[H++]=K,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=I,q[H++]=D,R[0]=Math.min(R[0],K+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],K+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),V=Math.max(V,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],V=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(V-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===V||(r=!0),this.intensityBounds=[N,V]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et.sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){et=this.contourLevels[nt];var it=[],at=[],ot=[0,0,0];for(o=0;o<et.length;++o){var st=h(this._field[nt],et[o]);it.push(rt.length/5|0),G=0;t:for(b=0;b<st.cells.length;++b){var lt=st.cells[b];for(X=0;X<2;++X){var ct=st.positions[lt[X]],ut=ct[0],ft=0|Math.floor(ut),ht=ut-ft,pt=ct[1],dt=0|Math.floor(pt),gt=pt-dt,vt=!1;e:for(var mt=0;mt<3;++mt){ot[mt]=0;var yt=(nt+mt+1)%3;for(W=0;W<2;++W){var xt=W?ht:1-ht;for($=0|Math.min(Math.max(ft+W,0),a[0]),Y=0;Y<2;++Y){var bt=Y?gt:1-gt;if(J=0|Math.min(Math.max(dt+Y,0),a[1]),Z=mt<2?this._field[yt].get($,J):(this.intensity.get($,J)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){vt=!0;break e}var _t=xt*bt;ot[mt]+=_t*Z}}}if(vt){if(X>0){for(var wt=0;wt<5;++wt)rt.pop();G-=1}continue t}rt.push(ot[0],ot[1],ct[0],ct[1],ot[2]),G+=1}}at.push(G)}this._contourOffsets[nt]=it,this._contourCounts[nt]=at}var kt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)kt[o]=rt[o];this._contourBuffer.update(kt),s.freeFloat(kt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},E.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},E.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],f=this._field[l],p=this._field[c],d=h(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,M=1-k,A=+x[1],T=0|A,S=0|Math.min(T+1,i[1]),C=A-T,E=1-C,L=M*E,z=M*C,O=k*E,I=k*C,D=L*f.get(_,T)+z*f.get(_,S)+O*f.get(w,T)+I*f.get(w,S),P=L*p.get(_,T)+z*p.get(_,S)+O*p.get(w,T)+I*p.get(w,S);if(isNaN(D)||isNaN(P)){y&&(n-=1);break}a[2*n+0]=D,a[2*n+1]=P,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":304,\"binary-search-bounds\":305,\"bit-twiddle\":81,colormap:115,\"gl-buffer\":231,\"gl-mat4/invert\":256,\"gl-mat4/multiply\":258,\"gl-texture2d\":308,\"gl-vao\":313,ndarray:436,\"ndarray-gradient\":427,\"ndarray-ops\":430,\"ndarray-pack\":431,\"surface-nets\":509,\"typedarray-pool\":523}],307:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),f=t(\"parse-rect\"),h=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(h(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=f(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),h=0;h<s.length;h++)s[h]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)e.textOffsets[b]=e.textOffsets[b-1]+t.text[b-1].length,e.count+=t.text[b].length,e.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,M=u.mallocFloat(2*this.count),A=0,T=0;A<this.counts.length;A++){var S=e.counts[A];if(w)for(var C=0;C<S;C++)M[T++]=t.position[2*A],M[T++]=t.position[2*A+1];else for(var E=0;E<S;E++)M[T++]=t.position[A][0],M[T++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:M}):this.position=this.regl.buffer({type:\"float\",data:M}),u.freeFloat(M)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),z=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,I=0;O<this.counts.length;O++){for(var D=e.counts[O],P=e.font[O]||e.font[0],R=e.fontAtlas[O]||e.fontAtlas[0],F=0;F<D;F++){var B=e.text.charAt(I),N=e.text.charAt(I-1);if(L[I]=R.ids[B],z[2*I]=P.width[B],F){var j=z[2*I-2],V=z[2*I],U=z[2*I-1]+.5*j+.5*V;if(e.kerning){var q=P.kerning[N+B];q&&(U+=.001*q)}z[2*I+1]=U}else z[2*I+1]=.5*z[2*I];I++}e.textWidth.push(z.length?.5*z[2*I-2]+z[2*I-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:z,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(z),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var W=(t.color.subarray||t.color.slice).bind(t.color),Y=0;Y<G;Y+=4)H.set(l(W(Y,Y+4),\"uint8\"),Y)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var $=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array($);for(var J=0;J<this.batch.length;J++)e.batch[J]={count:e.counts.length>1?e.counts[J]:e.counts[0],offset:e.textOffsets.length>1?e.textOffsets[J]:e.textOffsets[0],color:e.color?e.color.length<=4?e.color:e.color.subarray(4*J,4*J+4):[0,0,0,255],opacity:Array.isArray(e.opacity)?e.opacity[J]:e.opacity,baseline:null!=e.baselineOffset[J]?e.baselineOffset[J]:e.baselineOffset[0],align:e.align?null!=e.alignOffset[J]?e.alignOffset[J]:e.alignOffset[0]:0,atlas:e.fontAtlas[J]||e.fontAtlas[0],positionOffset:e.positionOffset.length>2?e.positionOffset.subarray(2*J,2*J+2):e.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":81,\"color-normalize\":109,\"css-font\":128,\"detect-kerning\":152,\"es6-weak-map\":210,\"flatten-vertex-data\":217,\"font-atlas\":218,\"font-measure\":219,\"gl-util/context\":309,\"is-plain-obj\":408,\"object-assign\":440,\"parse-rect\":445,\"parse-unit\":447,\"pick-by-alias\":451,regl:480,\"to-px\":517,\"typedarray-pool\":523}],308:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new h(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var f,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)f=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),f=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,f),l||a.free(p);return new h(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function f(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function h(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=h.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new h(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return f(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return f(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,f(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,f){var h=f.dtype,p=f.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,f.stride.slice());\"float32\"===h?g=t.FLOAT:\"float64\"===h?(g=t.FLOAT,m=!1,h=\"float32\"):\"uint8\"===h?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,h=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],f=n(f.data,p,[f.stride[0],f.stride[1],1],f.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=f.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===f.offset&&f.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,f.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,f.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,f.data.subarray(f.offset,f.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,f.data.subarray(f.offset,f.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,f):i.assign(_,f),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:436,\"ndarray-ops\":430,\"typedarray-pool\":523}],309:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*window.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*window.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\"},!0),t.pixelRatio||(t.pixelRatio=window.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var r=document.querySelector(t.container);if(!r)throw Error(\"Element \"+t.container+\" is not found\");t.container=r}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=document.createElement(\"canvas\"),t.container.appendChild(t.canvas),i(t))}else t.canvas||(t.container=document.body||document.documentElement,t.canvas=document.createElement(\"canvas\"),t.canvas.style.position=\"absolute\",t.canvas.style.top=0,t.canvas.style.left=0,t.container.appendChild(t.canvas),i(t));if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}},{\"pick-by-alias\":451}],310:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,f=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,f)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],311:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":310}],312:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":310}],313:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":311,\"./lib/vao-native.js\":312}],314:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],315:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":325,\"./fromValues\":331,\"./normalize\":342}],316:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],317:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],318:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],319:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],320:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],321:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":322}],322:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],323:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":324}],324:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],325:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],326:[function(t,e,r){e.exports=1e-6},{}],327:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":326}],328:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],329:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],330:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":319}],331:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],332:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":314,\"./angle\":315,\"./ceil\":316,\"./clone\":317,\"./copy\":318,\"./create\":319,\"./cross\":320,\"./dist\":321,\"./distance\":322,\"./div\":323,\"./divide\":324,\"./dot\":325,\"./epsilon\":326,\"./equals\":327,\"./exactEquals\":328,\"./floor\":329,\"./forEach\":330,\"./fromValues\":331,\"./inverse\":333,\"./len\":334,\"./length\":335,\"./lerp\":336,\"./max\":337,\"./min\":338,\"./mul\":339,\"./multiply\":340,\"./negate\":341,\"./normalize\":342,\"./random\":343,\"./rotateX\":344,\"./rotateY\":345,\"./rotateZ\":346,\"./round\":347,\"./scale\":348,\"./scaleAndAdd\":349,\"./set\":350,\"./sqrDist\":351,\"./sqrLen\":352,\"./squaredDistance\":353,\"./squaredLength\":354,\"./sub\":355,\"./subtract\":356,\"./transformMat3\":357,\"./transformMat4\":358,\"./transformQuat\":359}],333:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],334:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":335}],335:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],336:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],337:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],339:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":340}],340:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],341:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],342:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],343:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],345:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],346:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],348:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],349:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],351:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":353}],352:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":354}],353:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],354:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],355:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":356}],356:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],357:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],358:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],361:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],362:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],363:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],364:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],365:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],366:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],367:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],368:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":360,\"./clone\":361,\"./copy\":362,\"./create\":363,\"./distance\":364,\"./divide\":365,\"./dot\":366,\"./fromValues\":367,\"./inverse\":369,\"./length\":370,\"./lerp\":371,\"./max\":372,\"./min\":373,\"./multiply\":374,\"./negate\":375,\"./normalize\":376,\"./random\":377,\"./scale\":378,\"./scaleAndAdd\":379,\"./set\":380,\"./squaredDistance\":381,\"./squaredLength\":382,\"./subtract\":383,\"./transformMat4\":384,\"./transformQuat\":385}],369:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],370:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],371:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],375:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],376:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],377:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":376,\"./scale\":378}],378:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],379:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],380:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],381:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],382:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],383:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],384:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],385:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t[3]=e[3],t}},{}],386:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],387:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":61,\"glsl-tokenizer\":394}],388:[function(t,e,r){e.exports=function(t){var e,r,k,M=0,A=0,T=l,S=[],C=[],E=1,L=0,z=0,O=!1,I=!1,D=\"\",P=a,R=n;\"300 es\"===(t=t||{}).version&&(P=s,R=o);return function(t){return C=[],null!==t?function(t){var r;M=0,k=(D+=t).length;for(;e=D[M],M<k;){switch(r=M,T){case u:M=V();break;case f:case h:M=j();break;case p:M=U();break;case d:M=G();break;case _:M=H();break;case g:M=W();break;case c:M=Y();break;case x:M=N();break;case l:M=B()}if(r!==M)switch(D[r]){case\"\\n\":L=0,++E;break;default:++L}}return A+=M,D=D.slice(M),C}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return T=b,F(\"(eof)\"),C}()};function F(t){t.length&&C.push({type:w[T],data:t,position:z,line:E,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(z=A+M-1,T=u,r=e,M+1):\"/\"===r&&\"/\"===e?(z=A+M-1,T=f,r=e,M+1):\"#\"===e?(T=h,z=A+M,M):/\\s/.test(e)?(T=x,z=A+M,M):(O=/\\d/.test(e),I=/[^\\w_]/.test(e),z=A+M,T=O?d:I?p:c,M)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),T=l,M):(S.push(e),r=e,M+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,M+1):(F(S.join(\"\")),T=l,M)}function V(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),T=l,M+1):(S.push(e),r=e,M+1)}function U(){if(\".\"===r&&/\\d/.test(e))return T=g,M;if(\"/\"===r&&\"*\"===e)return T=u,M;if(\"/\"===r&&\"/\"===e)return T=f,M;if(\".\"===e&&S.length){for(;q(S););return T=g,M}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),T=l,M+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return T=l,M}return S.push(e),r=e,M+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),z+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),T=l,M):(S.push(e),r=e,M+1)}function G(){return\".\"===e?(S.push(e),T=g,r=e,M+1):/[eE]/.test(e)?(S.push(e),T=g,r=e,M+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(T=_,S.push(e),r=e,M+1):/[^\\d]/.test(e)?(F(S.join(\"\")),T=l,M):(S.push(e),r=e,M+1)}function W(){return\"f\"===e&&(S.push(e),r=e,M+=1),/[eE]/.test(e)?(S.push(e),r=e,M+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,M+1):/[^\\d]/.test(e)?(F(S.join(\"\")),T=l,M):(S.push(e),r=e,M+1)}function Y(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return T=R.indexOf(t)>-1?y:P.indexOf(t)>-1?m:v,F(S.join(\"\")),T=l,M}return S.push(e),r=e,M+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,f=1,h=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":390,\"./lib/builtins-300es\":389,\"./lib/literals\":392,\"./lib/literals-300es\":391,\"./lib/operators\":393}],389:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":390}],390:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],391:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":392}],392:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],393:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],394:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":388}],395:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],396:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":403}],397:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":403}],398:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],399:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var f=new a(l,new Array(i+1),!1),h=f.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);h[u]=m,p[u]=m}p[i+1]=f;for(var u=0;u<=i;++u)for(var d=h[u].vertices,y=h[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=f;else for(var b=0;b<=i;++b)h[b].vertices.indexOf(x)<0&&(y[g]=h[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,f=0;f<=r;++f){var h=u[f];i[f]=h<0?e:a[h]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var f=c[u];if(!(f.lastVisited>=r)){var h=a[u];a[u]=t;var p=this.orient();if(a[u]=h,p<0){s=f;continue t}f.boundary?f.lastVisited=-r:f.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,f=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var h=[];f.length>0;){var p=(e=f.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),f.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),M=new a(w,k,!0);u.push(M);var A=_.indexOf(e);if(!(A<0)){_[A]=M,k[g]=m,w[v]=-1,k[v]=e,d[v]=M,M.flip();for(b=0;b<=n;++b){var T=w[b];if(!(T<0||T===r)){for(var S=new Array(n-1),C=0,E=0;E<=n;++E){var L=w[E];L<0||E===b||(S[C++]=L)}h.push(new o(S,M,b))}}}}}}h.sort(s);for(v=0;v+1<h.length;v+=2){var z=h[v],O=h[v+1],I=z.index,D=O.index;I<0||D<0||(z.cell.adjacent[z.index]=O.cell,O.cell.adjacent[O.index]=z.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var f=o[0];o[0]=o[1],o[1]=f}e.push(o)}}return e}},{\"robust-orientation\":488,\"simplicial-complex\":498}],400:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function f(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function h(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?f(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?f(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return h(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?h(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":80}],401:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],402:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],403:[function(t,e,r){e.exports=!0},{}],404:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],405:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],406:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],407:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],408:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],409:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],410:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],411:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],412:[function(t,e,r){(function(t){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.mapboxgl=n()}(this,function(){\"use strict\";var e,r,n;function i(t,i){if(e)if(r){var a=\"var sharedChunk = {}; (\"+e+\")(sharedChunk); (\"+r+\")(sharedChunk);\",o={};e(o),(n=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else r=i;else e=i}return i(0,function(e){var r=\"undefined\"!=typeof window?window:\"undefined\"!=typeof t?t:\"undefined\"!=typeof self?self:{};function n(t){return t&&t.__esModule&&Object.prototype.hasOwnProperty.call(t,\"default\")?t.default:t}function i(t,e){return t(e={exports:{}},e.exports),e.exports}var a=o;function o(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}o.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},o.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},o.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},o.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},o.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var s=function(t,e,r){this.column=t,this.row=e,this.zoom=r};s.prototype.clone=function(){return new s(this.column,this.row,this.zoom)},s.prototype.zoomTo=function(t){return this.clone()._zoomTo(t)},s.prototype.sub=function(t){return this.clone()._sub(t)},s.prototype._zoomTo=function(t){var e=Math.pow(2,t-this.zoom);return this.column*=e,this.row*=e,this.zoom=t,this},s.prototype._sub=function(t){return t=t.zoomTo(this.zoom),this.column-=t.column,this.row-=t.row,this};var l=c;function c(t,e){this.x=t,this.y=e}function u(t,e,r,n){var i=new a(t,e,r,n);return function(t){return i.solve(t)}}c.prototype={clone:function(){return new c(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},c.convert=function(t){return t instanceof c?t:Array.isArray(t)?new c(t[0],t[1]):t};var f=u(.25,.1,.25,1);function h(t,e,r){return Math.min(r,Math.max(e,t))}function p(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var d=1;function g(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function v(t,e){return-1!==t.indexOf(e,t.length-e.length)}function m(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function y(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?m(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function k(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}var M={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(M);var A=function(t){function e(e,r,n){t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function T(t){var e=new self.XMLHttpRequest;for(var r in e.open(\"GET\",t.url,!0),t.headers)e.setRequestHeader(r,t.headers[r]);return e.withCredentials=\"include\"===t.credentials,e}var S=function(t,e){var r=T(t);return r.responseType=\"arraybuffer\",r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){var n=r.response;if(0===n.byteLength&&200===r.status)return e(new Error(\"http status 200 returned without content.\"));r.status>=200&&r.status<300&&r.response?e(null,{data:n,cacheControl:r.getResponseHeader(\"Cache-Control\"),expires:r.getResponseHeader(\"Expires\")}):e(new A(r.statusText,r.status,t.url))},r.send(),r};function C(t,e,r){r[t]=r[t]||[],r[t].push(e)}function E(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var L=function(t,e){void 0===e&&(e={}),p(this,e),this.type=t},z=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",p({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(L),O=function(){};O.prototype.on=function(t,e){return this._listeners=this._listeners||{},C(t,e,this._listeners),this},O.prototype.off=function(t,e){return E(t,e,this._listeners),E(t,e,this._oneTimeListeners),this},O.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},C(t,e,this._oneTimeListeners),this},O.prototype.fire=function(t){\"string\"==typeof t&&(t=new L(t,arguments[1]||{}));var e=t.type;if(this.listens(e)){t.target=this;for(var r=0,n=this._listeners&&this._listeners[e]?this._listeners[e].slice():[];r<n.length;r+=1)n[r].call(this,t);for(var i=0,a=this._oneTimeListeners&&this._oneTimeListeners[e]?this._oneTimeListeners[e].slice():[];i<a.length;i+=1){var o=a[i];E(e,o,this._oneTimeListeners),o.call(this,t)}var s=this._eventedParent;s&&(p(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),s.fire(t))}else v(e,\"error\")?console.error(t&&t.error||t||\"Empty error event\"):v(e,\"warning\")&&console.warn(t&&t.warning||t||\"Empty warning event\");return this},O.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},O.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var I={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.0511,180,85.0511]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.0511,180,85.0511]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.0511,180,85.0511]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},lineMetrics:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_line:{\"line-cap\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{butt:{},round:{},square:{}},default:\"butt\"},\"line-join\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,values:{bevel:{},round:{},miter:{}},default:\"miter\"},\"line-miter-limit\":{type:\"number\",default:2,function:\"interpolated\",\"zoom-function\":!0,requires:[{\"line-join\":\"miter\"}]},\"line-round-limit\":{type:\"number\",default:1.05,function:\"interpolated\",\"zoom-function\":!0,requires:[{\"line-join\":\"round\"}]},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{point:{},line:{}},default:\"point\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,function:\"interpolated\",\"zoom-function\":!0,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}]},\"symbol-avoid-edges\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1},\"icon-allow-overlap\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"icon-image\"]},\"icon-ignore-placement\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"icon-image\"]},\"icon-optional\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"icon-image\",\"text-field\"]},\"icon-rotation-alignment\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"]},\"icon-size\":{type:\"number\",default:1,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,units:\"factor of the original icon size\",requires:[\"icon-image\"]},\"icon-text-fit\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"]},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",function:\"interpolated\",\"zoom-function\":!0,requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}]},\"icon-image\":{type:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,tokens:!0},\"icon-rotate\":{type:\"number\",default:0,period:360,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,units:\"degrees\",requires:[\"icon-image\"]},\"icon-padding\":{type:\"number\",default:2,minimum:0,function:\"interpolated\",\"zoom-function\":!0,units:\"pixels\",requires:[\"icon-image\"]},\"icon-keep-upright\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":\"line\"}]},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,requires:[\"icon-image\"]},\"icon-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"]},\"icon-pitch-alignment\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"]},\"text-pitch-alignment\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"]},\"text-rotation-alignment\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"]},\"text-field\":{type:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,default:\"\",tokens:!0},\"text-font\":{type:\"array\",value:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"]},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,requires:[\"text-field\"]},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,requires:[\"text-field\"]},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",function:\"interpolated\",\"zoom-function\":!0,requires:[\"text-field\"]},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,requires:[\"text-field\"]},\"text-justify\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,values:{left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"]},\"text-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\"]},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",function:\"interpolated\",\"zoom-function\":!0,requires:[\"text-field\",{\"symbol-placement\":\"line\"}]},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,requires:[\"text-field\"]},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",function:\"interpolated\",\"zoom-function\":!0,requires:[\"text-field\"]},\"text-keep-upright\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":\"line\"}]},\"text-transform\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,\"property-function\":!0,values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"]},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,length:2,default:[0,0],requires:[\"text-field\"]},\"text-allow-overlap\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"text-field\"]},\"text-ignore-placement\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"text-field\"]},\"text-optional\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!1,requires:[\"text-field\",\"icon-image\"]},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Heatmap\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},transition:!1,\"zoom-function\":!0,\"property-function\":!1,function:\"piecewise-constant\"},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",transition:!0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!1},color:{type:\"color\",default:\"#ffffff\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!1,transition:!0},intensity:{type:\"number\",default:.5,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!1,transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",function:\"piecewise-constant\",\"zoom-function\":!0,default:!0},\"fill-opacity\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,default:1,minimum:0,maximum:1,transition:!0},\"fill-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[{\"!\":\"fill-pattern\"}]},\"fill-outline-color\":{type:\"color\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}]},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"pixels\"},\"fill-translate-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"]},\"fill-pattern\":{type:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,transition:!0}},paint_line:{\"line-opacity\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,default:1,minimum:0,maximum:1,transition:!0},\"line-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[{\"!\":\"line-pattern\"}]},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"pixels\"},\"line-translate-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"]},\"line-width\":{type:\"number\",default:1,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"line-offset\":{type:\"number\",default:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"line-blur\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"line-dasharray\":{type:\"array\",value:\"number\",function:\"piecewise-constant\",\"zoom-function\":!0,minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}]},\"line-pattern\":{type:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,transition:!0},\"line-gradient\":{type:\"color\",function:\"interpolated\",\"zoom-function\":!1,\"property-function\":!1,transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}]}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"circle-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0},\"circle-blur\":{type:\"number\",default:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"pixels\"},\"circle-translate-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"]},\"circle-pitch-scale\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\"},\"circle-pitch-alignment\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"viewport\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!1},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!1,transition:!0},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],function:\"interpolated\",\"zoom-function\":!1,\"property-function\":!1,transition:!1},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!1,transition:!0}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[\"icon-image\"]},\"icon-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[\"icon-image\"]},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[\"icon-image\"]},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\",requires:[\"icon-image\"]},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\",requires:[\"icon-image\"]},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"pixels\",requires:[\"icon-image\"]},\"icon-translate-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"]},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[\"text-field\"]},\"text-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[\"text-field\"]},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[\"text-field\"]},\"text-halo-width\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\",requires:[\"text-field\"]},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,units:\"pixels\",requires:[\"text-field\"]},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"pixels\",requires:[\"text-field\"]},\"text-translate-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"]}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,transition:!0},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"degrees\"},\"raster-brightness-min\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,default:0,minimum:0,maximum:1,transition:!0},\"raster-brightness-max\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,default:1,minimum:0,maximum:1,transition:!0},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,function:\"interpolated\",\"zoom-function\":!0,transition:!0},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,function:\"interpolated\",\"zoom-function\":!0,transition:!0},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,function:\"interpolated\",\"zoom-function\":!0,transition:!1,units:\"milliseconds\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,function:\"interpolated\",\"zoom-function\":!0,transition:!1},\"hillshade-illumination-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"viewport\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,transition:!0},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,transition:!0},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",function:\"interpolated\",\"zoom-function\":!0,transition:!0},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,transition:!0}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,transition:!0,requires:[{\"!\":\"background-pattern\"}]},\"background-pattern\":{type:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,transition:!0},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,function:\"interpolated\",\"zoom-function\":!0,transition:!0}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\"}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!1,default:1,minimum:0,maximum:1,transition:!0},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}]},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],function:\"interpolated\",\"zoom-function\":!0,transition:!0,units:\"pixels\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",function:\"piecewise-constant\",\"zoom-function\":!0,values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"]},\"fill-extrusion-pattern\":{type:\"string\",function:\"piecewise-constant\",\"zoom-function\":!0,transition:!0},\"fill-extrusion-height\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,default:0,minimum:0,units:\"meters\",transition:!0},\"fill-extrusion-base\":{type:\"number\",function:\"interpolated\",\"zoom-function\":!0,\"property-function\":!0,default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"]}}},D=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function P(t){var e=t.key,r=t.value;return r?[new D(e,r,\"constants have been deprecated as of v8\")]:[]}function R(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function F(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function B(t){return Array.isArray(t)?t.map(B):F(t)}var N=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),j=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};j.prototype.concat=function(t){return new j(this,t)},j.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},j.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var V={kind:\"null\"},U={kind:\"number\"},q={kind:\"string\"},H={kind:\"boolean\"},G={kind:\"color\"},W={kind:\"object\"},Y={kind:\"value\"},X={kind:\"collator\"};function Z(t,e){return{kind:\"array\",itemType:t,N:e}}function $(t){if(\"array\"===t.kind){var e=$(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var J=[V,U,q,H,G,W,Z(Y)];function K(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&!K(t.itemType,e.itemType)&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=J;r<n.length;r+=1)if(!K(n[r],e))return null}return\"Expected \"+$(t)+\" but found \"+$(e)+\" instead.\"}var Q=i(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),f=i.substr(l+1,c-(l+1)).split(\",\"),h=1;switch(u){case\"rgba\":if(4!==f.length)return null;h=o(f.pop());case\"rgb\":return 3!==f.length?null:[a(f[0]),a(f[1]),a(f[2]),h];case\"hsla\":if(4!==f.length)return null;h=o(f.pop());case\"hsl\":if(3!==f.length)return null;var p=(parseFloat(f[0])%360+360)%360/360,d=o(f[1]),g=o(f[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),h];default:return null}}return null}}catch(t){}}).parseCSSColor,tt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};tt.parse=function(t){if(t){if(t instanceof tt)return t;if(\"string\"==typeof t){var e=Q(t);if(e)return new tt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},tt.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},tt.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},tt.black=new tt(0,0,0,1),tt.white=new tt(1,1,1,1),tt.transparent=new tt(0,0,0,0);var et=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};et.prototype.compare=function(t,e){return this.collator.compare(t,e)},et.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var rt=function(t,e,r){this.type=X,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function nt(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function it(t){if(null===t)return V;if(\"string\"==typeof t)return q;if(\"boolean\"==typeof t)return H;if(\"number\"==typeof t)return U;if(t instanceof tt)return G;if(t instanceof et)return X;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=it(i[n]);if(e){if(e===a)continue;e=Y;break}e=a}return Z(e||Y,r)}return W}rt.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,H);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,H);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,q))?null:new rt(n,i,a)},rt.prototype.evaluate=function(t){return new et(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},rt.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},rt.prototype.possibleOutputs=function(){return[void 0]},rt.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var at=function(t,e){this.type=t,this.value=e};at.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof tt)return!0;if(e instanceof et)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=it(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new at(n,r)},at.prototype.evaluate=function(){return this.value},at.prototype.eachChild=function(){},at.prototype.possibleOutputs=function(){return[this.value]},at.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof tt?[\"rgba\"].concat(this.value.toArray()):this.value};var ot=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};ot.prototype.toJSON=function(){return this.message};var st={string:q,number:U,boolean:H,object:W},lt=function(t,e){this.type=t,this.args=e};lt.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");for(var r=t[0],n=st[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Y);if(!o)return null;i.push(o)}return new lt(n,i)},lt.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!K(this.type,it(r)))return r;if(e===this.args.length-1)throw new ot(\"Expected value to be of type \"+$(this.type)+\", but found \"+$(it(r))+\" instead.\")}return null},lt.prototype.eachChild=function(t){this.args.forEach(t)},lt.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}));var t},lt.prototype.serialize=function(){return[this.type.kind].concat(this.args.map(function(t){return t.serialize()}))};var ct={string:q,number:U,boolean:H},ut=function(t,e){this.type=t,this.input=e};ut.parse=function(t,e){if(t.length<2||t.length>4)return e.error(\"Expected 1, 2, or 3 arguments, but found \"+(t.length-1)+\" instead.\");var r,n;if(t.length>2){var i=t[1];if(\"string\"!=typeof i||!(i in ct))return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);r=ct[i]}else r=Y;if(t.length>3){if(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2]))return e.error('The length argument to \"array\" must be a positive integer literal',2);n=t[2]}var a=Z(r,n),o=e.parse(t[t.length-1],t.length-1,Y);return o?new ut(a,o):null},ut.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(K(this.type,it(e)))throw new ot(\"Expected value to be of type \"+$(this.type)+\", but found \"+$(it(e))+\" instead.\");return e},ut.prototype.eachChild=function(t){t(this.input)},ut.prototype.possibleOutputs=function(){return this.input.possibleOutputs()},ut.prototype.serialize=function(){var t=[\"array\"],e=this.type.itemType;if(\"string\"===e.kind||\"number\"===e.kind||\"boolean\"===e.kind){t.push(e.kind);var r=this.type.N;\"number\"==typeof r&&t.push(r)}return t.push(this.input.serialize()),t};var ft={\"to-number\":U,\"to-color\":G},ht=function(t,e){this.type=t,this.args=e};ht.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");for(var r=t[0],n=ft[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Y);if(!o)return null;i.push(o)}return new ht(n,i)},ht.prototype.evaluate=function(t){if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1)if(r=null,\"string\"==typeof(e=i[n].evaluate(t))){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":nt(e[0],e[1],e[2],e[3])))return new tt(e[0]/255,e[1]/255,e[2]/255,e[3]);throw new ot(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:JSON.stringify(e))+\"'\")}for(var o=null,s=0,l=this.args;s<l.length;s+=1)if(null!==(o=l[s].evaluate(t))){var c=Number(o);if(!isNaN(c))return c}throw new ot(\"Could not convert \"+JSON.stringify(o)+\" to number.\")},ht.prototype.eachChild=function(t){this.args.forEach(t)},ht.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}));var t},ht.prototype.serialize=function(){var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var pt=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],dt=function(){this._parseColorCache={}};dt.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},dt.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?pt[this.feature.type]:this.feature.type:null},dt.prototype.properties=function(){return this.feature&&this.feature.properties||{}},dt.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=tt.parse(t)),e};var gt=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};function vt(t){if(t instanceof gt){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!vt(t)&&(e=!1)}),e}function mt(t,e){if(t instanceof gt&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!mt(t,e)&&(r=!1)}),r}gt.prototype.evaluate=function(t){return this._evaluate(t,this.args)},gt.prototype.eachChild=function(t){this.args.forEach(t)},gt.prototype.possibleOutputs=function(){return[void 0]},gt.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},gt.parse=function(t,e){var r=t[0],n=gt.definitions[r];if(!n)return e.error('Unknown expression \"'+r+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var i=Array.isArray(n)?n[0]:n.type,a=Array.isArray(n)?[[n[1],n[2]]]:n.overloads,o=a.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),s=[],l=1;l<t.length;l++){var c=t[l],u=void 0;if(1===o.length){var f=o[0][0];u=Array.isArray(f)?f[l-1]:f.type}var h=e.parse(c,1+s.length,u);if(!h)return null;s.push(h)}for(var p=null,d=0,g=o;d<g.length;d+=1){var v=g[d],m=v[0],y=v[1];if(p=new xt(e.registry,e.path,null,e.scope),Array.isArray(m)&&m.length!==s.length)p.error(\"Expected \"+m.length+\" arguments, but found \"+s.length+\" instead.\");else{for(var x=0;x<s.length;x++){var b=Array.isArray(m)?m[x]:m.type,_=s[x];p.concat(x+1).checkSubtype(b,_.type)}if(0===p.errors.length)return new gt(r,i,y,s)}}if(1===o.length)e.errors.push.apply(e.errors,p.errors);else{var w=(o.length?o:a).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map($).join(\", \")+\")\":\"(\"+$(e.type)+\"...)\"}).join(\" | \"),k=s.map(function(t){return $(t.type)}).join(\", \");e.error(\"Expected arguments of type \"+w+\", but found (\"+k+\") instead.\")}return null},gt.register=function(t,e){for(var r in gt.definitions=e,e)t[r]=gt};var yt=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};yt.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new yt(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},yt.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},yt.prototype.eachChild=function(){},yt.prototype.possibleOutputs=function(){return[void 0]},yt.prototype.serialize=function(){return[\"var\",this.name]};var xt=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new j),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function bt(t,e){for(var r,n,i=0,a=t.length-1,o=0;i<=a;){if(r=t[o=Math.floor((i+a)/2)],n=t[o+1],e===r||e>r&&e<n)return o;if(r<e)i=o+1;else{if(!(r>e))throw new ot(\"Input is not a number.\");a=o-1}}return Math.max(o-1,0)}xt.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},xt.prototype._parse=function(t,e){if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var r=t[0];if(\"string\"!=typeof r)return this.error(\"Expression name must be a string, but found \"+typeof r+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var n=this.registry[r];if(n){var i=n.parse(t,this);if(!i)return null;if(this.expectedType){var a=this.expectedType,o=i.type;if(\"string\"!==a.kind&&\"number\"!==a.kind&&\"boolean\"!==a.kind&&\"object\"!==a.kind||\"value\"!==o.kind)if(\"array\"===a.kind&&\"value\"===o.kind)e.omitTypeAnnotations||(i=new ut(a,i));else if(\"color\"!==a.kind||\"value\"!==o.kind&&\"string\"!==o.kind){if(this.checkSubtype(this.expectedType,i.type))return null}else e.omitTypeAnnotations||(i=new ht(a,[i]));else e.omitTypeAnnotations||(i=new lt(a,[i]))}if(!(i instanceof at)&&function t(e){if(e instanceof yt)return t(e.boundExpression);if(e instanceof gt&&\"error\"===e.name)return!1;if(e instanceof rt)return!1;var r=e instanceof ht||e instanceof lt||e instanceof ut,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof at}),!!n&&(vt(e)&&mt(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"is-supported-script\"]))}(i)){var s=new dt;try{i=new at(i.type,i.evaluate(s))}catch(t){return this.error(t.message),null}}return i}return this.error('Unknown expression \"'+r+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},xt.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new xt(this.registry,n,e||null,i,this.errors)},xt.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new N(n,t))},xt.prototype.checkSubtype=function(t,e){var r=K(t,e);return r&&this.error(r),r};var _t=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function wt(t,e,r){return t*(1-r)+e*r}_t.parse=function(t,e){var r=t[1],n=t.slice(2);if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(r=e.parse(r,1,U)))return null;var i=[],a=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(a=e.expectedType),n.unshift(-1/0);for(var o=0;o<n.length;o+=2){var s=n[o],l=n[o+1],c=o+1,u=o+2;if(\"number\"!=typeof s)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',c);if(i.length&&i[i.length-1][0]>=s)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',c);var f=e.parse(l,u,a);if(!f)return null;a=a||f.type,i.push([s,f])}return new _t(a,r,i)},_t.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[bt(e,n)].evaluate(t)},_t.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},_t.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}));var t},_t.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var kt=Object.freeze({number:wt,color:function(t,e,r){return new tt(wt(t.r,e.r,r),wt(t.g,e.g,r),wt(t.b,e.b,r),wt(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return wt(t,e[n],r)})}}),Mt=function(t,e,r,n){this.type=t,this.interpolation=e,this.input=r,this.labels=[],this.outputs=[];for(var i=0,a=n;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1];this.labels.push(s),this.outputs.push(l)}};function At(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Mt.interpolationFactor=function(t,e,r,n){var i=0;if(\"exponential\"===t.name)i=At(e,t.base,r,n);else if(\"linear\"===t.name)i=At(e,1,r,n);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;i=new a(o[0],o[1],o[2],o[3]).solve(At(e,1,r,n))}return i},Mt.parse=function(t,e){var r=t[1],n=t[2],i=t.slice(3);if(!Array.isArray(r)||0===r.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===r[0])r={name:\"linear\"};else if(\"exponential\"===r[0]){var a=r[1];if(\"number\"!=typeof a)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);r={name:\"exponential\",base:a}}else{if(\"cubic-bezier\"!==r[0])return e.error(\"Unknown interpolation type \"+String(r[0]),1,0);var o=r.slice(1);if(4!==o.length||o.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);r={name:\"cubic-bezier\",controlPoints:o}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(n=e.parse(n,2,U)))return null;var s=[],l=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(l=e.expectedType);for(var c=0;c<i.length;c+=2){var u=i[c],f=i[c+1],h=c+3,p=c+4;if(\"number\"!=typeof u)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',h);if(s.length&&s[s.length-1][0]>=u)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',h);var d=e.parse(f,p,l);if(!d)return null;l=l||d.type,s.push([u,d])}return\"number\"===l.kind||\"color\"===l.kind||\"array\"===l.kind&&\"number\"===l.itemType.kind&&\"number\"==typeof l.N?new Mt(l,r,n,s):e.error(\"Type \"+$(l)+\" is not interpolatable.\")},Mt.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=bt(e,n),o=e[a],s=e[a+1],l=Mt.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return kt[this.type.kind.toLowerCase()](c,u,l)},Mt.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Mt.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}));var t},Mt.prototype.serialize=function(){for(var t=[\"interpolate\",\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints),this.input.serialize()],e=0;e<this.labels.length;e++)t.push(this.labels[e],this.outputs[e].serialize());return t};var Tt=function(t,e){this.type=t,this.args=e};Tt.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{omitTypeAnnotations:!0});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return K(n,t.type)});return new Tt(c?Y:r,i)},Tt.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Tt.prototype.eachChild=function(t){this.args.forEach(t)},Tt.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}));var t},Tt.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var St=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};St.prototype.evaluate=function(t){return this.result.evaluate(t)},St.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},St.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,void 0,r);return o?new St(r,o):null},St.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},St.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var Ct=function(t,e,r){this.type=t,this.index=e,this.input=r};Ct.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,U),n=e.parse(t[2],2,Z(e.expectedType||Y));if(!r||!n)return null;var i=n.type;return new Ct(i.itemType,r,n)},Ct.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new ot(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new ot(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new ot(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},Ct.prototype.eachChild=function(t){t(this.index),t(this.input)},Ct.prototype.possibleOutputs=function(){return[void 0]},Ct.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Et=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Et.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,f=s;u<f.length;u+=1){var h=f[u];if(\"number\"!=typeof h&&\"string\"!=typeof h)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof h&&Math.abs(h)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof h&&Math.floor(h)!==h)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,it(h)))return null}else r=it(h);if(void 0!==i[String(h)])return c.error(\"Branch labels must be unique.\");i[String(h)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,r);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?new Et(r,n,d,i,a,g):null},Et.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Et.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Et.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs());var t},Et.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i],s=n[t.cases[o]];void 0===s?(n[t.cases[o]]=r.length,r.push([t.cases[o],[o]])):r[s][1].push(o)}for(var l=function(e){return\"number\"===t.input.type.kind?Number(e):e},c=0,u=r;c<u.length;c+=1){var f=u[c],h=f[0],p=f[1];1===p.length?e.push(l(p[0])):e.push(p.map(l)),e.push(t.outputs[h].serialize())}return e.push(this.otherwise.serialize()),e};var Lt=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function zt(t){return\"string\"===t.kind||\"number\"===t.kind||\"boolean\"===t.kind||\"null\"===t.kind}function Ot(t,e){return function(){function r(t,e,r){this.type=H,this.lhs=t,this.rhs=e,this.collator=r}return r.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var n=e.parse(t[1],1,Y);if(!n)return null;var i=e.parse(t[2],2,Y);if(!i)return null;if(!zt(n.type)&&!zt(i.type))return e.error(\"Expected at least one argument to be a string, number, boolean, or null, but found (\"+$(n.type)+\", \"+$(i.type)+\") instead.\");if(n.type.kind!==i.type.kind&&\"value\"!==n.type.kind&&\"value\"!==i.type.kind)return e.error(\"Cannot compare \"+$(n.type)+\" and \"+$(i.type)+\".\");var a=null;if(4===t.length){if(\"string\"!==n.type.kind&&\"string\"!==i.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(a=e.parse(t[3],3,X)))return null}return new r(n,i,a)},r.prototype.evaluate=function(t){var r=this.collator?0===this.collator.evaluate(t).compare(this.lhs.evaluate(t),this.rhs.evaluate(t)):this.lhs.evaluate(t)===this.rhs.evaluate(t);return e?!r:r},r.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},r.prototype.possibleOutputs=function(){return[!0,!1]},r.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},r}()}Lt.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,H);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new Lt(r,n,s):null},Lt.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},Lt.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},Lt.prototype.possibleOutputs=function(){return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs());var t},Lt.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var It=Ot(\"==\",!1),Dt=Ot(\"!=\",!0),Pt=function(t){this.type=U,this.input=t};Pt.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+$(r.type)+\" instead.\"):new Pt(r):null},Pt.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new ot(\"Expected value to be of type string or array, but found \"+$(it(e))+\" instead.\")},Pt.prototype.eachChild=function(t){t(this.input)},Pt.prototype.possibleOutputs=function(){return[void 0]},Pt.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Rt={\"==\":It,\"!=\":Dt,array:ut,at:Ct,boolean:lt,case:Lt,coalesce:Tt,collator:rt,interpolate:Mt,length:Pt,let:St,literal:at,match:Et,number:lt,object:lt,step:_t,string:lt,\"to-color\":ht,\"to-number\":ht,var:yt};function Ft(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=nt(r,n,i,o);if(s)throw new ot(s);return new tt(r/255*o,n/255*o,i/255*o,o)}function Bt(t,e){return t in e}function Nt(t,e){var r=e[t];return void 0===r?null:r}function jt(t,e){var r=e[0],n=e[1];return r.evaluate(t)<n.evaluate(t)}function Vt(t,e){var r=e[0],n=e[1];return r.evaluate(t)>n.evaluate(t)}function Ut(t,e){var r=e[0],n=e[1];return r.evaluate(t)<=n.evaluate(t)}function qt(t,e){var r=e[0],n=e[1];return r.evaluate(t)>=n.evaluate(t)}function Ht(t){return{type:t}}function Gt(t){return{result:\"success\",value:t}}function Wt(t){return{result:\"error\",value:t}}gt.register(Rt,{error:[{kind:\"error\"},[q],function(t,e){var r=e[0];throw new ot(r.evaluate(t))}],typeof:[q,[Y],function(t,e){return $(it(e[0].evaluate(t)))}],\"to-string\":[q,[Y],function(t,e){var r=e[0],n=typeof(r=r.evaluate(t));return null===r?\"\":\"string\"===n||\"number\"===n||\"boolean\"===n?String(r):r instanceof tt?r.toString():JSON.stringify(r)}],\"to-boolean\":[H,[Y],function(t,e){var r=e[0];return Boolean(r.evaluate(t))}],\"to-rgba\":[Z(U,4),[G],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[G,[U,U,U],Ft],rgba:[G,[U,U,U,U],Ft],has:{type:H,overloads:[[[q],function(t,e){return Bt(e[0].evaluate(t),t.properties())}],[[q,W],function(t,e){var r=e[0],n=e[1];return Bt(r.evaluate(t),n.evaluate(t))}]]},get:{type:Y,overloads:[[[q],function(t,e){return Nt(e[0].evaluate(t),t.properties())}],[[q,W],function(t,e){var r=e[0],n=e[1];return Nt(r.evaluate(t),n.evaluate(t))}]]},properties:[W,[],function(t){return t.properties()}],\"geometry-type\":[q,[],function(t){return t.geometryType()}],id:[Y,[],function(t){return t.id()}],zoom:[U,[],function(t){return t.globals.zoom}],\"heatmap-density\":[U,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[U,[],function(t){return t.globals.lineProgress||0}],\"+\":[U,Ht(U),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[U,Ht(U),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:U,overloads:[[[U,U],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[U],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[U,[U,U],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[U,[U,U],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[U,[],function(){return Math.LN2}],pi:[U,[],function(){return Math.PI}],e:[U,[],function(){return Math.E}],\"^\":[U,[U,U],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[U,[U],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[U,[U],function(t,e){var r=e[0];return Math.log10(r.evaluate(t))}],ln:[U,[U],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[U,[U],function(t,e){var r=e[0];return Math.log2(r.evaluate(t))}],sin:[U,[U],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[U,[U],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[U,[U],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[U,[U],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[U,[U],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[U,[U],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[U,Ht(U),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[U,Ht(U),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[U,[U],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[U,[U],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[U,[U],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[U,[U],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[H,[q,Y],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[H,[Y],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[H,[q],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[H,[q,Y],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[H,[Y],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[H,[q,Y],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[H,[Y],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[H,[q,Y],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[H,[Y],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[H,[q,Y],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[H,[Y],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[H,[Y],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[H,[],function(t){return null!==t.id()}],\"filter-type-in\":[H,[Z(q)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[H,[Z(Y)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[H,[q,Z(Y)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[H,[q,Z(Y)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],\">\":{type:H,overloads:[[[U,U],Vt],[[q,q],Vt],[[q,q,X],function(t,e){var r=e[0],n=e[1];return e[2].evaluate(t).compare(r.evaluate(t),n.evaluate(t))>0}]]},\"<\":{type:H,overloads:[[[U,U],jt],[[q,q],jt],[[q,q,X],function(t,e){var r=e[0],n=e[1];return e[2].evaluate(t).compare(r.evaluate(t),n.evaluate(t))<0}]]},\">=\":{type:H,overloads:[[[U,U],qt],[[q,q],qt],[[q,q,X],function(t,e){var r=e[0],n=e[1];return e[2].evaluate(t).compare(r.evaluate(t),n.evaluate(t))>=0}]]},\"<=\":{type:H,overloads:[[[U,U],Ut],[[q,q],Ut],[[q,q,X],function(t,e){var r=e[0],n=e[1];return e[2].evaluate(t).compare(r.evaluate(t),n.evaluate(t))<=0}]]},all:{type:H,overloads:[[[H,H],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[Ht(H),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:H,overloads:[[[H,H],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[Ht(H),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[H,[H],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[H,[q],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[q,[q],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[q,[q],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[q,Ht(q),function(t,e){return e.map(function(e){return e.evaluate(t)}).join(\"\")}],\"resolved-locale\":[q,[X],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Yt=.95047,Xt=1,Zt=1.08883,$t=4/29,Jt=6/29,Kt=3*Jt*Jt,Qt=Jt*Jt*Jt,te=Math.PI/180,ee=180/Math.PI;function re(t){return t>Qt?Math.pow(t,1/3):t/Kt+$t}function ne(t){return t>Jt?t*t*t:Kt*(t-$t)}function ie(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function ae(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function oe(t){var e=ae(t.r),r=ae(t.g),n=ae(t.b),i=re((.4124564*e+.3575761*r+.1804375*n)/Yt),a=re((.2126729*e+.7151522*r+.072175*n)/Xt);return{l:116*a-16,a:500*(i-a),b:200*(a-re((.0193339*e+.119192*r+.9503041*n)/Zt)),alpha:t.a}}function se(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Xt*ne(e),r=Yt*ne(r),n=Zt*ne(n),new tt(ie(3.2404542*r-1.5371385*e-.4985314*n),ie(-.969266*r+1.8760108*e+.041556*n),ie(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var le={forward:oe,reverse:se,interpolate:function(t,e,r){return{l:wt(t.l,e.l,r),a:wt(t.a,e.a,r),b:wt(t.b,e.b,r),alpha:wt(t.alpha,e.alpha,r)}}},ce={forward:function(t){var e=oe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*ee;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*te,r=t.c;return se({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:wt(t.c,e.c,r),l:wt(t.l,e.l,r),alpha:wt(t.alpha,e.alpha,r)}}},ue=Object.freeze({lab:le,hcl:ce});function fe(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function he(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function pe(t){return t}function de(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function ge(t,e,r,n,i){return de(typeof r===i?n[r]:void 0,t.default,e.default)}function ve(t,e,r){if(\"number\"!==fe(r))return de(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=xe(t.stops,r);return t.stops[i][1]}function me(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==fe(r))return de(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=xe(t.stops,r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=kt[e.type]||pe;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=ue[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function ye(t,e,r){return\"color\"===e.type?r=tt.parse(r):fe(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),de(r,t.default,e.default)}function xe(t,e){for(var r,n,i=0,a=t.length-1,o=0;i<=a;){if(r=t[o=Math.floor((i+a)/2)][0],n=t[o+1][0],e===r||e>r&&e<n)return o;r<e?i=o+1:r>e&&(a=o-1)}return Math.max(o-1,0)}var be=function(t,e){var r;this.expression=t,this._warningHistory={},this._defaultValue=\"color\"===(r=e).type&&he(r.default)?new tt(0,0,0,0):\"color\"===r.type?tt.parse(r.default)||null:void 0===r.default?null:r.default,\"enum\"===e.type&&(this._enumValues=e.values)};function _e(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Rt}function we(t,e){var r=new xt(Rt,[],function(t){var e={color:G,string:q,number:U,enum:q,boolean:H};return\"array\"===t.type?Z(e[t.value]||Y,t.length):e[t.type]||null}(e)),n=r.parse(t);return n?Gt(new be(n,e)):Wt(r.errors)}be.prototype.evaluateWithoutErrorHandling=function(t,e){return this._evaluator||(this._evaluator=new dt),this._evaluator.globals=t,this._evaluator.feature=e,this.expression.evaluate(this._evaluator)},be.prototype.evaluate=function(t,e){this._evaluator||(this._evaluator=new dt),this._evaluator.globals=t,this._evaluator.feature=e;try{var r=this.expression.evaluate(this._evaluator);if(null==r)return this._defaultValue;if(this._enumValues&&!(r in this._enumValues))throw new ot(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(r)+\" instead.\");return r}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var ke=function(t,e){this.kind=t,this._styleExpression=e};ke.prototype.evaluateWithoutErrorHandling=function(t,e){return this._styleExpression.evaluateWithoutErrorHandling(t,e)},ke.prototype.evaluate=function(t,e){return this._styleExpression.evaluate(t,e)};var Me=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,r instanceof Mt&&(this._interpolationType=r.interpolation)};function Ae(t,e){if(\"error\"===(t=we(t,e)).result)return t;var r=t.value.expression,n=vt(r);if(!n&&!e[\"property-function\"])return Wt([new N(\"\",\"property expressions not supported\")]);var i=mt(r,[\"zoom\"]);if(!i&&!1===e[\"zoom-function\"])return Wt([new N(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof St)r=t(e.result);else if(e instanceof Tt)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof _t||e instanceof Mt)&&e.input instanceof gt&&\"zoom\"===e.input.name&&(r=e);return r instanceof N?r:(e.eachChild(function(e){var n=t(e);n instanceof N?r=n:!r&&n?r=new N(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new N(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof N?Wt([a]):a instanceof Mt&&\"piecewise-constant\"===e.function?Wt([new N(\"\",'\"interpolate\" expressions cannot be used with this property')]):Gt(a?new Me(n?\"camera\":\"composite\",t.value,a):new ke(n?\"constant\":\"source\",t.value)):Wt([new N(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Me.prototype.evaluateWithoutErrorHandling=function(t,e){return this._styleExpression.evaluateWithoutErrorHandling(t,e)},Me.prototype.evaluate=function(t,e){return this._styleExpression.evaluate(t,e)},Me.prototype.interpolationFactor=function(t,e,r){return this._interpolationType?Mt.interpolationFactor(this._interpolationType,t,e,r):0};var Te=function(t,e){this._parameters=t,this._specification=e,R(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(\"interpolated\"===r.function?\"exponential\":\"interval\");if(o&&((e=R({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],tt.parse(t[1])]})),e.default?e.default=tt.parse(e.default):e.default=tt.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!ue[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=me;else if(\"interval\"===u)n=ve;else if(\"categorical\"===u){n=ge,i=Object.create(null);for(var f=0,h=e.stops;f<h.length;f+=1){var p=h[f];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=ye}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}return{kind:\"composite\",interpolationFactor:Mt.interpolationFactor.bind(void 0,{name:\"linear\"}),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return me({stops:x,base:e.base},r,i).evaluate(i,n)}}}return c?{kind:\"camera\",interpolationFactor:\"exponential\"===u?Mt.interpolationFactor.bind(void 0,{name:\"exponential\",base:void 0!==e.base?e.base:1}):function(){return 0},zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}:{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?de(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Se(t,e){if(he(t))return new Te(t,e);if(_e(t)){var r=Ae(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=tt.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}function Ce(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=fe(r);if(\"object\"!==l)return[new D(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],f=n[u]||n[\"*\"],h=void 0;if(i[u])h=i[u];else if(n[u])h=Ke;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){s.push(new D(e,r[c],'unknown property \"'+c+'\"'));continue}h=Ke}s=s.concat(h({key:(e?e+\".\":e)+c,value:r[c],valueSpec:f,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new D(e,r,'missing required property \"'+p+'\"'));return s}function Ee(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||Ke;if(\"array\"!==fe(e))return[new D(a,e,\"array expected, \"+fe(e)+\" found\")];if(r.length&&e.length!==r.length)return[new D(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new D(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value};i.$version<7&&(s.function=r.function),\"object\"===fe(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Le(t){var e=t.key,r=t.value,n=t.valueSpec,i=fe(r);return\"number\"!==i?[new D(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new D(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new D(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function ze(t){var e,r,n,i=t.valueSpec,a=F(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===fe(t.value.stops)&&\"array\"===fe(t.value.stops[0])&&\"object\"===fe(t.value.stops[0][0]),u=Ce({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new D(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Ee({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:f})),\"array\"===fe(r)&&0===r.length&&e.push(new D(t.key,r,\"array must have at least one stop\")),e},default:function(t){return Ke({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new D(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new D(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&\"piecewise-constant\"===t.valueSpec.function&&u.push(new D(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!t.valueSpec[\"property-function\"]?u.push(new D(t.key,t.value,\"property functions not supported\")):s&&!t.valueSpec[\"zoom-function\"]&&\"heatmap-color\"!==t.objectKey&&\"line-gradient\"!==t.objectKey&&u.push(new D(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new D(t.key,t.value,'\"property\" property is required')),u;function f(t){var e=[],a=t.value,s=t.key;if(\"array\"!==fe(a))return[new D(s,a,\"array expected, \"+fe(a)+\" found\")];if(2!==a.length)return[new D(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==fe(a[0]))return[new D(s,a,\"object expected, \"+fe(a[0])+\" found\")];if(void 0===a[0].zoom)return[new D(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new D(s,a,\"object stop key must have value\")];if(n&&n>F(a[0].zoom))return[new D(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];F(a[0].zoom)!==n&&(n=F(a[0].zoom),r=void 0,o={}),e=e.concat(Ce({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Le,value:h}}))}else e=e.concat(h({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return e.concat(Ke({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function h(t,n){var s=fe(t.value),l=F(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new D(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new D(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return i[\"property-function\"]&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new D(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new D(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new D(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new D(t.key,c,\"integer expected, found \"+l)]}}function Oe(t){var e=(\"property\"===t.expressionContext?Ae:we)(B(t.value),t.valueSpec);return\"error\"===e.result?e.value.map(function(e){return new D(\"\"+t.key+e.key,t.value,e.message)}):\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==e.value._styleExpression.expression.possibleOutputs().indexOf(void 0)?[new D(t.key,t.value,'Invalid data expression for \"text-font\". Output values must be contained as literals within the expression.')]:[]}function Ie(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(F(r))&&i.push(new D(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(F(r))&&i.push(new D(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function De(t){if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3===t.length&&(Array.isArray(t[1])||Array.isArray(t[2]));case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!De(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Te.deserialize=function(t){return new Te(t._parameters,t._specification)},Te.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Pe={type:\"boolean\",default:!1,function:!0,\"property-function\":!0,\"zoom-function\":!0};function Re(t){if(!t)return function(){return!0};De(t)||(t=Be(t));var e=we(t,Pe);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Fe(t,e){return t<e?-1:t>e?1:0}function Be(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Ne(t[1],t[2],\"==\"):\"!=\"===r?Ue(Ne(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Ne(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Be))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Be)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Be).map(Ue)):\"in\"===r?je(t[1],t.slice(2)):\"!in\"===r?Ue(je(t[1],t.slice(2))):\"has\"===r?Ve(t[1]):\"!has\"!==r||Ue(Ve(t[1]))}function Ne(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function je(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Fe)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Ve(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Ue(t){return[\"!\",t]}function qe(t){return De(B(t.value))?Oe(R({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==fe(r))return[new D(n,r,\"array expected, \"+fe(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new D(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Ie({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),F(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===F(r[1])&&o.push(new D(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new D(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=fe(r[1]))&&o.push(new D(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=fe(r[s]),\"$type\"===F(r[1])?o=o.concat(Ie({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new D(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=fe(r[1]),2!==r.length?o.push(new D(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new D(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function He(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return Ke({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new D(r,a,'unknown property \"'+o+'\"')];if(\"string\"===fe(a)&&u[\"property-function\"]&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new D(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var f=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&f.push(new D(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&he(B(a))&&\"identity\"===F(a.type)&&f.push(new D(r,a,'\"text-font\" does not support identity functions'))),f.concat(Ke({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyKey:o}))}function Ge(t){return He(t,\"paint\")}function We(t){return He(t,\"layout\")}function Ye(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new D(n,r,'either \"type\" or \"ref\" is required'));var o,s=F(r.type),l=F(r.ref);if(r.id)for(var c=F(r.id),u=0;u<t.arrayIndex;u++){var f=i.layers[u];F(f.id)===c&&e.push(new D(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+f.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new D(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){F(t.id)===l&&(o=t)}),o?o.ref?e.push(new D(n,r.ref,\"ref cannot reference another ref layer\")):s=F(o.type):e.push(new D(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var h=i.sources&&i.sources[r.source],p=h&&F(h.type);h?\"vector\"===p&&\"raster\"===s?e.push(new D(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new D(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new D(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&h.lineMetrics||e.push(new D(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new D(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new D(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new D(n,r,'missing required property \"source\"'));return e=e.concat(Ce({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return Ke({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:qe,layout:function(t){return Ce({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return We(R({layerType:s},t))}}})},paint:function(t){return Ce({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return Ge(R({layerType:s},t))}}})}}}))}function Xe(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new D(r,e,'\"type\" is required')];var a=F(e.type),o=[];switch(a){case\"vector\":case\"raster\":case\"raster-dem\":if(o=o.concat(Ce({key:r,value:e,valueSpec:n[\"source_\"+a.replace(\"-\",\"_\")],style:t.style,styleSpec:n})),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&o.push(new D(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return o;case\"geojson\":return Ce({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n});case\"video\":return Ce({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Ce({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return o.push(new D(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")),o;default:return Ie({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function Ze(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=fe(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new D(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(Ke({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(Ke({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new D(s,e[s],'unknown property \"'+s+'\"')])}return a}function $e(t){var e=t.value,r=t.key,n=fe(e);return\"string\"!==n?[new D(r,e,\"string expected, \"+n+\" found\")]:[]}var Je={\"*\":function(){return[]},array:Ee,boolean:function(t){var e=t.value,r=t.key,n=fe(e);return\"boolean\"!==n?[new D(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Le,color:function(t){var e=t.key,r=t.value,n=fe(r);return\"string\"!==n?[new D(e,r,\"color expected, \"+n+\" found\")]:null===Q(r)?[new D(e,r,'color expected, \"'+r+'\" found')]:[]},constants:P,enum:Ie,filter:qe,function:ze,layer:Ye,object:Ce,source:Xe,light:Ze,string:$e};function Ke(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.function&&he(F(e))?ze(t):r.function&&_e(B(e))?Oe(t):r.type&&Je[r.type]?Je[r.type](t):Ce(R({},t,{valueSpec:r.type?n[r.type]:r}))}function Qe(t){var e=t.value,r=t.key,n=$e(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new D(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new D(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function tr(t,e){e=e||I;var r=[];return r=r.concat(Ke({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:Qe,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(P({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),er(r)}function er(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function rr(t){return function(){return er(t.apply(this,arguments))}}tr.source=rr(Xe),tr.light=rr(Ze),tr.layer=rr(Ye),tr.filter=rr(qe),tr.paintProperty=rr(Ge),tr.layoutProperty=rr(We);var nr=tr,ir=tr.light,ar=tr.paintProperty,or=tr.layoutProperty;function sr(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new z(new Error(a.message))),r=!0}return r}var lr=ur,cr=3;function ur(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[cr+a],s=i[cr+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[cr+n.length],c=i[cr+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var f=r/e*t;this.min=-f,this.max=t+f}ur.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},ur.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},ur.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},ur.prototype.query=function(t,e,r,n){var i=this.min,a=this.max;if(t<=i&&e<=i&&a<=r&&a<=n)return Array.prototype.slice.call(this.keys);var o=[];return this._forEachCell(t,e,r,n,this._queryCell,o,{}),o},ur.prototype._queryCell=function(t,e,r,n,i,a,o){var s=this.cells[i];if(null!==s)for(var l=this.keys,c=this.bboxes,u=0;u<s.length;u++){var f=s[u];if(void 0===o[f]){var h=4*f;t<=c[h+2]&&e<=c[h+3]&&r>=c[h+0]&&n>=c[h+1]?(o[f]=!0,a.push(l[f])):o[f]=!1}}},ur.prototype._forEachCell=function(t,e,r,n,i,a,o){for(var s=this._convertToCellCoord(t),l=this._convertToCellCoord(e),c=this._convertToCellCoord(r),u=this._convertToCellCoord(n),f=s;f<=c;f++)for(var h=l;h<=u;h++){var p=this.d*h+f;if(i.call(this,t,e,r,n,p,a,o))return}},ur.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},ur.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=cr+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[cr+o]=a,i.set(s,a),a+=s.length}return i[cr+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[cr+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var fr=self.ImageData,hr={};function pr(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),hr[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var dr in pr(\"Object\",Object),lr.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),r},lr.deserialize=function(t){return new lr(t)},pr(\"Grid\",lr),pr(\"Color\",tt),pr(\"Error\",Error),pr(\"StylePropertyFunction\",Te),pr(\"StyleExpression\",be,{omit:[\"_evaluator\"]}),pr(\"ZoomDependentExpression\",Me),pr(\"ZoomConstantExpression\",ke),pr(\"CompoundExpression\",gt,{omit:[\"_evaluate\"]}),Rt)Rt[dr]._classRegistryKey||pr(\"Expression_\"+dr,Rt[dr]);function gr(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof fr)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(gr(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c={};if(s.serialize)c._serialized=s.serialize(t,e);else{for(var u in t)if(t.hasOwnProperty(u)&&!(hr[l].omit.indexOf(u)>=0)){var f=t[u];c[u]=hr[l].shallow.indexOf(u)>=0?f:gr(f,e)}t instanceof Error&&(c.message=t.message)}return{name:l,properties:c}}throw new Error(\"can't serialize object of type \"+typeof t)}function vr(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof fr)return t;if(Array.isArray(t))return t.map(function(t){return vr(t)});if(\"object\"==typeof t){var e=t,r=e.name,n=e.properties;if(!r)throw new Error(\"can't deserialize object of anonymous class\");var i=hr[r].klass;if(!i)throw new Error(\"can't deserialize unregistered class \"+r);if(i.deserialize)return i.deserialize(n._serialized);for(var a=Object.create(i.prototype),o=0,s=Object.keys(n);o<s.length;o+=1){var l=s[o];a[l]=hr[r].shallow.indexOf(l)>=0?n[l]:vr(n[l])}return a}throw new Error(\"can't deserialize object of type \"+typeof t)}var mr=function(){this.first=!0};mr.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var yr={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function xr(t){for(var e=0,r=t;e<r.length;e+=1)if(_r(r[e].charCodeAt(0)))return!0;return!1}function br(t){return!(yr.Arabic(t)||yr[\"Arabic Supplement\"](t)||yr[\"Arabic Extended-A\"](t)||yr[\"Arabic Presentation Forms-A\"](t)||yr[\"Arabic Presentation Forms-B\"](t))}function _r(t){return!!(746===t||747===t||!(t<4352)&&(yr[\"Bopomofo Extended\"](t)||yr.Bopomofo(t)||yr[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||yr[\"CJK Compatibility Ideographs\"](t)||yr[\"CJK Compatibility\"](t)||yr[\"CJK Radicals Supplement\"](t)||yr[\"CJK Strokes\"](t)||!(!yr[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||yr[\"CJK Unified Ideographs Extension A\"](t)||yr[\"CJK Unified Ideographs\"](t)||yr[\"Enclosed CJK Letters and Months\"](t)||yr[\"Hangul Compatibility Jamo\"](t)||yr[\"Hangul Jamo Extended-A\"](t)||yr[\"Hangul Jamo Extended-B\"](t)||yr[\"Hangul Jamo\"](t)||yr[\"Hangul Syllables\"](t)||yr.Hiragana(t)||yr[\"Ideographic Description Characters\"](t)||yr.Kanbun(t)||yr[\"Kangxi Radicals\"](t)||yr[\"Katakana Phonetic Extensions\"](t)||yr.Katakana(t)&&12540!==t||!(!yr[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!yr[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||yr[\"Unified Canadian Aboriginal Syllabics\"](t)||yr[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||yr[\"Vertical Forms\"](t)||yr[\"Yijing Hexagram Symbols\"](t)||yr[\"Yi Syllables\"](t)||yr[\"Yi Radicals\"](t)))}function wr(t){return!(_r(t)||function(t){return!!(yr[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||yr[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||yr[\"Letterlike Symbols\"](t)||yr[\"Number Forms\"](t)||yr[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||yr[\"Control Pictures\"](t)&&9251!==t||yr[\"Optical Character Recognition\"](t)||yr[\"Enclosed Alphanumerics\"](t)||yr[\"Geometric Shapes\"](t)||yr[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||yr[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||yr[\"CJK Symbols and Punctuation\"](t)||yr.Katakana(t)||yr[\"Private Use Area\"](t)||yr[\"CJK Compatibility Forms\"](t)||yr[\"Small Form Variants\"](t)||yr[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function kr(t,e){return!(!e&&(t>=1424&&t<=2303||yr[\"Arabic Presentation Forms-A\"](t)||yr[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||yr.Khmer(t))}var Mr,Ar=!1,Tr=null,Sr=!1,Cr=new O,Er={applyArabicShaping:null,processBidirectionalText:null,isLoaded:function(){return Sr||null!=Er.applyArabicShaping}},Lr=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new mr,this.transition={})};Lr.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!kr(n[r].charCodeAt(0),e))return!1;return!0}(t,Er.isLoaded())},Lr.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)};var zr=function(t,e){this.property=t,this.value=e,this.expression=Se(void 0===e?t.specification.default:e,t.specification)};zr.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},zr.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var Or=function(t){this.property=t,this.value=new zr(t,void 0)};Or.prototype.transitioned=function(t,e){return new Dr(this.property,this.value,e,p({},t.transition,this.transition),t.now)},Or.prototype.untransitioned=function(){return new Dr(this.property,this.value,null,{},0)};var Ir=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Ir.prototype.getValue=function(t){return x(this._values[t].value.value)},Ir.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new Or(this._values[t].property)),this._values[t].value=new zr(this._values[t].property,null===e?void 0:x(e))},Ir.prototype.getTransition=function(t){return x(this._values[t].transition)},Ir.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new Or(this._values[t].property)),this._values[t].transition=x(e)||void 0},Ir.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Ir.prototype.transitioned=function(t,e){for(var r=new Pr(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Ir.prototype.untransitioned=function(){for(var t=new Pr(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Dr=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Dr.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Pr=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Pr.prototype.possiblyEvaluate=function(t){for(var e=new Br(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Pr.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Rr=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Rr.prototype.getValue=function(t){return x(this._values[t].value)},Rr.prototype.setValue=function(t,e){this._values[t]=new zr(this._values[t].property,null===e?void 0:x(e))},Rr.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Rr.prototype.possiblyEvaluate=function(t){for(var e=new Br(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Fr=function(t,e,r){this.property=t,this.value=e,this.globals=r};Fr.prototype.isConstant=function(){return\"constant\"===this.value.kind},Fr.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Fr.prototype.evaluate=function(t){return this.property.evaluate(this.value,this.globals,t)};var Br=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Br.prototype.get=function(t){return this._values[t]};var Nr=function(t){this.specification=t};Nr.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Nr.prototype.interpolate=function(t,e,r){var n=kt[this.specification.type];return n?n(t,e,r):t};var jr=function(t){this.specification=t};jr.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Fr(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Fr(this,t.expression,e)},jr.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Fr(this,{kind:\"constant\",value:void 0},t.globals);var n=kt[this.specification.type];return n?new Fr(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.globals):t},jr.prototype.evaluate=function(t,e,r){return\"constant\"===t.kind?t.value:t.evaluate(e,r)};var Vr=function(t){this.specification=t};Vr.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Lr(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Lr(Math.floor(e.zoom),e)),t.expression.evaluate(new Lr(Math.floor(e.zoom+1),e)),e)}},Vr.prototype._calculate=function(t,e,r,n){var i=n.zoom,a=i-Math.floor(i),o=n.crossFadingFactor();return i>n.zoomHistory.lastIntegerZoom?{from:t,to:e,fromScale:2,toScale:1,t:a+(1-a)*o}:{from:r,to:e,fromScale:.5,toScale:1,t:1-(1-o)*a}},Vr.prototype.interpolate=function(t){return t};var Ur=function(t){this.specification=t};Ur.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},Ur.prototype.interpolate=function(){return!1};var qr=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new zr(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new Or(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};pr(\"DataDrivenProperty\",jr),pr(\"DataConstantProperty\",Nr),pr(\"CrossFadedProperty\",Vr),pr(\"ColorRampProperty\",Ur);var Hr=function(t){function e(e,r){for(var n in t.call(this),this.id=e.id,this.metadata=e.metadata,this.type=e.type,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,this.visibility=\"visible\",\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),this._featureFilter=function(){return!0},r.layout&&(this._unevaluatedLayout=new Rr(r.layout)),this._transitionablePaint=new Ir(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(or,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=\"none\"===e?e:\"visible\"},e.prototype.getPaintProperty=function(t){return v(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(ar,n,t,e,r))return}v(t,\"-transition\")?this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0):this._transitionablePaint.setValue(t,e)},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return\"none\"===this.visibility&&(t.layout=t.layout||{},t.layout.visibility=\"none\"),y(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return(!i||!1!==i.validate)&&sr(this,t.call(nr,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:I,style:{glyphs:!0,sprite:!0}}))},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e}(O),Gr={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},Wr=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},Yr=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Xr(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,Gr[i].BYTES_PER_ELEMENT),o=r=Zr(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:Zr(r,Math.max(n,e)),alignment:e}}function Zr(t,e){return Math.ceil(t/e)*e}Yr.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},Yr.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},Yr.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},Yr.prototype.clear=function(){this.length=0},Yr.prototype.resize=function(t){this.reserve(t),this.length=t},Yr.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},Yr.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var $r=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;this.resize(r+1);var n=2*r;return this.int16[n+0]=t,this.int16[n+1]=e,r},e}(Yr);$r.prototype.bytesPerElement=4,pr(\"StructArrayLayout2i4\",$r);var Jr=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;this.resize(i+1);var a=4*i;return this.int16[a+0]=t,this.int16[a+1]=e,this.int16[a+2]=r,this.int16[a+3]=n,i},e}(Yr);Jr.prototype.bytesPerElement=8,pr(\"StructArrayLayout4i8\",Jr);var Kr=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;this.resize(o+1);var s=6*o;return this.int16[s+0]=t,this.int16[s+1]=e,this.int16[s+2]=r,this.int16[s+3]=n,this.int16[s+4]=i,this.int16[s+5]=a,o},e}(Yr);Kr.prototype.bytesPerElement=12,pr(\"StructArrayLayout2i4i12\",Kr);var Qr=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;this.resize(l+1);var c=6*l,u=12*l;return this.int16[c+0]=t,this.int16[c+1]=e,this.int16[c+2]=r,this.int16[c+3]=n,this.uint8[u+8]=i,this.uint8[u+9]=a,this.uint8[u+10]=o,this.uint8[u+11]=s,l},e}(Yr);Qr.prototype.bytesPerElement=12,pr(\"StructArrayLayout4i4ub12\",Qr);var tn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;this.resize(l+1);var c=8*l;return this.int16[c+0]=t,this.int16[c+1]=e,this.int16[c+2]=r,this.int16[c+3]=n,this.uint16[c+4]=i,this.uint16[c+5]=a,this.uint16[c+6]=o,this.uint16[c+7]=s,l},e}(Yr);tn.prototype.bytesPerElement=16,pr(\"StructArrayLayout4i4ui16\",tn);var en=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;this.resize(n+1);var i=3*n;return this.float32[i+0]=t,this.float32[i+1]=e,this.float32[i+2]=r,n},e}(Yr);en.prototype.bytesPerElement=12,pr(\"StructArrayLayout3f12\",en);var rn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;this.resize(e+1);var r=1*e;return this.uint32[r+0]=t,e},e}(Yr);rn.prototype.bytesPerElement=4,pr(\"StructArrayLayout1ul4\",rn);var nn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var f=this.length;this.resize(f+1);var h=12*f,p=6*f;return this.int16[h+0]=t,this.int16[h+1]=e,this.int16[h+2]=r,this.int16[h+3]=n,this.int16[h+4]=i,this.int16[h+5]=a,this.uint32[p+3]=o,this.uint16[h+8]=s,this.uint16[h+9]=l,this.int16[h+10]=c,this.int16[h+11]=u,f},e}(Yr);nn.prototype.bytesPerElement=24,pr(\"StructArrayLayout6i1ul2ui2i24\",nn);var an=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;this.resize(o+1);var s=6*o;return this.int16[s+0]=t,this.int16[s+1]=e,this.int16[s+2]=r,this.int16[s+3]=n,this.int16[s+4]=i,this.int16[s+5]=a,o},e}(Yr);an.prototype.bytesPerElement=12,pr(\"StructArrayLayout2i2i2i12\",an);var on=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;this.resize(r+1);var n=4*r;return this.uint8[n+0]=t,this.uint8[n+1]=e,r},e}(Yr);on.prototype.bytesPerElement=4,pr(\"StructArrayLayout2ub4\",on);var sn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p){var d=this.length;this.resize(d+1);var g=20*d,v=10*d,m=40*d;return this.int16[g+0]=t,this.int16[g+1]=e,this.uint16[g+2]=r,this.uint16[g+3]=n,this.uint32[v+2]=i,this.uint32[v+3]=a,this.uint32[v+4]=o,this.uint16[g+10]=s,this.uint16[g+11]=l,this.uint16[g+12]=c,this.float32[v+7]=u,this.float32[v+8]=f,this.uint8[m+36]=h,this.uint8[m+37]=p,d},e}(Yr);sn.prototype.bytesPerElement=40,pr(\"StructArrayLayout2i2ui3ul3ui2f2ub40\",sn);var ln=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;this.resize(e+1);var r=1*e;return this.float32[r+0]=t,e},e}(Yr);ln.prototype.bytesPerElement=4,pr(\"StructArrayLayout1f4\",ln);var cn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;this.resize(n+1);var i=3*n;return this.int16[i+0]=t,this.int16[i+1]=e,this.int16[i+2]=r,n},e}(Yr);cn.prototype.bytesPerElement=6,pr(\"StructArrayLayout3i6\",cn);var un=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;this.resize(n+1);var i=2*n,a=4*n;return this.uint32[i+0]=t,this.uint16[a+2]=e,this.uint16[a+3]=r,n},e}(Yr);un.prototype.bytesPerElement=8,pr(\"StructArrayLayout1ul2ui8\",un);var fn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;this.resize(n+1);var i=3*n;return this.uint16[i+0]=t,this.uint16[i+1]=e,this.uint16[i+2]=r,n},e}(Yr);fn.prototype.bytesPerElement=6,pr(\"StructArrayLayout3ui6\",fn);var hn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;this.resize(r+1);var n=2*r;return this.uint16[n+0]=t,this.uint16[n+1]=e,r},e}(Yr);hn.prototype.bytesPerElement=4,pr(\"StructArrayLayout2ui4\",hn);var pn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;this.resize(r+1);var n=2*r;return this.float32[n+0]=t,this.float32[n+1]=e,r},e}(Yr);pn.prototype.bytesPerElement=8,pr(\"StructArrayLayout2f8\",pn);var dn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;this.resize(i+1);var a=4*i;return this.float32[a+0]=t,this.float32[a+1]=e,this.float32[a+2]=r,this.float32[a+3]=n,i},e}(Yr);dn.prototype.bytesPerElement=16,pr(\"StructArrayLayout4f16\",dn);var gn=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new l(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(Wr);gn.prototype.size=24;var vn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new gn(this,t)},e}(nn);pr(\"CollisionBoxArray\",vn);var mn=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},Object.defineProperties(e.prototype,r),e}(Wr);mn.prototype.size=40;var yn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new mn(this,t)},e}(sn);pr(\"PlacedSymbolArray\",yn);var xn=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(Wr);xn.prototype.size=4;var bn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new xn(this,t)},e}(ln);pr(\"GlyphOffsetArray\",bn);var _n=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(Wr);_n.prototype.size=6;var wn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new _n(this,t)},e}(cn);pr(\"SymbolLineVertexArray\",wn);var kn=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(Wr);kn.prototype.size=8;var Mn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new kn(this,t)},e}(un);pr(\"FeatureIndexArray\",Mn);var An=Xr([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Tn=function(t){void 0===t&&(t=[]),this.segments=t};Tn.prototype.prepareSegment=function(t,e,r){var n=this.segments[this.segments.length-1];return t>Tn.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+Tn.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!n||n.vertexLength+t>Tn.MAX_VERTEX_ARRAY_LENGTH)&&(n={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},this.segments.push(n)),n},Tn.prototype.get=function(){return this.segments},Tn.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Tn.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,pr(\"SegmentVector\",Tn);var Sn=function(t,e){return 256*(t=h(Math.floor(t),0,255))+h(Math.floor(e),0,255)};function Cn(t){return[Sn(255*t.r,255*t.g),Sn(255*t.b,255*t.a)]}var En=function(t,e,r){this.value=t,this.name=e,this.type=r,this.statistics={max:-1/0}};En.prototype.defines=function(){return[\"#define HAS_UNIFORM_u_\"+this.name]},En.prototype.populatePaintArray=function(){},En.prototype.upload=function(){},En.prototype.destroy=function(){},En.prototype.setUniforms=function(t,e,r,n){var i=n.constantOr(this.value),a=t.gl;\"color\"===this.type?a.uniform4f(e.uniforms[\"u_\"+this.name],i.r,i.g,i.b,i.a):a.uniform1f(e.uniforms[\"u_\"+this.name],i)};var Ln=function(t,e,r){this.expression=t,this.name=e,this.type=r,this.statistics={max:-1/0};var n=\"color\"===r?pn:ln;this.paintVertexAttributes=[{name:\"a_\"+e,type:\"Float32\",components:\"color\"===r?2:1,offset:0}],this.paintVertexArray=new n};Ln.prototype.defines=function(){return[]},Ln.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Lr(0),e);if(\"color\"===this.type)for(var a=Cn(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.statistics.max=Math.max(this.statistics.max,i)}},Ln.prototype.upload=function(t){this.paintVertexArray&&(this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes))},Ln.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ln.prototype.setUniforms=function(t,e){t.gl.uniform1f(e.uniforms[\"a_\"+this.name+\"_t\"],0)};var zn=function(t,e,r,n,i){this.expression=t,this.name=e,this.type=r,this.useIntegerZoom=n,this.zoom=i,this.statistics={max:-1/0};var a=\"color\"===r?dn:pn;this.paintVertexAttributes=[{name:\"a_\"+e,type:\"Float32\",components:\"color\"===r?4:2,offset:0}],this.paintVertexArray=new a};zn.prototype.defines=function(){return[]},zn.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Lr(this.zoom),e),a=this.expression.evaluate(new Lr(this.zoom+1),e);if(\"color\"===this.type)for(var o=Cn(i),s=Cn(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.statistics.max=Math.max(this.statistics.max,i,a)}},zn.prototype.upload=function(t){this.paintVertexArray&&(this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes))},zn.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},zn.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},zn.prototype.setUniforms=function(t,e,r){t.gl.uniform1f(e.uniforms[\"a_\"+this.name+\"_t\"],this.interpolationFactor(r.zoom))};var On=function(){this.binders={},this.cacheKey=\"\",this._buffers=[]};On.createDynamic=function(t,e,r){var n=new On,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Fr&&o.property.specification[\"property-function\"]){var s=Dn(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;\"constant\"===o.value.kind?(n.binders[a]=new En(o.value,s,l),i.push(\"/u_\"+s)):\"source\"===o.value.kind?(n.binders[a]=new Ln(o.value,s,l),i.push(\"/a_\"+s)):(n.binders[a]=new zn(o.value,s,l,c,e),i.push(\"/z_\"+s))}}return n.cacheKey=i.sort().join(\"\"),n},On.prototype.populatePaintArrays=function(t,e){for(var r in this.binders)this.binders[r].populatePaintArray(t,e)},On.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},On.prototype.setUniforms=function(t,e,r,n){for(var i in this.binders)this.binders[i].setUniforms(t,e,n,r.get(i))},On.prototype.getPaintVertexBuffers=function(){return this._buffers},On.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof Ln||i instanceof zn)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},On.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var In=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=On.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}};function Dn(t,e){return{\"text-opacity\":\"opacity\",\"icon-opacity\":\"opacity\",\"text-color\":\"fill_color\",\"icon-color\":\"fill_color\",\"text-halo-color\":\"halo_color\",\"icon-halo-color\":\"halo_color\",\"text-halo-blur\":\"halo_blur\",\"icon-halo-blur\":\"halo_blur\",\"text-halo-width\":\"halo_width\",\"icon-halo-width\":\"halo_width\",\"line-gap-width\":\"gapwidth\"}[t]||t.replace(e+\"-\",\"\").replace(/-/g,\"_\")}In.prototype.populatePaintArrays=function(t,e){for(var r in this.programConfigurations)this.programConfigurations[r].populatePaintArrays(t,e)},In.prototype.get=function(t){return this.programConfigurations[t]},In.prototype.upload=function(t){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t)},In.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},pr(\"ConstantBinder\",En),pr(\"SourceExpressionBinder\",Ln),pr(\"CompositeExpressionBinder\",zn),pr(\"ProgramConfiguration\",On,{omit:[\"_buffers\"]}),pr(\"ProgramConfigurationSet\",In);var Pn=8192,Rn=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function Fn(t){for(var e=Pn/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Rn.min||o.x>Rn.max||o.y<Rn.min||o.y>Rn.max)&&_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function Bn(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var Nn=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.layoutVertexArray=new $r,this.indexArray=new fn,this.segments=new Tn,this.programConfigurations=new In(An,t.layers,t.zoom)};function jn(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(Zn(i,e))return!0;if(Wn(e,i,r))return!0}return!1}function Vn(t,e){if(1===t.length&&1===t[0].length)return Xn(e,t[0][0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Xn(t,n[i]))return!0;for(var a=0;a<t.length;a++){for(var o=t[a],s=0;s<o.length;s++)if(Xn(e,o[s]))return!0;for(var l=0;l<e.length;l++)if(Hn(o,e[l]))return!0}return!1}function Un(t,e,r){for(var n=0;n<e.length;n++)for(var i=e[n],a=0;a<t.length;a++){var o=t[a];if(o.length>=3)for(var s=0;s<i.length;s++)if(Zn(o,i[s]))return!0;if(qn(o,i,r))return!0}return!1}function qn(t,e,r){if(t.length>1){if(Hn(t,e))return!0;for(var n=0;n<e.length;n++)if(Wn(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(Wn(t[i],e,r))return!0;return!1}function Hn(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(Gn(n,i,e[a],e[a+1]))return!0;return!1}function Gn(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function Wn(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(Yn(t,e[i-1],e[i])<n)return!0;return!1}function Yn(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Xn(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Zn(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function $n(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].statistics.max}function Jn(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Kn(t,e,r,n,i){if(!e[0]&&!e[1])return t;var a=l.convert(e);\"viewport\"===r&&a._rotate(-n);for(var o=[],s=0;s<t.length;s++){for(var c=t[s],u=[],f=0;f<c.length;f++)u.push(c[f].sub(a._mult(i)));o.push(u)}return o}Nn.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Lr(this.zoom),a)){var l=Fn(a);this.addFeature(a,l),e.featureIndex.insert(a,l,o,s,this.index)}}},Nn.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Nn.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,An),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.programConfigurations.upload(t)},Nn.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Nn.prototype.addFeature=function(t,e){for(var r=0,n=e;r<n.length;r+=1)for(var i=0,a=n[r];i<a.length;i+=1){var o=a[i],s=o.x,l=o.y;if(!(s<0||s>=Pn||l<0||l>=Pn)){var c=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),u=c.vertexLength;Bn(this.layoutVertexArray,s,l,-1,-1),Bn(this.layoutVertexArray,s,l,1,-1),Bn(this.layoutVertexArray,s,l,1,1),Bn(this.layoutVertexArray,s,l,-1,1),this.indexArray.emplaceBack(u,u+1,u+2),this.indexArray.emplaceBack(u,u+3,u+2),c.vertexLength+=4,c.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t)},pr(\"CircleBucket\",Nn,{omit:[\"layers\"]});var Qn={paint:new qr({\"circle-radius\":new jr(I.paint_circle[\"circle-radius\"]),\"circle-color\":new jr(I.paint_circle[\"circle-color\"]),\"circle-blur\":new jr(I.paint_circle[\"circle-blur\"]),\"circle-opacity\":new jr(I.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Nr(I.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Nr(I.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Nr(I.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Nr(I.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new jr(I.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new jr(I.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new jr(I.paint_circle[\"circle-stroke-opacity\"])})},ti=i(function(t,e){var r;t.exports=((r=new Float32Array(3))[0]=0,r[1]=0,r[2]=0,function(){var t=new Float32Array(4);t[0]=0,t[1]=0,t[2]=0,t[3]=0}(),{vec3:{transformMat3:function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},vec4:{transformMat4:function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},mat2:{create:function(){var t=new Float32Array(4);return t[0]=1,t[1]=0,t[2]=0,t[3]=1,t},rotate:function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},scale:function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=r[0],l=r[1];return t[0]=n*s,t[1]=i*s,t[2]=a*l,t[3]=o*l,t}},mat3:{create:function(){var t=new Float32Array(9);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=1,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},fromRotation:function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t}},mat4:{create:function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},identity:function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},translate:function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*v+f*m+e[12],t[13]=i*g+l*v+h*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},scale:function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},multiply:function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*g,t[5]=x*i+b*l+_*h+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*g,t[9]=x*i+b*l+_*h+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*g,t[13]=x*i+b*l+_*h+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},perspective:function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t},rotateX:function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t},rotateZ:function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t},invert:function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,M=u*g-f*d,A=u*v-h*d,T=u*m-p*d,S=f*v-h*g,C=f*m-p*g,E=h*m-p*v,L=y*E-x*C+b*S+_*T-w*A+k*M;return L?(L=1/L,t[0]=(s*E-l*C+c*S)*L,t[1]=(i*C-n*E-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(h*w-f*k-p*_)*L,t[4]=(l*T-o*E-c*A)*L,t[5]=(r*E-i*T+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-h*b+p*x)*L,t[8]=(o*C-s*T+c*M)*L,t[9]=(n*T-r*C-a*M)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*M)*L,t[13]=(r*S-n*A+i*M)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-f*x+h*y)*L,t):null},ortho:function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}}})}),ei=(ti.vec3,ti.vec4),ri=(ti.mat2,ti.mat3,ti.mat4),ni=function(t){function e(e){t.call(this,e,Qn)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Nn(t)},e.prototype.queryRadius=function(t){var e=t;return $n(\"circle-radius\",this,e)+$n(\"circle-stroke-width\",this,e)+Jn(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){for(var s=Kn(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),i.angle,a),l=this.paint.get(\"circle-radius\").evaluate(e)+this.paint.get(\"circle-stroke-width\").evaluate(e),c=\"map\"===this.paint.get(\"circle-pitch-alignment\"),u=c?s:function(t,e,r){return s.map(function(t){return t.map(function(t){return ii(t,e,r)})})}(0,o,i),f=c?l*a:l,h=0,p=r;h<p.length;h+=1)for(var d=0,g=p[h];d<g.length;d+=1){var v=g[d],m=c?v:ii(v,o,i),y=f,x=ei.transformMat4([],[v.x,v.y,0,1],o);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?y*=x[3]/i.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(y*=i.cameraToCenterDistance/x[3]),jn(u,m,y))return!0}return!1},e}(Hr);function ii(t,e,r){var n=ei.transformMat4([],[t.x,t.y,0,1],e);return new l((n[0]/n[3]+1)*r.width*.5,(n[1]/n[3]+1)*r.height*.5)}var ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Nn);function oi(t,e,r,n){var i=e.width,a=e.height;if(n){if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function si(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=oi({},{width:n,height:i},r);li(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function li(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,f=0;f<i.width*a;f++)s[u+f]=o[c+f];return e}pr(\"HeatmapBucket\",ai,{omit:[\"layers\"]});var ci=function(t,e){oi(this,t,1,e)};ci.prototype.resize=function(t){si(this,t,1)},ci.prototype.clone=function(){return new ci({width:this.width,height:this.height},new Uint8Array(this.data))},ci.copy=function(t,e,r,n,i){li(t,e,r,n,i,1)};var ui=function(t,e){oi(this,t,4,e)};ui.prototype.resize=function(t){si(this,t,4)},ui.prototype.clone=function(){return new ui({width:this.width,height:this.height},new Uint8Array(this.data))},ui.copy=function(t,e,r,n,i){li(t,e,r,n,i,4)},pr(\"AlphaImage\",ci),pr(\"RGBAImage\",ui);var fi={paint:new qr({\"heatmap-radius\":new jr(I.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new jr(I.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Nr(I.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new Ur(I.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Nr(I.paint_heatmap[\"heatmap-opacity\"])})};function hi(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new ui({width:256,height:1},r)}var pi=function(t){function e(e){t.call(this,e,fi),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ai(t)},e.prototype.setPaintProperty=function(e,r,n){t.prototype.setPaintProperty.call(this,e,r,n),\"heatmap-color\"===e&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=hi(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(Hr),di={paint:new qr({\"hillshade-illumination-direction\":new Nr(I.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Nr(I.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Nr(I.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Nr(I.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Nr(I.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Nr(I.paint_hillshade[\"hillshade-accent-color\"])})},gi=function(t){function e(e){t.call(this,e,di)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(Hr),vi=Xr([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,mi=xi,yi=xi;function xi(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,f=u?e[0]*r:t.length,h=bi(t,0,f,r,!0),p=[];if(!h)return p;if(u&&(h=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=bi(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Li(o));for(s.sort(Si),i=0;i<s.length;i++)Ci(s[i],r),r=_i(r,r.next);return r}(t,e,h,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<f;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return wi(h,p,r,n,i,c),p}function bi(t,e,r,n,i){var a,o;if(i===Vi(t,e,r,n)>0)for(a=e;a<r;a+=n)o=Bi(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=Bi(a,t[a],t[a+1],o);return o&&Di(o,o.next)&&(Ni(o),o=o.next),o}function _i(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!Di(n,n.next)&&0!==Ii(n.prev,n,n.next))n=n.next;else{if(Ni(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function wi(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=Ei(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?Mi(t,n,i,a):ki(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Ni(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?wi(t=Ai(t,e,r),e,r,n,i,a,2):2===o&&Ti(t,e,r,n,i,a):wi(_i(t),e,r,n,i,a,1);break}}}function ki(t){var e=t.prev,r=t,n=t.next;if(Ii(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(zi(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&Ii(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function Mi(t,e,r,n){var i=t.prev,a=t,o=t.next;if(Ii(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=Ei(s,l,e,r,n),h=Ei(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=f&&d&&d.z<=h;){if(p!==t.prev&&p!==t.next&&zi(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&Ii(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&zi(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&Ii(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&zi(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&Ii(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=h;){if(d!==t.prev&&d!==t.next&&zi(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&Ii(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function Ai(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!Di(i,a)&&Pi(i,n,n.next,a)&&Ri(i,a)&&Ri(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),Ni(n),Ni(n.next),n=t=a),n=n.next}while(n!==t);return n}function Ti(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Oi(o,s)){var l=Fi(o,s);return o=_i(o,o.next),l=_i(l,l.next),wi(o,e,r,n,i,a),void wi(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function Si(t,e){return t.x-e.x}function Ci(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,f=r.y,h=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&zi(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<h||l===h&&n.x>r.x)&&Ri(n,t)&&(r=n,h=l),n=n.next;return r}(t,e)){var r=Fi(e,t);_i(r,r.next)}}function Ei(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Li(t){var e=t,r=t;do{e.x<r.x&&(r=e),e=e.next}while(e!==t);return r}function zi(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function Oi(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&Pi(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&Ri(t,e)&&Ri(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function Ii(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function Di(t,e){return t.x===e.x&&t.y===e.y}function Pi(t,e,r,n){return!!(Di(t,e)&&Di(r,n)||Di(t,n)&&Di(r,e))||Ii(t,e,r)>0!=Ii(t,e,n)>0&&Ii(r,n,t)>0!=Ii(r,n,e)>0}function Ri(t,e){return Ii(t.prev,t,t.next)<0?Ii(t,e,t.next)>=0&&Ii(t,t.prev,e)>=0:Ii(t,e,t.prev)<0||Ii(t,t.next,e)<0}function Fi(t,e){var r=new ji(t.i,t.x,t.y),n=new ji(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function Bi(t,e,r,n){var i=new ji(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function Ni(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function ji(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Vi(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}xi.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(Vi(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(Vi(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},xi.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},mi.default=yi;var Ui=Hi,qi=Hi;function Hi(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var f=e[r],h=n,p=i;for(Gi(e,n,r),a(e[i],f)>0&&Gi(e,n,i);h<p;){for(Gi(e,h,p),h++,p--;a(e[h],f)<0;)h++;for(;a(e[p],f)>0;)p--}0===a(e[n],f)?Gi(e,n,p):Gi(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Wi)}function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Wi(t,e){return t<e?-1:t>e?1:0}function Yi(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=k(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(Ui(a[l],e,1,a[l].length-1,Xi),a[l]=a[l].slice(0,e));return a}function Xi(t,e){return e.area-t.area}Ui.default=qi;var Zi=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.layoutVertexArray=new $r,this.indexArray=new fn,this.indexArray2=new hn,this.programConfigurations=new In(vi,t.layers,t.zoom),this.segments=new Tn,this.segments2=new Tn};Zi.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Lr(this.zoom),a)){var l=Fn(a);this.addFeature(a,l),e.featureIndex.insert(a,l,o,s,this.index)}}},Zi.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Zi.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,vi),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2),this.programConfigurations.upload(t)},Zi.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Zi.prototype.addFeature=function(t,e){for(var r=0,n=Yi(e,500);r<n.length;r+=1){for(var i=n[r],a=0,o=0,s=i;o<s.length;o+=1)a+=s[o].length;for(var l=this.segments.prepareSegment(a,this.layoutVertexArray,this.indexArray),c=l.vertexLength,u=[],f=[],h=0,p=i;h<p.length;h+=1){var d=p[h];if(0!==d.length){d!==i[0]&&f.push(u.length/2);var g=this.segments2.prepareSegment(d.length,this.layoutVertexArray,this.indexArray2),v=g.vertexLength;this.layoutVertexArray.emplaceBack(d[0].x,d[0].y),this.indexArray2.emplaceBack(v+d.length-1,v),u.push(d[0].x),u.push(d[0].y);for(var m=1;m<d.length;m++)this.layoutVertexArray.emplaceBack(d[m].x,d[m].y),this.indexArray2.emplaceBack(v+m-1,v+m),u.push(d[m].x),u.push(d[m].y);g.vertexLength+=d.length,g.primitiveLength+=d.length}}for(var y=mi(u,f),x=0;x<y.length;x+=3)this.indexArray.emplaceBack(c+y[x],c+y[x+1],c+y[x+2]);l.vertexLength+=a,l.primitiveLength+=y.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t)},pr(\"FillBucket\",Zi,{omit:[\"layers\"]});var $i={paint:new qr({\"fill-antialias\":new Nr(I.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new jr(I.paint_fill[\"fill-opacity\"]),\"fill-color\":new jr(I.paint_fill[\"fill-color\"]),\"fill-outline-color\":new jr(I.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Nr(I.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Nr(I.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new Vr(I.paint_fill[\"fill-pattern\"])})},Ji=function(t){function e(e){t.call(this,e,$i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(t){this.paint=this._transitioningPaint.possiblyEvaluate(t);var e=this.paint._values[\"fill-outline-color\"];\"constant\"===e.value.kind&&void 0===e.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Zi(t)},e.prototype.queryRadius=function(){return Jn(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a){return Vn(Kn(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),i.angle,a),r)},e}(Hr),Ki=Xr([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Qi=Math.pow(2,13);function ta(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Qi)+o,i*Qi*2,a*Qi*2,Math.round(s))}var ea=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.layoutVertexArray=new Kr,this.indexArray=new fn,this.programConfigurations=new In(Ki,t.layers,t.zoom),this.segments=new Tn};function ra(t,e){return t.x===e.x&&(t.x<0||t.x>Pn)||t.y===e.y&&(t.y<0||t.y>Pn)}function na(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>Pn})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>Pn})}ea.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Lr(this.zoom),a)){var l=Fn(a);this.addFeature(a,l),e.featureIndex.insert(a,l,o,s,this.index)}}},ea.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ea.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ki),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.programConfigurations.upload(t)},ea.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ea.prototype.addFeature=function(t,e){for(var r=0,n=Yi(e,500);r<n.length;r+=1){for(var i=n[r],a=0,o=0,s=i;o<s.length;o+=1)a+=s[o].length;for(var l=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),c=0,u=i;c<u.length;c+=1){var f=u[c];if(0!==f.length&&!na(f))for(var h=0,p=0;p<f.length;p++){var d=f[p];if(p>=1){var g=f[p-1];if(!ra(d,g)){l.vertexLength+4>Tn.MAX_VERTEX_ARRAY_LENGTH&&(l=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var v=d.sub(g)._perp()._unit(),m=g.dist(d);h+m>32768&&(h=0),ta(this.layoutVertexArray,d.x,d.y,v.x,v.y,0,0,h),ta(this.layoutVertexArray,d.x,d.y,v.x,v.y,0,1,h),h+=m,ta(this.layoutVertexArray,g.x,g.y,v.x,v.y,0,0,h),ta(this.layoutVertexArray,g.x,g.y,v.x,v.y,0,1,h);var y=l.vertexLength;this.indexArray.emplaceBack(y,y+1,y+2),this.indexArray.emplaceBack(y+1,y+2,y+3),l.vertexLength+=4,l.primitiveLength+=2}}}}l.vertexLength+a>Tn.MAX_VERTEX_ARRAY_LENGTH&&(l=this.segments.prepareSegment(a,this.layoutVertexArray,this.indexArray));for(var x=[],b=[],_=l.vertexLength,w=0,k=i;w<k.length;w+=1){var M=k[w];if(0!==M.length){M!==i[0]&&b.push(x.length/2);for(var A=0;A<M.length;A++){var T=M[A];ta(this.layoutVertexArray,T.x,T.y,0,0,1,1,0),x.push(T.x),x.push(T.y)}}}for(var S=mi(x,b),C=0;C<S.length;C+=3)this.indexArray.emplaceBack(_+S[C],_+S[C+1],_+S[C+2]);l.primitiveLength+=S.length/3,l.vertexLength+=a}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t)},pr(\"FillExtrusionBucket\",ea,{omit:[\"layers\"]});var ia={paint:new qr({\"fill-extrusion-opacity\":new Nr(I[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new jr(I[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Nr(I[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Nr(I[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new Vr(I[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new jr(I[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new jr(I[\"paint_fill-extrusion\"][\"fill-extrusion-base\"])})},aa=function(t){function e(e){t.call(this,e,ia)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ea(t)},e.prototype.queryRadius=function(){return Jn(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a){return Vn(Kn(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),i.angle,a),r)},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"fill-extrusion-opacity\")&&\"none\"!==this.visibility},e.prototype.resize=function(){this.viewportFrame&&(this.viewportFrame.destroy(),this.viewportFrame=null)},e}(Hr),oa=Xr([{name:\"a_pos_normal\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,sa=la;function la(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(ca,this,e)}function ca(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function ua(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}la.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],la.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,i=0,a=0,o=0,s=[];t.pos<r;){if(i<=0){var c=t.readVarint();n=7&c,i=c>>3}if(i--,1===n||2===n)a+=t.readSVarint(),o+=t.readSVarint(),1===n&&(e&&s.push(e),e=[]),e.push(new l(a,o));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&s.push(e),s},la.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},la.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=la.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var f=[];for(n=0;n<l.length;n++)f[n]=l[n][0];u(l=f);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=ua(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var h={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(h.id=this.id),h};var fa=ha;function ha(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(pa,this,e),this.length=this._features.length}function pa(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function da(t,e,r){if(3===t){var n=new fa(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}ha.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new sa(this._pbf,e,this.extent,this._keys,this._values)};var ga={VectorTile:function(t,e){this.layers=t.readFields(da,{},e)},VectorTileFeature:sa,VectorTileLayer:fa},va=ga.VectorTileFeature.types,ma=63,ya=Math.cos(Math.PI/180*37.5),xa=.5,ba=Math.pow(2,14)/xa;function _a(t,e,r,n,i,a,o){t.emplaceBack(e.x,e.y,n?1:0,i?1:-1,Math.round(ma*r.x)+128,Math.round(ma*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*xa&63)<<2,o*xa>>6)}var wa=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.layoutVertexArray=new Qr,this.indexArray=new fn,this.programConfigurations=new In(oa,t.layers,t.zoom),this.segments=new Tn};function ka(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(ba-1)}wa.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Lr(this.zoom),a)){var l=Fn(a);this.addFeature(a,l),e.featureIndex.insert(a,l,o,s,this.index)}}},wa.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},wa.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,oa),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.programConfigurations.upload(t)},wa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},wa.prototype.addFeature=function(t,e){for(var r=this.layers[0].layout,n=r.get(\"line-join\").evaluate(t),i=r.get(\"line-cap\"),a=r.get(\"line-miter-limit\"),o=r.get(\"line-round-limit\"),s=0,l=e;s<l.length;s+=1){var c=l[s];this.addLine(c,t,n,i,a,o)}},wa.prototype.addLine=function(t,e,r,n,i,a){var o=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(o={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var s=\"Polygon\"===va[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){o&&(o.tileTotal=function(t,e,r){for(var n,i,a=0,o=c;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,l)),\"bevel\"===r&&(i=1.05);var u=Pn/(512*this.overscaling)*15,f=t[c],h=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray);this.distance=0;var p,d,g,v=n,m=s?\"butt\":n,y=!0,x=void 0,b=void 0,_=void 0,w=void 0;this.e1=this.e2=this.e3=-1,s&&(p=t[l-2],w=f.sub(p)._unit()._perp());for(var k=c;k<l;k++)if(!(b=s&&k===l-1?t[c+1]:t[k+1])||!t[k].equals(b)){w&&(_=w),p&&(x=p),p=t[k],w=b?b.sub(p)._unit()._perp():_;var M=(_=_||w).add(w);0===M.x&&0===M.y||M._unit();var A=M.x*w.x+M.y*w.y,T=0!==A?1/A:1/0,S=A<ya&&x&&b;if(S&&k>c){var C=p.dist(x);if(C>2*u){var E=p.sub(p.sub(x)._mult(u/C)._round());this.distance+=E.dist(x),this.addCurrentVertex(E,this.distance,_.mult(1),0,0,!1,h,o),x=E}}var L=x&&b,z=L?r:b?v:m;if(L&&\"round\"===z&&(T<a?z=\"miter\":T<=2&&(z=\"fakeround\")),\"miter\"===z&&T>i&&(z=\"bevel\"),\"bevel\"===z&&(T>2&&(z=\"flipbevel\"),T<i&&(z=\"miter\")),x&&(this.distance+=p.dist(x)),\"miter\"===z)M._mult(T),this.addCurrentVertex(p,this.distance,M,0,0,!1,h,o);else if(\"flipbevel\"===z){if(T>100)M=w.clone().mult(-1);else{var O=_.x*w.y-_.y*w.x>0?-1:1,I=T*_.add(w).mag()/_.sub(w).mag();M._perp()._mult(I*O)}this.addCurrentVertex(p,this.distance,M,0,0,!1,h,o),this.addCurrentVertex(p,this.distance,M.mult(-1),0,0,!1,h,o)}else if(\"bevel\"===z||\"fakeround\"===z){var D=_.x*w.y-_.y*w.x>0,P=-Math.sqrt(T*T-1);if(D?(g=0,d=P):(d=0,g=P),y||this.addCurrentVertex(p,this.distance,_,d,g,!1,h,o),\"fakeround\"===z){for(var R=Math.floor(8*(.5-(A-.5))),F=void 0,B=0;B<R;B++)F=w.mult((B+1)/(R+1))._add(_)._unit(),this.addPieSliceVertex(p,this.distance,F,D,h,o);this.addPieSliceVertex(p,this.distance,M,D,h,o);for(var N=R-1;N>=0;N--)F=_.mult((N+1)/(R+1))._add(w)._unit(),this.addPieSliceVertex(p,this.distance,F,D,h,o)}b&&this.addCurrentVertex(p,this.distance,w,-d,-g,!1,h,o)}else\"butt\"===z?(y||this.addCurrentVertex(p,this.distance,_,0,0,!1,h,o),b&&this.addCurrentVertex(p,this.distance,w,0,0,!1,h,o)):\"square\"===z?(y||(this.addCurrentVertex(p,this.distance,_,1,1,!1,h,o),this.e1=this.e2=-1),b&&this.addCurrentVertex(p,this.distance,w,-1,-1,!1,h,o)):\"round\"===z&&(y||(this.addCurrentVertex(p,this.distance,_,0,0,!1,h,o),this.addCurrentVertex(p,this.distance,_,1,1,!0,h,o),this.e1=this.e2=-1),b&&(this.addCurrentVertex(p,this.distance,w,-1,-1,!0,h,o),this.addCurrentVertex(p,this.distance,w,0,0,!1,h,o)));if(S&&k<l-1){var j=p.dist(b);if(j>2*u){var V=p.add(b.sub(p)._mult(u/j)._round());this.distance+=V.dist(p),this.addCurrentVertex(V,this.distance,w.mult(1),0,0,!1,h,o),p=V}}y=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e)}},wa.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ka(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),_a(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),_a(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>ba/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},wa.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ka(e,a)),_a(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},pr(\"LineBucket\",wa,{omit:[\"layers\"]});var Ma=new qr({\"line-cap\":new Nr(I.layout_line[\"line-cap\"]),\"line-join\":new jr(I.layout_line[\"line-join\"]),\"line-miter-limit\":new Nr(I.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Nr(I.layout_line[\"line-round-limit\"])}),Aa={paint:new qr({\"line-opacity\":new jr(I.paint_line[\"line-opacity\"]),\"line-color\":new jr(I.paint_line[\"line-color\"]),\"line-translate\":new Nr(I.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Nr(I.paint_line[\"line-translate-anchor\"]),\"line-width\":new jr(I.paint_line[\"line-width\"]),\"line-gap-width\":new jr(I.paint_line[\"line-gap-width\"]),\"line-offset\":new jr(I.paint_line[\"line-offset\"]),\"line-blur\":new jr(I.paint_line[\"line-blur\"]),\"line-dasharray\":new Vr(I.paint_line[\"line-dasharray\"]),\"line-pattern\":new Vr(I.paint_line[\"line-pattern\"]),\"line-gradient\":new Ur(I.paint_line[\"line-gradient\"])}),layout:Ma},Ta=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Lr(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n){return r=p({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n)},e}(jr))(Aa.paint.properties[\"line-width\"].specification);Ta.useIntegerZoom=!0;var Sa=function(t){function e(e){t.call(this,e,Aa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setPaintProperty=function(e,r,n){t.prototype.setPaintProperty.call(this,e,r,n),\"line-gradient\"===e&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=hi(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=Ta.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new wa(t)},e.prototype.queryRadius=function(t){var e=t,r=Ca($n(\"line-width\",this,e),$n(\"line-gap-width\",this,e)),n=$n(\"line-offset\",this,e);return r/2+Math.abs(n)+Jn(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a){var o=Kn(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),i.angle,a),s=a/2*Ca(this.paint.get(\"line-width\").evaluate(e),this.paint.get(\"line-gap-width\").evaluate(e)),c=this.paint.get(\"line-offset\").evaluate(e);return c&&(r=function(t,e){for(var r=[],n=new l(0,0),i=0;i<t.length;i++){for(var a=t[i],o=[],s=0;s<a.length;s++){var c=a[s-1],u=a[s],f=a[s+1],h=0===s?n:u.sub(c)._unit()._perp(),p=s===a.length-1?n:f.sub(u)._unit()._perp(),d=h._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),o.push(d._mult(e)._add(u))}r.push(o)}return r}(r,c*a)),Un(o,r,s)},e}(Hr);function Ca(t,e){return e>0?e+2*t:t}var Ea=Xr([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),La=Xr([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),za=(Xr([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Xr([{name:\"a_placed\",components:2,type:\"Uint8\"}],4)),Oa=(Xr([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),Xr([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ia=Xr([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function Da(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r);return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),Er.applyArabicShaping&&(t=Er.applyArabicShaping(t)),t}Xr([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"}]),Xr([{type:\"Float32\",name:\"offsetX\"}]),Xr([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var Pa={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},Ra=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(l);function Fa(t,e){var r=e.expression;if(\"constant\"===r.kind)return{functionType:\"constant\",layoutSize:r.evaluate(new Lr(t+1))};if(\"source\"===r.kind)return{functionType:\"source\"};for(var n=r.zoomStops,i=0;i<n.length&&n[i]<=t;)i++;for(var a=i=Math.max(0,i-1);a<n.length&&n[a]<t+1;)a++;a=Math.min(n.length-1,a);var o={min:n[i],max:n[a]};return\"composite\"===r.kind?{functionType:\"composite\",zoomRange:o,propertyValue:e.value}:{functionType:\"camera\",layoutSize:r.evaluate(new Lr(t+1)),zoomRange:o,sizeRange:{min:r.evaluate(new Lr(o.min)),max:r.evaluate(new Lr(o.max))},propertyValue:e.value}}pr(\"Anchor\",Ra);var Ba=ga.VectorTileFeature.types,Na=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function ja(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Va(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ua=function(t){this.layoutVertexArray=new tn,this.indexArray=new fn,this.programConfigurations=t,this.segments=new Tn,this.dynamicLayoutVertexArray=new en,this.opacityVertexArray=new rn,this.placedSymbolArray=new yn};Ua.prototype.upload=function(t,e){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ea.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.programConfigurations.upload(t),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,La.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Na,!0),this.opacityVertexBuffer.itemSize=1},Ua.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},pr(\"SymbolBuffers\",Ua);var qa=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Tn,this.collisionVertexArray=new on};qa.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,za.members,!0)},qa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},pr(\"CollisionBuffers\",qa);var Ha=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Fa(this.zoom,e[\"text-size\"]),this.iconSizeData=Fa(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout;this.sortFeaturesByY=r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")};Ha.prototype.createArrays=function(){this.text=new Ua(new In(Ea.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ua(new In(Ea.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new qa(an,Oa.members,hn),this.collisionCircle=new qa(an,Ia.members,fn),this.glyphOffsetArray=new bn,this.lineVertexArray=new wn},Ha.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0;if(this.features=[],s||l){for(var c=e.iconDependencies,u=e.glyphDependencies,f=new Lr(this.zoom),h=0,p=t;h<p.length;h+=1){var d=p[h],g=d.feature,v=d.index,m=d.sourceLayerIndex;if(r._featureFilter(f,g)){var y=void 0;s&&(y=Da(y=r.getValueAndResolveTokens(\"text-field\",g),r,g));var x=void 0;if(l&&(x=r.getValueAndResolveTokens(\"icon-image\",g)),y||x){var b={text:y,icon:x,index:v,sourceLayerIndex:m,geometry:Fn(g),properties:g.properties,type:Ba[g.type]};if(void 0!==g.id&&(b.id=g.id),this.features.push(b),x&&(c[x]=!0),y)for(var _=i.evaluate(g).join(\",\"),w=u[_]=u[_]||{},k=\"map\"===n.get(\"text-rotation-alignment\")&&\"line\"===n.get(\"symbol-placement\"),M=xr(y),A=0;A<y.length;A++)if(w[y.charCodeAt(A)]=!0,k&&M){var T=Pa[y.charAt(A)];T&&(w[T.charCodeAt(0)]=!0)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.text;if(h){var p=l(h,f),d=l(h,f,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,f),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(h,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,f):d in e?s(p,d,f):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features))}},Ha.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Ha.prototype.upload=function(t){this.text.upload(t,this.sortFeaturesByY),this.icon.upload(t,this.sortFeaturesByY),this.collisionBox.upload(t),this.collisionCircle.upload(t)},Ha.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Ha.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Ha.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,f=t.layoutVertexArray,h=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,M=p.vertexLength,A=y.glyphOffset[1];ja(f,s.x,s.y,x.x,A+x.y,k.x,k.y,r),ja(f,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),ja(f,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),ja(f,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Va(h,s,0),u.emplaceBack(M,M+1,M+2),u.emplaceBack(M+1,M+2,M+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a)},Ha.prototype._addCollisionDebugVertex=function(t,e,r,n,i){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n.x,n.y,Math.round(i.x),Math.round(i.y))},Ha.prototype.addCollisionDebugVertices=function(t,e,r,n,i,a,o,s){var c=i.segments.prepareSegment(4,i.layoutVertexArray,i.indexArray),u=c.vertexLength,f=i.layoutVertexArray,h=i.collisionVertexArray;if(this._addCollisionDebugVertex(f,h,a,o.anchor,new l(t,e)),this._addCollisionDebugVertex(f,h,a,o.anchor,new l(r,e)),this._addCollisionDebugVertex(f,h,a,o.anchor,new l(r,n)),this._addCollisionDebugVertex(f,h,a,o.anchor,new l(t,n)),c.vertexLength+=4,s){var p=i.indexArray;p.emplaceBack(u,u+1,u+2),p.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var d=i.indexArray;d.emplaceBack(u,u+1),d.emplaceBack(u+1,u+2),d.emplaceBack(u+2,u+3),d.emplaceBack(u+3,u),c.primitiveLength+=4}},Ha.prototype.generateCollisionDebugBuffers=function(){for(var t=0,e=this.symbolInstances;t<e.length;t+=1){var r=e[t];r.textCollisionFeature={boxStartIndex:r.textBoxStartIndex,boxEndIndex:r.textBoxEndIndex},r.iconCollisionFeature={boxStartIndex:r.iconBoxStartIndex,boxEndIndex:r.iconBoxEndIndex};for(var n=0;n<2;n++){var i=r[0===n?\"textCollisionFeature\":\"iconCollisionFeature\"];if(i)for(var a=i.boxStartIndex;a<i.boxEndIndex;a++){var o=this.collisionBoxArray.get(a),s=o.x1,l=o.y1,c=o.x2,u=o.y2,f=o.radius>0;this.addCollisionDebugVertices(s,l,c,u,f?this.collisionCircle:this.collisionBox,o.anchorPoint,r,f)}}}},Ha.prototype.deserializeCollisionBoxes=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Ha.prototype.hasTextData=function(){return this.text.segments.get().length>0},Ha.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Ha.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Ha.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Ha.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&(this.sortedAngle=t,!(this.text.segments.get().length>1||this.icon.segments.get().length>1))){for(var r=[],n=0;n<this.symbolInstances.length;n++)r.push(n);var i=Math.sin(t),a=Math.cos(t);r.sort(function(t,r){var n=e.symbolInstances[t],o=e.symbolInstances[r];return(i*n.anchor.x+a*n.anchor.y|0)-(i*o.anchor.x+a*o.anchor.y|0)||o.featureIndex-n.featureIndex}),this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var o=0,s=r;o<s.length;o+=1){var l=s[o],c=e.symbolInstances[l];e.featureSortOrder.push(c.featureIndex);for(var u=0,f=c.placedTextSymbolIndices;u<f.length;u+=1)for(var h=f[u],p=e.text.placedSymbolArray.get(h),d=p.vertexStartIndex+4*p.numGlyphs,g=p.vertexStartIndex;g<d;g+=4)e.text.indexArray.emplaceBack(g,g+1,g+2),e.text.indexArray.emplaceBack(g+1,g+2,g+3);var v=e.icon.placedSymbolArray.get(l);if(v.numGlyphs){var m=v.vertexStartIndex;e.icon.indexArray.emplaceBack(m,m+1,m+2),e.icon.indexArray.emplaceBack(m+1,m+2,m+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},pr(\"SymbolBucket\",Ha,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"],shallow:[\"symbolInstances\"]}),Ha.MAX_GLYPHS=65535,Ha.addDynamicAttributes=Va;var Ga=new qr({\"symbol-placement\":new Nr(I.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Nr(I.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Nr(I.layout_symbol[\"symbol-avoid-edges\"]),\"icon-allow-overlap\":new Nr(I.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Nr(I.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Nr(I.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Nr(I.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new jr(I.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Nr(I.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Nr(I.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new jr(I.layout_symbol[\"icon-image\"]),\"icon-rotate\":new jr(I.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Nr(I.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Nr(I.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new jr(I.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new jr(I.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Nr(I.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Nr(I.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Nr(I.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new jr(I.layout_symbol[\"text-field\"]),\"text-font\":new jr(I.layout_symbol[\"text-font\"]),\"text-size\":new jr(I.layout_symbol[\"text-size\"]),\"text-max-width\":new jr(I.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Nr(I.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new jr(I.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new jr(I.layout_symbol[\"text-justify\"]),\"text-anchor\":new jr(I.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Nr(I.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new jr(I.layout_symbol[\"text-rotate\"]),\"text-padding\":new Nr(I.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Nr(I.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new jr(I.layout_symbol[\"text-transform\"]),\"text-offset\":new jr(I.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Nr(I.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Nr(I.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Nr(I.layout_symbol[\"text-optional\"])}),Wa={paint:new qr({\"icon-opacity\":new jr(I.paint_symbol[\"icon-opacity\"]),\"icon-color\":new jr(I.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new jr(I.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new jr(I.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new jr(I.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Nr(I.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Nr(I.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new jr(I.paint_symbol[\"text-opacity\"]),\"text-color\":new jr(I.paint_symbol[\"text-color\"]),\"text-halo-color\":new jr(I.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new jr(I.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new jr(I.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Nr(I.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Nr(I.paint_symbol[\"text-translate-anchor\"])}),layout:Ga},Ya=function(t){function e(e){t.call(this,e,Wa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"line\"===this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"line\"===this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||_e(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Ha(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(Hr),Xa={paint:new qr({\"background-color\":new Nr(I.paint_background[\"background-color\"]),\"background-pattern\":new Vr(I.paint_background[\"background-pattern\"]),\"background-opacity\":new Nr(I.paint_background[\"background-opacity\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Hr),$a={paint:new qr({\"raster-opacity\":new Nr(I.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Nr(I.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Nr(I.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Nr(I.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Nr(I.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Nr(I.paint_raster[\"raster-contrast\"]),\"raster-fade-duration\":new Nr(I.paint_raster[\"raster-fade-duration\"])})},Ja={circle:ni,heatmap:pi,hillshade:gi,fill:Ji,\"fill-extrusion\":aa,line:Sa,symbol:Ya,background:Za,raster:function(t){function e(e){t.call(this,e,$a)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Hr)},Ka=i(function(t,e){t.exports=function(){function t(t,e,r){r=r||{},this.w=t||64,this.h=e||64,this.autoResize=!!r.autoResize,this.shelves=[],this.freebins=[],this.stats={},this.bins={},this.maxId=0}function e(t,e,r){this.x=0,this.y=t,this.w=this.free=e,this.h=r}return t.prototype.pack=function(t,e){t=[].concat(t),e=e||{};for(var r,n,i,a,o=[],s=0;s<t.length;s++)if(r=t[s].w||t[s].width,n=t[s].h||t[s].height,i=t[s].id,r&&n){if(!(a=this.packOne(r,n,i)))continue;e.inPlace&&(t[s].x=a.x,t[s].y=a.y,t[s].id=a.id),o.push(a)}return this.shrink(),o},t.prototype.packOne=function(t,r,n){var i,a,o,s,l,c,u,f,h={freebin:-1,shelf:-1,waste:1/0},p=0;if(\"string\"==typeof n||\"number\"==typeof n){if(i=this.getBin(n))return this.ref(i),i;\"number\"==typeof n&&(this.maxId=Math.max(n,this.maxId))}else n=++this.maxId;for(s=0;s<this.freebins.length;s++){if(r===(i=this.freebins[s]).maxh&&t===i.maxw)return this.allocFreebin(s,t,r,n);r>i.maxh||t>i.maxw||r<=i.maxh&&t<=i.maxw&&(o=i.maxw*i.maxh-t*r)<h.waste&&(h.waste=o,h.freebin=s)}for(s=0;s<this.shelves.length;s++)if(p+=(a=this.shelves[s]).h,!(t>a.free)){if(r===a.h)return this.allocShelf(s,t,r,n);r>a.h||r<a.h&&(o=(a.h-r)*t)<h.waste&&(h.freebin=-1,h.waste=o,h.shelf=s)}return-1!==h.freebin?this.allocFreebin(h.freebin,t,r,n):-1!==h.shelf?this.allocShelf(h.shelf,t,r,n):r<=this.h-p&&t<=this.w?(a=new e(p,this.w,r),this.allocShelf(this.shelves.push(a)-1,t,r,n)):this.autoResize?(l=c=this.h,((u=f=this.w)<=l||t>u)&&(f=2*Math.max(t,u)),(l<u||r>l)&&(c=2*Math.max(r,l)),this.resize(f,c),this.packOne(t,r,n)):null},t.prototype.allocFreebin=function(t,e,r,n){var i=this.freebins.splice(t,1)[0];return i.id=n,i.w=e,i.h=r,i.refcount=0,this.bins[n]=i,this.ref(i),i},t.prototype.allocShelf=function(t,e,r,n){var i=this.shelves[t].alloc(e,r,n);return this.bins[n]=i,this.ref(i),i},t.prototype.shrink=function(){if(this.shelves.length>0){for(var t=0,e=0,r=0;r<this.shelves.length;r++){var n=this.shelves[r];e+=n.h,t=Math.max(n.w-n.free,t)}this.resize(t,e)}},t.prototype.getBin=function(t){return this.bins[t]},t.prototype.ref=function(t){if(1==++t.refcount){var e=t.h;this.stats[e]=1+(0|this.stats[e])}return t.refcount},t.prototype.unref=function(t){return 0===t.refcount?0:(0==--t.refcount&&(this.stats[t.h]--,delete this.bins[t.id],this.freebins.push(t)),t.refcount)},t.prototype.clear=function(){this.shelves=[],this.freebins=[],this.stats={},this.bins={},this.maxId=0},t.prototype.resize=function(t,e){this.w=t,this.h=e;for(var r=0;r<this.shelves.length;r++)this.shelves[r].resize(t);return!0},e.prototype.alloc=function(t,e,r){if(t>this.free||e>this.h)return null;var n=this.x;return this.x+=t,this.free-=t,new function(t,e,r,n,i,a,o){this.id=t,this.x=e,this.y=r,this.w=n,this.h=i,this.maxw=a||n,this.maxh=o||i,this.refcount=0}(r,n,this.y,t,e,t,this.h)},e.prototype.resize=function(t){return this.free+=t-this.w,this.w=t,!0},t}()}),Qa=function(t,e){var r=e.pixelRatio;this.paddedRect=t,this.pixelRatio=r},to={tl:{configurable:!0},br:{configurable:!0},displaySize:{configurable:!0}};to.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},to.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},to.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(Qa.prototype,to);var eo=function(t){var e=new ui({width:0,height:0}),r={},n=new Ka(0,0,{autoResize:!0});for(var i in t){var a=t[i],o=n.packOne(a.data.width+2,a.data.height+2);e.resize({width:n.w,height:n.h}),ui.copy(a.data,e,{x:0,y:0},{x:o.x+1,y:o.y+1},a.data),r[i]=new Qa(o,a)}n.shrink(),e.resize({width:n.w,height:n.h}),this.image=e,this.positions=r};pr(\"ImagePosition\",Qa),pr(\"ImageAtlas\",eo);var ro=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},no=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},io=ao;function ao(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function oo(t){return t.type===ao.Bytes?t.readVarint()+t.pos:t.pos+1}function so(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function lo(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.ceil(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function co(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function uo(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function fo(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function ho(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function po(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function go(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function vo(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function mo(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function yo(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function xo(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function bo(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function _o(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}ao.Varint=0,ao.Fixed64=1,ao.Bytes=2,ao.Fixed32=5,ao.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=xo(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=_o(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=xo(this.buf,this.pos)+4294967296*xo(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=xo(this.buf,this.pos)+4294967296*_o(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=ro(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=ro(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return so(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return so(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return so(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return so(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return so(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return so(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){var r=oo(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){var e=oo(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===ao.Varint)for(;this.buf[this.pos++]>127;);else if(e===ao.Bytes)this.pos=this.readVarint()+this.pos;else if(e===ao.Fixed32)this.pos+=4;else{if(e!==ao.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),bo(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),bo(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),bo(this.buf,-1&t,this.pos),bo(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),bo(this.buf,-1&t,this.pos),bo(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&lo(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),no(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),no(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&lo(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,ao.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){this.writeMessage(t,co,e)},writePackedSVarint:function(t,e){this.writeMessage(t,uo,e)},writePackedBoolean:function(t,e){this.writeMessage(t,po,e)},writePackedFloat:function(t,e){this.writeMessage(t,fo,e)},writePackedDouble:function(t,e){this.writeMessage(t,ho,e)},writePackedFixed32:function(t,e){this.writeMessage(t,go,e)},writePackedSFixed32:function(t,e){this.writeMessage(t,vo,e)},writePackedFixed64:function(t,e){this.writeMessage(t,mo,e)},writePackedSFixed64:function(t,e){this.writeMessage(t,yo,e)},writeBytesField:function(t,e){this.writeTag(t,ao.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,ao.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,ao.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,ao.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,ao.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,ao.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,ao.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,ao.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,ao.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,ao.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var wo=3;function ko(t,e,r){1===t&&r.readMessage(Mo,e)}function Mo(t,e,r){if(3===t){var n=r.readMessage(Ao,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new ci({width:o+2*wo,height:s+2*wo},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function Ao(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var To=wo,So=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,g([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};So.prototype.send=function(t,e,r,n){var i=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[i]=r);var a=[];this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(i),data:gr(e,a)},a)},So.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?gr(t):null,data:gr(e,n)},n)};if(\"<response>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(vr(n.error)):e&&e(null,vr(n.data));else if(void 0!==n.id&&this.parent[n.type])this.parent[n.type](n.sourceMapId,vr(n.data),a);else if(void 0!==n.id&&this.parent.getWorkerSource){var o=n.type.split(\".\");this.parent.getWorkerSource(n.sourceMapId,o[0],o[1])[o[2]](vr(n.data),a)}else this.parent[n.type](vr(n.data))}},So.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var Co=n(i(function(t,e){!function(t){function e(t,e,n){var i=r(256*t,256*(e=Math.pow(2,n)-e-1),n),a=r(256*(t+1),256*(e+1),n);return i[0]+\",\"+i[1]+\",\"+a[0]+\",\"+a[1]}function r(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}t.getURL=function(t,r,n,i,a,o){return o=o||{},t+\"?\"+[\"bbox=\"+e(n,i,a),\"format=\"+(o.format||\"image/png\"),\"service=\"+(o.service||\"WMS\"),\"version=\"+(o.version||\"1.1.1\"),\"request=\"+(o.request||\"GetMap\"),\"srs=\"+(o.srs||\"EPSG:3857\"),\"width=\"+(o.width||256),\"height=\"+(o.height||256),\"layers=\"+r].join(\"&\")},t.getTileBBox=e,t.getMercCoords=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(e)})),Eo=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Oo(0,t,e,r)};Eo.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Eo.prototype.url=function(t,e){var r=Co.getTileBBox(this.x,this.y,this.z),n=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",n).replace(\"{bbox-epsg-3857}\",r)};var Lo=function(t,e){this.wrap=t,this.canonical=e,this.key=Oo(t,e.z,e.x,e.y)},zo=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Eo(r,+n,+i),this.key=Oo(e,t,n,i)};function Oo(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zo.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zo.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zo(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zo(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zo.prototype.isChildOf=function(t){var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zo.prototype.children=function(t){if(this.overscaledZ>=t)return[new zo(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zo(e,this.wrap,e,r,n),new zo(e,this.wrap,e,r+1,n),new zo(e,this.wrap,e,r,n+1),new zo(e,this.wrap,e,r+1,n+1)]},zo.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zo.prototype.wrapped=function(){return new zo(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zo.prototype.unwrapTo=function(t){return new zo(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zo.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zo.prototype.toUnwrapped=function(){return new Lo(this.wrap,this.canonical)},zo.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zo.prototype.toCoordinate=function(){return new s(this.canonical.x+Math.pow(2,this.wrap),this.canonical.y,this.canonical.z)},pr(\"CanonicalTileID\",Eo),pr(\"OverscaledTileID\",zo,{omit:[\"posMatrix\"]});var Io=function(t,e,r){if(t<=0)throw new RangeError(\"Level must have positive dimension\");this.dim=t,this.border=e,this.stride=this.dim+2*this.border,this.data=r||new Int32Array((this.dim+2*this.border)*(this.dim+2*this.border))};Io.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Io.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Io.prototype._idx=function(t,e){if(t<-this.border||t>=this.dim+this.border||e<-this.border||e>=this.dim+this.border)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+this.border)*this.stride+(t+this.border)},pr(\"Level\",Io);var Do=function(t,e,r){this.uid=t,this.scale=e||1,this.level=r||new Io(256,512),this.loaded=!!r};Do.prototype.loadFromImage=function(t,e){if(t.height!==t.width)throw new RangeError(\"DEM tiles must be square\");if(e&&\"mapbox\"!==e&&\"terrarium\"!==e)return _('\"'+e+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var r=this.level=new Io(t.width,t.width/2),n=t.data;this._unpackData(r,n,e||\"mapbox\");for(var i=0;i<r.dim;i++)r.set(-1,i,r.get(0,i)),r.set(r.dim,i,r.get(r.dim-1,i)),r.set(i,-1,r.get(i,0)),r.set(i,r.dim,r.get(i,r.dim-1));r.set(-1,-1,r.get(0,0)),r.set(r.dim,-1,r.get(r.dim-1,0)),r.set(-1,r.dim,r.get(0,r.dim-1)),r.set(r.dim,r.dim,r.get(r.dim-1,r.dim-1)),this.loaded=!0},Do.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Do.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Do.prototype._unpackData=function(t,e,r){for(var n={mapbox:this._unpackMapbox,terrarium:this._unpackTerrarium}[r],i=0;i<t.dim;i++)for(var a=0;a<t.dim;a++){var o=4*(i*t.dim+a);t.set(a,i,this.scale*n(e[o],e[o+1],e[o+2]))}},Do.prototype.getPixels=function(){return new ui({width:this.level.dim+2*this.level.border,height:this.level.dim+2*this.level.border},new Uint8Array(this.level.data.buffer))},Do.prototype.backfillBorder=function(t,e,r){var n=this.level,i=t.level;if(n.dim!==i.dim)throw new Error(\"level mismatch (dem dimension)\");var a=e*n.dim,o=e*n.dim+n.dim,s=r*n.dim,l=r*n.dim+n.dim;switch(e){case-1:a=o-1;break;case 1:o=a+1}switch(r){case-1:s=l-1;break;case 1:l=s+1}for(var c=h(a,-n.border,n.dim+n.border),u=h(o,-n.border,n.dim+n.border),f=h(s,-n.border,n.dim+n.border),p=h(l,-n.border,n.dim+n.border),d=-e*n.dim,g=-r*n.dim,v=f;v<p;v++)for(var m=c;m<u;m++)n.set(m,v,i.get(m+d,v+g))},pr(\"DEMData\",Do);var Po=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Po.prototype.encode=function(t){return this._stringToNumber[t]},Po.prototype.decode=function(t){return this._numberToString[t]};var Ro=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Fo={geometry:{configurable:!0}};Fo.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Fo.geometry.set=function(t){this._geometry=t},Ro.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Ro.prototype,Fo);var Bo=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new lr(Pn,16,0),this.featureIndexArray=r||new Mn};function No(t,e){return e-t}Bo.prototype.insert=function(t,e,r,n,i){var a=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var o=0;o<e.length;o++){for(var s=e[o],l=[1/0,1/0,-1/0,-1/0],c=0;c<s.length;c++){var u=s[c];l[0]=Math.min(l[0],u.x),l[1]=Math.min(l[1],u.y),l[2]=Math.max(l[2],u.x),l[3]=Math.max(l[3],u.y)}l[0]<Pn&&l[1]<Pn&&l[2]>=0&&l[3]>=0&&this.grid.insert(a,l[0],l[1],l[2],l[3])}},Bo.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new ga.VectorTile(new io(this.rawTileData)).layers,this.sourceLayerCoder=new Po(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Bo.prototype.query=function(t,e){var r=this;this.loadVTLayers();for(var n=t.params||{},i=Pn/t.tileSize/t.scale,a=Re(n.filter),o=t.queryGeometry,s=t.queryPadding*i,l=1/0,c=1/0,u=-1/0,f=-1/0,h=0;h<o.length;h++)for(var p=o[h],d=0;d<p.length;d++){var g=p[d];l=Math.min(l,g.x),c=Math.min(c,g.y),u=Math.max(u,g.x),f=Math.max(f,g.y)}var v=this.grid.query(l-s,c-s,u+s,f+s);v.sort(No);for(var m,y={},x=function(s){var l=v[s];if(l!==m){m=l;var c=r.featureIndexArray.get(l),u=null;r.loadMatchingFeature(y,c.bucketIndex,c.sourceLayerIndex,c.featureIndex,a,n.layers,e,function(e,n){return u||(u=Fn(e)),n.queryIntersectsFeature(o,e,u,r.z,t.transform,i,t.posMatrix)})}},b=0;b<v.length;b++)x(b);return y},Bo.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Lr(this.tileID.overscaledZ),u))for(var f=0;f<l.length;f++){var h=l[f];if(!(a&&a.indexOf(h)<0)){var p=o[h];if(p&&(!s||s(u,p))){var d=new Ro(u,this.z,this.x,this.y);d.layer=p.serialize();var g=t[h];void 0===g&&(g=t[h]=[]),g.push({featureIndex:n,feature:d})}}}}},Bo.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Re(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Bo.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},pr(\"FeatureIndex\",Bo,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var jo={horizontal:1,vertical:2,horizontalOnly:3},Vo={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Uo={};function qo(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function Ho(t,e){var r=0;return 10===t&&(r-=1e4),40!==t&&65288!==t||(r+=50),41!==e&&65289!==e||(r+=50),r}function Go(t,e,r,n,i,a){for(var o=null,s=qo(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],f=qo(e-u.x,r,i,a)+u.badness;f<=s&&(o=u,s=f)}return{index:t,x:e,priorBreak:o,badness:s}}function Wo(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length;a++){var o=n[t.charCodeAt(a)];o&&(i+=o.metrics.advance+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=0,l=0;l<t.length;l++){var c=t.charCodeAt(l),u=n[c];u&&!Vo[c]&&(s+=u.metrics.advance+e),l<t.length-1&&(Uo[c]||!((i=c)<11904)&&(yr[\"Bopomofo Extended\"](i)||yr.Bopomofo(i)||yr[\"CJK Compatibility Forms\"](i)||yr[\"CJK Compatibility Ideographs\"](i)||yr[\"CJK Compatibility\"](i)||yr[\"CJK Radicals Supplement\"](i)||yr[\"CJK Strokes\"](i)||yr[\"CJK Symbols and Punctuation\"](i)||yr[\"CJK Unified Ideographs Extension A\"](i)||yr[\"CJK Unified Ideographs\"](i)||yr[\"Enclosed CJK Letters and Months\"](i)||yr[\"Halfwidth and Fullwidth Forms\"](i)||yr.Hiragana(i)||yr[\"Ideographic Description Characters\"](i)||yr[\"Kangxi Radicals\"](i)||yr[\"Katakana Phonetic Extensions\"](i)||yr.Katakana(i)||yr[\"Vertical Forms\"](i)||yr[\"Yi Radicals\"](i)||yr[\"Yi Syllables\"](i)))&&a.push(Go(l+1,s,o,a,Ho(c,t.charCodeAt(l+1)),!1))}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Go(t.length,s,o,a,0,!0))}function Yo(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Xo(t,e,r,n,i){if(i){var a=e[t[n].glyph];if(a)for(var o=a.metrics.advance,s=(t[n].x+o)*i,l=r;l<=n;l++)t[l].x-=s}}Uo[10]=!0,Uo[32]=!0,Uo[38]=!0,Uo[40]=!0,Uo[41]=!0,Uo[43]=!0,Uo[45]=!0,Uo[47]=!0,Uo[173]=!0,Uo[183]=!0,Uo[8203]=!0,Uo[8208]=!0,Uo[8211]=!0,Uo[8231]=!0,e.commonjsGlobal=r,e.unwrapExports=n,e.createCommonjsModule=i,e.default=self,e.default$1=l,e.getJSON=function(t,e){var r=T(t);return r.setRequestHeader(\"Accept\",\"application/json\"),r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if(r.status>=200&&r.status<300&&r.response){var n;try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n)}else 401===r.status&&t.url.match(/mapbox.com/)?e(new A(r.statusText+\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens\",r.status,t.url)):e(new A(r.statusText,r.status,t.url))},r.send(),r},e.getImage=function(t,e){return S(t,function(t,r){if(t)e(t);else if(r){var n=new self.Image,i=self.URL||self.webkitURL;n.onload=function(){e(null,n),i.revokeObjectURL(n.src)};var a=new self.Blob([new Uint8Array(r.data)],{type:\"image/png\"});n.cacheControl=r.cacheControl,n.expires=r.expires,n.src=r.data.byteLength?i.createObjectURL(a):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}})},e.ResourceType=M,e.RGBAImage=ui,e.default$2=Ka,e.ImagePosition=Qa,e.getArrayBuffer=S,e.default$3=function(t){return new io(t).readFields(ko,[])},e.default$4=yr,e.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},e.AlphaImage=ci,e.default$5=I,e.endsWith=v,e.extend=p,e.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},e.Evented=O,e.validateStyle=nr,e.validateLight=ir,e.emitValidationErrors=sr,e.default$6=tt,e.number=wt,e.Properties=qr,e.Transitionable=Ir,e.Transitioning=Pr,e.PossiblyEvaluated=Br,e.DataConstantProperty=Nr,e.warnOnce=_,e.uniqueId=function(){return d++},e.default$7=So,e.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},e.wrap=function(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i},e.clamp=h,e.Event=L,e.ErrorEvent=z,e.OverscaledTileID=zo,e.default$8=Pn,e.createLayout=Xr,e.getCoordinatesCenter=function(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0;a<t.length;a++)e=Math.min(e,t[a].column),r=Math.min(r,t[a].row),n=Math.max(n,t[a].column),i=Math.max(i,t[a].row);var o=n-e,l=i-r,c=Math.max(o,l),u=Math.max(0,Math.floor(-Math.log(c)/Math.LN2));return new s((e+n)/2,(r+i)/2,0).zoomTo(u)},e.CanonicalTileID=Eo,e.RasterBoundsArray=Jr,e.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return i},e.default$9=D,e.bindAll=g,e.default$10=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},e.parseCacheControl=function(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e},e.default$11=Bo,e.default$12=Ro,e.default$13=Re,e.default$14=Ha,e.CollisionBoxArray=vn,e.default$15=Tn,e.TriangleIndexArray=fn,e.default$16=Lr,e.default$17=s,e.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},e.default$18=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],e.mat4=ri,e.vec4=ei,e.getSizeData=Fa,e.evaluateSizeForFeature=function(t,e,r){var n=e;return\"source\"===t.functionType?r.lowerSize/10:\"composite\"===t.functionType?wt(r.lowerSize/10,r.upperSize/10,n.uSizeT):n.uSize},e.evaluateSizeForZoom=function(t,e,r){if(\"constant\"===t.functionType)return{uSizeT:0,uSize:t.layoutSize};if(\"source\"===t.functionType)return{uSizeT:0,uSize:0};if(\"camera\"===t.functionType){var n=t.propertyValue,i=t.zoomRange,a=t.sizeRange,o=h(Se(n,r.specification).interpolationFactor(e,i.min,i.max),0,1);return{uSizeT:0,uSize:a.min+o*(a.max-a.min)}}var s=t.propertyValue,l=t.zoomRange;return{uSizeT:h(Se(s,r.specification).interpolationFactor(e,l.min,l.max),0,1),uSize:0}},e.addDynamicAttributes=Va,e.default$19=Wa,e.WritingMode=jo,e.multiPolygonIntersectsBufferedPoint=jn,e.multiPolygonIntersectsMultiPolygon=Vn,e.multiPolygonIntersectsBufferedMultiLine=Un,e.polygonIntersectsPolygon=function(t,e){for(var r=0;r<t.length;r++)if(Zn(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Zn(t,e[n]))return!0;return!!Hn(t,e)},e.distToSegmentSquared=Yn,e.default$20=ti,e.default$21=Hr,e.default$22=function(t){return new Ja[t.type](t)},e.clone=x,e.filterObject=y,e.mapObject=m,e.registerForPluginAvailability=function(t){return Tr?t({pluginURL:Tr,completionCallback:Mr}):Cr.once(\"pluginAvailable\",t),t},e.evented=Cr,e.default$23=mr,e.default$24=On,e.PosArray=$r,e.UnwrappedTileID=Lo,e.ease=f,e.bezier=u,e.setRTLTextPlugin=function(t,e){if(Ar)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Ar=!0,Tr=t,Mr=function(t){t?(Ar=!1,Tr=null,e&&e(t)):Sr=!0},Cr.fire(new L(\"pluginAvailable\",{pluginURL:Tr,completionCallback:Mr}))},e.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},e.default$25=Ra,e.register=pr,e.GLYPH_PBF_BORDER=To,e.shapeText=function(t,e,r,n,i,a,o,s,l,c){var u=t.trim();c===jo.vertical&&(u=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&wr(n)&&!Pa[t[r+1]]||i&&wr(i)&&!Pa[t[r-1]]||!Pa[t[r]]?e+=t[r]:e+=Pa[t[r]]}return e}(u));var f=[],h={positionedGlyphs:f,text:u,top:s[1],bottom:s[1],left:s[0],right:s[0],writingMode:c},p=Er.processBidirectionalText;return function(t,e,r,n,i,a,o,s,l){for(var c=0,u=-17,f=0,h=t.positionedGlyphs,p=\"right\"===a?1:\"left\"===a?0:.5,d=0,g=r;d<g.length;d+=1){var v=g[d];if((v=v.trim()).length){for(var m=h.length,y=0;y<v.length;y++){var x=v.charCodeAt(y),b=e[x];b&&(_r(x)&&o!==jo.horizontal?(h.push({glyph:x,x:c,y:0,vertical:!0}),c+=l+s):(h.push({glyph:x,x:c,y:u,vertical:!1}),c+=b.metrics.advance+s))}if(h.length!==m){var _=c-s;f=Math.max(_,f),Xo(h,e,m,h.length-1,p)}c=0,u+=n}else u+=n}var w=Yo(i),k=w.horizontalAlign,M=w.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,p,k,M,f,n,r.length);var A=r.length*n;t.top+=-M*A,t.bottom=t.top+A,t.left+=-k*f,t.right=t.left+f}(h,e,p?p(u,Wo(u,o,r,e)):function(t,e){for(var r=[],n=0,i=0,a=e;i<a.length;i+=1){var o=a[i];r.push(t.substring(n,o)),n=o}return n<t.length&&r.push(t.substring(n,t.length)),r}(u,Wo(u,o,r,e)),n,i,a,c,o,l),!!f.length&&h},e.shapeIcon=function(t,e,r){var n=Yo(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}},e.allowsVerticalWritingMode=xr,e.allowsLetterSpacing=function(t){for(var e=0,r=t;e<r.length;e+=1)if(!br(r[e].charCodeAt(0)))return!1;return!0},e.default$26=Yi,e.default$27=Po,e.default$28=eo,e.default$29=ga,e.default$30=io,e.default$31=Do,e.__moduleExports=ga,e.default$32=l,e.__moduleExports$1=io,e.plugin=Er}),i(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.default$18;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){t&&this.replace(t)};function i(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],f=t[o],h=t[o+1];if(!h)return!1;var p=u.angleTo(f)-f.angleTo(h);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=f.dist(h)}return!0}function a(e,r,n,a,o,s,l,c,u){var f=a?.6*s*l:0,h=Math.max(a?a.right-a.left:0,o?o.right-o.left:0),p=0===e[0].x||e[0].x===u||0===e[0].y||e[0].y===u;return r-h*l<r/4&&(r=h*l+r/4),function e(r,n,a,o,s,l,c,u,f){for(var h=l/2,p=0,d=0;d<r.length-1;d++)p+=r[d].dist(r[d+1]);for(var g=0,v=n-a,m=[],y=0;y<r.length-1;y++){for(var x=r[y],b=r[y+1],_=x.dist(b),w=b.angleTo(x);v+a<g+_;){var k=((v+=a)-g)/_,M=t.number(x.x,b.x,k),A=t.number(x.y,b.y,k);if(M>=0&&M<f&&A>=0&&A<f&&v-h>=0&&v+h<=p){var T=new t.default$25(M,A,w,y);T._round(),o&&!i(r,T,l,o,s)||m.push(T)}}g+=_}return u||m.length||c||(m=e(r,g/2,a,o,s,l,c,!0,f)),m}(e,p?r/2*c%r:(h/2+2*s)*l*c%r,r,f,n,h*l,p,!1,u)}n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];i._layerConfigs[s.id]=s;var l=i._layers[s.id]=t.default$22(s);l._featureFilter=t.default$13(l.filter)}for(var c=0,u=n;c<u.length;c+=1){var f=u[c];delete i._layerConfigs[f],delete i._layers[f]}this.familiesBySource={};for(var h=0,p=function(t){for(var e={},n=0;n<t.length;n++){var i=r(t[n]),a=e[i];a||(a=e[i]=[]),a.push(t[n])}var o=[];for(var s in e)o.push(e[s]);return o}(t.values(this._layerConfigs));h<p.length;h+=1){var d=p[h].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=i.familiesBySource[v];m||(m=i.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var o=function(){this.opacity=0,this.targetOpacity=0,this.time=0};o.prototype.clone=function(){var t=new o;return t.opacity=this.opacity,t.targetOpacity=this.targetOpacity,t.time=this.time,t},t.register(\"OpacityState\",o);var s=function(t,e,r,n,i,a,o,s,l,c,u){var f=o.top*s-l,h=o.bottom*s+l,p=o.left*s-l,d=o.right*s+l;if(this.boxStartIndex=t.length,c){var g=h-f,v=d-p;g>0&&(g=Math.max(10*s,g),this._addLineCollisionCircles(t,e,r,r.segment,v,g,n,i,a,u))}else t.emplaceBack(r.x,r.y,p,f,d,h,n,i,a,0,0);this.boxEndIndex=t.length};s.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,f=Math.floor(i/u),h=1+.4*Math.log(c)/Math.LN2,p=Math.floor(f*h/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<f+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var M=k-m,A=e[v],T=e[v+1].sub(A)._unit()._mult(M)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(T.x,T.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var l=u,c=u;function u(t,e){if(!(this instanceof u))return new u(t,e);if(this.data=t||[],this.length=this.data.length,this.compare=e||f,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)}function f(t,e){return t<e?-1:t>e?1:0}function h(e,r,n){void 0===r&&(r=1),void 0===n&&(n=!1);for(var i=1/0,a=1/0,o=-1/0,s=-1/0,c=e[0],u=0;u<c.length;u++){var f=c[u];(!u||f.x<i)&&(i=f.x),(!u||f.y<a)&&(a=f.y),(!u||f.x>o)&&(o=f.x),(!u||f.y>s)&&(s=f.y)}var h=o-i,g=s-a,v=Math.min(h,g),m=v/2,y=new l(null,p);if(0===v)return new t.default$1(i,a);for(var x=i;x<o;x+=v)for(var b=a;b<s;b+=v)y.push(new d(x+m,b+m,m,e));for(var _=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new d(r/e,n/e,0,t)}(e),w=y.length;y.length;){var k=y.pop();(k.d>_.d||!_.d)&&(_=k,n&&console.log(\"found best %d after %d probes\",Math.round(1e4*k.d)/1e4,w)),k.max-_.d<=r||(m=k.h/2,y.push(new d(k.p.x-m,k.p.y-m,m,e)),y.push(new d(k.p.x+m,k.p.y-m,m,e)),y.push(new d(k.p.x-m,k.p.y+m,m,e)),y.push(new d(k.p.x+m,k.p.y+m,m,e)),w+=4)}return n&&(console.log(\"num probes: \"+w),console.log(\"best distance: \"+_.d)),_.p}function p(t,e){return e.max-t.max}function d(e,r,n,i){this.p=new t.default$1(e,r),this.h=n,this.d=function(e,r){for(var n=!1,i=1/0,a=0;a<r.length;a++)for(var o=r[a],s=0,l=o.length,c=l-1;s<l;c=s++){var u=o[s],f=o[c];u.y>e.y!=f.y>e.y&&e.x<(f.x-u.x)*(e.y-u.y)/(f.y-u.y)+u.x&&(n=!n),i=Math.min(i,t.distToSegmentSquared(e,u,f))}return(n?1:-1)*Math.sqrt(i)}(this.p,i),this.max=this.d+this.h*Math.SQRT2}function g(e,r,n,i,a,o){e.createArrays(),e.symbolInstances=[];var s=512*e.overscaling;e.tilePixelRatio=t.default$8/s,e.compareText={},e.iconsNeedLinear=!1;var l=e.layers[0].layout,c=e.layers[0]._unevaluatedLayout._values,u={};if(\"composite\"===e.textSizeData.functionType){var f=e.textSizeData.zoomRange,h=f.min,p=f.max;u.compositeTextSizes=[c[\"text-size\"].possiblyEvaluate(new t.default$16(h)),c[\"text-size\"].possiblyEvaluate(new t.default$16(p))]}if(\"composite\"===e.iconSizeData.functionType){var d=e.iconSizeData.zoomRange,g=d.min,m=d.max;u.compositeIconSizes=[c[\"icon-size\"].possiblyEvaluate(new t.default$16(g)),c[\"icon-size\"].possiblyEvaluate(new t.default$16(m))]}u.layoutTextSize=c[\"text-size\"].possiblyEvaluate(new t.default$16(e.zoom+1)),u.layoutIconSize=c[\"icon-size\"].possiblyEvaluate(new t.default$16(e.zoom+1)),u.textMaxSize=c[\"text-size\"].possiblyEvaluate(new t.default$16(18));for(var y=24*l.get(\"text-line-height\"),x=\"map\"===l.get(\"text-rotation-alignment\")&&\"line\"===l.get(\"symbol-placement\"),b=l.get(\"text-keep-upright\"),_=0,w=e.features;_<w.length;_+=1){var k=w[_],M=l.get(\"text-font\").evaluate(k).join(\",\"),A=r[M]||{},T=n[M]||{},S={},C=k.text;if(C){var E=l.get(\"text-offset\").evaluate(k).map(function(t){return 24*t}),L=24*l.get(\"text-letter-spacing\").evaluate(k),z=t.allowsLetterSpacing(C)?L:0,O=l.get(\"text-anchor\").evaluate(k),I=l.get(\"text-justify\").evaluate(k),D=\"line\"!==l.get(\"symbol-placement\")?24*l.get(\"text-max-width\").evaluate(k):0;S.horizontal=t.shapeText(C,A,D,y,O,I,z,E,24,t.WritingMode.horizontal),t.allowsVerticalWritingMode(C)&&x&&b&&(S.vertical=t.shapeText(C,A,D,y,O,I,z,E,24,t.WritingMode.vertical))}var P=void 0;if(k.icon){var R=i[k.icon];R&&(P=t.shapeIcon(a[k.icon],l.get(\"icon-offset\").evaluate(k),l.get(\"icon-anchor\").evaluate(k)),void 0===e.sdfIcons?e.sdfIcons=R.sdf:e.sdfIcons!==R.sdf&&t.warnOnce(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),R.pixelRatio!==e.pixelRatio?e.iconsNeedLinear=!0:0!==l.get(\"icon-rotate\").constantOr(1)&&(e.iconsNeedLinear=!0))}(S.horizontal||P)&&v(e,k,S,P,T,u)}o&&e.generateCollisionDebugBuffers()}function v(e,r,n,i,l,c){var u=c.layoutTextSize.evaluate(r),f=c.layoutIconSize.evaluate(r),p=c.textMaxSize.evaluate(r);void 0===p&&(p=u);var d=e.layers[0].layout,g=d.get(\"text-offset\").evaluate(r),v=d.get(\"icon-offset\").evaluate(r),x=u/24,b=e.tilePixelRatio*x,_=e.tilePixelRatio*p/24,w=e.tilePixelRatio*f,k=e.tilePixelRatio*d.get(\"symbol-spacing\"),M=d.get(\"text-padding\")*e.tilePixelRatio,A=d.get(\"icon-padding\")*e.tilePixelRatio,T=d.get(\"text-max-angle\")/180*Math.PI,S=\"map\"===d.get(\"text-rotation-alignment\")&&\"line\"===d.get(\"symbol-placement\"),C=\"map\"===d.get(\"icon-rotation-alignment\")&&\"line\"===d.get(\"symbol-placement\"),E=k/2,L=function(a,u){u.x<0||u.x>=t.default$8||u.y<0||u.y>=t.default$8||e.symbolInstances.push(function(e,r,n,i,a,l,c,u,f,h,p,d,g,v,y,x,b,_,w,k,M){var A,T,S=e.addToLineVertexArray(r,n),C=0,E=0,L=0,z=i.horizontal?i.horizontal.text:\"\",O=[];i.horizontal&&(A=new s(c,n,r,u,f,h,i.horizontal,p,d,g,e.overscaling),E+=m(e,r,i.horizontal,l,g,w,v,S,i.vertical?t.WritingMode.horizontal:t.WritingMode.horizontalOnly,O,k,M),i.vertical&&(L+=m(e,r,i.vertical,l,g,w,v,S,t.WritingMode.vertical,O,k,M)));var I=A?A.boxStartIndex:e.collisionBoxArray.length,D=A?A.boxEndIndex:e.collisionBoxArray.length;if(a){var P=function(e,r,n,i,a,o){var s,l,c,u,f=r.image,h=n.layout,p=r.top-1/f.pixelRatio,d=r.left-1/f.pixelRatio,g=r.bottom+1/f.pixelRatio,v=r.right+1/f.pixelRatio;if(\"none\"!==h.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=h.get(\"text-size\").evaluate(o)/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,M=a.bottom*x-w,A=h.get(\"icon-text-fit-padding\")[0],T=h.get(\"icon-text-fit-padding\")[1],S=h.get(\"icon-text-fit-padding\")[2],C=h.get(\"icon-text-fit-padding\")[3],E=\"width\"===h.get(\"icon-text-fit\")?.5*(M-y):0,L=\"height\"===h.get(\"icon-text-fit\")?.5*(k-m):0,z=\"width\"===h.get(\"icon-text-fit\")||\"both\"===h.get(\"icon-text-fit\")?k:m,O=\"height\"===h.get(\"icon-text-fit\")||\"both\"===h.get(\"icon-text-fit\")?M:y;s=new t.default$1(b+L-C,w+E-A),l=new t.default$1(b+L+T+z,w+E-A),c=new t.default$1(b+L+T+z,w+E+S+O),u=new t.default$1(b+L-C,w+E+S+O)}else s=new t.default$1(d,p),l=new t.default$1(v,p),c=new t.default$1(v,g),u=new t.default$1(d,g);var I=n.layout.get(\"icon-rotate\").evaluate(o)*Math.PI/180;if(I){var D=Math.sin(I),P=Math.cos(I),R=[P,-D,D,P];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:f.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,l,0,i.horizontal,w);T=new s(c,n,r,u,f,h,a,y,x,!1,e.overscaling),C=4*P.length;var R=e.iconSizeData,F=null;\"source\"===R.functionType?F=[10*l.layout.get(\"icon-size\").evaluate(w)]:\"composite\"===R.functionType&&(F=[10*M.compositeIconSizes[0].evaluate(w),10*M.compositeIconSizes[1].evaluate(w)]),e.addSymbols(e.icon,P,F,_,b,w,!1,r,S.lineStartIndex,S.lineLength)}var B=T?T.boxStartIndex:e.collisionBoxArray.length,N=T?T.boxEndIndex:e.collisionBoxArray.length;return e.glyphOffsetArray.length>=t.default$14.MAX_GLYPHS&&t.warnOnce(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),{key:z,textBoxStartIndex:I,textBoxEndIndex:D,iconBoxStartIndex:B,iconBoxEndIndex:N,textOffset:v,iconOffset:_,anchor:r,line:n,featureIndex:u,feature:w,numGlyphVertices:E,numVerticalGlyphVertices:L,numIconVertices:C,textOpacityState:new o,iconOpacityState:new o,isDuplicate:!1,placedTextSymbolIndices:O,crossTileID:0}}(e,u,a,n,i,e.layers[0],e.collisionBoxArray,r.index,r.sourceLayerIndex,e.index,b,M,S,g,w,A,C,v,r,l,c))};if(\"line\"===d.get(\"symbol-placement\"))for(var z=0,O=function(e,r,n,i,a){for(var o=[],s=0;s<e.length;s++)for(var l=e[s],c=void 0,u=0;u<l.length-1;u++){var f=l[u],h=l[u+1];f.x<0&&h.x<0||(f.x<0?f=new t.default$1(0,f.y+(h.y-f.y)*((0-f.x)/(h.x-f.x)))._round():h.x<0&&(h=new t.default$1(0,f.y+(h.y-f.y)*((0-f.x)/(h.x-f.x)))._round()),f.y<0&&h.y<0||(f.y<0?f=new t.default$1(f.x+(h.x-f.x)*((0-f.y)/(h.y-f.y)),0)._round():h.y<0&&(h=new t.default$1(f.x+(h.x-f.x)*((0-f.y)/(h.y-f.y)),0)._round()),f.x>=i&&h.x>=i||(f.x>=i?f=new t.default$1(i,f.y+(h.y-f.y)*((i-f.x)/(h.x-f.x)))._round():h.x>=i&&(h=new t.default$1(i,f.y+(h.y-f.y)*((i-f.x)/(h.x-f.x)))._round()),f.y>=a&&h.y>=a||(f.y>=a?f=new t.default$1(f.x+(h.x-f.x)*((a-f.y)/(h.y-f.y)),a)._round():h.y>=a&&(h=new t.default$1(f.x+(h.x-f.x)*((a-f.y)/(h.y-f.y)),a)._round()),c&&f.equals(c[c.length-1])||(c=[f],o.push(c)),c.push(h)))))}return o}(r.geometry,0,0,t.default$8,t.default$8);z<O.length;z+=1)for(var I=O[z],D=0,P=a(I,k,T,n.vertical||n.horizontal,i,24,_,e.overscaling,t.default$8);D<P.length;D+=1){var R=P[D],F=n.horizontal;F&&y(e,F.text,E,R)||L(I,R)}else if(\"Polygon\"===r.type)for(var B=0,N=t.default$26(r.geometry,0);B<N.length;B+=1){var j=N[B],V=h(j,16);L(j[0],new t.default$25(V.x,V.y,0))}else if(\"LineString\"===r.type)for(var U=0,q=r.geometry;U<q.length;U+=1){var H=q[U];L(H,new t.default$25(H[0].x,H[0].y,0))}else if(\"Point\"===r.type)for(var G=0,W=r.geometry;G<W.length;G+=1)for(var Y=0,X=W[G];Y<X.length;Y+=1){var Z=X[Y];L([Z],new t.default$25(Z.x,Z.y,0))}}function m(e,r,n,i,a,o,s,l,c,u,f,h){var p=function(e,r,n,i,a,o){for(var s=n.layout.get(\"text-rotate\").evaluate(a)*Math.PI/180,l=n.layout.get(\"text-offset\").evaluate(a).map(function(t){return 24*t}),c=r.positionedGlyphs,u=[],f=0;f<c.length;f++){var h=c[f],p=o[h.glyph];if(p){var d=p.rect;if(d){var g=t.GLYPH_PBF_BORDER+1,v=p.metrics.advance/2,m=i?[h.x+v,h.y]:[0,0],y=i?[0,0]:[h.x+v+l[0],h.y+l[1]],x=p.metrics.left-g-v+y[0],b=-p.metrics.top-g+y[1],_=x+d.w,w=b+d.h,k=new t.default$1(x,b),M=new t.default$1(_,b),A=new t.default$1(x,w),T=new t.default$1(_,w);if(i&&h.vertical){var S=new t.default$1(-v,v),C=-Math.PI/2,E=new t.default$1(5,0);k._rotateAround(C,S)._add(E),M._rotateAround(C,S)._add(E),A._rotateAround(C,S)._add(E),T._rotateAround(C,S)._add(E)}if(s){var L=Math.sin(s),z=Math.cos(s),O=[z,-L,L,z];k._matMult(O),M._matMult(O),A._matMult(O),T._matMult(O)}u.push({tl:k,tr:M,bl:A,br:T,tex:d,writingMode:r.writingMode,glyphOffset:m})}}}return u}(0,n,i,a,o,f),d=e.textSizeData,g=null;return\"source\"===d.functionType?g=[10*i.layout.get(\"text-size\").evaluate(o)]:\"composite\"===d.functionType&&(g=[10*h.compositeTextSizes[0].evaluate(o),10*h.compositeTextSizes[1].evaluate(o)]),e.addSymbols(e.text,p,g,s,a,o,c,r,l.lineStartIndex,l.lineLength),u.push(e.text.placedSymbolArray.length-1),4*p.length}function y(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}u.prototype={push:function(t){this.data.push(t),this.length++,this._up(this.length-1)},pop:function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},peek:function(){return this.data[0]},_up:function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},_down:function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=a+1,s=e[a];if(o<this.length&&r(e[o],s)<0&&(a=o,s=e[o]),r(s,i)>=0)break;e[t]=s,t=a}e[t]=i}},l.default=c;var x=function(e){var r=new t.AlphaImage({width:0,height:0}),n={},i=new t.default$2(0,0,{autoResize:!0});for(var a in e){var o=e[a],s=n[a]={};for(var l in o){var c=o[+l];if(c&&0!==c.bitmap.width&&0!==c.bitmap.height){var u=i.packOne(c.bitmap.width+2,c.bitmap.height+2);r.resize({width:i.w,height:i.h}),t.AlphaImage.copy(c.bitmap,r,{x:0,y:0},{x:u.x+1,y:u.y+1},c.bitmap),s[l]={rect:u,metrics:c.metrics}}}}i.shrink(),r.resize({width:i.w,height:i.h}),this.image=r,this.positions=n};t.register(\"GlyphAtlas\",x);var b=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming};function _(e,r){for(var n=new t.default$16(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}b.prototype.parse=function(e,r,n,i){var a=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var o=new t.default$27(Object.keys(e.layers).sort()),s=new t.default$11(this.tileID);s.bucketLayerIDs=[];var l,c,u,f={},h={featureIndex:s,iconDependencies:{},glyphDependencies:{}},p=r.familiesBySource[this.source];for(var d in p){var v=e.layers[d];if(v){1===v.version&&t.warnOnce('Vector tile source \"'+a.source+'\" layer \"'+d+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var m=o.encode(d),y=[],b=0;b<v.length;b++){var w=v.feature(b);y.push({feature:w,index:b,sourceLayerIndex:m})}for(var k=0,M=p[d];k<M.length;k+=1){var A=M[k],T=A[0];T.minzoom&&a.zoom<Math.floor(T.minzoom)||T.maxzoom&&a.zoom>=T.maxzoom||\"none\"!==T.visibility&&(_(A,a.zoom),(f[T.id]=T.createBucket({index:s.bucketLayerIDs.length,layers:A,zoom:a.zoom,pixelRatio:a.pixelRatio,overscaling:a.overscaling,collisionBoxArray:a.collisionBoxArray,sourceLayerIndex:m})).populate(y,h),s.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(h.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){l||(l=t,c=e,E.call(a))}):c={};var C=Object.keys(h.iconDependencies);function E(){if(l)return i(l);if(c&&u){var e=new x(c),r=new t.default$28(u);for(var n in f){var a=f[n];a instanceof t.default$14&&(_(a.layers,this.zoom),g(a,c,e.positions,u,r.positions,this.showCollisionBoxes))}this.status=\"done\",i(null,{buckets:t.values(f).filter(function(t){return!t.isEmpty()}),featureIndex:s,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,iconAtlasImage:r.image})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){l||(l=t,u=e,E.call(a))}):u={},E.call(this)};var w=function(t){return!(!performance||!performance.getEntriesByName)&&performance.getEntriesByName(t)};function k(e,r){var n=t.getArrayBuffer(e.request,function(e,n){e?r(e):n&&r(null,{vectorTile:new t.default$29.VectorTile(new t.default$30(n.data)),rawData:n.data,cacheControl:n.cacheControl,expires:n.expires})});return function(){n.abort(),r()}}var M=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||k,this.loading={},this.loaded={}};M.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var a=this.loading[i]=new b(e);a.abort=this.loadVectorData(e,function(o,s){if(delete n.loading[i],o||!s)return r(o);var l=s.rawData,c={};s.expires&&(c.expires=s.expires),s.cacheControl&&(c.cacheControl=s.cacheControl);var u={};if(e.request&&e.request.collectResourceTiming){var f=w(e.request.url);f&&(u.resourceTiming=JSON.parse(JSON.stringify(f)))}a.vectorTile=s.vectorTile,a.parse(s.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=a})},M.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&a.parse(a.vectorTile,this.layerIndex,this.actor,o)}},M.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},M.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var A=function(){this.loading={},this.loaded={}};A.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=new t.default$31(n);this.loading[n]=a,a.loadFromImage(e.rawImageData,i),delete this.loading[n],this.loaded=this.loaded||{},this.loaded[n]=a,r(null,a)},A.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var T={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function S(t){var e=0;if(t&&t.length>0){e+=Math.abs(C(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(C(t[r]))}return e}function C(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(E(t[a][0])-E(e[0]))*Math.sin(E(r[1]));s=s*T.RADIUS*T.RADIUS/2}return s}function E(t){return t*Math.PI/180}var L={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return S(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=S(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:C};function z(t,e){return function(r){return t(r,e)}}function O(t,e){e=!!e,t[0]=I(t[0],e);for(var r=1;r<t.length;r++)t[r]=I(t[r],!e);return t}function I(t,e){return function(t){return L.ring(t)>=0}(t)===e?t:t.reverse()}var D=t.default$29.VectorTileFeature.prototype.toGeoJSON,P=function(e){this._feature=e,this.extent=t.default$8,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};P.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.default$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var f=u[c];l.push(new t.default$1(f[0],f[1]))}a.push(l)}return a},P.prototype.toGeoJSON=function(t,e,r){return D.call(this,t,e,r)};var R=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.default$8,this.length=e.length,this._features=e};R.prototype.feature=function(t){return new P(this._features[t])};var F=t.__moduleExports.VectorTileFeature,B=N;function N(t,e){this.options=e||{},this.features=t,this.length=t.length}function j(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}N.prototype.feature=function(t){return new j(this.features[t],this.options.extent)},j.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.default$32(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},j.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},j.prototype.toGeoJSON=F.prototype.toGeoJSON;var V=H,U=H,q=B;function H(e){var r=new t.__moduleExports$1;return function(t,e){for(var r in t.layers)e.writeMessage(3,G,t.layers[r])}(e,r),r.finish()}function G(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,W,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,J,a[r])}function W(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,Y,t),e.writeVarintField(3,r.type),e.writeMessage(4,$,r)}function Y(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var f=u+\":\"+c,h=o[f];void 0===h&&(i.push(c),h=i.length-1,o[f]=h),e.writeVarint(h)}}function X(t,e){return(e<<3)+(7&t)}function Z(t){return t<<1^t>>31}function $(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(X(1,c));for(var u=3===n?l.length-1:l.length,f=0;f<u;f++){1===f&&1!==n&&e.writeVarint(X(2,u-1));var h=l[f].x-i,p=l[f].y-a;e.writeVarint(Z(h)),e.writeVarint(Z(p)),i+=h,a+=p}3===n&&e.writeVarint(X(7,0))}}function J(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}V.fromVectorTileJs=U,V.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new B(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return H({layers:r})},V.GeoJSONWrapper=q;var K=function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=Math.floor((i+a)/2);!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),f=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+f)),Math.min(a,Math.floor(n+(s-l)*u/s+f)),o)}var h=r[2*n+o],p=i,d=a;for(Q(e,r,i,n),r[2*a+o]>h&&Q(e,r,i,a);p<d;){for(Q(e,r,p,d),p++,d--;r[2*p+o]<h;)p++;for(;r[2*d+o]>h;)d--}r[2*i+o]===h?Q(e,r,i,d):Q(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}};function Q(t,e,r,n){tt(t,r,n),tt(e,2*r,2*n),tt(e,2*r+1,2*n+1)}function tt(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function et(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}var rt=function(t,e,r,n,i){return new nt(t,e,r,n,i)};function nt(t,e,r,n,i){e=e||it,r=r||at,i=i||Array,this.nodeSize=n||64,this.points=t,this.ids=new i(t.length),this.coords=new i(2*t.length);for(var a=0;a<t.length;a++)this.ids[a]=a,this.coords[2*a]=e(t[a]),this.coords[2*a+1]=r(t[a]);K(this.ids,this.coords,this.nodeSize,0,this.ids.length-1,0)}function it(t){return t[0]}function at(t){return t[1]}nt.prototype={range:function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var f=c.pop(),h=c.pop(),p=c.pop();if(h-p<=o)for(var d=p;d<=h;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+h)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(f+1)%2;(0===f?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===f?i>=s:a>=l)&&(c.push(g+1),c.push(h),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},within:function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),f=o.pop();if(u-f<=a)for(var h=f;h<=u;h++)et(e[2*h],e[2*h+1],r,n)<=l&&s.push(t[h]);else{var p=Math.floor((f+u)/2),d=e[2*p],g=e[2*p+1];et(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(f),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)}};function ot(t){this.options=pt(Object.create(this.options),t),this.trees=new Array(this.options.maxZoom+1)}function st(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:n,properties:i,parentId:-1,numPoints:r}}function lt(t,e){var r=t.geometry.coordinates;return{x:ft(r[0]),y:ht(r[1]),zoom:1/0,id:e,parentId:-1}}function ct(t){return{type:\"Feature\",properties:ut(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function ut(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return pt(pt({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function ft(t){return t/360+.5}function ht(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function pt(t,e){for(var r in e)t[r]=e[r];return t}function dt(t){return t.x}function gt(t){return t.y}function vt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function mt(t,e,r,n){var i={id:t||null,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)yt(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)yt(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)yt(t,e[n][i])}(i),i}function yt(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function xt(t,e,r){if(e.geometry){var n=e.geometry.coordinates,i=e.geometry.type,a=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),o=[];if(\"Point\"===i)bt(n,o);else if(\"MultiPoint\"===i)for(var s=0;s<n.length;s++)bt(n[s],o);else if(\"LineString\"===i)_t(n,o,a,!1);else if(\"MultiLineString\"===i)if(r.lineMetrics)for(s=0;s<n.length;s++)return o=[],_t(n[s],o,a,!1),void t.push(mt(e.id,\"LineString\",o,e.properties));else wt(n,o,a,!1);else if(\"Polygon\"===i)wt(n,o,a,!0);else{if(\"MultiPolygon\"!==i){if(\"GeometryCollection\"===i){for(s=0;s<e.geometry.geometries.length;s++)xt(t,{id:e.id,geometry:e.geometry.geometries[s],properties:e.properties},r);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(s=0;s<n.length;s++){var l=[];wt(n[s],l,a,!0),o.push(l)}}t.push(mt(e.id,i,o,e.properties))}}function bt(t,e){e.push(kt(t[0])),e.push(Mt(t[1])),e.push(0)}function _t(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=kt(t[s][0]),c=Mt(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=e[r],l=e[r+1],c=e[n],u=e[n+1],f=r+3;f<n;f+=3){var h=vt(e[f],e[f+1],s,l,c,u);h>o&&(a=f,o=h)}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function wt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];_t(t[i],a,r,n),e.push(a)}}function kt(t){return t/360+.5}function Mt(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function At(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<=n)return t;if(a>n||o<r)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<=n)l.push(u);else if(!(p>n||d<r)){var g=[];if(\"Point\"===h||\"MultiPoint\"===h)Tt(f,g,r,n,i);else if(\"LineString\"===h)St(f,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===h)Et(f,g,r,n,i,!1);else if(\"Polygon\"===h)Et(f,g,r,n,i,!0);else if(\"MultiPolygon\"===h)for(var v=0;v<f.length;v++){var m=[];Et(f[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===h){for(v=0;v<g.length;v++)l.push(mt(u.id,h,g[v],u.tags));continue}\"LineString\"!==h&&\"MultiLineString\"!==h||(1===g.length?(h=\"LineString\",g=g[0]):h=\"MultiLineString\"),\"Point\"!==h&&\"MultiPoint\"!==h||(h=3===g.length?\"Point\":\"MultiPoint\"),l.push(mt(u.id,h,g,u.tags))}}}return l.length?l:null}function Tt(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function St(t,e,r,n,i,a,o){for(var s,l,c=Ct(t),u=0===i?zt:Ot,f=t.start,h=0;h<t.length-3;h+=3){var p=t[h],d=t[h+1],g=t[h+2],v=t[h+3],m=t[h+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>=r&&(l=u(c,p,d,v,m,r),o&&(c.start=f+s*l)):y>n?x<=n&&(l=u(c,p,d,v,m,n),o&&(c.start=f+s*l)):Lt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=f+s*l),e.push(c),c=Ct(t)),o&&(f+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&Lt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&Lt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function Ct(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function Et(t,e,r,n,i,a){for(var o=0;o<t.length;o++)St(t[o],e,r,n,i,a,!1)}function Lt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function zt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function Ot(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function It(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=Dt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(Dt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(Dt(a.geometry[s][c],e));i.push(l)}r.push(mt(a.id,o,i,a.tags))}return r}function Dt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function Pt(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(Rt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var f=[];for(i=0;i<c[n].length;i+=2)f.push(Rt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(f)}}return t.transformed=!0,t}function Rt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function Ft(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Bt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,f=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),f>o.maxY&&(o.maxY=f)}return o}function Bt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)Nt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)Nt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)Nt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var f in u={},e.tags)u[f]=e.tags[f];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var h={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(h.id=e.id),t.features.push(h)}}function Nt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function jt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)xt(r,t.features[n],e);else\"Feature\"===t.type?xt(r,t,e):xt(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=At(t,1,-1-r,r,0,-1,2,e),a=At(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=At(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=It(i,1).concat(n)),a&&(n=n.concat(It(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function Vt(t,e,r){return 32*((1<<t)*r+e)+t}function Ut(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new R(n.features),a=V(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}ot.prototype={options:{minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,initial:function(){return{}},map:function(t){return t}},load:function(t){var e=this.options.log;e&&console.time(\"total time\");var r=\"prepare \"+t.length+\" points\";e&&console.time(r),this.points=t;var n=t.map(lt);e&&console.timeEnd(r);for(var i=this.options.maxZoom;i>=this.options.minZoom;i--){var a=+Date.now();this.trees[i+1]=rt(n,dt,gt,this.options.nodeSize,Float32Array),n=this._cluster(n,i),e&&console.log(\"z%d: %d clusters in %dms\",i,n.length,+Date.now()-a)}return this.trees[this.options.minZoom]=rt(n,dt,gt,this.options.nodeSize,Float32Array),e&&console.timeEnd(\"total time\"),this},getClusters:function(t,e){for(var r=this.trees[this._limitZoom(e)],n=r.range(ft(t[0]),ht(t[3]),ft(t[2]),ht(t[1])),i=[],a=0;a<n.length;a++){var o=r.points[n[a]];i.push(o.numPoints?ct(o):this.points[o.id])}return i},getChildren:function(t,e){for(var r=this.trees[e+1].points[t],n=this.options.radius/(this.options.extent*Math.pow(2,e)),i=this.trees[e+1].within(r.x,r.y,n),a=[],o=0;o<i.length;o++){var s=this.trees[e+1].points[i[o]];s.parentId===t&&a.push(s.numPoints?ct(s):this.points[s.id])}return a},getLeaves:function(t,e,r,n){r=r||10,n=n||0;var i=[];return this._appendLeaves(i,t,e,r,n,0),i},getTile:function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options.extent,o=this.options.radius/a,s=(r-o)/i,l=(r+1+o)/i,c={features:[]};return this._addTileFeatures(n.range((e-o)/i,s,(e+1+o)/i,l),n.points,e,r,i,c),0===e&&this._addTileFeatures(n.range(1-o/i,s,1,l),n.points,i,r,i,c),e===i-1&&this._addTileFeatures(n.range(0,s,o/i,l),n.points,-1,r,i,c),c.features.length?c:null},getClusterExpansionZoom:function(t,e){for(;e<this.options.maxZoom;){var r=this.getChildren(t,e);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},_appendLeaves:function(t,e,r,n,i,a){for(var o=this.getChildren(e,r),s=0;s<o.length;s++){var l=o[s].properties;if(l.cluster?a+l.point_count<=i?a+=l.point_count:a=this._appendLeaves(t,l.cluster_id,r+1,n,i,a):a<i?a++:t.push(o[s]),t.length===n)break}return a},_addTileFeatures:function(t,e,r,n,i,a){for(var o=0;o<t.length;o++){var s=e[t[o]];a.features.push({type:1,geometry:[[Math.round(this.options.extent*(s.x*i-r)),Math.round(this.options.extent*(s.y*i-n))]],tags:s.numPoints?ut(s):this.points[s.id].properties})}},_limitZoom:function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},_cluster:function(t,e){for(var r=[],n=this.options.radius/(this.options.extent*Math.pow(2,e)),i=0;i<t.length;i++){var a=t[i];if(!(a.zoom<=e)){a.zoom=e;var o=this.trees[e+1],s=o.within(a.x,a.y,n),l=a.numPoints||1,c=a.x*l,u=a.y*l,f=null;this.options.reduce&&(f=this.options.initial(),this._accumulate(f,a));for(var h=0;h<s.length;h++){var p=o.points[s[h]];if(e<p.zoom){var d=p.numPoints||1;p.zoom=e,c+=p.x*d,u+=p.y*d,l+=d,p.parentId=i,this.options.reduce&&this._accumulate(f,p)}}1===l?r.push(a):(a.parentId=i,r.push(st(c/l,u/l,l,i,f)))}}return r},_accumulate:function(t,e){var r=e.numPoints?e.properties:this.options.map(this.points[e.id].properties);this.options.reduce(t,r)}},jt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,debug:0},jt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,f=Vt(e,r,n),h=this.tiles[f];if(!h&&(c>1&&console.time(\"creation\"),h=this.tiles[f]=Ft(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,h.numFeatures,h.numPoints,h.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(h.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||h.numPoints<=l.indexMaxPoints)continue;if(h.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,M=1+_;g=v=m=y=null,x=At(t,u,r-_,r+k,0,h.minX,h.maxX,l),b=At(t,u,r+w,r+M,0,h.minX,h.maxX,l),t=null,x&&(g=At(x,u,n-_,n+k,1,h.minY,h.maxY,l),v=At(x,u,n+w,n+M,1,h.minY,h.maxY,l),x=null),b&&(m=At(b,u,n-_,n+k,1,h.minY,h.maxY,l),y=At(b,u,n+w,n+M,1,h.minY,h.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},jt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=Vt(t,e=(e%o+o)%o,r);if(this.tiles[s])return Pt(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,f=r;!l&&c>0;)c--,u=Math.floor(u/2),f=Math.floor(f/2),l=this.tiles[Vt(c,u,f)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,f),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,f,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?Pt(this.tiles[s],i):null):null};var qt=function(e){function r(t,r,n){e.call(this,t,r,Ut),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var t=this;if(this._pendingCallback&&this._pendingLoadDataParams){var e=this._pendingCallback,r=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams,this.loadGeoJSON(r,function(n,i){if(n||!i)return e(n);if(\"object\"!=typeof i)return e(new Error(\"Input data is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(z(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=O(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(z(O,e))),t}(e,r);default:return e}}(i,!0);try{t._geoJSONIndex=r.cluster?function(t){return new ot(t)}(r.superclusterOptions).load(i.features):new jt(i,r.geojsonVtOptions)}catch(n){return e(n)}t.loaded={};var a={};if(r.request&&r.request.collectResourceTiming){var o=w(r.request.url);o&&(a.resourceTiming={},a.resourceTiming[r.source]=JSON.parse(JSON.stringify(o)))}e(null,a)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r}(M),Ht=function(e){var r=this;this.self=e,this.actor=new t.default$7(e,this),this.layerIndexes={},this.workerSourceTypes={vector:M,geojson:qt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText}};return Ht.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Ht.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Ht.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Ht.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Ht.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Ht.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Ht.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Ht.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Ht.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Ht.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Ht.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Ht.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Ht.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Ht.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new A),this.demWorkerSources[t][e]},\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope&&new Ht(self),Ht}),i(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r=t.default.performance&&t.default.performance.now?t.default.performance.now.bind(t.default.performance):Date.now.bind(Date),n=t.default.requestAnimationFrame||t.default.mozRequestAnimationFrame||t.default.webkitRequestAnimationFrame||t.default.msRequestAnimationFrame,i=t.default.cancelAnimationFrame||t.default.mozCancelAnimationFrame||t.default.webkitCancelAnimationFrame||t.default.msCancelAnimationFrame,a={now:r,frame:function(t){return n(t)},cancelFrame:function(t){return i(t)},getImageData:function(e){var r=t.default.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=e.width,r.height=e.height,n.drawImage(e,0,0,e.width,e.height),n.getImageData(0,0,e.width,e.height)},hardwareConcurrency:t.default.navigator.hardwareConcurrency||4,get devicePixelRatio(){return t.default.devicePixelRatio},supportsWebp:!1};if(t.default.document){var o=t.default.document.createElement(\"img\");o.onload=function(){a.supportsWebp=!0},o.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\"}var s={create:function(e,r,n){var i=t.default.document.createElement(e);return r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.default.document.createElementNS(e,r)}},l=t.default.document?t.default.document.documentElement.style:null;function c(t){if(!l)return null;for(var e=0;e<t.length;e++)if(t[e]in l)return t[e];return t[0]}var u,f=c([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);s.disableDrag=function(){l&&f&&(u=l[f],l[f]=\"none\")},s.enableDrag=function(){l&&f&&(l[f]=u)};var h=c([\"transform\",\"WebkitTransform\"]);s.setTransform=function(t,e){t.style[h]=e};var p=!1;try{var d=Object.defineProperty({},\"passive\",{get:function(){p=!0}});t.default.addEventListener(\"test\",d,d),t.default.removeEventListener(\"test\",d,d)}catch(t){p=!1}s.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&p?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},s.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&p?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var g=function(e){e.preventDefault(),e.stopPropagation(),t.default.removeEventListener(\"click\",g,!0)};s.suppressClick=function(){t.default.addEventListener(\"click\",g,!0),t.default.setTimeout(function(){t.default.removeEventListener(\"click\",g,!0)},0)},s.mousePos=function(e,r){var n=e.getBoundingClientRect();return r=r.touches?r.touches[0]:r,new t.default$1(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},s.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.default$1(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},s.mouseButton=function(e){return void 0!==t.default.InstallTrigger&&2===e.button&&e.ctrlKey&&t.default.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},s.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var v={API_URL:\"https://api.mapbox.com\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null},m=\"See https://www.mapbox.com/api-documentation/#access-tokens\";function y(t,e){var r=A(v.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!v.REQUIRE_ACCESS_TOKEN)return T(t);if(!(e=e||v.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+m);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+m);return t.params.push(\"access_token=\"+e),T(t)}function x(t){return 0===t.indexOf(\"mapbox:\")}var b=function(t,e){if(!x(t))return t;var r=A(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),y(r,e)},_=function(t,e,r,n){var i=A(t);return x(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,y(i,n)):(i.path+=\"\"+e+r,T(i))},w=/(\\.(png|jpg)\\d*)(?=$)/,k=function(t,e,r){if(!e||!x(e))return t;var n=A(t),i=a.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=a.supportsWebp?\".webp\":\"$1\";return n.path=n.path.replace(w,\"\"+i+o),function(t){for(var e=0;e<t.length;e++)0===t[e].indexOf(\"access_token=tk.\")&&(t[e]=\"access_token=\"+(v.ACCESS_TOKEN||\"\"))}(n.params),T(n)},M=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function A(t){var e=t.match(M);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function T(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}var S=t.default.HTMLImageElement,C=t.default.HTMLCanvasElement,E=t.default.HTMLVideoElement,L=t.default.ImageData,z=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};z.prototype.update=function(t,e){var r=t.width,n=t.height,i=!this.size||this.size[0]!==r||this.size[1]!==n,a=this.context,o=a.gl;this.useMipmap=Boolean(e&&e.useMipmap),o.bindTexture(o.TEXTURE_2D,this.texture),i?(this.size=[r,n],a.pixelStoreUnpack.set(1),this.format!==o.RGBA||e&&!1===e.premultiply||a.pixelStoreUnpackPremultiplyAlpha.set(!0),t instanceof S||t instanceof C||t instanceof E||t instanceof L?o.texImage2D(o.TEXTURE_2D,0,this.format,this.format,o.UNSIGNED_BYTE,t):o.texImage2D(o.TEXTURE_2D,0,this.format,r,n,0,this.format,o.UNSIGNED_BYTE,t.data)):t instanceof S||t instanceof C||t instanceof E||t instanceof L?o.texSubImage2D(o.TEXTURE_2D,0,0,0,o.RGBA,o.UNSIGNED_BYTE,t):o.texSubImage2D(o.TEXTURE_2D,0,0,0,r,n,o.RGBA,o.UNSIGNED_BYTE,t.data),this.useMipmap&&this.isSizePowerOfTwo()&&o.generateMipmap(o.TEXTURE_2D)},z.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},z.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},z.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var O=function(){this.images={},this.loaded=!1,this.requestors=[],this.shelfPack=new t.default$2(64,64,{autoResize:!0}),this.patterns={},this.atlasImage=new t.RGBAImage({width:64,height:64}),this.dirty=!0};O.prototype.isLoaded=function(){return this.loaded},O.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},O.prototype.getImage=function(t){return this.images[t]},O.prototype.addImage=function(t,e){this.images[t]=e},O.prototype.removeImage=function(t){delete this.images[t];var e=this.patterns[t];e&&(this.shelfPack.unref(e.bin),delete this.patterns[t])},O.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},O.prototype._notify=function(t,e){for(var r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=this.images[a];o&&(r[a]={data:o.data.clone(),pixelRatio:o.pixelRatio,sdf:o.sdf})}e(null,r)},O.prototype.getPixelSize=function(){return{width:this.shelfPack.w,height:this.shelfPack.h}},O.prototype.getPattern=function(e){var r=this.patterns[e];if(r)return r.position;var n=this.getImage(e);if(!n)return null;var i=n.data.width+2,a=n.data.height+2,o=this.shelfPack.packOne(i,a);if(!o)return null;this.atlasImage.resize(this.getPixelSize());var s=n.data,l=this.atlasImage,c=o.x+1,u=o.y+1,f=s.width,h=s.height;t.RGBAImage.copy(s,l,{x:0,y:0},{x:c,y:u},{width:f,height:h}),t.RGBAImage.copy(s,l,{x:0,y:h-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(s,l,{x:0,y:0},{x:c,y:u+h},{width:f,height:1}),t.RGBAImage.copy(s,l,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:h}),t.RGBAImage.copy(s,l,{x:0,y:0},{x:c+f,y:u},{width:1,height:h}),this.dirty=!0;var p=new t.ImagePosition(o,n);return this.patterns[e]={bin:o,position:p},p},O.prototype.bind=function(t){var e=t.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new z(t,this.atlasImage,e.RGBA),this.atlasTexture.bind(e.LINEAR,e.CLAMP_TO_EDGE)};var I=P,D=1e20;function P(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function R(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(F(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(F(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function F(t,e,r,n,i){r[0]=0,n[0]=-D,n[1]=+D;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+D}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}P.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?D:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?D:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(R(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),R(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var B=function(t,e){this.requestTransform=t,this.localIdeographFontFamily=e,this.entries={}};B.prototype.setURL=function(t){this.url=t},B.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],B.loadGlyphRange(r,s,n.url,n.requestTransform,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},B.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.default$4[\"CJK Unified Ideographs\"](n)||t.default$4[\"Hangul Syllables\"](n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new B.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},B.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i(function(t,e){if(!x(t))return t;var r=A(t);return r.path=\"/fonts/v1\"+r.path,y(r,e)}(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.default$3(r.data);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},B.TinySDF=I;var N=function(){this.specification=t.default$5.light.position};N.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},N.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var j=new t.Properties({anchor:new t.DataConstantProperty(t.default$5.light.anchor),position:new N,color:new t.DataConstantProperty(t.default$5.light.color),intensity:new t.DataConstantProperty(t.default$5.light.intensity)}),V=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(j),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e){if(!this._validate(t.validateLight,e))for(var r in e){var n=e[r];t.endsWith(r,\"-transition\")?this._transitionable.setTransition(r.slice(0,-\"-transition\".length),n):this._transitionable.setValue(r,n)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r){return t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.default$5})))},r}(t.Evented),U=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};U.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},U.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var f=this.nextRow+n+u,h=this.width*f,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(h+v)]=Math.max(0,Math.min(255,_+128))}var M={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,M},U.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var q=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function H(e,r,n){var i=function(e,r){if(e)return n(e);if(r){var i=t.pick(r,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);r.vector_layers&&(i.vectorLayers=r.vector_layers,i.vectorLayerIds=i.vectorLayers.map(function(t){return t.id})),n(null,i)}};e.url?t.getJSON(r(b(e.url),t.ResourceType.Source),i):a.frame(function(){return i(null,e)})}q.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},q.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},q.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},q.Actor=t.default$7;var G=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};G.prototype.wrap=function(){return new G(t.wrap(this.lng,-180,180),this.lat)},G.prototype.toArray=function(){return[this.lng,this.lat]},G.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},G.prototype.toBounds=function(t){var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new W(new G(this.lng-r,this.lat-e),new G(this.lng+r,this.lat+e))},G.convert=function(t){if(t instanceof G)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new G(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new G(Number(t.lng),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var W=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};W.prototype.setNorthEast=function(t){return this._ne=t instanceof G?new G(t.lng,t.lat):G.convert(t),this},W.prototype.setSouthWest=function(t){return this._sw=t instanceof G?new G(t.lng,t.lat):G.convert(t),this},W.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof G)e=t,r=t;else{if(!(t instanceof W))return Array.isArray(t)?t.every(Array.isArray)?this.extend(W.convert(t)):this.extend(G.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new G(e.lng,e.lat),this._ne=new G(r.lng,r.lat)),this},W.prototype.getCenter=function(){return new G((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},W.prototype.getSouthWest=function(){return this._sw},W.prototype.getNorthEast=function(){return this._ne},W.prototype.getNorthWest=function(){return new G(this.getWest(),this.getNorth())},W.prototype.getSouthEast=function(){return new G(this.getEast(),this.getSouth())},W.prototype.getWest=function(){return this._sw.lng},W.prototype.getSouth=function(){return this._sw.lat},W.prototype.getEast=function(){return this._ne.lng},W.prototype.getNorth=function(){return this._ne.lat},W.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},W.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},W.prototype.isEmpty=function(){return!(this._sw&&this._ne)},W.convert=function(t){return!t||t instanceof W?t:new W(t)};var Y=function(t,e,r){this.bounds=W.convert(this.validateBounds(t)),this.minzoom=e||0,this.maxzoom=r||24};Y.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},Y.prototype.contains=function(t){var e=Math.floor(this.lngX(this.bounds.getWest(),t.z)),r=Math.floor(this.latY(this.bounds.getNorth(),t.z)),n=Math.ceil(this.lngX(this.bounds.getEast(),t.z)),i=Math.ceil(this.latY(this.bounds.getSouth(),t.z));return t.x>=e&&t.x<n&&t.y>=r&&t.y<i},Y.prototype.lngX=function(t,e){return(t+180)*(Math.pow(2,e)/360)},Y.prototype.latY=function(e,r){var n=t.clamp(Math.sin(Math.PI/180*e),-.9999,.9999),i=Math.pow(2,r)/(2*Math.PI);return Math.pow(2,r-1)+.5*Math.log((1+n)/(1-n))*-i};var X=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),H(this._options,this.map._transformRequest,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new Y(n.bounds,e.minzoom,e.maxzoom)),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=k(e.tileID.canonical.url(this.tiles,this.scheme),this.url),i={request:this.map._transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:a.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function o(t,n){return e.aborted?r(null):t?r(t):(n&&n.resourceTiming&&(e.resourceTiming=n.resourceTiming),this.map._refreshExpiredTiles&&e.setExpiryData(n),e.loadVectorData(n,this.map.painter),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,o.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,o.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),Z=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),H(this._options,this.map._transformRequest,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new Y(n.bounds,e.minzoom,e.maxzoom)),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=k(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._transformRequest(i,t.ResourceType.Tile),function(t,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(t)e.state=\"errored\",r(t);else if(i){n.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=n.map.painter.context,o=a.gl;e.texture=n.map.painter.getTileTexture(i.width),e.texture?e.texture.update(i,{useMipmap:!0}):(e.texture=new z(a,i,o.RGBA,{useMipmap:!0}),e.texture.bind(o.LINEAR,o.CLAMP_TO_EDGE,o.LINEAR_MIPMAP_NEAREST),a.extTextureFilterAnisotropic&&o.texParameterf(o.TEXTURE_2D,a.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,a.extTextureFilterAnisotropicMax)),e.state=\"loaded\",r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.abort(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),$=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=k(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._transformRequest(n,t.ResourceType.Tile),function(t,n){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(t)e.state=\"errored\",r(t);else if(n){this.map._refreshExpiredTiles&&e.setExpiryData(n),delete n.cacheControl,delete n.expires;var i=a.getImageData(n),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:i,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(Z),J=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type);var o=t.default$8/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.default$8,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.default$8,radius:(n.clusterRadius||50)*o,log:!1}},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)return r.fire(new t.ErrorEvent(e));var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}),this},r.prototype._updateWorkerData=function(e){var r,n,i=this,a=t.extend({},this.workerOptions),o=this._data;\"string\"==typeof o?(a.request=this.map._transformRequest((r=o,(n=t.default.document.createElement(\"a\")).href=r,n.href),t.ResourceType.Source),a.request.collectResourceTiming=this._collectResourceTiming):a.data=JSON.stringify(o),this.workerID=this.dispatcher.send(this.type+\".\"+a.source+\".loadData\",a,function(t,r){i._removed||r&&r.abandoned||(i._loaded=!0,r&&r.resourceTiming&&r.resourceTiming[i.id]&&(i._resourceTiming=r.resourceTiming[i.id].slice(0)),i.dispatcher.send(i.type+\".\"+a.source+\".coalesce\",null,null,i.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(t,e){var r=this,n=void 0===t.workerID?\"loadTile\":\"reloadTile\",i={type:this.type,uid:t.uid,tileID:t.tileID,zoom:t.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:a.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};t.workerID=this.dispatcher.send(n,i,function(i,a){return t.unloadVectorData(),t.aborted?e(null):i?e(i):(t.loadVectorData(a,r.map.painter,\"reloadTile\"===n),e(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),K=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Q=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};Q.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},Q.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var f=l;f<s;f++)u.disableVertexAttribArray(f)}e.enableAttributes(u,t);for(var h=0,p=r;h<p.length;h+=1)p[h].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},Q.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var tt=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._transformRequest(this.url,t.ResourceType.Image),function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.image=a.getImageData(n),e._finishLoading())})},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){this.coordinates=e;var r=this.map,n=e.map(function(t){return r.transform.locationCoordinate(G.convert(t)).zoomTo(0)}),i=this.centerCoord=t.getCoordinatesCenter(n);i.column=Math.floor(i.column),i.row=Math.floor(i.row),this.tileID=new t.CanonicalTileID(i.zoom,i.column,i.row),this.minzoom=this.maxzoom=i.zoom;var a=n.map(function(e){var r=e.zoomTo(i.zoom);return new t.default$1(Math.round((r.column-i.column)*t.default$8),Math.round((r.row-i.row)*t.default$8))});return this._boundsArray=new t.RasterBoundsArray,this._boundsArray.emplaceBack(a[0].x,a[0].y,0,0),this._boundsArray.emplaceBack(a[1].x,a[1].y,t.default$8,0),this._boundsArray.emplaceBack(a[3].x,a[3].y,0,t.default$8),this._boundsArray.emplaceBack(a[2].x,a[2].y,t.default$8,t.default$8),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var t=this.map.painter.context,e=t.gl;for(var r in this.boundsBuffer||(this.boundsBuffer=t.createVertexBuffer(this._boundsArray,K.members)),this.boundsVAO||(this.boundsVAO=new Q),this.texture||(this.texture=new z(t,this.image,e.RGBA),this.texture.bind(e.LINEAR,e.CLAMP_TO_EDGE)),this.tiles){var n=this.tiles[r];\"loaded\"!==n.state&&(n.state=\"loaded\",n.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),et=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];e.urls.push(e.map._transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map._rerender()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var t=this.map.painter.context,e=t.gl;for(var r in this.boundsBuffer||(this.boundsBuffer=t.createVertexBuffer(this._boundsArray,K.members)),this.boundsVAO||(this.boundsVAO=new Q),this.texture?this.video.paused||(this.texture.bind(e.LINEAR,e.CLAMP_TO_EDGE),e.texSubImage2D(e.TEXTURE_2D,0,0,0,e.RGBA,e.UNSIGNED_BYTE,this.video)):(this.texture=new z(t,this.video,e.RGBA),this.texture.bind(e.LINEAR,e.CLAMP_TO_EDGE)),this.tiles){var n=this.tiles[r];\"loaded\"!==n.state&&(n.state=\"loaded\",n.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(tt),rt=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.default$9(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.default$9(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.default$9(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.default.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.default$9(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.default$9(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.default.HTMLCanvasElement?this.options.canvas:t.default.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map._rerender()},this.pause=function(){this._playing=!1},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var t=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,t=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,t=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,K.members)),this.boundsVAO||(this.boundsVAO=new Q),this.texture?t?this.texture.update(this.canvas):this._playing&&(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.canvas)):(this.texture=new z(e,this.canvas,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(tt),nt={vector:X,raster:Z,\"raster-dem\":$,geojson:J,video:et,image:tt,canvas:rt},it=function(e,r,n,i){var a=new nt[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function at(t,e,r,n,i){var a=i.maxPitchScaleFactor(),o=t.tilesIn(r,a);o.sort(ot);for(var s=[],l=0,c=o;l<c.length;l+=1){var u=c[l];s.push({wrappedTileID:u.tileID.wrapped().key,queryResults:u.tile.queryRenderedFeatures(e,u.queryGeometry,u.scale,n,i,a,t.transform.calculatePosMatrix(u.tileID.toUnwrapped()))})}return function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],f=l[c]=l[c]||{},h=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];f[g.featureIndex]||(f[g.featureIndex]=!0,h.push(g.feature))}}return e}(s)}function ot(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var st=function(e,r){this.tileID=e,this.uid=t.uniqueId(),this.uses=0,this.tileSize=r,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.expiredRequestCount=0,this.state=\"loading\"};st.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<a.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},st.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},st.prototype.loadVectorData=function(e,r,n){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",e){if(e.featureIndex&&(this.latestFeatureIndex=e.featureIndex,e.rawTileData?(this.latestRawTileData=e.rawTileData,this.latestFeatureIndex.rawTileData=e.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=e.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==o.length){a.layers=o;for(var s=0,l=o;s<l.length;s+=1)r[l[s].id]=a}}return r}(e.buckets,r.style),n)for(var i in this.buckets){var a=this.buckets[i];a instanceof t.default$14&&(a.justReloaded=!0)}for(var o in this.queryPadding=0,this.buckets){var s=this.buckets[o];this.queryPadding=Math.max(this.queryPadding,r.style.getLayer(s.layerIds[0]).queryRadius(s))}e.iconAtlasImage&&(this.iconAtlasImage=e.iconAtlasImage),e.glyphAtlasImage&&(this.glyphAtlasImage=e.glyphAtlasImage)}else this.collisionBoxArray=new t.CollisionBoxArray},st.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.iconAtlasTexture&&this.iconAtlasTexture.destroy(),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},st.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},st.prototype.getBucket=function(t){return this.buckets[t.id]},st.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploaded||(r.upload(t),r.uploaded=!0)}var n=t.gl;this.iconAtlasImage&&(this.iconAtlasTexture=new z(t,this.iconAtlasImage,n.RGBA),this.iconAtlasImage=null),this.glyphAtlasImage&&(this.glyphAtlasTexture=new z(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},st.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:e,scale:r,tileSize:this.tileSize,posMatrix:o,transform:i,params:n,queryPadding:this.queryPadding*a},t):{}},st.prototype.querySourceFeatures=function(e,r){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var n=this.latestFeatureIndex.loadVTLayers(),i=r?r.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=t.default$13(r&&r.filter),s={z:this.tileID.overscaledZ,x:this.tileID.canonical.x,y:this.tileID.canonical.y},l=0;l<a.length;l++){var c=a.feature(l);if(o(new t.default$16(this.tileID.overscaledZ),c)){var u=new t.default$12(c,s.z,s.x,s.y);u.tile=s,e.push(u)}}}},st.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},st.prototype.setMask=function(e,r){if(!t.default$10(this.mask,e)&&(this.mask=e,this.clearMask(),!t.default$10(e,{0:!0}))){var n=new t.RasterBoundsArray,i=new t.TriangleIndexArray;this.segments=new t.default$15,this.segments.prepareSegment(0,n,i);for(var a=Object.keys(e),o=0;o<a.length;o++){var s=e[a[o]],l=t.default$8>>s.z,c=new t.default$1(s.x*l,s.y*l),u=new t.default$1(c.x+l,c.y+l),f=this.segments.prepareSegment(4,n,i);n.emplaceBack(c.x,c.y,c.x,c.y),n.emplaceBack(u.x,c.y,u.x,c.y),n.emplaceBack(c.x,u.y,c.x,u.y),n.emplaceBack(u.x,u.y,u.x,u.y);var h=f.vertexLength;i.emplaceBack(h,h+1,h+2),i.emplaceBack(h+1,h+2,h+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=r.createVertexBuffer(n,K.members),this.maskedIndexBuffer=r.createIndexBuffer(i)}},st.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},st.prototype.setExpiryData=function(e){var r=this.expirationTime;if(e.cacheControl){var n=t.parseCacheControl(e.cacheControl);n[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*n[\"max-age\"])}else e.expires&&(this.expirationTime=new Date(e.expires).getTime());if(this.expirationTime){var i=Date.now(),a=!1;if(this.expirationTime>i)a=!1;else if(r)if(this.expirationTime<r)a=!0;else{var o=this.expirationTime-r;o?this.expirationTime=i+Math.max(o,3e4):a=!0}else a=!0;a?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},st.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)};var lt=function(t,e){this.max=t,this.onRemove=e,this.reset()};lt.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},lt.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},lt.prototype.has=function(t){return t.wrapped().key in this.data},lt.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},lt.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},lt.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},lt.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},lt.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var ct=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};ct.prototype.unbindVAO=function(){this.context.extVertexArrayObject&&this.context.bindVertexArrayOES.set(null)},ct.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},ct.prototype.updateData=function(t){var e=this.context.gl;this.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},ct.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var ut={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},ft=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};ft.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},ft.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},ft.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},ft.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[ut[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},ft.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var ht=function(e){this.context=e,this.current=t.default$6.transparent};ht.prototype.get=function(){return this.current},ht.prototype.set=function(t){var e=this.current;t.r===e.r&&t.g===e.g&&t.b===e.b&&t.a===e.a||(this.context.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t)};var pt=function(t){this.context=t,this.current=1};pt.prototype.get=function(){return this.current},pt.prototype.set=function(t){this.current!==t&&(this.context.gl.clearDepth(t),this.current=t)};var dt=function(t){this.context=t,this.current=0};dt.prototype.get=function(){return this.current},dt.prototype.set=function(t){this.current!==t&&(this.context.gl.clearStencil(t),this.current=t)};var gt=function(t){this.context=t,this.current=[!0,!0,!0,!0]};gt.prototype.get=function(){return this.current},gt.prototype.set=function(t){var e=this.current;t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]&&t[3]===e[3]||(this.context.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t)};var vt=function(t){this.context=t,this.current=!0};vt.prototype.get=function(){return this.current},vt.prototype.set=function(t){this.current!==t&&(this.context.gl.depthMask(t),this.current=t)};var mt=function(t){this.context=t,this.current=255};mt.prototype.get=function(){return this.current},mt.prototype.set=function(t){this.current!==t&&(this.context.gl.stencilMask(t),this.current=t)};var yt=function(t){this.context=t,this.current={func:t.gl.ALWAYS,ref:0,mask:255}};yt.prototype.get=function(){return this.current},yt.prototype.set=function(t){var e=this.current;t.func===e.func&&t.ref===e.ref&&t.mask===e.mask||(this.context.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t)};var xt=function(t){this.context=t;var e=this.context.gl;this.current=[e.KEEP,e.KEEP,e.KEEP]};xt.prototype.get=function(){return this.current},xt.prototype.set=function(t){var e=this.current;t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]||(this.context.gl.stencilOp(t[0],t[1],t[2]),this.current=t)};var bt=function(t){this.context=t,this.current=!1};bt.prototype.get=function(){return this.current},bt.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t}};var _t=function(t){this.context=t,this.current=[0,1]};_t.prototype.get=function(){return this.current},_t.prototype.set=function(t){var e=this.current;t[0]===e[0]&&t[1]===e[1]||(this.context.gl.depthRange(t[0],t[1]),this.current=t)};var wt=function(t){this.context=t,this.current=!1};wt.prototype.get=function(){return this.current},wt.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t}};var kt=function(t){this.context=t,this.current=t.gl.LESS};kt.prototype.get=function(){return this.current},kt.prototype.set=function(t){this.current!==t&&(this.context.gl.depthFunc(t),this.current=t)};var Mt=function(t){this.context=t,this.current=!1};Mt.prototype.get=function(){return this.current},Mt.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t}};var At=function(t){this.context=t;var e=this.context.gl;this.current=[e.ONE,e.ZERO]};At.prototype.get=function(){return this.current},At.prototype.set=function(t){var e=this.current;t[0]===e[0]&&t[1]===e[1]||(this.context.gl.blendFunc(t[0],t[1]),this.current=t)};var Tt=function(e){this.context=e,this.current=t.default$6.transparent};Tt.prototype.get=function(){return this.current},Tt.prototype.set=function(t){var e=this.current;t.r===e.r&&t.g===e.g&&t.b===e.b&&t.a===e.a||(this.context.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t)};var St=function(t){this.context=t,this.current=null};St.prototype.get=function(){return this.current},St.prototype.set=function(t){this.current!==t&&(this.context.gl.useProgram(t),this.current=t)};var Ct=function(t){this.context=t,this.current=1};Ct.prototype.get=function(){return this.current},Ct.prototype.set=function(e){var r=this.context.lineWidthRange,n=t.clamp(e,r[0],r[1]);this.current!==n&&(this.context.gl.lineWidth(n),this.current=e)};var Et=function(t){this.context=t,this.current=t.gl.TEXTURE0};Et.prototype.get=function(){return this.current},Et.prototype.set=function(t){this.current!==t&&(this.context.gl.activeTexture(t),this.current=t)};var Lt=function(t){this.context=t;var e=this.context.gl;this.current=[0,0,e.drawingBufferWidth,e.drawingBufferHeight]};Lt.prototype.get=function(){return this.current},Lt.prototype.set=function(t){var e=this.current;t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]&&t[3]===e[3]||(this.context.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t)};var zt=function(t){this.context=t,this.current=null};zt.prototype.get=function(){return this.current},zt.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t}};var Ot=function(t){this.context=t,this.current=null};Ot.prototype.get=function(){return this.current},Ot.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t}};var It=function(t){this.context=t,this.current=null};It.prototype.get=function(){return this.current},It.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t}};var Dt=function(t){this.context=t,this.current=null};Dt.prototype.get=function(){return this.current},Dt.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t}};var Pt=function(t){this.context=t,this.current=null};Pt.prototype.get=function(){return this.current},Pt.prototype.set=function(t){var e=this.context.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t};var Rt=function(t){this.context=t,this.current=null};Rt.prototype.get=function(){return this.current},Rt.prototype.set=function(t){this.current!==t&&this.context.extVertexArrayObject&&(this.context.extVertexArrayObject.bindVertexArrayOES(t),this.current=t)};var Ft=function(t){this.context=t,this.current=4};Ft.prototype.get=function(){return this.current},Ft.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t}};var Bt=function(t){this.context=t,this.current=!1};Bt.prototype.get=function(){return this.current},Bt.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t}};var Nt=function(t,e){this.context=t,this.current=null,this.parent=e};Nt.prototype.get=function(){return this.current};var jt=function(t){function e(e,r){t.call(this,e,r),this.dirty=!1}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(this.dirty||this.current!==t){var e=this.context.gl;this.context.bindFramebuffer.set(this.parent),e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e.prototype.setDirty=function(){this.dirty=!0},e}(Nt),Vt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(this.current!==t){var e=this.context.gl;this.context.bindFramebuffer.set(this.parent),e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t}},e}(Nt),Ut=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new jt(t,i),this.depthAttachment=new Vt(t,i)};Ut.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var qt=function(t,e,r){this.func=t,this.mask=e,this.range=r};qt.ReadOnly=!1,qt.ReadWrite=!0,qt.disabled=new qt(519,qt.ReadOnly,[0,1]);var Ht=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};Ht.disabled=new Ht({func:519,mask:0},0,0,7680,7680,7680);var Gt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Gt.disabled=new Gt(Gt.Replace=[1,0],t.default$6.transparent,[!1,!1,!1,!1]),Gt.unblended=new Gt(Gt.Replace,t.default$6.transparent,[!0,!0,!0,!0]),Gt.alphaBlended=new Gt([1,771],t.default$6.transparent,[!0,!0,!0,!0]);var Wt=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.lineWidthRange=t.getParameter(t.ALIASED_LINE_WIDTH_RANGE),this.clearColor=new ht(this),this.clearDepth=new pt(this),this.clearStencil=new dt(this),this.colorMask=new gt(this),this.depthMask=new vt(this),this.stencilMask=new mt(this),this.stencilFunc=new yt(this),this.stencilOp=new xt(this),this.stencilTest=new bt(this),this.depthRange=new _t(this),this.depthTest=new wt(this),this.depthFunc=new kt(this),this.blend=new Mt(this),this.blendFunc=new At(this),this.blendColor=new Tt(this),this.program=new St(this),this.lineWidth=new Ct(this),this.activeTexture=new Et(this),this.viewport=new Lt(this),this.bindFramebuffer=new zt(this),this.bindRenderbuffer=new Ot(this),this.bindTexture=new It(this),this.bindVertexBuffer=new Dt(this),this.bindElementBuffer=new Pt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new Rt(this),this.pixelStoreUnpack=new Ft(this),this.pixelStoreUnpackPremultiplyAlpha=new Bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Wt.prototype.createIndexBuffer=function(t,e){return new ct(this,t,e)},Wt.prototype.createVertexBuffer=function(t,e,r){return new ft(this,t,e,r)},Wt.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Wt.prototype.createFramebuffer=function(t,e){return new Ut(this,t,e)},Wt.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Wt.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Wt.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Wt.prototype.setColorMode=function(e){t.default$10(e.blendFunction,Gt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)};var Yt=function(e){function r(t,r,n){var i=this;e.call(this),this.id=t,this.dispatcher=n,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(i._sourceLoaded=!0),i._sourceLoaded&&!i._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(i.reload(),i.transform&&i.update(i.transform))}),this.on(\"error\",function(){i._sourceErrored=!0}),this._source=it(t,r,n,this),this._tiles={},this._cache=new lt(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._isIdRenderable=this._isIdRenderable.bind(this),this._coveredTiles={}}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._tiles)this._tiles[e].upload(t)},r.prototype.getIds=function(){var e=this;return Object.keys(this._tiles).map(Number).sort(function(r,n){var i=e._tiles[r].tileID,a=e._tiles[n].tileID,o=new t.default$1(i.canonical.x,i.canonical.y).rotate(e.transform.angle),s=new t.default$1(a.canonical.x,a.canonical.y).rotate(e.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})},r.prototype.getRenderableIds=function(){return this.getIds().filter(this._isIdRenderable)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0,{});return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=a.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID})),this.map&&(this.map.painter.tileExtentVAO.vao=null)},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._findLoadedChildren=function(t,e,r){var n=!1;for(var i in this._tiles){var a=this._tiles[i];if(!(r[i]||!a.hasData()||a.tileID.overscaledZ<=t.overscaledZ||a.tileID.overscaledZ>e)){var o=Math.pow(2,a.tileID.canonical.z-t.canonical.z);if(Math.floor(a.tileID.canonical.x/o)===t.canonical.x&&Math.floor(a.tileID.canonical.y/o)===t.canonical.y)for(r[i]=a.tileID,n=!0;a&&a.tileID.overscaledZ-1>t.overscaledZ;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);if(!s)break;(a=this._tiles[s.key])&&a.hasData()&&(delete r[i],r[s.key]=s)}}}return n},r.prototype.findLoadedParent=function(t,e,r){for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n);if(!i)return;var a=String(i.key),o=this._tiles[a];if(o&&o.hasData())return r[a]=i,o;if(this._cache.has(i))return r[a]=i,this._cache.get(i)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var o,s=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),l=Math.max(s-r.maxOverzooming,this._source.minzoom),c=Math.max(s+r.maxUnderzooming,this._source.minzoom),u=this._updateRetainedTiles(i,s),f={};if(Zt(this._source.type))for(var h=Object.keys(u),p=0;p<h.length;p++){var d=h[p],g=u[d],v=n._tiles[d];if(v&&(void 0===v.fadeEndTime||v.fadeEndTime>=a.now())){n._findLoadedChildren(g,c,u)&&(u[d]=g);var m=n.findLoadedParent(g,l,f);m&&n._addTile(m.tileID)}}for(o in f)u[o]||(n._coveredTiles[o]=!0);for(o in f)u[o]=f[o];for(var y=t.keysDifference(this._tiles,u),x=0;x<y.length;x++)n._removeTile(y[x])}},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s=0;s<t.length;s++){var l=t[s],c=this._addTile(l),u=!1;if(c.hasData())n[l.key]=l;else{u=c.wasRequested(),n[l.key]=l;var f=!0;if(e+1>this._source.maxzoom){var h=l.children(this._source.maxzoom)[0],p=this.getTile(h);p&&p.hasData()?n[h.key]=h:f=!1}else{this._findLoadedChildren(l,o,n);for(var d=l.children(this._source.maxzoom),g=0;g<d.length;g++)if(!n[d[g].key]){f=!1;break}}if(!f)for(var v=l.overscaledZ-1;v>=a;--v){var m=l.scaledTo(v);if(i[m.key])break;if(i[m.key]=!0,!(c=this.getTile(m))&&u&&(c=this._addTile(m)),c&&(n[m.key]=m,u=c.wasRequested(),c.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e);var n=Boolean(r);return n||(r=new st(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r){for(var n=[],i=this.getIds(),a=1/0,o=1/0,s=-1/0,l=-1/0,c=e[0].zoom,u=0;u<e.length;u++){var f=e[u];a=Math.min(a,f.column),o=Math.min(o,f.row),s=Math.max(s,f.column),l=Math.max(l,f.row)}for(var h=0;h<i.length;h++){var p=this._tiles[i[h]],d=p.tileID,g=Math.pow(2,this.transform.zoom-p.tileID.overscaledZ),v=r*p.queryPadding*t.default$8/p.tileSize/g,m=[Xt(d,new t.default$17(a,o,c)),Xt(d,new t.default$17(s,l,c))];if(m[0].x-v<t.default$8&&m[0].y-v<t.default$8&&m[1].x+v>=0&&m[1].y+v>=0){for(var y=[],x=0;x<e.length;x++)y.push(Xt(d,e[x]));n.push({tile:p,tileID:d,queryGeometry:[y],scale:g})}}return n},r.prototype.getVisibleCoordinates=function(){for(var t=this,e=this.getRenderableIds().map(function(e){return t._tiles[e].tileID}),r=0,n=e;r<n.length;r+=1){var i=n[r];i.posMatrix=t.transform.calculatePosMatrix(i.toUnwrapped())}return e},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Zt(this._source.type))for(var t in this._tiles){var e=this._tiles[t];if(void 0!==e.fadeEndTime&&e.fadeEndTime>=a.now())return!0}return!1},r}(t.Evented);function Xt(e,r){var n=r.zoomTo(e.canonical.z);return new t.default$1((n.column-(e.canonical.x+e.wrap*Math.pow(2,e.canonical.z)))*t.default$8,(n.row-e.canonical.y)*t.default$8)}function Zt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function $t(){return new t.default.Worker(Cn.workerUrl)}Yt.maxOverzooming=10,Yt.maxUnderzooming=3;var Jt,Kt=function(){this.active={}};function Qt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.default$18.forEach(function(t){t in r&&(n[t]=r[t])}),n}function te(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Qt(t[n],e[t[n].ref]));return t}Kt.prototype.acquire=function(t){if(!this.workers){var e=Cn.workerCount;for(this.workers=[];this.workers.length<e;)this.workers.push(new $t)}return this.active[t]=!0,this.workers.slice()},Kt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var ee={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function re(t,e,r){r.push({command:ee.addSource,args:[t,e[t]]})}function ne(t,e,r){e.push({command:ee.removeSource,args:[t]}),r[t]=!0}function ie(t,e,r,n){ne(t,r,n),re(t,e,r)}function ae(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.default$10(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.default$10(e[n][i],r[n][i]))return!1;return!0}function oe(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.default$10(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.default$10(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function se(t){return t.id}function le(t,e){return t[e.id]=e,t}var ce=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};ce.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},ce.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},ce.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},ce.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},ce.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},ce.prototype._query=function(t,e,r,n,i){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var a=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var o=0;o<this.boxKeys.length;o++)a.push({key:this.boxKeys[o],x1:this.bboxes[4*o],y1:this.bboxes[4*o+1],x2:this.bboxes[4*o+2],y2:this.bboxes[4*o+3]});for(var s=0;s<this.circleKeys.length;s++){var l=this.circles[3*s],c=this.circles[3*s+1],u=this.circles[3*s+2];a.push({key:this.circleKeys[s],x1:l-u,y1:c-u,x2:l+u,y2:c+u})}}else{var f={hitTest:i,seenUids:{box:{},circle:{}}};this._forEachCell(t,e,r,n,this._queryCell,a,f)}return i?a.length>0:a},ce.prototype._queryCircle=function(t,e,r,n){var i=t-r,a=t+r,o=e-r,s=e+r;if(a<0||i>this.width||s<0||o>this.height)return!n&&[];var l=[],c={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(i,o,a,s,this._queryCellCircle,l,c),n?l.length>0:l},ce.prototype.query=function(t,e,r,n){return this._query(t,e,r,n,!1)},ce.prototype.hitTest=function(t,e,r,n){return this._query(t,e,r,n,!0)},ce.prototype.hitTestCircle=function(t,e,r){return this._queryCircle(t,e,r,!0)},ce.prototype._queryCell=function(t,e,r,n,i,a,o){var s=o.seenUids,l=this.boxCells[i];if(null!==l)for(var c=this.bboxes,u=0,f=l;u<f.length;u+=1){var h=f[u];if(!s.box[h]){s.box[h]=!0;var p=4*h;if(t<=c[p+2]&&e<=c[p+3]&&r>=c[p+0]&&n>=c[p+1]){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[h],x1:c[p],y1:c[p+1],x2:c[p+2],y2:c[p+3]})}}}var d=this.circleCells[i];if(null!==d)for(var g=this.circles,v=0,m=d;v<m.length;v+=1){var y=m[v];if(!s.circle[y]){s.circle[y]=!0;var x=3*y;if(this._circleAndRectCollide(g[x],g[x+1],g[x+2],t,e,r,n)){if(o.hitTest)return a.push(!0),!0;var b=g[x],_=g[x+1],w=g[x+2];a.push({key:this.circleKeys[y],x1:b-w,y1:_-w,x2:b+w,y2:_+w})}}}},ce.prototype._queryCellCircle=function(t,e,r,n,i,a,o){var s=o.circle,l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,f=0,h=c;f<h.length;f+=1){var p=h[f];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(this._circleAndRectCollide(s.x,s.y,s.radius,u[d+0],u[d+1],u[d+2],u[d+3]))return a.push(!0),!0}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circlesCollide(v[b],v[b+1],v[b+2],s.x,s.y,s.radius))return a.push(!0),!0}}},ce.prototype._forEachCell=function(t,e,r,n,i,a,o){for(var s=this._convertToXCellCoord(t),l=this._convertToYCellCoord(e),c=this._convertToXCellCoord(r),u=this._convertToYCellCoord(n),f=s;f<=c;f++)for(var h=l;h<=u;h++){var p=this.xCellCount*h+f;if(i.call(this,t,e,r,n,p,a,o))return}},ce.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},ce.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},ce.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},ce.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var f=l-s,h=u-c;return f*f+h*h<=r*r};var ue=t.default$19.layout;function fe(e,r,n,i,a){var o=t.mat4.identity(new Float32Array(16));return r?(t.mat4.identity(o),t.mat4.scale(o,o,[1/a,1/a,1]),n||t.mat4.rotateZ(o,o,i.angle)):(t.mat4.scale(o,o,[i.width/2,-i.height/2,1]),t.mat4.translate(o,o,[1,-1,0]),t.mat4.multiply(o,o,e)),o}function he(e,r,n,i,a){var o=t.mat4.identity(new Float32Array(16));return r?(t.mat4.multiply(o,o,e),t.mat4.scale(o,o,[a,a,1]),n||t.mat4.rotateZ(o,o,-i.angle)):(t.mat4.scale(o,o,[1,-1,1]),t.mat4.translate(o,o,[-1,-1,0]),t.mat4.scale(o,o,[2/i.width,2/i.height,1])),o}function pe(e,r){var n=[e.x,e.y,0,1];ke(n,n,r);var i=n[3];return{point:new t.default$1(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function de(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function ge(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom,ue.properties[i?\"text-size\":\"icon-size\"]),f=[256/n.width*2+1,256/n.height*2+1],h=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;h.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)we(y.numGlyphs,h);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.vec4.transformMat4(x,x,r),de(x,f)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.default$1(y.anchorX,y.anchorY),M=pe(k,a).point,A={},T=ye(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,h,M,k,A,g);v=T.useVertical,(T.notEnoughRoom||v||T.needsFlipping&&ye(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,h,M,k,A,g).notEnoughRoom)&&we(y.numGlyphs,h)}else we(y.numGlyphs,h)}}i?e.text.dynamicLayoutVertexBuffer.updateData(h):e.icon.dynamicLayoutVertexBuffer.updateData(h)}function ve(t,e,r,n,i,a,o,s,l,c,u,f){var h=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(h-1),m=be(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,f);if(!m)return null;var y=be(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,f);return y?{first:m,last:y}:null}function me(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ye(e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,v=r/24,m=e.lineOffsetX*r,y=e.lineOffsetY*r;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ve(v,l,m,y,n,f,h,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=pe(w.first.point,s).point,M=pe(w.last.point,s).point;if(i&&!n){var A=me(e.writingMode,k,M,d);if(A)return A}g=[w.first];for(var T=e.glyphStartIndex+1;T<x-1;T++)g.push(be(v*l.getoffsetX(T),m,y,n,f,h,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=pe(h,a).point,C=e.lineStartIndex+e.segment+1,E=new t.default$1(c.getx(C),c.gety(C)),L=pe(E,a),z=L.signedDistanceFromCamera>0?L.point:xe(h,E,S,1,a),O=me(e.writingMode,S,z,d);if(O)return O}var I=be(v*l.getoffsetX(e.glyphStartIndex),m,y,n,f,h,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!I)return{notEnoughRoom:!0};g=[I]}for(var D=0,P=g;D<P.length;D+=1){var R=P[D];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function xe(t,e,r,n,i){var a=pe(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function be(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=h[m])){var M=new t.default$1(u.getx(m),u.gety(m)),A=pe(M,f);if(A.signedDistanceFromCamera>0)x=h[m]=A.point;else{var T=m-g;x=xe(0===_?o:new t.default$1(u.getx(T),u.gety(T)),M,b,k-_+1,f)}}_+=w,w=b.dist(x)}var S=(k-_)/w,C=x.sub(b),E=C.mult(S)._add(b);return E._add(C._unit()._perp()._mult(n*g)),{point:E,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}var _e=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function we(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(_e,3*n)}}function ke(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}t.default$20.mat4;var Me=function(t,e,r){void 0===e&&(e=new ce(t.width+200,t.height+200,25)),void 0===r&&(r=new ce(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100};function Ae(t,e,r){t[e+4]=r?1:0}function Te(e,r,n){return r*(t.default$8/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}Me.prototype.placeCollisionBox=function(t,e,r,n){var i=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),a=r*i.perspectiveRatio,o=t.x1*a+i.point.x,s=t.y1*a+i.point.y,l=t.x2*a+i.point.x,c=t.y2*a+i.point.y;return!e&&this.grid.hitTest(o,s,l,c)?{box:[],offscreen:!1}:{box:[o,s,l,c],offscreen:this.isOffscreen(o,s,l,c)}},Me.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},Me.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=[],g=this.projectAnchor(u,o.anchorX,o.anchorY),v=c/24,m=o.lineOffsetX*c,y=o.lineOffsetY*c,x=new t.default$1(o.anchorX,o.anchorY),b=ve(v,l,m,y,!1,pe(x,f).point,x,o,s,f,{},!0),_=!1,w=!0,k=g.perspectiveRatio*i,M=1/(i*n),A=0,T=0;b&&(A=this.approximateTileDistance(b.first.tileDistance,b.first.angle,M,g.cameraDistance,p),T=this.approximateTileDistance(b.last.tileDistance,b.last.angle,M,g.cameraDistance,p));for(var S=0;S<e.length;S+=5){var C=e[S],E=e[S+1],L=e[S+2],z=e[S+3];if(!b||z<-A||z>T)Ae(e,S,!1);else{var O=this.projectPoint(u,C,E),I=L*k;if(d.length>0){var D=O.x-d[d.length-4],P=O.y-d[d.length-3];if(I*I*2>D*D+P*P&&S+8<e.length){var R=e[S+8];if(R>-A&&R<T){Ae(e,S,!1);continue}}}var F=S/5;if(d.push(O.x,O.y,I,F),Ae(e,S,!0),w=w&&this.isOffscreen(O.x-I,O.y-I,O.x+I,O.y+I),!r&&this.grid.hitTestCircle(O.x,O.y,I)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_?[]:d,offscreen:w}},Me.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.default$1(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var f={},h={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]={}),!f[v.bucketInstanceId][v.featureIndex]){var m=[new t.default$1(g.x1,g.y1),new t.default$1(g.x2,g.y1),new t.default$1(g.x2,g.y2),new t.default$1(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(f[v.bucketInstanceId][v.featureIndex]=!0,void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]=[]),h[v.bucketInstanceId].push(v.featureIndex))}}return h},Me.prototype.insertCollisionBox=function(t,e,r,n){var i={bucketInstanceId:r,featureIndex:n};(e?this.ignoredGrid:this.grid).insert(i,t[0],t[1],t[2],t[3])},Me.prototype.insertCollisionCircles=function(t,e,r,n){for(var i=e?this.ignoredGrid:this.grid,a={bucketInstanceId:r,featureIndex:n},o=0;o<t.length;o+=4)i.insertCircle(a,t[o],t[o+1],t[o+2])},Me.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ke(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},Me.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ke(i,i,e),new t.default$1((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},Me.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ke(i,i,e),{point:new t.default$1((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},Me.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary};var Se=t.default$19.layout,Ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};Ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var Ee=function(t,e,r,n,i){this.text=new Ce(t?t.text:null,e,r,i),this.icon=new Ce(t?t.icon:null,e,n,i)};Ee.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var Le=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},ze=function(t,e){this.transform=t.clone(),this.collisionIndex=new Me(this.transform),this.placements={},this.opacities={},this.stale=!1,this.fadeDuration=e,this.retainedQueryData={}};function Oe(t,e,r){t.emplaceBack(e?1:0,r?1:0),t.emplaceBack(e?1:0,r?1:0),t.emplaceBack(e?1:0,r?1:0),t.emplaceBack(e?1:0,r?1:0)}ze.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.default$8,f=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),h=fe(f,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,Te(r,1,this.transform.zoom)),p=fe(f,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,Te(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i}(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,f,h,p,c,u,n,i,s)}},ze.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c){for(var u=e.layers[0].layout,f=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom,Se.properties[\"text-size\"]),h=!e.hasTextData()||u.get(\"text-optional\"),p=!e.hasIconData()||u.get(\"icon-optional\"),d=0,g=e.symbolInstances;d<g.length;d+=1){var v=g[d];if(!l[v.crossTileID]){var m=void 0!==v.feature.text,y=void 0!==v.feature.icon,x=!0,b=null,_=null,w=null,k=0,M=0;v.collisionArrays||(v.collisionArrays=e.deserializeCollisionBoxes(c,v.textBoxStartIndex,v.textBoxEndIndex,v.iconBoxStartIndex,v.iconBoxEndIndex)),v.collisionArrays.textFeatureIndex&&(k=v.collisionArrays.textFeatureIndex),v.collisionArrays.textBox&&(m=(b=this.collisionIndex.placeCollisionBox(v.collisionArrays.textBox,u.get(\"text-allow-overlap\"),o,r)).box.length>0,x=x&&b.offscreen);var A=v.collisionArrays.textCircles;if(A){var T=e.text.placedSymbolArray.get(v.placedTextSymbolIndices[0]),S=t.evaluateSizeForFeature(e.textSizeData,f,T);_=this.collisionIndex.placeCollisionCircles(A,u.get(\"text-allow-overlap\"),a,o,v.key,T,e.lineVertexArray,e.glyphOffsetArray,S,r,n,s,\"map\"===u.get(\"text-pitch-alignment\")),m=u.get(\"text-allow-overlap\")||_.circles.length>0,x=x&&_.offscreen}v.collisionArrays.iconFeatureIndex&&(M=v.collisionArrays.iconFeatureIndex),v.collisionArrays.iconBox&&(y=(w=this.collisionIndex.placeCollisionBox(v.collisionArrays.iconBox,u.get(\"icon-allow-overlap\"),o,r)).box.length>0,x=x&&w.offscreen),h||p?p?h||(y=y&&m):m=y&&m:y=m=y&&m,m&&b&&this.collisionIndex.insertCollisionBox(b.box,u.get(\"text-ignore-placement\"),e.bucketInstanceId,k),y&&w&&this.collisionIndex.insertCollisionBox(w.box,u.get(\"icon-ignore-placement\"),e.bucketInstanceId,M),m&&_&&this.collisionIndex.insertCollisionCircles(_.circles,u.get(\"text-ignore-placement\"),e.bucketInstanceId,k),this.placements[v.crossTileID]=new Le(m,y,x||e.justReloaded),l[v.crossTileID]=!0}}e.justReloaded=!1},ze.prototype.commit=function(t,e){this.commitTime=e;var r=!1,n=t&&0!==this.fadeDuration?(this.commitTime-t.commitTime)/this.fadeDuration:1,i=t?t.opacities:{};for(var a in this.placements){var o=this.placements[a],s=i[a];s?(this.opacities[a]=new Ee(s,n,o.text,o.icon),r=r||o.text!==s.text.placed||o.icon!==s.icon.placed):(this.opacities[a]=new Ee(null,n,o.text,o.icon,o.skipFade),r=r||o.text||o.icon)}for(var l in i){var c=i[l];if(!this.opacities[l]){var u=new Ee(c,n,!1,!1);u.isHidden()||(this.opacities[l]=u,r=r||c.text.placed||c.icon.placed)}}r?this.lastPlacementChangeTime=e:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=t?t.lastPlacementChangeTime:e)},ze.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ze.prototype.updateBucketOpacities=function(t,e,r){t.hasTextData()&&t.text.opacityVertexArray.clear(),t.hasIconData()&&t.icon.opacityVertexArray.clear(),t.hasCollisionBoxData()&&t.collisionBox.collisionVertexArray.clear(),t.hasCollisionCircleData()&&t.collisionCircle.collisionVertexArray.clear();for(var n=t.layers[0].layout,i=new Ee(null,0,!1,!1,!0),a=new Ee(null,0,n.get(\"text-allow-overlap\"),n.get(\"icon-allow-overlap\"),!0),o=0;o<t.symbolInstances.length;o++){var s=t.symbolInstances[o],l=e[s.crossTileID],c=this.opacities[s.crossTileID];l?c=i:c||(c=a,this.opacities[s.crossTileID]=c),e[s.crossTileID]=!0;var u=s.numGlyphVertices>0||s.numVerticalGlyphVertices>0,f=s.numIconVertices>0;if(u){for(var h=je(c.text),p=(s.numGlyphVertices+s.numVerticalGlyphVertices)/4,d=0;d<p;d++)t.text.opacityVertexArray.emplaceBack(h);for(var g=0,v=s.placedTextSymbolIndices;g<v.length;g+=1){var m=v[g];t.text.placedSymbolArray.get(m).hidden=c.text.isHidden()}}if(f){for(var y=je(c.icon),x=0;x<s.numIconVertices/4;x++)t.icon.opacityVertexArray.emplaceBack(y);t.icon.placedSymbolArray.get(o).hidden=c.icon.isHidden()}s.collisionArrays||(s.collisionArrays=t.deserializeCollisionBoxes(r,s.textBoxStartIndex,s.textBoxEndIndex,s.iconBoxStartIndex,s.iconBoxEndIndex));var b=s.collisionArrays;if(b){b.textBox&&t.hasCollisionBoxData()&&Oe(t.collisionBox.collisionVertexArray,c.text.placed,!1),b.iconBox&&t.hasCollisionBoxData()&&Oe(t.collisionBox.collisionVertexArray,c.icon.placed,!1);var _=b.textCircles;if(_&&t.hasCollisionCircleData())for(var w=0;w<_.length;w+=5){var k=l||0===_[w+4];Oe(t.collisionCircle.collisionVertexArray,c.text.placed,k)}}}t.sortFeatures(this.transform.angle),this.retainedQueryData[t.bucketInstanceId]&&(this.retainedQueryData[t.bucketInstanceId].featureSortOrder=t.featureSortOrder),t.hasTextData()&&t.text.opacityVertexBuffer&&t.text.opacityVertexBuffer.updateData(t.text.opacityVertexArray),t.hasIconData()&&t.icon.opacityVertexBuffer&&t.icon.opacityVertexBuffer.updateData(t.icon.opacityVertexArray),t.hasCollisionBoxData()&&t.collisionBox.collisionVertexBuffer&&t.collisionBox.collisionVertexBuffer.updateData(t.collisionBox.collisionVertexArray),t.hasCollisionCircleData()&&t.collisionCircle.collisionVertexBuffer&&t.collisionCircle.collisionVertexBuffer.updateData(t.collisionCircle.collisionVertexArray)},ze.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ze.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ze.prototype.stillRecent=function(t){return\"undefined\"!==this.commitTime&&this.commitTime+this.fadeDuration>t},ze.prototype.setStale=function(){this.stale=!0};var Ie=Math.pow(2,25),De=Math.pow(2,24),Pe=Math.pow(2,17),Re=Math.pow(2,16),Fe=Math.pow(2,9),Be=Math.pow(2,8),Ne=Math.pow(2,1);function je(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Ie+e*De+r*Pe+e*Re+r*Fe+e*Be+r*Ne+e}var Ve=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ve.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Ue=function(t,e,r,n,i){this.placement=new ze(t,i),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Ue.prototype.isDone=function(){return this._done},Ue.prototype.continuePlacement=function(t,e,r){for(var n=this,i=a.now(),o=function(){var t=a.now()-i;return!n._forceFullPlacement&&t>2};this._currentPlacementIndex>=0;){var s=e[t[n._currentPlacementIndex]],l=n.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(n._inProgressLayer||(n._inProgressLayer=new Ve),n._inProgressLayer.continuePlacement(r[s.source],n.placement,n._showCollisionBoxes,s,o))return;delete n._inProgressLayer}n._currentPlacementIndex--}this._done=!0},Ue.prototype.commit=function(t,e){return this.placement.commit(t,e),this.placement};var qe=512/t.default$8/2,He=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.key;this.indexedSymbolInstances[o]||(this.indexedSymbolInstances[o]=[]),this.indexedSymbolInstances[o].push({crossTileID:a.crossTileID,coord:this.getScaledCoordinates(a,t)})}};He.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=qe/Math.pow(2,n),a=e.anchor;return{x:Math.floor((r.canonical.x*t.default$8+a.x)*i),y:Math.floor((r.canonical.y*t.default$8+a.y)*i)}},He.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0,a=t;i<a.length;i+=1){var o=a[i];if(!o.crossTileID){var s=this.indexedSymbolInstances[o.key];if(s)for(var l=this.getScaledCoordinates(o,e),c=0,u=s;c<u.length;c+=1){var f=u[c];if(Math.abs(f.coord.x-l.x)<=n&&Math.abs(f.coord.y-l.y)<=n&&!r[f.crossTileID]){r[f.crossTileID]=!0,o.crossTileID=f.crossTileID;break}}}}};var Ge=function(){this.maxCrossTileID=0};Ge.prototype.generate=function(){return++this.maxCrossTileID};var We=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};We.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},We.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0,i=e.symbolInstances;n<i.length;n+=1)i[n].crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var a=this.usedCrossTileIDs[t.overscaledZ];for(var o in this.indexes){var s=this.indexes[o];if(Number(o)>t.overscaledZ)for(var l in s){var c=s[l];c.tileID.isChildOf(t)&&c.findMatches(e.symbolInstances,t,a)}else{var u=s[t.scaledTo(Number(o)).key];u&&u.findMatches(e.symbolInstances,t,a)}}for(var f=0,h=e.symbolInstances;f<h.length;f+=1){var p=h[f];p.crossTileID||(p.crossTileID=r.generate(),a[p.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new He(t,e.symbolInstances,e.bucketInstanceId),!0},We.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},We.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Ye=function(){this.layerIndexes={},this.crossTileIDs=new Ge,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Ye.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new We);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Ye.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Xe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},Ze=t.pick(ee,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),$e=t.pick(ee,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Je=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new q((Jt||(Jt=new Kt),Jt),this),this.imageManager=new O,this.glyphManager=new B(n._transformRequest,i.localIdeographFontFamily),this.lineAtlas=new U(256,512),this.crossTileSymbolIndex=new Ye,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.default$23,this._loaded=!1,this._resetUpdates();var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!x(e);e=function(t,e){if(!x(t))return t;var r=A(t);return r.path=\"/styles/v1\"+r.path,y(r,e)}(e,r.accessToken);var a=this.map._transformRequest(e,t.ResourceType.Style);t.getJSON(a,function(e,r){e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),a.frame(function(){n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Xe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)n.addSource(i,e.sources[i],{validate:!1});e.sprite?function(e,r,n){var i,o,s,l=a.devicePixelRatio>1?\"@2x\":\"\";function c(){if(s)n(s);else if(i&&o){var e=a.getImageData(o),r={};for(var l in i){var c=i[l],u=c.width,f=c.height,h=c.x,p=c.y,d=c.sdf,g=c.pixelRatio,v=new t.RGBAImage({width:u,height:f});t.RGBAImage.copy(e,v,{x:h,y:p},{x:0,y:0},{width:u,height:f}),r[l]={data:v,pixelRatio:g,sdf:d}}n(null,r)}}t.getJSON(r(_(e,l,\".json\"),t.ResourceType.SpriteJSON),function(t,e){s||(s=t,i=e,c())}),t.getImage(r(_(e,l,\".png\"),t.ResourceType.SpriteImage),function(t,e){s||(s=t,o=e,c())})}(e.sprite,this.map._transformRequest,function(e,r){if(e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var o=te(this.stylesheet.layers);this._order=o.map(function(t){return t.id}),this._layers={};for(var s=0,l=o;s<l.length;s+=1){var c=l[s];(c=t.default$22(c)).setEventedParent(n,{layer:{id:c.id}}),n._layers[c.id]=c}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new V(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){var e=this;return t.map(function(t){return e._layers[t].serialize()})},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){if(this._changed){var r=Object.keys(this._updatedLayers),n=Object.keys(this._removedLayers);for(var i in(r.length||n.length)&&this._updateWorkerLayers(r,n),this._updatedSources){var a=this._updatedSources[i];\"reload\"===a?this._reloadSource(i):\"clear\"===a&&this._clearSource(i)}for(var o in this._updatedPaintProps)this._layers[o].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates(),this.fire(new t.Event(\"data\",{dataType:\"style\"}))}for(var s in this.sourceCaches)this.sourceCaches[s].used=!1;for(var l=0,c=this._order;l<c.length;l+=1){var u=c[l],f=this._layers[u];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Xe(this,t.validateStyle(e)))return!1;(e=t.clone(e)).layers=te(e.layers);var n=function(e,r){if(!e)return[{command:ee.setStyle,args:[r]}];var n=[];try{if(!t.default$10(e.version,r.version))return[{command:ee.setStyle,args:[r]}];t.default$10(e.center,r.center)||n.push({command:ee.setCenter,args:[r.center]}),t.default$10(e.zoom,r.zoom)||n.push({command:ee.setZoom,args:[r.zoom]}),t.default$10(e.bearing,r.bearing)||n.push({command:ee.setBearing,args:[r.bearing]}),t.default$10(e.pitch,r.pitch)||n.push({command:ee.setPitch,args:[r.pitch]}),t.default$10(e.sprite,r.sprite)||n.push({command:ee.setSprite,args:[r.sprite]}),t.default$10(e.glyphs,r.glyphs)||n.push({command:ee.setGlyphs,args:[r.glyphs]}),t.default$10(e.transition,r.transition)||n.push({command:ee.setTransition,args:[r.transition]}),t.default$10(e.light,r.light)||n.push({command:ee.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||ne(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.default$10(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&ae(e,r,a)?n.push({command:ee.setGeoJSONSourceData,args:[a,r[a].data]}):ie(a,r,n,i)):re(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:ee.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,f=(e=e||[]).map(se),h=r.map(se),p=e.reduce(le,{}),d=r.reduce(le,{}),g=f.slice(),v=Object.create(null);for(i=0,a=0;i<f.length;i++)o=f[i],d.hasOwnProperty(o)?a++:(n.push({command:ee.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<h.length;i++)o=h[h.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:ee.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:ee.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<h.length;i++)if(s=p[o=h[i]],l=d[o],!v[o]&&!t.default$10(s,l))if(t.default$10(s.source,l.source)&&t.default$10(s[\"source-layer\"],l[\"source-layer\"])&&t.default$10(s.type,l.type)){for(u in oe(s.layout,l.layout,n,o,null,ee.setLayoutProperty),oe(s.paint,l.paint,n,o,null,ee.setPaintProperty),t.default$10(s.filter,l.filter)||n.push({command:ee.setFilter,args:[o,l.filter]}),t.default$10(s.minzoom,l.minzoom)&&t.default$10(s.maxzoom,l.maxzoom)||n.push({command:ee.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?oe(s[u],l[u],n,o,u.slice(6),ee.setPaintProperty):t.default$10(s[u],l[u])||n.push({command:ee.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?oe(s[u],l[u],n,o,u.slice(6),ee.setPaintProperty):t.default$10(s[u],l[u])||n.push({command:ee.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:ee.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:ee.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:ee.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in $e)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in Ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.addSource=function(e,r,n){var i=this;if(this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Yt(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone(e),e=t.extend(e,{source:i})),!this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n)){var a=t.default$22(e);this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}});var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e]}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r){this._checkLoaded();var n=this.getLayer(e);if(n){if(!t.default$10(n.filter,r))return null==r?(n.filter=void 0,void this._updateLayer(n)):void(this._validate(t.validateStyle.filter,\"layers.\"+n.id+\".filter\",r)||(n.filter=t.clone(r),this._updateLayer(n)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?t.default$10(i.getLayoutProperty(r),n)||(i.setLayoutProperty(r,n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(t,e){return this.getLayer(t).getLayoutProperty(e)},r.prototype.setPaintProperty=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.default$10(i.getPaintProperty(r),n)){var a=i._transitionablePaint._values[r].value.isDataDriven();i.setPaintProperty(r,n),(i._transitionablePaint._values[r].value.isDataDriven()||a)&&this._updateLayer(i),this._changed=!0,this._updatedPaintProps[e]=!0}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){var e=this;return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._order.map(function(t){return e._layers[t].serialize()})},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenRenderedFeatures=function(t){for(var e=[],r=this._order.length-1;r>=0;r--)for(var n=this._order[r],i=0,a=t;i<a.length;i+=1){var o=a[i][n];if(o)for(var s=0,l=o;s<l.length;s+=1){var c=l[s];e.push(c)}}return e},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(at(this.sourceCaches[u],this._layers,e.worldCoordinate,r,n));return this.placement&&c.push(function(t,e,r,n,i){for(var a={},o=n.queryRenderedSymbols(e),s=[],l=0,c=Object.keys(o).map(Number);l<c.length;l+=1){var u=c[l];s.push(i[u])}s.sort(ot);for(var f=function(){var e=p[h],n=e.featureIndex.lookupSymbolFeatures(o[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,r.filter,r.layers,t);for(var i in n){var s=a[i]=a[i]||[],l=n[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var f=u[c];s.push(f.feature)}}},h=0,p=s;h<p.length;h+=1)f();return a}(this._layers,e.viewport,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e){this._checkLoaded();var r=this.light.getLight(),n=!1;for(var i in e)if(!t.default$10(e[i],r[i])){n=!0;break}if(n){var o={now:a.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return(!a||!1!==a.validate)&&Xe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.default$5},i)))},r.prototype._remove=function(){for(var e in t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(t,e,r){for(var n=!1,i=!1,o={},s=0,l=this._order;s<l.length;s+=1){var c=l[s],u=this._layers[c];if(\"symbol\"===u.type){if(!o[u.source]){var f=this.sourceCaches[u.source];o[u.source]=f.getRenderableIds().map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var h=this.crossTileSymbolIndex.addLayer(u,o[u.source],t.center.lng);n=n||h}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var p=this._layerOrderChanged;if((p||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(a.now()))&&(this.pauseablePlacement=new Ue(t,this._order,p,e,r),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,o),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(this.placement,a.now()),i=!0),n&&this.pauseablePlacement.placement.setStale()),i||n)for(var d=0,g=this._order;d<g.length;d+=1){var v=g[d],m=this._layers[v];\"symbol\"===m.type&&this.placement.updateLayerOpacities(m,o[m.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(a.now())},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r}(t.Evented);Je.getSourceType=function(t){return nt[t]},Je.setSourceType=function(t,e){nt[t]=e},Je.registerForPluginAvailability=t.registerForPluginAvailability;var Ke=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Qe={prelude:{fragmentSource:\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n\\n#if !defined(highp)\\n#define highp\\n#endif\\n\\n#endif\\n\",vertexSource:\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n\\n#if !defined(highp)\\n#define highp\\n#endif\\n\\n#endif\\n\\n// Unpack a pair of values that have been packed into a single float.\\n// The packed values are assumed to be 8-bit unsigned integers, and are\\n// packed like so:\\n// packedValue = floor(input[0]) * 256 + input[1],\\nvec2 unpack_float(const float packedValue) {\\n    int packedIntValue = int(packedValue);\\n    int v0 = packedIntValue / 256;\\n    return vec2(v0, packedIntValue - v0 * 256);\\n}\\n\\nvec2 unpack_opacity(const float packedOpacity) {\\n    int intOpacity = int(packedOpacity) / 2;\\n    return vec2(float(intOpacity) / 127.0, mod(packedOpacity, 2.0));\\n}\\n\\n// To minimize the number of attributes needed, we encode a 4-component\\n// color into a pair of floats (i.e. a vec2) as follows:\\n// [ floor(color.r * 255) * 256 + color.g * 255,\\n//   floor(color.b * 255) * 256 + color.g * 255 ]\\nvec4 decode_color(const vec2 encodedColor) {\\n    return vec4(\\n        unpack_float(encodedColor[0]) / 255.0,\\n        unpack_float(encodedColor[1]) / 255.0\\n    );\\n}\\n\\n// Unpack a pair of paint values and interpolate between them.\\nfloat unpack_mix_vec2(const vec2 packedValue, const float t) {\\n    return mix(packedValue[0], packedValue[1], t);\\n}\\n\\n// Unpack a pair of paint values and interpolate between them.\\nvec4 unpack_mix_vec4(const vec4 packedColors, const float t) {\\n    vec4 minColor = decode_color(vec2(packedColors[0], packedColors[1]));\\n    vec4 maxColor = decode_color(vec2(packedColors[2], packedColors[3]));\\n    return mix(minColor, maxColor, t);\\n}\\n\\n// The offset depends on how many pixels are between the world origin and the edge of the tile:\\n// vec2 offset = mod(pixel_coord, size)\\n//\\n// At high zoom levels there are a ton of pixels between the world origin and the edge of the tile.\\n// The glsl spec only guarantees 16 bits of precision for highp floats. We need more than that.\\n//\\n// The pixel_coord is passed in as two 16 bit values:\\n// pixel_coord_upper = floor(pixel_coord / 2^16)\\n// pixel_coord_lower = mod(pixel_coord, 2^16)\\n//\\n// The offset is calculated in a series of steps that should preserve this precision:\\nvec2 get_pattern_pos(const vec2 pixel_coord_upper, const vec2 pixel_coord_lower,\\n    const vec2 pattern_size, const float tile_units_to_pixels, const vec2 pos) {\\n\\n    vec2 offset = mod(mod(mod(pixel_coord_upper, pattern_size) * 256.0, pattern_size) * 256.0 + pixel_coord_lower, pattern_size);\\n    return (tile_units_to_pixels * pos + offset) / pattern_size;\\n}\\n\"},background:{fragmentSource:\"uniform vec4 u_color;\\nuniform float u_opacity;\\n\\nvoid main() {\\n    gl_FragColor = u_color * u_opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"attribute vec2 a_pos;\\n\\nuniform mat4 u_matrix;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n}\\n\"},backgroundPattern:{fragmentSource:\"uniform vec2 u_pattern_tl_a;\\nuniform vec2 u_pattern_br_a;\\nuniform vec2 u_pattern_tl_b;\\nuniform vec2 u_pattern_br_b;\\nuniform vec2 u_texsize;\\nuniform float u_mix;\\nuniform float u_opacity;\\n\\nuniform sampler2D u_image;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\n\\nvoid main() {\\n    vec2 imagecoord = mod(v_pos_a, 1.0);\\n    vec2 pos = mix(u_pattern_tl_a / u_texsize, u_pattern_br_a / u_texsize, imagecoord);\\n    vec4 color1 = texture2D(u_image, pos);\\n\\n    vec2 imagecoord_b = mod(v_pos_b, 1.0);\\n    vec2 pos2 = mix(u_pattern_tl_b / u_texsize, u_pattern_br_b / u_texsize, imagecoord_b);\\n    vec4 color2 = texture2D(u_image, pos2);\\n\\n    gl_FragColor = mix(color1, color2, u_mix) * u_opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_pattern_size_a;\\nuniform vec2 u_pattern_size_b;\\nuniform vec2 u_pixel_coord_upper;\\nuniform vec2 u_pixel_coord_lower;\\nuniform float u_scale_a;\\nuniform float u_scale_b;\\nuniform float u_tile_units_to_pixels;\\n\\nattribute vec2 a_pos;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n\\n    v_pos_a = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_a * u_pattern_size_a, u_tile_units_to_pixels, a_pos);\\n    v_pos_b = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_b * u_pattern_size_b, u_tile_units_to_pixels, a_pos);\\n}\\n\"},circle:{fragmentSource:\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\n\\nvarying vec3 v_data;\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize mediump float radius\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize highp vec4 stroke_color\\n    #pragma mapbox: initialize mediump float stroke_width\\n    #pragma mapbox: initialize lowp float stroke_opacity\\n\\n    vec2 extrude = v_data.xy;\\n    float extrude_length = length(extrude);\\n\\n    lowp float antialiasblur = v_data.z;\\n    float antialiased_blur = -max(blur, antialiasblur);\\n\\n    float opacity_t = smoothstep(0.0, antialiased_blur, extrude_length - 1.0);\\n\\n    float color_t = stroke_width < 0.01 ? 0.0 : smoothstep(\\n        antialiased_blur,\\n        0.0,\\n        extrude_length - radius / (radius + stroke_width)\\n    );\\n\\n    gl_FragColor = opacity_t * mix(color * opacity, stroke_color * stroke_opacity, color_t);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform bool u_scale_with_map;\\nuniform bool u_pitch_with_map;\\nuniform vec2 u_extrude_scale;\\nuniform highp float u_camera_to_center_distance;\\n\\nattribute vec2 a_pos;\\n\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\n\\nvarying vec3 v_data;\\n\\nvoid main(void) {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize mediump float radius\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize highp vec4 stroke_color\\n    #pragma mapbox: initialize mediump float stroke_width\\n    #pragma mapbox: initialize lowp float stroke_opacity\\n\\n    // unencode the extrusion vector that we snuck into the a_pos vector\\n    vec2 extrude = vec2(mod(a_pos, 2.0) * 2.0 - 1.0);\\n\\n    // multiply a_pos by 0.5, since we had it * 2 in order to sneak\\n    // in extrusion data\\n    vec2 circle_center = floor(a_pos * 0.5);\\n    if (u_pitch_with_map) {\\n        vec2 corner_position = circle_center;\\n        if (u_scale_with_map) {\\n            corner_position += extrude * (radius + stroke_width) * u_extrude_scale;\\n        } else {\\n            // Pitching the circle with the map effectively scales it with the map\\n            // To counteract the effect for pitch-scale: viewport, we rescale the\\n            // whole circle based on the pitch scaling effect at its central point\\n            vec4 projected_center = u_matrix * vec4(circle_center, 0, 1);\\n            corner_position += extrude * (radius + stroke_width) * u_extrude_scale * (projected_center.w / u_camera_to_center_distance);\\n        }\\n\\n        gl_Position = u_matrix * vec4(corner_position, 0, 1);\\n    } else {\\n        gl_Position = u_matrix * vec4(circle_center, 0, 1);\\n\\n        if (u_scale_with_map) {\\n            gl_Position.xy += extrude * (radius + stroke_width) * u_extrude_scale * u_camera_to_center_distance;\\n        } else {\\n            gl_Position.xy += extrude * (radius + stroke_width) * u_extrude_scale * gl_Position.w;\\n        }\\n    }\\n\\n    // This is a minimum blur distance that serves as a faux-antialiasing for\\n    // the circle. since blur is a ratio of the circle's size and the intent is\\n    // to keep the blur at roughly 1px, the two are inversely related.\\n    lowp float antialiasblur = 1.0 / DEVICE_PIXEL_RATIO / (radius + stroke_width);\\n\\n    v_data = vec3(extrude.x, extrude.y, antialiasblur);\\n}\\n\"},clippingMask:{fragmentSource:\"void main() {\\n    gl_FragColor = vec4(1.0);\\n}\\n\",vertexSource:\"attribute vec2 a_pos;\\n\\nuniform mat4 u_matrix;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n}\\n\"},heatmap:{fragmentSource:\"#pragma mapbox: define highp float weight\\n\\nuniform highp float u_intensity;\\nvarying vec2 v_extrude;\\n\\n// Gaussian kernel coefficient: 1 / sqrt(2 * PI)\\n#define GAUSS_COEF 0.3989422804014327\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp float weight\\n\\n    // Kernel density estimation with a Gaussian kernel of size 5x5\\n    float d = -0.5 * 3.0 * 3.0 * dot(v_extrude, v_extrude);\\n    float val = weight * u_intensity * GAUSS_COEF * exp(d);\\n\\n    gl_FragColor = vec4(val, 1.0, 1.0, 1.0);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\n\\nuniform mat4 u_matrix;\\nuniform float u_extrude_scale;\\nuniform float u_opacity;\\nuniform float u_intensity;\\n\\nattribute vec2 a_pos;\\n\\nvarying vec2 v_extrude;\\n\\n// Effective \\\"0\\\" in the kernel density texture to adjust the kernel size to;\\n// this empirically chosen number minimizes artifacts on overlapping kernels\\n// for typical heatmap cases (assuming clustered source)\\nconst highp float ZERO = 1.0 / 255.0 / 16.0;\\n\\n// Gaussian kernel coefficient: 1 / sqrt(2 * PI)\\n#define GAUSS_COEF 0.3989422804014327\\n\\nvoid main(void) {\\n    #pragma mapbox: initialize highp float weight\\n    #pragma mapbox: initialize mediump float radius\\n\\n    // unencode the extrusion vector that we snuck into the a_pos vector\\n    vec2 unscaled_extrude = vec2(mod(a_pos, 2.0) * 2.0 - 1.0);\\n\\n    // This 'extrude' comes in ranging from [-1, -1], to [1, 1].  We'll use\\n    // it to produce the vertices of a square mesh framing the point feature\\n    // we're adding to the kernel density texture.  We'll also pass it as\\n    // a varying, so that the fragment shader can determine the distance of\\n    // each fragment from the point feature.\\n    // Before we do so, we need to scale it up sufficiently so that the\\n    // kernel falls effectively to zero at the edge of the mesh.\\n    // That is, we want to know S such that\\n    // weight * u_intensity * GAUSS_COEF * exp(-0.5 * 3.0^2 * S^2) == ZERO\\n    // Which solves to:\\n    // S = sqrt(-2.0 * log(ZERO / (weight * u_intensity * GAUSS_COEF))) / 3.0\\n    float S = sqrt(-2.0 * log(ZERO / weight / u_intensity / GAUSS_COEF)) / 3.0;\\n\\n    // Pass the varying in units of radius\\n    v_extrude = S * unscaled_extrude;\\n\\n    // Scale by radius and the zoom-based scale factor to produce actual\\n    // mesh position\\n    vec2 extrude = v_extrude * radius * u_extrude_scale;\\n\\n    // multiply a_pos by 0.5, since we had it * 2 in order to sneak\\n    // in extrusion data\\n    vec4 pos = vec4(floor(a_pos * 0.5) + extrude, 0, 1);\\n\\n    gl_Position = u_matrix * pos;\\n}\\n\"},heatmapTexture:{fragmentSource:\"uniform sampler2D u_image;\\nuniform sampler2D u_color_ramp;\\nuniform float u_opacity;\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    float t = texture2D(u_image, v_pos).r;\\n    vec4 color = texture2D(u_color_ramp, vec2(t, 0.5));\\n    gl_FragColor = color * u_opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(0.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_world;\\nattribute vec2 a_pos;\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos * u_world, 0, 1);\\n\\n    v_pos.x = a_pos.x;\\n    v_pos.y = 1.0 - a_pos.y;\\n}\\n\"},collisionBox:{fragmentSource:\"\\nvarying float v_placed;\\nvarying float v_notUsed;\\n\\nvoid main() {\\n\\n    float alpha = 0.5;\\n\\n    // Red = collision, hide label\\n    gl_FragColor = vec4(1.0, 0.0, 0.0, 1.0) * alpha;\\n\\n    // Blue = no collision, label is showing\\n    if (v_placed > 0.5) {\\n        gl_FragColor = vec4(0.0, 0.0, 1.0, 0.5) * alpha;\\n    }\\n\\n    if (v_notUsed > 0.5) {\\n        // This box not used, fade it out\\n        gl_FragColor *= .1;\\n    }\\n}\",vertexSource:\"attribute vec2 a_pos;\\nattribute vec2 a_anchor_pos;\\nattribute vec2 a_extrude;\\nattribute vec2 a_placed;\\n\\nuniform mat4 u_matrix;\\nuniform vec2 u_extrude_scale;\\nuniform float u_camera_to_center_distance;\\n\\nvarying float v_placed;\\nvarying float v_notUsed;\\n\\nvoid main() {\\n    vec4 projectedPoint = u_matrix * vec4(a_anchor_pos, 0, 1);\\n    highp float camera_to_anchor_distance = projectedPoint.w;\\n    highp float collision_perspective_ratio = clamp(\\n        0.5 + 0.5 * (u_camera_to_center_distance / camera_to_anchor_distance),\\n        0.0, // Prevents oversized near-field boxes in pitched/overzoomed tiles\\n        4.0);\\n\\n    gl_Position = u_matrix * vec4(a_pos, 0.0, 1.0);\\n    gl_Position.xy += a_extrude * u_extrude_scale * gl_Position.w * collision_perspective_ratio;\\n\\n    v_placed = a_placed.x;\\n    v_notUsed = a_placed.y;\\n}\\n\"},collisionCircle:{fragmentSource:\"uniform float u_overscale_factor;\\n\\nvarying float v_placed;\\nvarying float v_notUsed;\\nvarying float v_radius;\\nvarying vec2 v_extrude;\\nvarying vec2 v_extrude_scale;\\n\\nvoid main() {\\n    float alpha = 0.5;\\n\\n    // Red = collision, hide label\\n    vec4 color = vec4(1.0, 0.0, 0.0, 1.0) * alpha;\\n\\n    // Blue = no collision, label is showing\\n    if (v_placed > 0.5) {\\n        color = vec4(0.0, 0.0, 1.0, 0.5) * alpha;\\n    }\\n\\n    if (v_notUsed > 0.5) {\\n        // This box not used, fade it out\\n        color *= .2;\\n    }\\n\\n    float extrude_scale_length = length(v_extrude_scale);\\n    float extrude_length = length(v_extrude) * extrude_scale_length;\\n    float stroke_width = 15.0 * extrude_scale_length / u_overscale_factor;\\n    float radius = v_radius * extrude_scale_length;\\n\\n    float distance_to_edge = abs(extrude_length - radius);\\n    float opacity_t = smoothstep(-stroke_width, 0.0, -distance_to_edge);\\n\\n    gl_FragColor = opacity_t * color;\\n}\\n\",vertexSource:\"attribute vec2 a_pos;\\nattribute vec2 a_anchor_pos;\\nattribute vec2 a_extrude;\\nattribute vec2 a_placed;\\n\\nuniform mat4 u_matrix;\\nuniform vec2 u_extrude_scale;\\nuniform float u_camera_to_center_distance;\\n\\nvarying float v_placed;\\nvarying float v_notUsed;\\nvarying float v_radius;\\n\\nvarying vec2 v_extrude;\\nvarying vec2 v_extrude_scale;\\n\\nvoid main() {\\n    vec4 projectedPoint = u_matrix * vec4(a_anchor_pos, 0, 1);\\n    highp float camera_to_anchor_distance = projectedPoint.w;\\n    highp float collision_perspective_ratio = clamp(\\n        0.5 + 0.5 * (u_camera_to_center_distance / camera_to_anchor_distance),\\n        0.0, // Prevents oversized near-field circles in pitched/overzoomed tiles\\n        4.0);\\n\\n    gl_Position = u_matrix * vec4(a_pos, 0.0, 1.0);\\n\\n    highp float padding_factor = 1.2; // Pad the vertices slightly to make room for anti-alias blur\\n    gl_Position.xy += a_extrude * u_extrude_scale * padding_factor * gl_Position.w * collision_perspective_ratio;\\n\\n    v_placed = a_placed.x;\\n    v_notUsed = a_placed.y;\\n    v_radius = abs(a_extrude.y); // We don't pitch the circles, so both units of the extrusion vector are equal in magnitude to the radius\\n\\n    v_extrude = a_extrude * padding_factor;\\n    v_extrude_scale = u_extrude_scale * u_camera_to_center_distance * collision_perspective_ratio;\\n}\\n\"},debug:{fragmentSource:\"uniform highp vec4 u_color;\\n\\nvoid main() {\\n    gl_FragColor = u_color;\\n}\\n\",vertexSource:\"attribute vec2 a_pos;\\n\\nuniform mat4 u_matrix;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n}\\n\"},fill:{fragmentSource:\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    gl_FragColor = color * opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"attribute vec2 a_pos;\\n\\nuniform mat4 u_matrix;\\n\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n}\\n\"},fillOutline:{fragmentSource:\"#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\n\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 outline_color\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    float dist = length(v_pos - gl_FragCoord.xy);\\n    float alpha = 1.0 - smoothstep(0.0, 1.0, dist);\\n    gl_FragColor = outline_color * (alpha * opacity);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"attribute vec2 a_pos;\\n\\nuniform mat4 u_matrix;\\nuniform vec2 u_world;\\n\\nvarying vec2 v_pos;\\n\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 outline_color\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n    v_pos = (gl_Position.xy / gl_Position.w + 1.0) / 2.0 * u_world;\\n}\\n\"},fillOutlinePattern:{fragmentSource:\"uniform vec2 u_pattern_tl_a;\\nuniform vec2 u_pattern_br_a;\\nuniform vec2 u_pattern_tl_b;\\nuniform vec2 u_pattern_br_b;\\nuniform vec2 u_texsize;\\nuniform float u_mix;\\n\\nuniform sampler2D u_image;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\nvarying vec2 v_pos;\\n\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    vec2 imagecoord = mod(v_pos_a, 1.0);\\n    vec2 pos = mix(u_pattern_tl_a / u_texsize, u_pattern_br_a / u_texsize, imagecoord);\\n    vec4 color1 = texture2D(u_image, pos);\\n\\n    vec2 imagecoord_b = mod(v_pos_b, 1.0);\\n    vec2 pos2 = mix(u_pattern_tl_b / u_texsize, u_pattern_br_b / u_texsize, imagecoord_b);\\n    vec4 color2 = texture2D(u_image, pos2);\\n\\n    // find distance to outline for alpha interpolation\\n\\n    float dist = length(v_pos - gl_FragCoord.xy);\\n    float alpha = 1.0 - smoothstep(0.0, 1.0, dist);\\n\\n\\n    gl_FragColor = mix(color1, color2, u_mix) * alpha * opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_world;\\nuniform vec2 u_pattern_size_a;\\nuniform vec2 u_pattern_size_b;\\nuniform vec2 u_pixel_coord_upper;\\nuniform vec2 u_pixel_coord_lower;\\nuniform float u_scale_a;\\nuniform float u_scale_b;\\nuniform float u_tile_units_to_pixels;\\n\\nattribute vec2 a_pos;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\nvarying vec2 v_pos;\\n\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n\\n    v_pos_a = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_a * u_pattern_size_a, u_tile_units_to_pixels, a_pos);\\n    v_pos_b = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_b * u_pattern_size_b, u_tile_units_to_pixels, a_pos);\\n\\n    v_pos = (gl_Position.xy / gl_Position.w + 1.0) / 2.0 * u_world;\\n}\\n\"},fillPattern:{fragmentSource:\"uniform vec2 u_pattern_tl_a;\\nuniform vec2 u_pattern_br_a;\\nuniform vec2 u_pattern_tl_b;\\nuniform vec2 u_pattern_br_b;\\nuniform vec2 u_texsize;\\nuniform float u_mix;\\n\\nuniform sampler2D u_image;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\n\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    vec2 imagecoord = mod(v_pos_a, 1.0);\\n    vec2 pos = mix(u_pattern_tl_a / u_texsize, u_pattern_br_a / u_texsize, imagecoord);\\n    vec4 color1 = texture2D(u_image, pos);\\n\\n    vec2 imagecoord_b = mod(v_pos_b, 1.0);\\n    vec2 pos2 = mix(u_pattern_tl_b / u_texsize, u_pattern_br_b / u_texsize, imagecoord_b);\\n    vec4 color2 = texture2D(u_image, pos2);\\n\\n    gl_FragColor = mix(color1, color2, u_mix) * opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_pattern_size_a;\\nuniform vec2 u_pattern_size_b;\\nuniform vec2 u_pixel_coord_upper;\\nuniform vec2 u_pixel_coord_lower;\\nuniform float u_scale_a;\\nuniform float u_scale_b;\\nuniform float u_tile_units_to_pixels;\\n\\nattribute vec2 a_pos;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\n\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n\\n    v_pos_a = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_a * u_pattern_size_a, u_tile_units_to_pixels, a_pos);\\n    v_pos_b = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_b * u_pattern_size_b, u_tile_units_to_pixels, a_pos);\\n}\\n\"},fillExtrusion:{fragmentSource:\"varying vec4 v_color;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define highp vec4 color\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float base\\n    #pragma mapbox: initialize lowp float height\\n    #pragma mapbox: initialize highp vec4 color\\n\\n    gl_FragColor = v_color;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec3 u_lightcolor;\\nuniform lowp vec3 u_lightpos;\\nuniform lowp float u_lightintensity;\\n\\nattribute vec2 a_pos;\\nattribute vec4 a_normal_ed;\\n\\nvarying vec4 v_color;\\n\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n\\n#pragma mapbox: define highp vec4 color\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float base\\n    #pragma mapbox: initialize lowp float height\\n    #pragma mapbox: initialize highp vec4 color\\n\\n    vec3 normal = a_normal_ed.xyz;\\n\\n    base = max(0.0, base);\\n    height = max(0.0, height);\\n\\n    float t = mod(normal.x, 2.0);\\n\\n    gl_Position = u_matrix * vec4(a_pos, t > 0.0 ? height : base, 1);\\n\\n    // Relative luminance (how dark/bright is the surface color?)\\n    float colorvalue = color.r * 0.2126 + color.g * 0.7152 + color.b * 0.0722;\\n\\n    v_color = vec4(0.0, 0.0, 0.0, 1.0);\\n\\n    // Add slight ambient lighting so no extrusions are totally black\\n    vec4 ambientlight = vec4(0.03, 0.03, 0.03, 1.0);\\n    color += ambientlight;\\n\\n    // Calculate cos(theta), where theta is the angle between surface normal and diffuse light ray\\n    float directional = clamp(dot(normal / 16384.0, u_lightpos), 0.0, 1.0);\\n\\n    // Adjust directional so that\\n    // the range of values for highlight/shading is narrower\\n    // with lower light intensity\\n    // and with lighter/brighter surface colors\\n    directional = mix((1.0 - u_lightintensity), max((1.0 - colorvalue + u_lightintensity), 1.0), directional);\\n\\n    // Add gradient along z axis of side surfaces\\n    if (normal.y != 0.0) {\\n        directional *= clamp((t + base) * pow(height / 150.0, 0.5), mix(0.7, 0.98, 1.0 - u_lightintensity), 1.0);\\n    }\\n\\n    // Assign final color based on surface + ambient light color, diffuse light directional, and light color\\n    // with lower bounds adjusted to hue of light\\n    // so that shading is tinted with the complementary (opposite) color to the light color\\n    v_color.r += clamp(color.r * directional * u_lightcolor.r, mix(0.0, 0.3, 1.0 - u_lightcolor.r), 1.0);\\n    v_color.g += clamp(color.g * directional * u_lightcolor.g, mix(0.0, 0.3, 1.0 - u_lightcolor.g), 1.0);\\n    v_color.b += clamp(color.b * directional * u_lightcolor.b, mix(0.0, 0.3, 1.0 - u_lightcolor.b), 1.0);\\n}\\n\"},fillExtrusionPattern:{fragmentSource:\"uniform vec2 u_pattern_tl_a;\\nuniform vec2 u_pattern_br_a;\\nuniform vec2 u_pattern_tl_b;\\nuniform vec2 u_pattern_br_b;\\nuniform vec2 u_texsize;\\nuniform float u_mix;\\n\\nuniform sampler2D u_image;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\nvarying vec4 v_lighting;\\n\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float base\\n    #pragma mapbox: initialize lowp float height\\n\\n    vec2 imagecoord = mod(v_pos_a, 1.0);\\n    vec2 pos = mix(u_pattern_tl_a / u_texsize, u_pattern_br_a / u_texsize, imagecoord);\\n    vec4 color1 = texture2D(u_image, pos);\\n\\n    vec2 imagecoord_b = mod(v_pos_b, 1.0);\\n    vec2 pos2 = mix(u_pattern_tl_b / u_texsize, u_pattern_br_b / u_texsize, imagecoord_b);\\n    vec4 color2 = texture2D(u_image, pos2);\\n\\n    vec4 mixedColor = mix(color1, color2, u_mix);\\n\\n    gl_FragColor = mixedColor * v_lighting;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_pattern_size_a;\\nuniform vec2 u_pattern_size_b;\\nuniform vec2 u_pixel_coord_upper;\\nuniform vec2 u_pixel_coord_lower;\\nuniform float u_scale_a;\\nuniform float u_scale_b;\\nuniform float u_tile_units_to_pixels;\\nuniform float u_height_factor;\\n\\nuniform vec3 u_lightcolor;\\nuniform lowp vec3 u_lightpos;\\nuniform lowp float u_lightintensity;\\n\\nattribute vec2 a_pos;\\nattribute vec4 a_normal_ed;\\n\\nvarying vec2 v_pos_a;\\nvarying vec2 v_pos_b;\\nvarying vec4 v_lighting;\\nvarying float v_directional;\\n\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float base\\n    #pragma mapbox: initialize lowp float height\\n\\n    vec3 normal = a_normal_ed.xyz;\\n    float edgedistance = a_normal_ed.w;\\n\\n    base = max(0.0, base);\\n    height = max(0.0, height);\\n\\n    float t = mod(normal.x, 2.0);\\n    float z = t > 0.0 ? height : base;\\n\\n    gl_Position = u_matrix * vec4(a_pos, z, 1);\\n\\n    vec2 pos = normal.x == 1.0 && normal.y == 0.0 && normal.z == 16384.0\\n        ? a_pos // extrusion top\\n        : vec2(edgedistance, z * u_height_factor); // extrusion side\\n\\n    v_pos_a = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_a * u_pattern_size_a, u_tile_units_to_pixels, pos);\\n    v_pos_b = get_pattern_pos(u_pixel_coord_upper, u_pixel_coord_lower, u_scale_b * u_pattern_size_b, u_tile_units_to_pixels, pos);\\n\\n    v_lighting = vec4(0.0, 0.0, 0.0, 1.0);\\n    float directional = clamp(dot(normal / 16383.0, u_lightpos), 0.0, 1.0);\\n    directional = mix((1.0 - u_lightintensity), max((0.5 + u_lightintensity), 1.0), directional);\\n\\n    if (normal.y != 0.0) {\\n        directional *= clamp((t + base) * pow(height / 150.0, 0.5), mix(0.7, 0.98, 1.0 - u_lightintensity), 1.0);\\n    }\\n\\n    v_lighting.rgb += clamp(directional * u_lightcolor, mix(vec3(0.0), vec3(0.3), 1.0 - u_lightcolor), vec3(1.0));\\n}\\n\"},extrusionTexture:{fragmentSource:\"uniform sampler2D u_image;\\nuniform float u_opacity;\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    gl_FragColor = texture2D(u_image, v_pos) * u_opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(0.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_world;\\nattribute vec2 a_pos;\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos * u_world, 0, 1);\\n\\n    v_pos.x = a_pos.x;\\n    v_pos.y = 1.0 - a_pos.y;\\n}\\n\"},hillshadePrepare:{fragmentSource:\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\n\\nuniform sampler2D u_image;\\nvarying vec2 v_pos;\\nuniform vec2 u_dimension;\\nuniform float u_zoom;\\nuniform float u_maxzoom;\\n\\nfloat getElevation(vec2 coord, float bias) {\\n    // Convert encoded elevation value to meters\\n    vec4 data = texture2D(u_image, coord) * 255.0;\\n    return (data.r + data.g * 256.0 + data.b * 256.0 * 256.0) / 4.0;\\n}\\n\\nvoid main() {\\n    vec2 epsilon = 1.0 / u_dimension;\\n\\n    // queried pixels:\\n    // +-----------+\\n    // |   |   |   |\\n    // | a | b | c |\\n    // |   |   |   |\\n    // +-----------+\\n    // |   |   |   |\\n    // | d | e | f |\\n    // |   |   |   |\\n    // +-----------+\\n    // |   |   |   |\\n    // | g | h | i |\\n    // |   |   |   |\\n    // +-----------+\\n\\n    float a = getElevation(v_pos + vec2(-epsilon.x, -epsilon.y), 0.0);\\n    float b = getElevation(v_pos + vec2(0, -epsilon.y), 0.0);\\n    float c = getElevation(v_pos + vec2(epsilon.x, -epsilon.y), 0.0);\\n    float d = getElevation(v_pos + vec2(-epsilon.x, 0), 0.0);\\n    float e = getElevation(v_pos, 0.0);\\n    float f = getElevation(v_pos + vec2(epsilon.x, 0), 0.0);\\n    float g = getElevation(v_pos + vec2(-epsilon.x, epsilon.y), 0.0);\\n    float h = getElevation(v_pos + vec2(0, epsilon.y), 0.0);\\n    float i = getElevation(v_pos + vec2(epsilon.x, epsilon.y), 0.0);\\n\\n    // here we divide the x and y slopes by 8 * pixel size\\n    // where pixel size (aka meters/pixel) is:\\n    // circumference of the world / (pixels per tile * number of tiles)\\n    // which is equivalent to: 8 * 40075016.6855785 / (512 * pow(2, u_zoom))\\n    // which can be reduced to: pow(2, 19.25619978527 - u_zoom)\\n    // we want to vertically exaggerate the hillshading though, because otherwise\\n    // it is barely noticeable at low zooms. to do this, we multiply this by some\\n    // scale factor pow(2, (u_zoom - u_maxzoom) * a) where a is an arbitrary value\\n    // Here we use a=0.3 which works out to the expression below. see \\n    // nickidlugash's awesome breakdown for more info\\n    // https://github.com/mapbox/mapbox-gl-js/pull/5286#discussion_r148419556\\n    float exaggeration = u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;\\n\\n    vec2 deriv = vec2(\\n        (c + f + f + i) - (a + d + d + g),\\n        (g + h + h + i) - (a + b + b + c)\\n    ) /  pow(2.0, (u_zoom - u_maxzoom) * exaggeration + 19.2562 - u_zoom);\\n\\n    gl_FragColor = clamp(vec4(\\n        deriv.x / 2.0 + 0.5,\\n        deriv.y / 2.0 + 0.5,\\n        1.0,\\n        1.0), 0.0, 1.0);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\n\\nattribute vec2 a_pos;\\nattribute vec2 a_texture_pos;\\n\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n    v_pos = (a_texture_pos / 8192.0) / 2.0 + 0.25;\\n}\\n\"},hillshade:{fragmentSource:\"uniform sampler2D u_image;\\nvarying vec2 v_pos;\\n\\nuniform vec2 u_latrange;\\nuniform vec2 u_light;\\nuniform vec4 u_shadow;\\nuniform vec4 u_highlight;\\nuniform vec4 u_accent;\\n\\n#define PI 3.141592653589793\\n\\nvoid main() {\\n    vec4 pixel = texture2D(u_image, v_pos);\\n\\n    vec2 deriv = ((pixel.rg * 2.0) - 1.0);\\n\\n    // We divide the slope by a scale factor based on the cosin of the pixel's approximate latitude\\n    // to account for mercator projection distortion. see #4807 for details\\n    float scaleFactor = cos(radians((u_latrange[0] - u_latrange[1]) * (1.0 - v_pos.y) + u_latrange[1]));\\n    // We also multiply the slope by an arbitrary z-factor of 1.25\\n    float slope = atan(1.25 * length(deriv) / scaleFactor);\\n    float aspect = deriv.x != 0.0 ? atan(deriv.y, -deriv.x) : PI / 2.0 * (deriv.y > 0.0 ? 1.0 : -1.0);\\n\\n    float intensity = u_light.x;\\n    // We add PI to make this property match the global light object, which adds PI/2 to the light's azimuthal\\n    // position property to account for 0deg corresponding to north/the top of the viewport in the style spec\\n    // and the original shader was written to accept (-illuminationDirection - 90) as the azimuthal.\\n    float azimuth = u_light.y + PI;\\n\\n    // We scale the slope exponentially based on intensity, using a calculation similar to\\n    // the exponential interpolation function in the style spec:\\n    // https://github.com/mapbox/mapbox-gl-js/blob/master/src/style-spec/expression/definitions/interpolate.js#L217-L228\\n    // so that higher intensity values create more opaque hillshading.\\n    float base = 1.875 - intensity * 1.75;\\n    float maxValue = 0.5 * PI;\\n    float scaledSlope = intensity != 0.5 ? ((pow(base, slope) - 1.0) / (pow(base, maxValue) - 1.0)) * maxValue : slope;\\n\\n    // The accent color is calculated with the cosine of the slope while the shade color is calculated with the sine\\n    // so that the accent color's rate of change eases in while the shade color's eases out.\\n    float accent = cos(scaledSlope);\\n    // We multiply both the accent and shade color by a clamped intensity value\\n    // so that intensities >= 0.5 do not additionally affect the color values\\n    // while intensity values < 0.5 make the overall color more transparent.\\n    vec4 accent_color = (1.0 - accent) * u_accent * clamp(intensity * 2.0, 0.0, 1.0);\\n    float shade = abs(mod((aspect + azimuth) / PI + 0.5, 2.0) - 1.0);\\n    vec4 shade_color = mix(u_shadow, u_highlight, shade) * sin(scaledSlope) * clamp(intensity * 2.0, 0.0, 1.0);\\n    gl_FragColor = accent_color * (1.0 - shade_color.a) + shade_color;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\n\\nattribute vec2 a_pos;\\nattribute vec2 a_texture_pos;\\n\\nvarying vec2 v_pos;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n    v_pos = a_texture_pos / 8192.0;\\n}\\n\"},line:{fragmentSource:\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n\\nvarying vec2 v_width2;\\nvarying vec2 v_normal;\\nvarying float v_gamma_scale;\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    // Calculate the distance of the pixel from the line in pixels.\\n    float dist = length(v_normal) * v_width2.s;\\n\\n    // Calculate the antialiasing fade factor. This is either when fading in\\n    // the line in case of an offset line (v_width2.t) or when fading out\\n    // (v_width2.s)\\n    float blur2 = (blur + 1.0 / DEVICE_PIXEL_RATIO) * v_gamma_scale;\\n    float alpha = clamp(min(dist - (v_width2.t - blur2), v_width2.s - dist) / blur2, 0.0, 1.0);\\n\\n    gl_FragColor = color * (alpha * opacity);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"\\n\\n// the distance over which the line edge fades out.\\n// Retina devices need a smaller distance to avoid aliasing.\\n#define ANTIALIASING 1.0 / DEVICE_PIXEL_RATIO / 2.0\\n\\n// floor(127 / 2) == 63.0\\n// the maximum allowed miter limit is 2.0 at the moment. the extrude normal is\\n// stored in a byte (-128..127). we scale regular normals up to length 63, but\\n// there are also \\\"special\\\" normals that have a bigger length (of up to 126 in\\n// this case).\\n// #define scale 63.0\\n#define scale 0.015873016\\n\\nattribute vec4 a_pos_normal;\\nattribute vec4 a_data;\\n\\nuniform mat4 u_matrix;\\nuniform mediump float u_ratio;\\nuniform vec2 u_gl_units_to_pixels;\\n\\nvarying vec2 v_normal;\\nvarying vec2 v_width2;\\nvarying float v_gamma_scale;\\nvarying highp float v_linesofar;\\n\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize mediump float gapwidth\\n    #pragma mapbox: initialize lowp float offset\\n    #pragma mapbox: initialize mediump float width\\n\\n    vec2 a_extrude = a_data.xy - 128.0;\\n    float a_direction = mod(a_data.z, 4.0) - 1.0;\\n\\n    v_linesofar = (floor(a_data.z / 4.0) + a_data.w * 64.0) * 2.0;\\n\\n    vec2 pos = a_pos_normal.xy;\\n\\n    // x is 1 if it's a round cap, 0 otherwise\\n    // y is 1 if the normal points up, and -1 if it points down\\n    mediump vec2 normal = a_pos_normal.zw;\\n    v_normal = normal;\\n\\n    // these transformations used to be applied in the JS and native code bases.\\n    // moved them into the shader for clarity and simplicity.\\n    gapwidth = gapwidth / 2.0;\\n    float halfwidth = width / 2.0;\\n    offset = -1.0 * offset;\\n\\n    float inset = gapwidth + (gapwidth > 0.0 ? ANTIALIASING : 0.0);\\n    float outset = gapwidth + halfwidth * (gapwidth > 0.0 ? 2.0 : 1.0) + ANTIALIASING;\\n\\n    // Scale the extrusion vector down to a normal and then up by the line width\\n    // of this vertex.\\n    mediump vec2 dist = outset * a_extrude * scale;\\n\\n    // Calculate the offset when drawing a line that is to the side of the actual line.\\n    // We do this by creating a vector that points towards the extrude, but rotate\\n    // it when we're drawing round end points (a_direction = -1 or 1) since their\\n    // extrude vector points in another direction.\\n    mediump float u = 0.5 * a_direction;\\n    mediump float t = 1.0 - abs(u);\\n    mediump vec2 offset2 = offset * a_extrude * scale * normal.y * mat2(t, -u, u, t);\\n\\n    vec4 projected_extrude = u_matrix * vec4(dist / u_ratio, 0.0, 0.0);\\n    gl_Position = u_matrix * vec4(pos + offset2 / u_ratio, 0.0, 1.0) + projected_extrude;\\n\\n    // calculate how much the perspective view squishes or stretches the extrude\\n    float extrude_length_without_perspective = length(dist);\\n    float extrude_length_with_perspective = length(projected_extrude.xy / gl_Position.w * u_gl_units_to_pixels);\\n    v_gamma_scale = extrude_length_without_perspective / extrude_length_with_perspective;\\n\\n    v_width2 = vec2(outset, inset);\\n}\\n\"},lineGradient:{fragmentSource:\"\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n\\nuniform sampler2D u_image;\\n\\nvarying vec2 v_width2;\\nvarying vec2 v_normal;\\nvarying float v_gamma_scale;\\nvarying highp float v_lineprogress;\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    // Calculate the distance of the pixel from the line in pixels.\\n    float dist = length(v_normal) * v_width2.s;\\n\\n    // Calculate the antialiasing fade factor. This is either when fading in\\n    // the line in case of an offset line (v_width2.t) or when fading out\\n    // (v_width2.s)\\n    float blur2 = (blur + 1.0 / DEVICE_PIXEL_RATIO) * v_gamma_scale;\\n    float alpha = clamp(min(dist - (v_width2.t - blur2), v_width2.s - dist) / blur2, 0.0, 1.0);\\n\\n    // For gradient lines, v_lineprogress is the ratio along the entire line,\\n    // scaled to [0, 2^15), and the gradient ramp is stored in a texture.\\n    vec4 color = texture2D(u_image, vec2(v_lineprogress, 0.5));\\n\\n    gl_FragColor = color * (alpha * opacity);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"\\n// the attribute conveying progress along a line is scaled to [0, 2^15)\\n#define MAX_LINE_DISTANCE 32767.0\\n\\n// the distance over which the line edge fades out.\\n// Retina devices need a smaller distance to avoid aliasing.\\n#define ANTIALIASING 1.0 / DEVICE_PIXEL_RATIO / 2.0\\n\\n// floor(127 / 2) == 63.0\\n// the maximum allowed miter limit is 2.0 at the moment. the extrude normal is\\n// stored in a byte (-128..127). we scale regular normals up to length 63, but\\n// there are also \\\"special\\\" normals that have a bigger length (of up to 126 in\\n// this case).\\n// #define scale 63.0\\n#define scale 0.015873016\\n\\nattribute vec4 a_pos_normal;\\nattribute vec4 a_data;\\n\\nuniform mat4 u_matrix;\\nuniform mediump float u_ratio;\\nuniform vec2 u_gl_units_to_pixels;\\n\\nvarying vec2 v_normal;\\nvarying vec2 v_width2;\\nvarying float v_gamma_scale;\\nvarying highp float v_lineprogress;\\n\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize mediump float gapwidth\\n    #pragma mapbox: initialize lowp float offset\\n    #pragma mapbox: initialize mediump float width\\n\\n    vec2 a_extrude = a_data.xy - 128.0;\\n    float a_direction = mod(a_data.z, 4.0) - 1.0;\\n\\n    v_lineprogress = (floor(a_data.z / 4.0) + a_data.w * 64.0) * 2.0 / MAX_LINE_DISTANCE;\\n\\n    vec2 pos = a_pos_normal.xy;\\n\\n    // x is 1 if it's a round cap, 0 otherwise\\n    // y is 1 if the normal points up, and -1 if it points down\\n    mediump vec2 normal = a_pos_normal.zw;\\n    v_normal = normal;\\n\\n    // these transformations used to be applied in the JS and native code bases.\\n    // moved them into the shader for clarity and simplicity.\\n    gapwidth = gapwidth / 2.0;\\n    float halfwidth = width / 2.0;\\n    offset = -1.0 * offset;\\n\\n    float inset = gapwidth + (gapwidth > 0.0 ? ANTIALIASING : 0.0);\\n    float outset = gapwidth + halfwidth * (gapwidth > 0.0 ? 2.0 : 1.0) + ANTIALIASING;\\n\\n    // Scale the extrusion vector down to a normal and then up by the line width\\n    // of this vertex.\\n    mediump vec2 dist = outset * a_extrude * scale;\\n\\n    // Calculate the offset when drawing a line that is to the side of the actual line.\\n    // We do this by creating a vector that points towards the extrude, but rotate\\n    // it when we're drawing round end points (a_direction = -1 or 1) since their\\n    // extrude vector points in another direction.\\n    mediump float u = 0.5 * a_direction;\\n    mediump float t = 1.0 - abs(u);\\n    mediump vec2 offset2 = offset * a_extrude * scale * normal.y * mat2(t, -u, u, t);\\n\\n    vec4 projected_extrude = u_matrix * vec4(dist / u_ratio, 0.0, 0.0);\\n    gl_Position = u_matrix * vec4(pos + offset2 / u_ratio, 0.0, 1.0) + projected_extrude;\\n\\n    // calculate how much the perspective view squishes or stretches the extrude\\n    float extrude_length_without_perspective = length(dist);\\n    float extrude_length_with_perspective = length(projected_extrude.xy / gl_Position.w * u_gl_units_to_pixels);\\n    v_gamma_scale = extrude_length_without_perspective / extrude_length_with_perspective;\\n\\n    v_width2 = vec2(outset, inset);\\n}\\n\"},linePattern:{fragmentSource:\"uniform vec2 u_pattern_size_a;\\nuniform vec2 u_pattern_size_b;\\nuniform vec2 u_pattern_tl_a;\\nuniform vec2 u_pattern_br_a;\\nuniform vec2 u_pattern_tl_b;\\nuniform vec2 u_pattern_br_b;\\nuniform vec2 u_texsize;\\nuniform float u_fade;\\n\\nuniform sampler2D u_image;\\n\\nvarying vec2 v_normal;\\nvarying vec2 v_width2;\\nvarying float v_linesofar;\\nvarying float v_gamma_scale;\\n\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    // Calculate the distance of the pixel from the line in pixels.\\n    float dist = length(v_normal) * v_width2.s;\\n\\n    // Calculate the antialiasing fade factor. This is either when fading in\\n    // the line in case of an offset line (v_width2.t) or when fading out\\n    // (v_width2.s)\\n    float blur2 = (blur + 1.0 / DEVICE_PIXEL_RATIO) * v_gamma_scale;\\n    float alpha = clamp(min(dist - (v_width2.t - blur2), v_width2.s - dist) / blur2, 0.0, 1.0);\\n\\n    float x_a = mod(v_linesofar / u_pattern_size_a.x, 1.0);\\n    float x_b = mod(v_linesofar / u_pattern_size_b.x, 1.0);\\n\\n    // v_normal.y is 0 at the midpoint of the line, -1 at the lower edge, 1 at the upper edge\\n    // we clamp the line width outset to be between 0 and half the pattern height plus padding (2.0)\\n    // to ensure we don't sample outside the designated symbol on the sprite sheet.\\n    // 0.5 is added to shift the component to be bounded between 0 and 1 for interpolation of\\n    // the texture coordinate\\n    float y_a = 0.5 + (v_normal.y * clamp(v_width2.s, 0.0, (u_pattern_size_a.y + 2.0) / 2.0) / u_pattern_size_a.y);\\n    float y_b = 0.5 + (v_normal.y * clamp(v_width2.s, 0.0, (u_pattern_size_b.y + 2.0) / 2.0) / u_pattern_size_b.y);\\n    vec2 pos_a = mix(u_pattern_tl_a / u_texsize, u_pattern_br_a / u_texsize, vec2(x_a, y_a));\\n    vec2 pos_b = mix(u_pattern_tl_b / u_texsize, u_pattern_br_b / u_texsize, vec2(x_b, y_b));\\n\\n    vec4 color = mix(texture2D(u_image, pos_a), texture2D(u_image, pos_b), u_fade);\\n\\n    gl_FragColor = color * alpha * opacity;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"// floor(127 / 2) == 63.0\\n// the maximum allowed miter limit is 2.0 at the moment. the extrude normal is\\n// stored in a byte (-128..127). we scale regular normals up to length 63, but\\n// there are also \\\"special\\\" normals that have a bigger length (of up to 126 in\\n// this case).\\n// #define scale 63.0\\n#define scale 0.015873016\\n\\n// We scale the distance before adding it to the buffers so that we can store\\n// long distances for long segments. Use this value to unscale the distance.\\n#define LINE_DISTANCE_SCALE 2.0\\n\\n// the distance over which the line edge fades out.\\n// Retina devices need a smaller distance to avoid aliasing.\\n#define ANTIALIASING 1.0 / DEVICE_PIXEL_RATIO / 2.0\\n\\nattribute vec4 a_pos_normal;\\nattribute vec4 a_data;\\n\\nuniform mat4 u_matrix;\\nuniform mediump float u_ratio;\\nuniform vec2 u_gl_units_to_pixels;\\n\\nvarying vec2 v_normal;\\nvarying vec2 v_width2;\\nvarying float v_linesofar;\\nvarying float v_gamma_scale;\\n\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize lowp float offset\\n    #pragma mapbox: initialize mediump float gapwidth\\n    #pragma mapbox: initialize mediump float width\\n\\n    vec2 a_extrude = a_data.xy - 128.0;\\n    float a_direction = mod(a_data.z, 4.0) - 1.0;\\n    float a_linesofar = (floor(a_data.z / 4.0) + a_data.w * 64.0) * LINE_DISTANCE_SCALE;\\n\\n    vec2 pos = a_pos_normal.xy;\\n\\n    // x is 1 if it's a round cap, 0 otherwise\\n    // y is 1 if the normal points up, and -1 if it points down\\n    mediump vec2 normal = a_pos_normal.zw;\\n    v_normal = normal;\\n\\n    // these transformations used to be applied in the JS and native code bases.\\n    // moved them into the shader for clarity and simplicity.\\n    gapwidth = gapwidth / 2.0;\\n    float halfwidth = width / 2.0;\\n    offset = -1.0 * offset;\\n\\n    float inset = gapwidth + (gapwidth > 0.0 ? ANTIALIASING : 0.0);\\n    float outset = gapwidth + halfwidth * (gapwidth > 0.0 ? 2.0 : 1.0) + ANTIALIASING;\\n\\n    // Scale the extrusion vector down to a normal and then up by the line width\\n    // of this vertex.\\n    mediump vec2 dist = outset * a_extrude * scale;\\n\\n    // Calculate the offset when drawing a line that is to the side of the actual line.\\n    // We do this by creating a vector that points towards the extrude, but rotate\\n    // it when we're drawing round end points (a_direction = -1 or 1) since their\\n    // extrude vector points in another direction.\\n    mediump float u = 0.5 * a_direction;\\n    mediump float t = 1.0 - abs(u);\\n    mediump vec2 offset2 = offset * a_extrude * scale * normal.y * mat2(t, -u, u, t);\\n\\n    vec4 projected_extrude = u_matrix * vec4(dist / u_ratio, 0.0, 0.0);\\n    gl_Position = u_matrix * vec4(pos + offset2 / u_ratio, 0.0, 1.0) + projected_extrude;\\n\\n    // calculate how much the perspective view squishes or stretches the extrude\\n    float extrude_length_without_perspective = length(dist);\\n    float extrude_length_with_perspective = length(projected_extrude.xy / gl_Position.w * u_gl_units_to_pixels);\\n    v_gamma_scale = extrude_length_without_perspective / extrude_length_with_perspective;\\n\\n    v_linesofar = a_linesofar;\\n    v_width2 = vec2(outset, inset);\\n}\\n\"},lineSDF:{fragmentSource:\"\\nuniform sampler2D u_image;\\nuniform float u_sdfgamma;\\nuniform float u_mix;\\n\\nvarying vec2 v_normal;\\nvarying vec2 v_width2;\\nvarying vec2 v_tex_a;\\nvarying vec2 v_tex_b;\\nvarying float v_gamma_scale;\\n\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize mediump float width\\n    #pragma mapbox: initialize lowp float floorwidth\\n\\n    // Calculate the distance of the pixel from the line in pixels.\\n    float dist = length(v_normal) * v_width2.s;\\n\\n    // Calculate the antialiasing fade factor. This is either when fading in\\n    // the line in case of an offset line (v_width2.t) or when fading out\\n    // (v_width2.s)\\n    float blur2 = (blur + 1.0 / DEVICE_PIXEL_RATIO) * v_gamma_scale;\\n    float alpha = clamp(min(dist - (v_width2.t - blur2), v_width2.s - dist) / blur2, 0.0, 1.0);\\n\\n    float sdfdist_a = texture2D(u_image, v_tex_a).a;\\n    float sdfdist_b = texture2D(u_image, v_tex_b).a;\\n    float sdfdist = mix(sdfdist_a, sdfdist_b, u_mix);\\n    alpha *= smoothstep(0.5 - u_sdfgamma / floorwidth, 0.5 + u_sdfgamma / floorwidth, sdfdist);\\n\\n    gl_FragColor = color * (alpha * opacity);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"// floor(127 / 2) == 63.0\\n// the maximum allowed miter limit is 2.0 at the moment. the extrude normal is\\n// stored in a byte (-128..127). we scale regular normals up to length 63, but\\n// there are also \\\"special\\\" normals that have a bigger length (of up to 126 in\\n// this case).\\n// #define scale 63.0\\n#define scale 0.015873016\\n\\n// We scale the distance before adding it to the buffers so that we can store\\n// long distances for long segments. Use this value to unscale the distance.\\n#define LINE_DISTANCE_SCALE 2.0\\n\\n// the distance over which the line edge fades out.\\n// Retina devices need a smaller distance to avoid aliasing.\\n#define ANTIALIASING 1.0 / DEVICE_PIXEL_RATIO / 2.0\\n\\nattribute vec4 a_pos_normal;\\nattribute vec4 a_data;\\n\\nuniform mat4 u_matrix;\\nuniform mediump float u_ratio;\\nuniform vec2 u_patternscale_a;\\nuniform float u_tex_y_a;\\nuniform vec2 u_patternscale_b;\\nuniform float u_tex_y_b;\\nuniform vec2 u_gl_units_to_pixels;\\n\\nvarying vec2 v_normal;\\nvarying vec2 v_width2;\\nvarying vec2 v_tex_a;\\nvarying vec2 v_tex_b;\\nvarying float v_gamma_scale;\\n\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 color\\n    #pragma mapbox: initialize lowp float blur\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize mediump float gapwidth\\n    #pragma mapbox: initialize lowp float offset\\n    #pragma mapbox: initialize mediump float width\\n    #pragma mapbox: initialize lowp float floorwidth\\n\\n    vec2 a_extrude = a_data.xy - 128.0;\\n    float a_direction = mod(a_data.z, 4.0) - 1.0;\\n    float a_linesofar = (floor(a_data.z / 4.0) + a_data.w * 64.0) * LINE_DISTANCE_SCALE;\\n\\n    vec2 pos = a_pos_normal.xy;\\n\\n    // x is 1 if it's a round cap, 0 otherwise\\n    // y is 1 if the normal points up, and -1 if it points down\\n    mediump vec2 normal = a_pos_normal.zw;\\n    v_normal = normal;\\n\\n    // these transformations used to be applied in the JS and native code bases.\\n    // moved them into the shader for clarity and simplicity.\\n    gapwidth = gapwidth / 2.0;\\n    float halfwidth = width / 2.0;\\n    offset = -1.0 * offset;\\n\\n    float inset = gapwidth + (gapwidth > 0.0 ? ANTIALIASING : 0.0);\\n    float outset = gapwidth + halfwidth * (gapwidth > 0.0 ? 2.0 : 1.0) + ANTIALIASING;\\n\\n    // Scale the extrusion vector down to a normal and then up by the line width\\n    // of this vertex.\\n    mediump vec2 dist =outset * a_extrude * scale;\\n\\n    // Calculate the offset when drawing a line that is to the side of the actual line.\\n    // We do this by creating a vector that points towards the extrude, but rotate\\n    // it when we're drawing round end points (a_direction = -1 or 1) since their\\n    // extrude vector points in another direction.\\n    mediump float u = 0.5 * a_direction;\\n    mediump float t = 1.0 - abs(u);\\n    mediump vec2 offset2 = offset * a_extrude * scale * normal.y * mat2(t, -u, u, t);\\n\\n    vec4 projected_extrude = u_matrix * vec4(dist / u_ratio, 0.0, 0.0);\\n    gl_Position = u_matrix * vec4(pos + offset2 / u_ratio, 0.0, 1.0) + projected_extrude;\\n\\n    // calculate how much the perspective view squishes or stretches the extrude\\n    float extrude_length_without_perspective = length(dist);\\n    float extrude_length_with_perspective = length(projected_extrude.xy / gl_Position.w * u_gl_units_to_pixels);\\n    v_gamma_scale = extrude_length_without_perspective / extrude_length_with_perspective;\\n\\n    v_tex_a = vec2(a_linesofar * u_patternscale_a.x / floorwidth, normal.y * u_patternscale_a.y + u_tex_y_a);\\n    v_tex_b = vec2(a_linesofar * u_patternscale_b.x / floorwidth, normal.y * u_patternscale_b.y + u_tex_y_b);\\n\\n    v_width2 = vec2(outset, inset);\\n}\\n\"},raster:{fragmentSource:\"uniform float u_fade_t;\\nuniform float u_opacity;\\nuniform sampler2D u_image0;\\nuniform sampler2D u_image1;\\nvarying vec2 v_pos0;\\nvarying vec2 v_pos1;\\n\\nuniform float u_brightness_low;\\nuniform float u_brightness_high;\\n\\nuniform float u_saturation_factor;\\nuniform float u_contrast_factor;\\nuniform vec3 u_spin_weights;\\n\\nvoid main() {\\n\\n    // read and cross-fade colors from the main and parent tiles\\n    vec4 color0 = texture2D(u_image0, v_pos0);\\n    vec4 color1 = texture2D(u_image1, v_pos1);\\n    if (color0.a > 0.0) {\\n        color0.rgb = color0.rgb / color0.a;\\n    }\\n    if (color1.a > 0.0) {\\n        color1.rgb = color1.rgb / color1.a;\\n    }\\n    vec4 color = mix(color0, color1, u_fade_t);\\n    color.a *= u_opacity;\\n    vec3 rgb = color.rgb;\\n\\n    // spin\\n    rgb = vec3(\\n        dot(rgb, u_spin_weights.xyz),\\n        dot(rgb, u_spin_weights.zxy),\\n        dot(rgb, u_spin_weights.yzx));\\n\\n    // saturation\\n    float average = (color.r + color.g + color.b) / 3.0;\\n    rgb += (average - rgb) * u_saturation_factor;\\n\\n    // contrast\\n    rgb = (rgb - 0.5) * u_contrast_factor + 0.5;\\n\\n    // brightness\\n    vec3 u_high_vec = vec3(u_brightness_low, u_brightness_low, u_brightness_low);\\n    vec3 u_low_vec = vec3(u_brightness_high, u_brightness_high, u_brightness_high);\\n\\n    gl_FragColor = vec4(mix(u_high_vec, u_low_vec, rgb) * color.a, color.a);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"uniform mat4 u_matrix;\\nuniform vec2 u_tl_parent;\\nuniform float u_scale_parent;\\nuniform float u_buffer_scale;\\n\\nattribute vec2 a_pos;\\nattribute vec2 a_texture_pos;\\n\\nvarying vec2 v_pos0;\\nvarying vec2 v_pos1;\\n\\nvoid main() {\\n    gl_Position = u_matrix * vec4(a_pos, 0, 1);\\n    // We are using Int16 for texture position coordinates to give us enough precision for\\n    // fractional coordinates. We use 8192 to scale the texture coordinates in the buffer\\n    // as an arbitrarily high number to preserve adequate precision when rendering.\\n    // This is also the same value as the EXTENT we are using for our tile buffer pos coordinates,\\n    // so math for modifying either is consistent.\\n    v_pos0 = (((a_texture_pos / 8192.0) - 0.5) / u_buffer_scale ) + 0.5;\\n    v_pos1 = (v_pos0 * u_scale_parent) + u_tl_parent;\\n}\\n\"},symbolIcon:{fragmentSource:\"uniform sampler2D u_texture;\\n\\n#pragma mapbox: define lowp float opacity\\n\\nvarying vec2 v_tex;\\nvarying float v_fade_opacity;\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    lowp float alpha = opacity * v_fade_opacity;\\n    gl_FragColor = texture2D(u_texture, v_tex) * alpha;\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"const float PI = 3.141592653589793;\\n\\nattribute vec4 a_pos_offset;\\nattribute vec4 a_data;\\nattribute vec3 a_projected_pos;\\nattribute float a_fade_opacity;\\n\\nuniform bool u_is_size_zoom_constant;\\nuniform bool u_is_size_feature_constant;\\nuniform highp float u_size_t; // used to interpolate between zoom stops when size is a composite function\\nuniform highp float u_size; // used when size is both zoom and feature constant\\nuniform highp float u_camera_to_center_distance;\\nuniform highp float u_pitch;\\nuniform bool u_rotate_symbol;\\nuniform highp float u_aspect_ratio;\\nuniform float u_fade_change;\\n\\n#pragma mapbox: define lowp float opacity\\n\\nuniform mat4 u_matrix;\\nuniform mat4 u_label_plane_matrix;\\nuniform mat4 u_gl_coord_matrix;\\n\\nuniform bool u_is_text;\\nuniform bool u_pitch_with_map;\\n\\nuniform vec2 u_texsize;\\n\\nvarying vec2 v_tex;\\nvarying float v_fade_opacity;\\n\\nvoid main() {\\n    #pragma mapbox: initialize lowp float opacity\\n\\n    vec2 a_pos = a_pos_offset.xy;\\n    vec2 a_offset = a_pos_offset.zw;\\n\\n    vec2 a_tex = a_data.xy;\\n    vec2 a_size = a_data.zw;\\n\\n    highp float segment_angle = -a_projected_pos[2];\\n\\n    float size;\\n    if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {\\n        size = mix(a_size[0], a_size[1], u_size_t) / 10.0;\\n    } else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {\\n        size = a_size[0] / 10.0;\\n    } else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {\\n        size = u_size;\\n    } else {\\n        size = u_size;\\n    }\\n\\n    vec4 projectedPoint = u_matrix * vec4(a_pos, 0, 1);\\n    highp float camera_to_anchor_distance = projectedPoint.w;\\n    // See comments in symbol_sdf.vertex\\n    highp float distance_ratio = u_pitch_with_map ?\\n        camera_to_anchor_distance / u_camera_to_center_distance :\\n        u_camera_to_center_distance / camera_to_anchor_distance;\\n    highp float perspective_ratio = clamp(\\n            0.5 + 0.5 * distance_ratio,\\n            0.0, // Prevents oversized near-field symbols in pitched/overzoomed tiles\\n            4.0);\\n\\n    size *= perspective_ratio;\\n\\n    float fontScale = u_is_text ? size / 24.0 : size;\\n\\n    highp float symbol_rotation = 0.0;\\n    if (u_rotate_symbol) {\\n        // See comments in symbol_sdf.vertex\\n        vec4 offsetProjectedPoint = u_matrix * vec4(a_pos + vec2(1, 0), 0, 1);\\n\\n        vec2 a = projectedPoint.xy / projectedPoint.w;\\n        vec2 b = offsetProjectedPoint.xy / offsetProjectedPoint.w;\\n\\n        symbol_rotation = atan((b.y - a.y) / u_aspect_ratio, b.x - a.x);\\n    }\\n\\n    highp float angle_sin = sin(segment_angle + symbol_rotation);\\n    highp float angle_cos = cos(segment_angle + symbol_rotation);\\n    mat2 rotation_matrix = mat2(angle_cos, -1.0 * angle_sin, angle_sin, angle_cos);\\n\\n    vec4 projected_pos = u_label_plane_matrix * vec4(a_projected_pos.xy, 0.0, 1.0);\\n    gl_Position = u_gl_coord_matrix * vec4(projected_pos.xy / projected_pos.w + rotation_matrix * (a_offset / 32.0 * fontScale), 0.0, 1.0);\\n\\n    v_tex = a_tex / u_texsize;\\n    vec2 fade_opacity = unpack_opacity(a_fade_opacity);\\n    float fade_change = fade_opacity[1] > 0.5 ? u_fade_change : -u_fade_change;\\n    v_fade_opacity = max(0.0, min(1.0, fade_opacity[0] + fade_change));\\n}\\n\"},symbolSDF:{fragmentSource:\"#define SDF_PX 8.0\\n#define EDGE_GAMMA 0.105/DEVICE_PIXEL_RATIO\\n\\nuniform bool u_is_halo;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\n\\nuniform sampler2D u_texture;\\nuniform highp float u_gamma_scale;\\nuniform bool u_is_text;\\n\\nvarying vec2 v_data0;\\nvarying vec3 v_data1;\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 fill_color\\n    #pragma mapbox: initialize highp vec4 halo_color\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize lowp float halo_width\\n    #pragma mapbox: initialize lowp float halo_blur\\n\\n    vec2 tex = v_data0.xy;\\n    float gamma_scale = v_data1.x;\\n    float size = v_data1.y;\\n    float fade_opacity = v_data1[2];\\n\\n    float fontScale = u_is_text ? size / 24.0 : size;\\n\\n    lowp vec4 color = fill_color;\\n    highp float gamma = EDGE_GAMMA / (fontScale * u_gamma_scale);\\n    lowp float buff = (256.0 - 64.0) / 256.0;\\n    if (u_is_halo) {\\n        color = halo_color;\\n        gamma = (halo_blur * 1.19 / SDF_PX + EDGE_GAMMA) / (fontScale * u_gamma_scale);\\n        buff = (6.0 - halo_width / fontScale) / SDF_PX;\\n    }\\n\\n    lowp float dist = texture2D(u_texture, tex).a;\\n    highp float gamma_scaled = gamma * gamma_scale;\\n    highp float alpha = smoothstep(buff - gamma_scaled, buff + gamma_scaled, dist);\\n\\n    gl_FragColor = color * (alpha * opacity * fade_opacity);\\n\\n#ifdef OVERDRAW_INSPECTOR\\n    gl_FragColor = vec4(1.0);\\n#endif\\n}\\n\",vertexSource:\"const float PI = 3.141592653589793;\\n\\nattribute vec4 a_pos_offset;\\nattribute vec4 a_data;\\nattribute vec3 a_projected_pos;\\nattribute float a_fade_opacity;\\n\\n// contents of a_size vary based on the type of property value\\n// used for {text,icon}-size.\\n// For constants, a_size is disabled.\\n// For source functions, we bind only one value per vertex: the value of {text,icon}-size evaluated for the current feature.\\n// For composite functions:\\n// [ text-size(lowerZoomStop, feature),\\n//   text-size(upperZoomStop, feature) ]\\nuniform bool u_is_size_zoom_constant;\\nuniform bool u_is_size_feature_constant;\\nuniform highp float u_size_t; // used to interpolate between zoom stops when size is a composite function\\nuniform highp float u_size; // used when size is both zoom and feature constant\\n\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\n\\nuniform mat4 u_matrix;\\nuniform mat4 u_label_plane_matrix;\\nuniform mat4 u_gl_coord_matrix;\\n\\nuniform bool u_is_text;\\nuniform bool u_pitch_with_map;\\nuniform highp float u_pitch;\\nuniform bool u_rotate_symbol;\\nuniform highp float u_aspect_ratio;\\nuniform highp float u_camera_to_center_distance;\\nuniform float u_fade_change;\\n\\nuniform vec2 u_texsize;\\n\\nvarying vec2 v_data0;\\nvarying vec3 v_data1;\\n\\nvoid main() {\\n    #pragma mapbox: initialize highp vec4 fill_color\\n    #pragma mapbox: initialize highp vec4 halo_color\\n    #pragma mapbox: initialize lowp float opacity\\n    #pragma mapbox: initialize lowp float halo_width\\n    #pragma mapbox: initialize lowp float halo_blur\\n\\n    vec2 a_pos = a_pos_offset.xy;\\n    vec2 a_offset = a_pos_offset.zw;\\n\\n    vec2 a_tex = a_data.xy;\\n    vec2 a_size = a_data.zw;\\n\\n    highp float segment_angle = -a_projected_pos[2];\\n    float size;\\n\\n    if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {\\n        size = mix(a_size[0], a_size[1], u_size_t) / 10.0;\\n    } else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {\\n        size = a_size[0] / 10.0;\\n    } else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {\\n        size = u_size;\\n    } else {\\n        size = u_size;\\n    }\\n\\n    vec4 projectedPoint = u_matrix * vec4(a_pos, 0, 1);\\n    highp float camera_to_anchor_distance = projectedPoint.w;\\n    // If the label is pitched with the map, layout is done in pitched space,\\n    // which makes labels in the distance smaller relative to viewport space.\\n    // We counteract part of that effect by multiplying by the perspective ratio.\\n    // If the label isn't pitched with the map, we do layout in viewport space,\\n    // which makes labels in the distance larger relative to the features around\\n    // them. We counteract part of that effect by dividing by the perspective ratio.\\n    highp float distance_ratio = u_pitch_with_map ?\\n        camera_to_anchor_distance / u_camera_to_center_distance :\\n        u_camera_to_center_distance / camera_to_anchor_distance;\\n    highp float perspective_ratio = clamp(\\n        0.5 + 0.5 * distance_ratio,\\n        0.0, // Prevents oversized near-field symbols in pitched/overzoomed tiles\\n        4.0);\\n\\n    size *= perspective_ratio;\\n\\n    float fontScale = u_is_text ? size / 24.0 : size;\\n\\n    highp float symbol_rotation = 0.0;\\n    if (u_rotate_symbol) {\\n        // Point labels with 'rotation-alignment: map' are horizontal with respect to tile units\\n        // To figure out that angle in projected space, we draw a short horizontal line in tile\\n        // space, project it, and measure its angle in projected space.\\n        vec4 offsetProjectedPoint = u_matrix * vec4(a_pos + vec2(1, 0), 0, 1);\\n\\n        vec2 a = projectedPoint.xy / projectedPoint.w;\\n        vec2 b = offsetProjectedPoint.xy / offsetProjectedPoint.w;\\n\\n        symbol_rotation = atan((b.y - a.y) / u_aspect_ratio, b.x - a.x);\\n    }\\n\\n    highp float angle_sin = sin(segment_angle + symbol_rotation);\\n    highp float angle_cos = cos(segment_angle + symbol_rotation);\\n    mat2 rotation_matrix = mat2(angle_cos, -1.0 * angle_sin, angle_sin, angle_cos);\\n\\n    vec4 projected_pos = u_label_plane_matrix * vec4(a_projected_pos.xy, 0.0, 1.0);\\n    gl_Position = u_gl_coord_matrix * vec4(projected_pos.xy / projected_pos.w + rotation_matrix * (a_offset / 32.0 * fontScale), 0.0, 1.0);\\n    float gamma_scale = gl_Position.w;\\n\\n    vec2 tex = a_tex / u_texsize;\\n    vec2 fade_opacity = unpack_opacity(a_fade_opacity);\\n    float fade_change = fade_opacity[1] > 0.5 ? u_fade_change : -u_fade_change;\\n    float interpolated_fade_opacity = max(0.0, min(1.0, fade_opacity[0] + fade_change));\\n\\n    v_data0 = vec2(tex.x, tex.y);\\n    v_data1 = vec3(gamma_scale, size, interpolated_fade_opacity);\\n}\\n\"}},tr=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,er=function(t){var e=Qe[t],r={};e.fragmentSource=e.fragmentSource.replace(tr,function(t,e,n,i,a){return r[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+n+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+n+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+n+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),e.vertexSource=e.vertexSource.replace(tr,function(t,e,n,i,a){var o=\"float\"===i?\"vec2\":\"vec4\";return r[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float a_\"+a+\"_t;\\nattribute \"+n+\" \"+o+\" a_\"+a+\";\\nvarying \"+n+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+n+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+o+\"(a_\"+a+\", a_\"+a+\"_t);\\n#else\\n    \"+n+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float a_\"+a+\"_t;\\nattribute \"+n+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+n+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+n+\" \"+i+\" \"+a+\" = unpack_mix_\"+o+\"(a_\"+a+\", a_\"+a+\"_t);\\n#else\\n    \"+n+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})};for(var rr in Qe)er(rr);var nr=Qe,ir=function(t,e,r,n){var i=t.gl;this.program=i.createProgram();var o=r.defines().concat(\"#define DEVICE_PIXEL_RATIO \"+a.devicePixelRatio.toFixed(1));n&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(nr.prelude.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(nr.prelude.vertexSource,e.vertexSource).join(\"\\n\"),c=i.createShader(i.FRAGMENT_SHADER);i.shaderSource(c,s),i.compileShader(c),i.attachShader(this.program,c);var u=i.createShader(i.VERTEX_SHADER);i.shaderSource(u,l),i.compileShader(u),i.attachShader(this.program,u);for(var f=r.layoutAttributes||[],h=0;h<f.length;h++)i.bindAttribLocation(this.program,h,f[h].name);i.linkProgram(this.program),this.numAttributes=i.getProgramParameter(this.program,i.ACTIVE_ATTRIBUTES),this.attributes={},this.uniforms={};for(var p=0;p<this.numAttributes;p++){var d=i.getActiveAttrib(this.program,p);d&&(this.attributes[d.name]=i.getAttribLocation(this.program,d.name))}for(var g=i.getProgramParameter(this.program,i.ACTIVE_UNIFORMS),v=0;v<g;v++){var m=i.getActiveUniform(this.program,v);m&&(this.uniforms[m.name]=i.getUniformLocation(this.program,m.name))}};function ar(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)ar(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,f=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[f.key]=a[f.key]||f}function or(t,e,r,n,i){var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\");a.setDepthMode(qt.disabled),a.setStencilMode(Ht.disabled),a.setColorMode(t.colorModeForRenderPass());for(var l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),f=u.getBucket(r);if(f){var h=i?f.collisionCircle:f.collisionBox;if(h){o.uniformMatrix4fv(s.uniforms.u_matrix,!1,c.posMatrix),i||a.lineWidth.set(1),o.uniform1f(s.uniforms.u_camera_to_center_distance,t.transform.cameraToCenterDistance);var p=Te(u,1,t.transform.zoom),d=Math.pow(2,t.transform.zoom-u.tileID.overscaledZ);o.uniform1f(s.uniforms.u_pixels_to_tile_units,p),o.uniform2f(s.uniforms.u_extrude_scale,t.transform.pixelsToGLUnits[0]/(p*d),t.transform.pixelsToGLUnits[1]/(p*d)),o.uniform1f(s.uniforms.u_overscale_factor,u.tileID.overscaleFactor()),s.draw(a,i?o.TRIANGLES:o.LINES,r.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,null,h.collisionVertexBuffer,null)}}}}ir.prototype.draw=function(t,e,r,n,i,a,o,s,l){for(var c,u=t.gl,f=(c={},c[u.LINES]=2,c[u.TRIANGLES]=3,c)[e],h=0,p=a.get();h<p.length;h+=1){var d=p[h],g=d.vaos||(d.vaos={});(g[r]||(g[r]=new Q)).bind(t,this,n,o?o.getPaintVertexBuffers():[],i,d.vertexOffset,s,l),u.drawElements(e,d.primitiveLength*f,u.UNSIGNED_SHORT,d.primitiveOffset*f*2)}};var sr=t.mat4.identity(new Float32Array(16)),lr=t.default$19.layout;function cr(t,e,r,n,i,a,o,s,l,c){var u,f=t.context,h=f.gl,p=t.transform,d=\"map\"===s,g=\"map\"===l,v=d&&\"line\"===r.layout.get(\"symbol-placement\"),m=d&&!g&&!v,y=g;f.setDepthMode(y?t.depthModeForSublayer(0,qt.ReadOnly):qt.disabled);for(var x=0,b=n;x<b.length;x+=1){var _=b[x],w=e.getTile(_),k=w.getBucket(r);if(k){var M=i?k.text:k.icon;if(M&&M.segments.get().length){var A=M.programConfigurations.get(r.id),T=i||k.sdfIcons,S=i?k.textSizeData:k.iconSizeData;if(u||(u=t.useProgram(T?\"symbolSDF\":\"symbolIcon\",A),A.setUniforms(t.context,u,r.paint,{zoom:t.transform.zoom}),ur(u,t,r,i,m,g,S)),f.activeTexture.set(h.TEXTURE0),h.uniform1i(u.uniforms.u_texture,0),i)w.glyphAtlasTexture.bind(h.LINEAR,h.CLAMP_TO_EDGE),h.uniform2fv(u.uniforms.u_texsize,w.glyphAtlasTexture.size);else{var C=1!==r.layout.get(\"icon-size\").constantOr(0)||k.iconsNeedLinear,E=g||0!==p.pitch;w.iconAtlasTexture.bind(T||t.options.rotating||t.options.zooming||C||E?h.LINEAR:h.NEAREST,h.CLAMP_TO_EDGE),h.uniform2fv(u.uniforms.u_texsize,w.iconAtlasTexture.size)}h.uniformMatrix4fv(u.uniforms.u_matrix,!1,t.translatePosMatrix(_.posMatrix,w,a,o));var L=Te(w,1,t.transform.zoom),z=fe(_.posMatrix,g,d,t.transform,L),O=he(_.posMatrix,g,d,t.transform,L);h.uniformMatrix4fv(u.uniforms.u_gl_coord_matrix,!1,t.translatePosMatrix(O,w,a,o,!0)),v?(h.uniformMatrix4fv(u.uniforms.u_label_plane_matrix,!1,sr),ge(k,_.posMatrix,t,i,z,O,g,c)):h.uniformMatrix4fv(u.uniforms.u_label_plane_matrix,!1,z),h.uniform1f(u.uniforms.u_fade_change,t.options.fadeDuration?t.symbolFadeChange:1),fr(u,A,t,r,w,M,i,T,g)}}}}function ur(e,r,n,i,a,o,s){var l=r.context.gl,c=r.transform;l.uniform1i(e.uniforms.u_pitch_with_map,o?1:0),l.uniform1f(e.uniforms.u_is_text,i?1:0),l.uniform1f(e.uniforms.u_pitch,c.pitch/360*2*Math.PI);var u=\"constant\"===s.functionType||\"source\"===s.functionType,f=\"constant\"===s.functionType||\"camera\"===s.functionType;l.uniform1i(e.uniforms.u_is_size_zoom_constant,u?1:0),l.uniform1i(e.uniforms.u_is_size_feature_constant,f?1:0),l.uniform1f(e.uniforms.u_camera_to_center_distance,c.cameraToCenterDistance);var h=t.evaluateSizeForZoom(s,c.zoom,lr.properties[i?\"text-size\":\"icon-size\"]);void 0!==h.uSizeT&&l.uniform1f(e.uniforms.u_size_t,h.uSizeT),void 0!==h.uSize&&l.uniform1f(e.uniforms.u_size,h.uSize),l.uniform1f(e.uniforms.u_aspect_ratio,c.width/c.height),l.uniform1i(e.uniforms.u_rotate_symbol,a?1:0)}function fr(t,e,r,n,i,a,o,s,l){var c=r.context,u=c.gl,f=r.transform;if(s){var h=0!==n.paint.get(o?\"text-halo-width\":\"icon-halo-width\").constantOr(1),p=l?Math.cos(f._pitch)*f.cameraToCenterDistance:1;u.uniform1f(t.uniforms.u_gamma_scale,p),h&&(u.uniform1f(t.uniforms.u_is_halo,1),hr(a,n,c,t)),u.uniform1f(t.uniforms.u_is_halo,0)}hr(a,n,c,t)}function hr(t,e,r,n){n.draw(r,r.gl.TRIANGLES,e.id,t.layoutVertexBuffer,t.indexBuffer,t.segments,t.programConfigurations.get(e.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function pr(t,e,r,n,i,o,s,l,c){var u,f,h,p,d=e.context,g=d.gl,v=i.paint.get(\"line-dasharray\"),m=i.paint.get(\"line-pattern\");if(l||c){var y=1/Te(r,1,e.transform.tileZoom);if(v){u=e.lineAtlas.getDash(v.from,\"round\"===i.layout.get(\"line-cap\")),f=e.lineAtlas.getDash(v.to,\"round\"===i.layout.get(\"line-cap\"));var x=u.width*v.fromScale,b=f.width*v.toScale;g.uniform2f(t.uniforms.u_patternscale_a,y/x,-u.height/2),g.uniform2f(t.uniforms.u_patternscale_b,y/b,-f.height/2),g.uniform1f(t.uniforms.u_sdfgamma,e.lineAtlas.width/(256*Math.min(x,b)*a.devicePixelRatio)/2)}else if(m){if(h=e.imageManager.getPattern(m.from),p=e.imageManager.getPattern(m.to),!h||!p)return;g.uniform2f(t.uniforms.u_pattern_size_a,h.displaySize[0]*m.fromScale/y,h.displaySize[1]),g.uniform2f(t.uniforms.u_pattern_size_b,p.displaySize[0]*m.toScale/y,p.displaySize[1]);var _=e.imageManager.getPixelSize(),w=_.width,k=_.height;g.uniform2fv(t.uniforms.u_texsize,[w,k])}g.uniform2f(t.uniforms.u_gl_units_to_pixels,1/e.transform.pixelsToGLUnits[0],1/e.transform.pixelsToGLUnits[1])}l&&(v?(g.uniform1i(t.uniforms.u_image,0),d.activeTexture.set(g.TEXTURE0),e.lineAtlas.bind(d),g.uniform1f(t.uniforms.u_tex_y_a,u.y),g.uniform1f(t.uniforms.u_tex_y_b,f.y),g.uniform1f(t.uniforms.u_mix,v.t)):m&&(g.uniform1i(t.uniforms.u_image,0),d.activeTexture.set(g.TEXTURE0),e.imageManager.bind(d),g.uniform2fv(t.uniforms.u_pattern_tl_a,h.tl),g.uniform2fv(t.uniforms.u_pattern_br_a,h.br),g.uniform2fv(t.uniforms.u_pattern_tl_b,p.tl),g.uniform2fv(t.uniforms.u_pattern_br_b,p.br),g.uniform1f(t.uniforms.u_fade,m.t))),d.setStencilMode(e.stencilModeForClipping(o));var M=e.translatePosMatrix(o.posMatrix,r,i.paint.get(\"line-translate\"),i.paint.get(\"line-translate-anchor\"));if(g.uniformMatrix4fv(t.uniforms.u_matrix,!1,M),g.uniform1f(t.uniforms.u_ratio,1/Te(r,1,e.transform.zoom)),i.paint.get(\"line-gradient\")){d.activeTexture.set(g.TEXTURE0);var A=i.gradientTexture;if(!i.gradient)return;A||(A=i.gradientTexture=new z(d,i.gradient,g.RGBA)),A.bind(g.LINEAR,g.CLAMP_TO_EDGE),g.uniform1i(t.uniforms.u_image,0)}t.draw(d,g.TRIANGLES,i.id,n.layoutVertexBuffer,n.indexBuffer,n.segments,s)}var dr=function(t,e){if(!t)return!1;var r=e.imageManager.getPattern(t.from),n=e.imageManager.getPattern(t.to);return!r||!n},gr=function(t,e,r){var n=e.context,i=n.gl,a=e.imageManager.getPattern(t.from),o=e.imageManager.getPattern(t.to);i.uniform1i(r.uniforms.u_image,0),i.uniform2fv(r.uniforms.u_pattern_tl_a,a.tl),i.uniform2fv(r.uniforms.u_pattern_br_a,a.br),i.uniform2fv(r.uniforms.u_pattern_tl_b,o.tl),i.uniform2fv(r.uniforms.u_pattern_br_b,o.br);var s=e.imageManager.getPixelSize(),l=s.width,c=s.height;i.uniform2fv(r.uniforms.u_texsize,[l,c]),i.uniform1f(r.uniforms.u_mix,t.t),i.uniform2fv(r.uniforms.u_pattern_size_a,a.displaySize),i.uniform2fv(r.uniforms.u_pattern_size_b,o.displaySize),i.uniform1f(r.uniforms.u_scale_a,t.fromScale),i.uniform1f(r.uniforms.u_scale_b,t.toScale),n.activeTexture.set(i.TEXTURE0),e.imageManager.bind(e.context)},vr=function(t,e,r){var n=e.context.gl;n.uniform1f(r.uniforms.u_tile_units_to_pixels,1/Te(t,1,e.transform.tileZoom));var i=Math.pow(2,t.tileID.overscaledZ),a=t.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(t.tileID.canonical.x+t.tileID.wrap*i),s=a*t.tileID.canonical.y;n.uniform2f(r.uniforms.u_pixel_coord_upper,o>>16,s>>16),n.uniform2f(r.uniforms.u_pixel_coord_lower,65535&o,65535&s)};function mr(t,e,r,n,i){if(!dr(r.paint.get(\"fill-pattern\"),t))for(var a=!0,o=0,s=n;o<s.length;o+=1){var l=s[o],c=e.getTile(l),u=c.getBucket(r);u&&(t.context.setStencilMode(t.stencilModeForClipping(l)),i(t,e,r,c,l,u,a),a=!1)}}function yr(t,e,r,n,i,a,o){var s=t.context.gl,l=a.programConfigurations.get(r.id);br(\"fill\",r.paint.get(\"fill-pattern\"),t,l,r,n,i,o).draw(t.context,s.TRIANGLES,r.id,a.layoutVertexBuffer,a.indexBuffer,a.segments,l)}function xr(t,e,r,n,i,a,o){var s=t.context.gl,l=a.programConfigurations.get(r.id),c=br(\"fillOutline\",r.getPaintProperty(\"fill-outline-color\")?null:r.paint.get(\"fill-pattern\"),t,l,r,n,i,o);s.uniform2f(c.uniforms.u_world,s.drawingBufferWidth,s.drawingBufferHeight),c.draw(t.context,s.LINES,r.id,a.layoutVertexBuffer,a.indexBuffer2,a.segments2,l)}function br(t,e,r,n,i,a,o,s){var l,c=r.context.program.get();return e?(l=r.useProgram(t+\"Pattern\",n),(s||l.program!==c)&&(n.setUniforms(r.context,l,i.paint,{zoom:r.transform.zoom}),gr(e,r,l)),vr(a,r,l)):(l=r.useProgram(t,n),(s||l.program!==c)&&n.setUniforms(r.context,l,i.paint,{zoom:r.transform.zoom})),r.context.gl.uniformMatrix4fv(l.uniforms.u_matrix,!1,r.translatePosMatrix(o.posMatrix,a,i.paint.get(\"fill-translate\"),i.paint.get(\"fill-translate-anchor\"))),l}var _r=t.default$20.mat3,wr=t.default$20.mat4,kr=t.default$20.vec3;function Mr(t,e,r,n,i,a,o){var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=t.context.program.get(),f=a.programConfigurations.get(r.id),h=t.useProgram(c?\"fillExtrusionPattern\":\"fillExtrusion\",f);if((o||h.program!==u)&&f.setUniforms(s,h,r.paint,{zoom:t.transform.zoom}),c){if(dr(c,t))return;gr(c,t,h),vr(n,t,h),l.uniform1f(h.uniforms.u_height_factor,-Math.pow(2,i.overscaledZ)/n.tileSize/8)}t.context.gl.uniformMatrix4fv(h.uniforms.u_matrix,!1,t.translatePosMatrix(i.posMatrix,n,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\"))),function(t,e){var r=e.context.gl,n=e.style.light,i=n.properties.get(\"position\"),a=[i.x,i.y,i.z],o=_r.create();\"viewport\"===n.properties.get(\"anchor\")&&_r.fromRotation(o,-e.transform.angle),kr.transformMat3(a,a,o);var s=n.properties.get(\"color\");r.uniform3fv(t.uniforms.u_lightpos,a),r.uniform1f(t.uniforms.u_lightintensity,n.properties.get(\"intensity\")),r.uniform3f(t.uniforms.u_lightcolor,s.r,s.g,s.b)}(h,t),h.draw(s,l.TRIANGLES,r.id,a.layoutVertexBuffer,a.indexBuffer,a.segments,f)}function Ar(e,r,n){var i=e.context,a=i.gl,o=r.fbo;if(o){var s=e.useProgram(\"hillshade\"),l=e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),!0);!function(t,e,r){var n=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(n-=e.transform.angle),e.context.gl.uniform2f(t.uniforms.u_light,r.paint.get(\"hillshade-exaggeration\"),n)}(s,e,n);var c=function(e,r){var n=r.toCoordinate(),i=new t.default$17(n.column,n.row+1,n.zoom);return[e.transform.coordinateLocation(n).lat,e.transform.coordinateLocation(i).lat]}(e,r.tileID);i.activeTexture.set(a.TEXTURE0),a.bindTexture(a.TEXTURE_2D,o.colorAttachment.get()),a.uniformMatrix4fv(s.uniforms.u_matrix,!1,l),a.uniform2fv(s.uniforms.u_latrange,c),a.uniform1i(s.uniforms.u_image,0);var u=n.paint.get(\"hillshade-shadow-color\");a.uniform4f(s.uniforms.u_shadow,u.r,u.g,u.b,u.a);var f=n.paint.get(\"hillshade-highlight-color\");a.uniform4f(s.uniforms.u_highlight,f.r,f.g,f.b,f.a);var h=n.paint.get(\"hillshade-accent-color\");if(a.uniform4f(s.uniforms.u_accent,h.r,h.g,h.b,h.a),r.maskedBoundsBuffer&&r.maskedIndexBuffer&&r.segments)s.draw(i,a.TRIANGLES,n.id,r.maskedBoundsBuffer,r.maskedIndexBuffer,r.segments);else{var p=e.rasterBoundsBuffer;e.rasterBoundsVAO.bind(i,s,p,[]),a.drawArrays(a.TRIANGLE_STRIP,0,p.length)}}}function Tr(e,r,n){var i=e.context,a=i.gl;if(r.dem&&r.dem.level){var o=r.dem.level.dim,s=r.dem.getPixels();if(i.activeTexture.set(a.TEXTURE1),i.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(r.tileSize),r.demTexture){var l=r.demTexture;l.update(s,{premultiply:!1}),l.bind(a.NEAREST,a.CLAMP_TO_EDGE)}else r.demTexture=new z(i,s,a.RGBA,{premultiply:!1}),r.demTexture.bind(a.NEAREST,a.CLAMP_TO_EDGE);i.activeTexture.set(a.TEXTURE0);var c=r.fbo;if(!c){var u=new z(i,{width:o,height:o,data:null},a.RGBA);u.bind(a.LINEAR,a.CLAMP_TO_EDGE),(c=r.fbo=i.createFramebuffer(o,o)).colorAttachment.set(u.texture)}i.bindFramebuffer.set(c.framebuffer),i.viewport.set([0,0,o,o]);var f=t.mat4.create();t.mat4.ortho(f,0,t.default$8,-t.default$8,0,0,1),t.mat4.translate(f,f,[0,-t.default$8,0]);var h=e.useProgram(\"hillshadePrepare\");a.uniformMatrix4fv(h.uniforms.u_matrix,!1,f),a.uniform1f(h.uniforms.u_zoom,r.tileID.overscaledZ),a.uniform2fv(h.uniforms.u_dimension,[2*o,2*o]),a.uniform1i(h.uniforms.u_image,1),a.uniform1f(h.uniforms.u_maxzoom,n);var p=e.rasterBoundsBuffer;e.rasterBoundsVAO.bind(i,h,p,[]),a.drawArrays(a.TRIANGLE_STRIP,0,p.length),r.needsHillshadePrepare=!1}}function Sr(e,r,n,i,o){var s=i.paint.get(\"raster-fade-duration\");if(s>0){var l=a.now(),c=(l-e.timeAdded)/s,u=r?(l-r.timeAdded)/s:-1,f=n.getSource(),h=o.coveringZoomLevel({tileSize:f.tileSize,roundZoom:f.roundZoom}),p=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),d=p&&e.refreshedUponExpiration?1:t.clamp(p?c:1-u,0,1);return e.refreshedUponExpiration&&c>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-d}:{opacity:d,mix:0}}return{opacity:1,mix:0}}function Cr(e,r,n){var i=e.context,o=i.gl;i.lineWidth.set(1*a.devicePixelRatio);var s=n.posMatrix,l=e.useProgram(\"debug\");i.setDepthMode(qt.disabled),i.setStencilMode(Ht.disabled),i.setColorMode(e.colorModeForRenderPass()),o.uniformMatrix4fv(l.uniforms.u_matrix,!1,s),o.uniform4f(l.uniforms.u_color,1,0,0,1),e.debugVAO.bind(i,l,e.debugBuffer,[]),o.drawArrays(o.LINE_STRIP,0,e.debugBuffer.length);for(var c=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,f,h=[];for(i=0,a=t.length;i<a;i++)if(l=Er[t[i]]){for(f=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?f=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,f&&h.push(f.x,f.y,c,u),f={x:c,y:u});e+=l[0]*n}return h}(n.toString(),50,0,5),u=new t.PosArray,f=0;f<c.length;f+=2)u.emplaceBack(c[f],c[f+1]);var h=i.createVertexBuffer(u,Ke.members);(new Q).bind(i,l,h,[]),o.uniform4f(l.uniforms.u_color,1,1,1,1);for(var p=r.getTile(n).tileSize,d=t.default$8/(Math.pow(2,e.transform.zoom-n.overscaledZ)*p),g=[[-1,-1],[-1,1],[1,-1],[1,1]],v=0;v<g.length;v++){var m=g[v];o.uniformMatrix4fv(l.uniforms.u_matrix,!1,t.mat4.translate([],s,[d*m[0],d*m[1],0])),o.drawArrays(o.LINES,0,h.length)}o.uniform4f(l.uniforms.u_color,0,0,0,1),o.uniformMatrix4fv(l.uniforms.u_matrix,!1,s),o.drawArrays(o.LINES,0,h.length)}var Er={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},Lr={symbol:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=t.context;i.setStencilMode(Ht.disabled),i.setColorMode(t.colorModeForRenderPass()),0!==r.paint.get(\"icon-opacity\").constantOr(1)&&cr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\")),0!==r.paint.get(\"text-opacity\").constantOr(1)&&cr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\")),e.map.showCollisionBoxes&&function(t,e,r,n){or(t,e,r,n,!1),or(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=t.context,l=s.gl;s.setDepthMode(t.depthModeForSublayer(0,qt.ReadOnly)),s.setStencilMode(Ht.disabled),s.setColorMode(t.colorModeForRenderPass());for(var c=!0,u=0;u<n.length;u++){var f=n[u],h=e.getTile(f),p=h.getBucket(r);if(p){var d=t.context.program.get(),g=p.programConfigurations.get(r.id),v=t.useProgram(\"circle\",g);if((c||v.program!==d)&&(g.setUniforms(s,v,r.paint,{zoom:t.transform.zoom}),c=!1),l.uniform1f(v.uniforms.u_camera_to_center_distance,t.transform.cameraToCenterDistance),l.uniform1i(v.uniforms.u_scale_with_map,\"map\"===r.paint.get(\"circle-pitch-scale\")?1:0),\"map\"===r.paint.get(\"circle-pitch-alignment\")){l.uniform1i(v.uniforms.u_pitch_with_map,1);var m=Te(h,1,t.transform.zoom);l.uniform2f(v.uniforms.u_extrude_scale,m,m)}else l.uniform1i(v.uniforms.u_pitch_with_map,0),l.uniform2fv(v.uniforms.u_extrude_scale,t.transform.pixelsToGLUnits);l.uniformMatrix4fv(v.uniforms.u_matrix,!1,t.translatePosMatrix(f.posMatrix,h,r.paint.get(\"circle-translate\"),r.paint.get(\"circle-translate-anchor\"))),v.draw(s,l.TRIANGLES,r.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,g)}}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl;a.setDepthMode(e.depthModeForSublayer(0,qt.ReadOnly)),a.setStencilMode(Ht.disabled),function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.default$6.transparent}),a.setColorMode(new Gt([o.ONE,o.ONE],t.default$6.transparent,[!0,!0,!0,!0]));for(var s=!0,l=0;l<i.length;l++){var c=i[l];if(!r.hasRenderableParent(c)){var u=r.getTile(c),f=u.getBucket(n);if(f){var h=e.context.program.get(),p=f.programConfigurations.get(n.id),d=e.useProgram(\"heatmap\",p),g=e.transform.zoom;(s||d.program!==h)&&(p.setUniforms(e.context,d,n.paint,{zoom:g}),s=!1),o.uniform1f(d.uniforms.u_extrude_scale,Te(u,1,g)),o.uniform1f(d.uniforms.u_intensity,n.paint.get(\"heatmap-intensity\")),o.uniformMatrix4fv(d.uniforms.u_matrix,!1,c.posMatrix),d.draw(a,o.TRIANGLES,n.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new z(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),n.setDepthMode(qt.disabled);var s=e.useProgram(\"heatmapTexture\"),l=r.paint.get(\"heatmap-opacity\");i.uniform1f(s.uniforms.u_opacity,l),i.uniform1i(s.uniforms.u_image,0),i.uniform1i(s.uniforms.u_color_ramp,1);var c=t.mat4.create();t.mat4.ortho(c,0,e.width,e.height,0,0,1),i.uniformMatrix4fv(s.uniforms.u_matrix,!1,c),i.uniform2f(s.uniforms.u_world,i.drawingBufferWidth,i.drawingBufferHeight),e.viewportVAO.bind(e.context,s,e.viewportBuffer,[]),i.drawArrays(i.TRIANGLE_STRIP,0,4)}}(e,n))},line:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"line-opacity\").constantOr(1)){var i=t.context;i.setDepthMode(t.depthModeForSublayer(0,qt.ReadOnly)),i.setColorMode(t.colorModeForRenderPass());for(var a,o=r.paint.get(\"line-dasharray\")?\"lineSDF\":r.paint.get(\"line-pattern\")?\"linePattern\":r.paint.get(\"line-gradient\")?\"lineGradient\":\"line\",s=!0,l=0,c=n;l<c.length;l+=1){var u=c[l],f=e.getTile(u),h=f.getBucket(r);if(h){var p=h.programConfigurations.get(r.id),d=t.context.program.get(),g=t.useProgram(o,p),v=s||g.program!==d,m=a!==f.tileID.overscaledZ;v&&p.setUniforms(t.context,g,r.paint,{zoom:t.transform.zoom}),pr(g,t,f,h,r,u,p,v,m),a=f.tileID.overscaledZ,s=!1}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.context;s.setColorMode(e.colorModeForRenderPass());var l=n.paint.get(\"fill-pattern\")||1!==a.constantOr(t.default$6.transparent).a||1!==o.constantOr(0)?\"translucent\":\"opaque\";e.renderPass===l&&(s.setDepthMode(e.depthModeForSublayer(1,\"opaque\"===e.renderPass?qt.ReadWrite:qt.ReadOnly)),mr(e,r,n,i,yr)),\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")&&(s.lineWidth.set(2),s.setDepthMode(e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,qt.ReadOnly)),mr(e,r,n,i,xr))}},\"fill-extrusion\":function(e,r,n,i){if(0!==n.paint.get(\"fill-extrusion-opacity\"))if(\"offscreen\"===e.renderPass){!function(e,r){var n=e.context,i=n.gl,a=r.viewportFrame;if(e.depthRboNeedsClear&&e.setupOffscreenDepthRenderbuffer(),!a){var o=new z(n,{width:e.width,height:e.height,data:null},i.RGBA);o.bind(i.LINEAR,i.CLAMP_TO_EDGE),(a=r.viewportFrame=n.createFramebuffer(e.width,e.height)).colorAttachment.set(o.texture)}n.bindFramebuffer.set(a.framebuffer),a.depthAttachment.set(e.depthRbo),e.depthRboNeedsClear&&(n.clear({depth:1}),e.depthRboNeedsClear=!1),n.clear({color:t.default$6.transparent}),n.setStencilMode(Ht.disabled),n.setDepthMode(new qt(i.LEQUAL,qt.ReadWrite,[0,1])),n.setColorMode(e.colorModeForRenderPass())}(e,n);for(var a=!0,o=0,s=i;o<s.length;o+=1){var l=s[o],c=r.getTile(l),u=c.getBucket(n);u&&(Mr(e,0,n,c,l,u,a),a=!1)}}else\"translucent\"===e.renderPass&&function(t,e){var r=e.viewportFrame;if(r){var n=t.context,i=n.gl,a=t.useProgram(\"extrusionTexture\");n.setStencilMode(Ht.disabled),n.setDepthMode(qt.disabled),n.setColorMode(t.colorModeForRenderPass()),n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,r.colorAttachment.get()),i.uniform1f(a.uniforms.u_opacity,e.paint.get(\"fill-extrusion-opacity\")),i.uniform1i(a.uniforms.u_image,0);var o=wr.create();wr.ortho(o,0,t.width,t.height,0,0,1),i.uniformMatrix4fv(a.uniforms.u_matrix,!1,o),i.uniform2f(a.uniforms.u_world,i.drawingBufferWidth,i.drawingBufferHeight),t.viewportVAO.bind(n,a,t.viewportBuffer,[]),i.drawArrays(i.TRIANGLE_STRIP,0,4)}}(e,n)},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){var i=t.context,a=e.getSource().maxzoom;i.setDepthMode(t.depthModeForSublayer(0,qt.ReadOnly)),i.setStencilMode(Ht.disabled),i.setColorMode(t.colorModeForRenderPass());for(var o=0,s=n;o<s.length;o+=1){var l=s[o],c=e.getTile(l);c.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Tr(t,c,a):\"translucent\"===t.renderPass&&Ar(t,c,r)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")){var i,a,o=t.context,s=o.gl,l=e.getSource(),c=t.useProgram(\"raster\");o.setStencilMode(Ht.disabled),o.setColorMode(t.colorModeForRenderPass()),s.uniform1f(c.uniforms.u_brightness_low,r.paint.get(\"raster-brightness-min\")),s.uniform1f(c.uniforms.u_brightness_high,r.paint.get(\"raster-brightness-max\")),s.uniform1f(c.uniforms.u_saturation_factor,(i=r.paint.get(\"raster-saturation\"))>0?1-1/(1.001-i):-i),s.uniform1f(c.uniforms.u_contrast_factor,(a=r.paint.get(\"raster-contrast\"))>0?1/(1-a):1+a),s.uniform3fv(c.uniforms.u_spin_weights,function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(r.paint.get(\"raster-hue-rotate\"))),s.uniform1f(c.uniforms.u_buffer_scale,1),s.uniform1i(c.uniforms.u_image0,0),s.uniform1i(c.uniforms.u_image1,1);for(var u=n.length&&n[0].overscaledZ,f=0,h=n;f<h.length;f+=1){var p=h[f];o.setDepthMode(t.depthModeForSublayer(p.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?qt.ReadWrite:qt.ReadOnly,s.LESS));var d=e.getTile(p),g=t.transform.calculatePosMatrix(p.toUnwrapped(),!0);d.registerFadeDuration(r.paint.get(\"raster-fade-duration\")),s.uniformMatrix4fv(c.uniforms.u_matrix,!1,g);var v=e.findLoadedParent(p,0,{}),m=Sr(d,v,e,r,t.transform),y=void 0,x=void 0;if(o.activeTexture.set(s.TEXTURE0),d.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.activeTexture.set(s.TEXTURE1),v?(v.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),y=Math.pow(2,v.tileID.overscaledZ-d.tileID.overscaledZ),x=[d.tileID.canonical.x*y%1,d.tileID.canonical.y*y%1]):d.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),s.uniform2fv(c.uniforms.u_tl_parent,x||[0,0]),s.uniform1f(c.uniforms.u_scale_parent,y||1),s.uniform1f(c.uniforms.u_fade_t,m.mix),s.uniform1f(c.uniforms.u_opacity,m.opacity*r.paint.get(\"raster-opacity\")),l instanceof tt){var b=l.boundsBuffer;l.boundsVAO.bind(o,c,b,[]),s.drawArrays(s.TRIANGLE_STRIP,0,b.length)}else if(d.maskedBoundsBuffer&&d.maskedIndexBuffer&&d.segments)c.draw(o,s.TRIANGLES,r.id,d.maskedBoundsBuffer,d.maskedIndexBuffer,d.segments);else{var _=t.rasterBoundsBuffer;t.rasterBoundsVAO.bind(o,c,_,[]),s.drawArrays(s.TRIANGLE_STRIP,0,_.length)}}}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\"),u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var f;if(a.setStencilMode(Ht.disabled),a.setDepthMode(t.depthModeForSublayer(0,\"opaque\"===u?qt.ReadWrite:qt.ReadOnly)),a.setColorMode(t.colorModeForRenderPass()),c){if(dr(c,t))return;f=t.useProgram(\"backgroundPattern\"),gr(c,t,f),t.tileExtentPatternVAO.bind(a,f,t.tileExtentBuffer,[])}else f=t.useProgram(\"background\"),o.uniform4fv(f.uniforms.u_color,[n.r,n.g,n.b,n.a]),t.tileExtentVAO.bind(a,f,t.tileExtentBuffer,[]);o.uniform1f(f.uniforms.u_opacity,i);for(var h=0,p=s.coveringTiles({tileSize:l});h<p.length;h+=1){var d=p[h];c&&vr({tileID:d,tileSize:l},t,f),o.uniformMatrix4fv(f.uniforms.u_matrix,!1,t.transform.calculatePosMatrix(d.toUnwrapped())),o.drawArrays(o.TRIANGLE_STRIP,0,t.tileExtentBuffer.length)}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Cr(t,e,r[n])}},zr=function(e,r){this.context=new Wt(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Yt.maxUnderzooming+Yt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.default$24,this.crossTileSymbolIndex=new Ye};function Or(t,e){if(t.row>e.row){var r=t;t=e,e=r}return{x0:t.column,y0:t.row,x1:e.column,y1:e.row,dx:e.column-t.column,dy:e.row-t.row}}function Ir(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,f=e.dx<0,h=a;h<o;h++){var p=l*Math.max(0,Math.min(t.dy,h+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,h+f-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),h)}}function Dr(t,e,r,n,i,a){var o,s=Or(t,e),l=Or(e,r),c=Or(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&Ir(c,s,n,i,a),l.dy&&Ir(c,l,n,i,a)}zr.prototype.resize=function(t,e){var r=this.context.gl;if(this.width=t*a.devicePixelRatio,this.height=e*a.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1){var o=i[n];this.style._layers[o].resize()}this.depthRbo&&(r.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},zr.prototype.setup=function(){var e=this.context,r=new t.PosArray;r.emplaceBack(0,0),r.emplaceBack(t.default$8,0),r.emplaceBack(0,t.default$8),r.emplaceBack(t.default$8,t.default$8),this.tileExtentBuffer=e.createVertexBuffer(r,Ke.members),this.tileExtentVAO=new Q,this.tileExtentPatternVAO=new Q;var n=new t.PosArray;n.emplaceBack(0,0),n.emplaceBack(t.default$8,0),n.emplaceBack(t.default$8,t.default$8),n.emplaceBack(0,t.default$8),n.emplaceBack(0,0),this.debugBuffer=e.createVertexBuffer(n,Ke.members),this.debugVAO=new Q;var i=new t.RasterBoundsArray;i.emplaceBack(0,0,0,0),i.emplaceBack(t.default$8,0,t.default$8,0),i.emplaceBack(0,t.default$8,0,t.default$8),i.emplaceBack(t.default$8,t.default$8,t.default$8,t.default$8),this.rasterBoundsBuffer=e.createVertexBuffer(i,K.members),this.rasterBoundsVAO=new Q;var a=new t.PosArray;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Ke.members),this.viewportVAO=new Q},zr.prototype.clearStencil=function(){var e=this.context,r=e.gl;e.setColorMode(Gt.disabled),e.setDepthMode(qt.disabled),e.setStencilMode(new Ht({func:r.ALWAYS,mask:0},0,255,r.ZERO,r.ZERO,r.ZERO));var n=t.mat4.create();t.mat4.ortho(n,0,this.width,this.height,0,0,1),t.mat4.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]);var i=this.useProgram(\"clippingMask\");r.uniformMatrix4fv(i.uniforms.u_matrix,!1,n),this.viewportVAO.bind(e,i,this.viewportBuffer,[]),r.drawArrays(r.TRIANGLE_STRIP,0,4)},zr.prototype._renderTileClippingMasks=function(t){var e=this.context,r=e.gl;e.setColorMode(Gt.disabled),e.setDepthMode(qt.disabled);var n=1;this._tileClippingMaskIDs={};for(var i=0,a=t;i<a.length;i+=1){var o=a[i],s=this._tileClippingMaskIDs[o.key]=n++;e.setStencilMode(new Ht({func:r.ALWAYS,mask:0},s,255,r.KEEP,r.KEEP,r.REPLACE));var l=this.useProgram(\"clippingMask\");r.uniformMatrix4fv(l.uniforms.u_matrix,!1,o.posMatrix),this.tileExtentVAO.bind(this.context,l,this.tileExtentBuffer,[]),r.drawArrays(r.TRIANGLE_STRIP,0,this.tileExtentBuffer.length)}},zr.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new Ht({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},zr.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Gt([e.CONSTANT_COLOR,e.ONE],new t.default$6(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Gt.unblended:Gt.alphaBlended},zr.prototype.depthModeForSublayer=function(t,e,r){var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon,i=n-1+this.depthRange;return new qt(r||this.context.gl.LEQUAL,e,[i,n])},zr.prototype.render=function(e,r){var n=this;for(var i in this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(a.now()),e.sourceCaches){var o=n.style.sourceCaches[i];o.used&&o.prepare(n.context)}var s=this.style._order,l=t.filterObject(this.style.sourceCaches,function(t){return\"raster\"===t.getSource().type||\"raster-dem\"===t.getSource().type}),c=function(e){var r=l[e];!function(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);ar(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}(r.getVisibleCoordinates().map(function(t){return r.getTile(t)}),n.context)};for(var u in l)c(u);this.renderPass=\"offscreen\";var f,h=[];this.depthRboNeedsClear=!0;for(var p=0;p<s.length;p++){var d=n.style._layers[s[p]];d.hasOffscreenPass()&&!d.isHidden(n.transform.zoom)&&(d.source!==(f&&f.id)&&(h=[],(f=n.style.sourceCaches[d.source])&&(h=f.getVisibleCoordinates()).reverse()),h.length&&n.renderLayer(n,f,d,h))}this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.default$6.black:t.default$6.transparent,depth:1}),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRange=(e._order.length+2)*this.numSublayers*this.depthEpsilon,this.renderPass=\"opaque\";var g,v=[];for(this.currentLayer=s.length-1,this.currentLayer;this.currentLayer>=0;this.currentLayer--){var m=n.style._layers[s[n.currentLayer]];m.source!==(g&&g.id)&&(v=[],(g=n.style.sourceCaches[m.source])&&(n.clearStencil(),v=g.getVisibleCoordinates(),g.getSource().isTileClipped&&n._renderTileClippingMasks(v))),n.renderLayer(n,g,m,v)}this.renderPass=\"translucent\";var y,x=[];for(this.currentLayer=0,this.currentLayer;this.currentLayer<s.length;this.currentLayer++){var b=n.style._layers[s[n.currentLayer]];b.source!==(y&&y.id)&&(x=[],(y=n.style.sourceCaches[b.source])&&(n.clearStencil(),x=y.getVisibleCoordinates(),y.getSource().isTileClipped&&n._renderTileClippingMasks(x)),x.reverse()),n.renderLayer(n,y,b,x)}if(this.options.showTileBoundaries){var _=this.style.sourceCaches[Object.keys(this.style.sourceCaches)[0]];_&&Lr.debug(this,_,_.getVisibleCoordinates())}},zr.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},zr.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||n.length)&&(this.id=r.id,Lr[r.type](t,e,r,n))},zr.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:Te(r,n[0],this.transform.zoom),a?n[1]:Te(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.mat4.translate(u,e,c),u},zr.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},zr.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},zr.prototype._createProgramCached=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new ir(this.context,nr[t],e,this._showOverdrawInspector)),this.cache[r]},zr.prototype.useProgram=function(t,e){var r=this._createProgramCached(t,e||this.emptyProgramConfiguration);return this.context.program.set(r.program),r};var Pr=t.default$20.vec4,Rr=t.default$20.mat4,Fr=t.default$20.mat2,Br=function(t,e,r){this.tileSize=512,this._renderWorldCopies=void 0===r||r,this._minZoom=t||0,this._maxZoom=e||22,this.latRange=[-85.05113,85.05113],this.width=0,this.height=0,this._center=new G(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},Nr={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},x:{configurable:!0},y:{configurable:!0},point:{configurable:!0}};Br.prototype.clone=function(){var t=new Br(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},Nr.minZoom.get=function(){return this._minZoom},Nr.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Nr.maxZoom.get=function(){return this._maxZoom},Nr.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Nr.renderWorldCopies.get=function(){return this._renderWorldCopies},Nr.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Nr.worldSize.get=function(){return this.tileSize*this.scale},Nr.centerPoint.get=function(){return this.size._div(2)},Nr.size.get=function(){return new t.default$1(this.width,this.height)},Nr.bearing.get=function(){return-this.angle/Math.PI*180},Nr.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=Fr.create(),Fr.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Nr.pitch.get=function(){return this._pitch/Math.PI*180},Nr.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Nr.fov.get=function(){return this._fov/Math.PI*180},Nr.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Nr.zoom.get=function(){return this._zoom},Nr.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Nr.center.get=function(){return this._center},Nr.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Br.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},Br.prototype.getVisibleUnwrappedCoordinates=function(e){var r=this.pointCoordinate(new t.default$1(0,0),0),n=this.pointCoordinate(new t.default$1(this.width,0),0),i=Math.floor(r.column),a=Math.floor(n.column),o=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var s=i;s<=a;s++)0!==s&&o.push(new t.UnwrappedTileID(s,e));return o},Br.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=this.pointCoordinate(this.centerPoint,r),a=new t.default$1(i.column-.5,i.row-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,f,h;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),f=(c%a+a)%a,0!==u&&!0!==i||(h=new t.OverscaledTileID(n,u,e,f,l),o[h.key]=h)}return Dr(r[0],r[1],r[2],0,a,s),Dr(r[2],r[3],r[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.default$1(0,0),r),this.pointCoordinate(new t.default$1(this.width,0),r),this.pointCoordinate(new t.default$1(this.width,this.height),r),this.pointCoordinate(new t.default$1(0,this.height),r)],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return a.dist(t.canonical)-a.dist(e.canonical)})},Br.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Nr.unmodified.get=function(){return this._unmodified},Br.prototype.zoomScale=function(t){return Math.pow(2,t)},Br.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},Br.prototype.project=function(e){return new t.default$1(this.lngX(e.lng),this.latY(e.lat))},Br.prototype.unproject=function(t){return new G(this.xLng(t.x),this.yLat(t.y))},Nr.x.get=function(){return this.lngX(this.center.lng)},Nr.y.get=function(){return this.latY(this.center.lat)},Nr.point.get=function(){return new t.default$1(this.x,this.y)},Br.prototype.lngX=function(t){return(180+t)*this.worldSize/360},Br.prototype.latY=function(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))*this.worldSize/360},Br.prototype.xLng=function(t){return 360*t/this.worldSize-180},Br.prototype.yLat=function(t){var e=180-360*t/this.worldSize;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90},Br.prototype.setLocationAtPoint=function(t,e){var r=this.pointCoordinate(e)._sub(this.pointCoordinate(this.centerPoint));this.center=this.coordinateLocation(this.locationCoordinate(t)._sub(r)),this._renderWorldCopies&&(this.center=this.center.wrap())},Br.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},Br.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},Br.prototype.locationCoordinate=function(e){return new t.default$17(this.lngX(e.lng)/this.tileSize,this.latY(e.lat)/this.tileSize,this.zoom).zoomTo(this.tileZoom)},Br.prototype.coordinateLocation=function(t){var e=t.zoomTo(this.zoom);return new G(this.xLng(e.column*this.tileSize),this.yLat(e.row*this.tileSize))},Br.prototype.pointCoordinate=function(e,r){void 0===r&&(r=this.tileZoom);var n=[e.x,e.y,0,1],i=[e.x,e.y,1,1];Pr.transformMat4(n,n,this.pixelMatrixInverse),Pr.transformMat4(i,i,this.pixelMatrixInverse);var a=n[3],o=i[3],s=n[0]/a,l=i[0]/o,c=n[1]/a,u=i[1]/o,f=n[2]/a,h=i[2]/o,p=f===h?0:(0-f)/(h-f);return new t.default$17(t.number(s,l,p)/this.tileSize,t.number(c,u,p)/this.tileSize,this.zoom)._zoomTo(r)},Br.prototype.coordinatePoint=function(e){var r=e.zoomTo(this.zoom),n=[r.column*this.tileSize,r.row*this.tileSize,0,1];return Pr.transformMat4(n,n,this.pixelMatrix),new t.default$1(n[0]/n[3],n[1]/n[3])},Br.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=Rr.identity(new Float64Array(16));return Rr.translate(l,l,[s*o,a.y*o,0]),Rr.scale(l,l,[o/t.default$8,o/t.default$8,1]),Rr.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},Br.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var f=this.latRange;a=this.latY(f[1]),e=(o=this.latY(f[0]))-a<c.y?c.y/(o-a):0}if(this.lngRange){var h=this.lngRange;s=this.lngX(h[0]),r=(l=this.lngX(h[1]))-s<c.x?c.x/(l-s):0}var p=Math.max(r||0,e||0);if(p)return this.center=this.unproject(new t.default$1(r?(l+s)/2:this.x,e?(o+a)/2:this.y)),this.zoom+=this.scaleZoom(p),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var d=this.y,g=c.y/2;d-g<a&&(i=a+g),d+g>o&&(i=o-g)}if(this.lngRange){var v=this.x,m=c.x/2;v-m<s&&(n=s+m),v+m>l&&(n=l-m)}void 0===n&&void 0===i||(this.center=this.unproject(new t.default$1(void 0!==n?n:this.x,void 0!==i?i:this.y))),this._unmodified=u,this._constraining=!1}},Br.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var t=this._fov/2,e=Math.PI/2+this._pitch,r=Math.sin(t)*this.cameraToCenterDistance/Math.sin(Math.PI-e-t),n=this.x,i=this.y,a=1.01*(Math.cos(Math.PI/2-this._pitch)*r+this.cameraToCenterDistance),o=new Float64Array(16);Rr.perspective(o,this._fov,this.width/this.height,1,a),Rr.scale(o,o,[1,-1,1]),Rr.translate(o,o,[0,0,-this.cameraToCenterDistance]),Rr.rotateX(o,o,this._pitch),Rr.rotateZ(o,o,this.angle),Rr.translate(o,o,[-n,-i,0]);var s=this.worldSize/(2*Math.PI*6378137*Math.abs(Math.cos(this.center.lat*(Math.PI/180))));Rr.scale(o,o,[1,1,s,1]),this.projMatrix=o;var l=this.width%2/2,c=this.height%2/2,u=Math.cos(this.angle),f=Math.sin(this.angle),h=n-Math.round(n)+u*l+f*c,p=i-Math.round(i)+u*c+f*l,d=new Float64Array(o);if(Rr.translate(d,d,[h>.5?h-1:h,p>.5?p-1:p,0]),this.alignedProjMatrix=d,o=Rr.create(),Rr.scale(o,o,[this.width/2,-this.height/2,1]),Rr.translate(o,o,[1,-1,0]),this.pixelMatrix=Rr.multiply(new Float64Array(16),o,this.projMatrix),!(o=Rr.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=o,this._posMatrixCache={},this._alignedPosMatrixCache={}}},Br.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.default$1(0,0)).zoomTo(this.zoom),r=[e.column*this.tileSize,e.row*this.tileSize,0,1];return Pr.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},Object.defineProperties(Br.prototype,Nr);var jr=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=0,i=function(){n=0,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};jr.prototype.addTo=function(e){return this._map=e,t.default.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},jr.prototype.remove=function(){return t.default.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},jr.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},jr.prototype._onHashChange=function(){var e=t.default.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},jr.prototype._updateHashUnthrottled=function(){var e=this.getHashString();t.default.history.replaceState(t.default.history.state,\"\",e)};var Vr=function(e){function r(r,n,i,a){void 0===a&&(a={});var o=s.mousePos(n.getCanvasContainer(),i),l=n.unproject(o);e.call(this,r,t.extend({point:o,lngLat:l,originalEvent:i},a)),this._defaultPrevented=!1,this.target=n}e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r;var n={defaultPrevented:{configurable:!0}};return r.prototype.preventDefault=function(){this._defaultPrevented=!0},n.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(r.prototype,n),r}(t.Event),Ur=function(e){function r(r,n,i){var a=s.touchPos(n.getCanvasContainer(),i),o=a.map(function(t){return n.unproject(t)}),l=a.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.default$1(0,0)),c=n.unproject(l);e.call(this,r,{points:a,point:l,lngLats:o,lngLat:c,originalEvent:i}),this._defaultPrevented=!1}e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r;var n={defaultPrevented:{configurable:!0}};return r.prototype.preventDefault=function(){this._defaultPrevented=!0},n.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(r.prototype,n),r}(t.Event),qr=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Hr=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};Hr.prototype.isEnabled=function(){return!!this._enabled},Hr.prototype.isActive=function(){return!!this._active},Hr.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},Hr.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Hr.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.default.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=a.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},Hr.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},Hr.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e})),this._finishTimeout&&clearTimeout(this._finishTimeout);var r=s.mousePos(this._el,e);this._around=G.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(r)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},Hr.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?1/450:.01,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var o=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(o*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var s=!1;if(\"wheel\"===this._type){var l=Math.min((a.now()-this._lastWheelEventTime)/200,1),c=this._easing(l);r.zoom=t.number(this._startZoom,this._targetZoom,c),l<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):s=!0}else r.zoom=this._targetZoom,s=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),s&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},Hr.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(a.now()-n.start)/n.duration,o=n.easing(i+.01)-n.easing(i),s=.27/Math.sqrt(o*o+1e-4)*.01,l=Math.sqrt(.0729-s*s);r=t.bezier(s,l,.25,1)}return this._prevEase={start:a.now(),duration:e,easing:r},r};var Gr=function(e){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};Gr.prototype.isEnabled=function(){return!!this._enabled},Gr.prototype.isActive=function(){return!!this._active},Gr.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Gr.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Gr.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.default.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.default.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.default.document.addEventListener(\"mouseup\",this._onMouseUp,!1),s.disableDrag(),this._startPos=s.mousePos(this._el,e),this._active=!0)},Gr.prototype._onMouseMove=function(t){var e=this._startPos,r=s.mousePos(this._el,t);this._box||(this._box=s.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var n=Math.min(e.x,r.x),i=Math.max(e.x,r.x),a=Math.min(e.y,r.y),o=Math.max(e.y,r.y);s.setTransform(this._box,\"translate(\"+n+\"px,\"+a+\"px)\"),this._box.style.width=i-n+\"px\",this._box.style.height=o-a+\"px\"},Gr.prototype._onMouseUp=function(e){if(0===e.button){var r=this._startPos,n=s.mousePos(this._el,e),i=(new W).extend(this._map.unproject(r)).extend(this._map.unproject(n));this._finish(),s.suppressClick(),r.x===n.x&&r.y===n.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitBounds(i,{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e,boxZoomBounds:i}))}},Gr.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},Gr.prototype._finish=function(){this._active=!1,t.default.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.default.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.default.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(s.remove(this._box),this._box=null),s.enableDrag()},Gr.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var Wr=t.bezier(0,0,.25,1),Yr=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};Yr.prototype.isEnabled=function(){return\"disabled\"!==this._state},Yr.prototype.isActive=function(){return\"active\"===this._state},Yr.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},Yr.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},Yr.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=s.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==s.mouseButton(e))return;this._eventButton=0}s.disableDrag(),t.default.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.default.document.addEventListener(\"mouseup\",this._onMouseUp),t.default.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[a.now(),this._map.getBearing()]],this._previousPos=s.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},Yr.prototype._onMouseMove=function(t){this._lastMoveEvent=t,this._pos=s.mousePos(this._el,t),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame))},Yr.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform,r=this._previousPos,n=this._pos,i=.8*(r.x-n.x),o=-.5*(r.y-n.y),s=e.bearing-i,l=e.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([a.now(),this._map._normalizeBearing(s,u[1])]),e.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",t),e.pitch=l),this._fireEvent(\"rotate\",t),this._fireEvent(\"move\",t),delete this._lastMoveEvent,this._previousPos=this._pos}},Yr.prototype._onMouseUp=function(t){if(s.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",s.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},Yr.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},Yr.prototype._unbind=function(){t.default.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.default.document.removeEventListener(\"mouseup\",this._onMouseUp),t.default.removeEventListener(\"blur\",this._onBlur),s.enableDrag()},Yr.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._previousPos},Yr.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],f=u<0?-1:1,h=(s[0]-o[0])/1e3;if(0!==u&&0!==h){var p=Math.abs(u*(.25/h));p>180&&(p=180);var d=p/180;c+=f*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:Wr,noMoveStart:!0},{originalEvent:t})}else a()}},Yr.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},Yr.prototype._drainInertiaBuffer=function(){for(var t=this._inertia,e=a.now();t.length>0&&e-t[0][0]>160;)t.shift()};var Xr=t.bezier(0,0,.3,1),Zr=function(e){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};Zr.prototype.isEnabled=function(){return\"disabled\"!==this._state},Zr.prototype.isActive=function(){return\"active\"===this._state},Zr.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},Zr.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},Zr.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==s.mouseButton(e)||(s.addEventListener(t.default.document,\"mousemove\",this._onMove,{capture:!0}),s.addEventListener(t.default.document,\"mouseup\",this._onMouseUp),this._start(e)))},Zr.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(s.addEventListener(t.default.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),s.addEventListener(t.default.document,\"touchend\",this._onTouchEnd),this._start(e)))},Zr.prototype._start=function(e){t.default.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._previousPos=s.mousePos(this._el,e),this._inertia=[[a.now(),this._previousPos]]},Zr.prototype._onMove=function(t){this._lastMoveEvent=t,t.preventDefault(),this._pos=s.mousePos(this._el,t),this._drainInertiaBuffer(),this._inertia.push([a.now(),this._pos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",t),this._fireEvent(\"movestart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame))},Zr.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._previousPos),this._pos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._previousPos=this._pos,delete this._lastMoveEvent}},Zr.prototype._onMouseUp=function(t){if(0===s.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",s.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},Zr.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},Zr.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},Zr.prototype._unbind=function(){s.removeEventListener(t.default.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),s.removeEventListener(t.default.document,\"touchend\",this._onTouchEnd),s.removeEventListener(t.default.document,\"mousemove\",this._onMove,{capture:!0}),s.removeEventListener(t.default.document,\"mouseup\",this._onMouseUp),s.removeEventListener(t.default,\"blur\",this._onBlur)},Zr.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._previousPos,delete this._pos},Zr.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:Xr,noMoveStart:!0},{originalEvent:t})}}},Zr.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},Zr.prototype._drainInertiaBuffer=function(){for(var t=this._inertia,e=a.now();t.length>0&&e-t[0][0]>160;)t.shift()};var $r=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function Jr(t){return t*(2-t)}$r.prototype.isEnabled=function(){return!!this._enabled},$r.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},$r.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},$r.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:Jr,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var Kr=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};Kr.prototype.isEnabled=function(){return!!this._enabled},Kr.prototype.isActive=function(){return!!this._active},Kr.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Kr.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Kr.prototype.onTouchStart=function(t){var e=this;this.isEnabled()&&(t.points.length>1||(this._tapped?(clearTimeout(this._tapped),this._tapped=null,this._zoom(t)):this._tapped=setTimeout(function(){e._tapped=null},300)))},Kr.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},Kr.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},Kr.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var Qr=t.bezier(0,0,.15,1),tn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};tn.prototype.isEnabled=function(){return!!this._enabled},tn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},tn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},tn.prototype.disableRotation=function(){this._rotationDisabled=!0},tn.prototype.enableRotation=function(){this._rotationDisabled=!1},tn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var r=s.mousePos(this._el,e.touches[0]),n=s.mousePos(this._el,e.touches[1]);this._startVec=r.sub(n),this._gestureIntent=void 0,this._inertia=[],s.addEventListener(t.default.document,\"touchmove\",this._onMove,{passive:!1}),s.addEventListener(t.default.document,\"touchend\",this._onEnd)}},tn.prototype._getTouchEventData=function(t){var e=s.mousePos(this._el,t.touches[0]),r=s.mousePos(this._el,t.touches[1]),n=e.sub(r);return{vec:n,center:e.add(r).div(2),scale:n.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*n.angleWith(this._startVec)/Math.PI}},tn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},tn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,o=n.bearing,s=n.scale,l=r.pointLocation(i),c=r.locationPoint(l);\"rotate\"===e&&(r.bearing=this._startBearing+o),r.zoom=r.scaleZoom(this._startScale*s),r.setLocationAtPoint(l,c),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([a.now(),s,i])}},tn.prototype._onEnd=function(e){s.removeEventListener(t.default.document,\"touchmove\",this._onMove,{passive:!1}),s.removeEventListener(t.default.document,\"touchend\",this._onEnd);var r=this._gestureIntent,n=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,r){this._map.fire(new t.Event(r+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var i=this._inertia,a=this._map;if(i.length<2)a.snapToNorth({},{originalEvent:e});else{var o=i[i.length-1],l=i[0],c=a.transform.scaleZoom(n*o[1]),u=a.transform.scaleZoom(n*l[1]),f=c-u,h=(o[0]-l[0])/1e3,p=o[2];if(0!==h&&c!==u){var d=.15*f/h;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),a.easeTo({zoom:v,duration:g,easing:Qr,around:this._aroundCenter?a.getCenter():a.unproject(p),noMoveStart:!0},{originalEvent:e})}else a.snapToNorth({},{originalEvent:e})}}},tn.prototype._drainInertiaBuffer=function(){for(var t=this._inertia,e=a.now();t.length>2&&e-t[0][0]>160;)t.shift()};var en={scrollZoom:Hr,boxZoom:Gr,dragRotate:Yr,dragPan:Zr,keyboard:$r,doubleClickZoom:Kr,touchZoomRotate:tn},rn=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return this.transform.center},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.default$1.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.fitBounds=function(e,r,n){if(\"number\"==typeof(r=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},r)).padding){var i=r.padding;r.padding={top:i,bottom:i,right:i,left:i}}if(!t.default$10(Object.keys(r.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"]))return t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\"),this;e=W.convert(e);var a=[(r.padding.left-r.padding.right)/2,(r.padding.top-r.padding.bottom)/2],o=Math.min(r.padding.right,r.padding.left),s=Math.min(r.padding.top,r.padding.bottom);r.offset=[r.offset[0]+a[0],r.offset[1]+a[1]];var l=t.default$1.convert(r.offset),c=this.transform,u=c.project(e.getNorthWest()),f=c.project(e.getSouthEast()),h=f.sub(u),p=(c.width-2*o-2*Math.abs(l.x))/h.x,d=(c.height-2*s-2*Math.abs(l.y))/h.y;return d<0||p<0?(t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\"),this):(r.center=c.unproject(u.add(f).div(2)),r.zoom=Math.min(c.scaleZoom(c.scale*Math.min(p,d)),r.maxZoom),r.bearing=0,r.linear?this.easeTo(r,n):this.flyTo(r,n))},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=G.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,f=i.centerPoint.add(t.default$1.convert(e.offset)),h=i.pointLocation(f),p=G.convert(e.center||h);this._normalizeCenter(p);var d,g,v=i.project(h),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=G.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var h=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(h));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,f)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,f=i.zoomScale(l-a),h=i.centerPoint.add(t.default$1.convert(e.offset)),p=i.pointLocation(h),d=G.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/f,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function M(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function T(t){return(Math.exp(t)+Math.exp(-t))/2}var S=M(0),C=function(t){return T(S)/T(S+m*t)},E=function(t){return y*((T(S)*(A(e=S+m*t)/T(e))-A(S))/k)/b;var e},L=(M(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var z=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,E=function(){return 0},C=function(t){return Math.exp(z*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var l=e*L,f=1/C(l);i.zoom=a+i.scaleZoom(f),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var p=i.unproject(g.add(v.mult(E(l))).mult(f));i.setLocationAtPoint(i.renderWorldCopies?p.wrap():p,h),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(t,e,r){!1===r.animate||0===r.duration?(t(1),e()):(this._easeStart=a.now(),this._easeOptions=r,this._onEaseFrame=t,this._onEaseEnd=e,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var t=Math.min((a.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(t)),t<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),nn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};nn.prototype.getDefaultPosition=function(){return\"bottom-right\"},nn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=s.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},nn.prototype.onRemove=function(){s.remove(this._container),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},nn.prototype._updateEditLink=function(){var t=this._editLink;t||(t=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var e=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:v.ACCESS_TOKEN}];if(t){var r=e.reduce(function(t,r,n){return r.value&&(t+=r.key+\"=\"+r.value+(n<e.length-1?\"&\":\"\")),t},\"?\");t.href=\"https://www.mapbox.com/feedback/\"+r+(this._map._hash?this._map._hash.getHashString(!0):\"\")}},nn.prototype._updateData=function(t){t&&\"metadata\"===t.sourceDataType&&(this._updateAttributions(),this._updateEditLink())},nn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n].getSource();i.attribution&&t.indexOf(i.attribution)<0&&t.push(i.attribution)}t.sort(function(t,e){return t.length-e.length}),(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).length?(this._container.innerHTML=t.join(\" | \"),this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null}},nn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var an=function(){t.bindAll([\"_updateLogo\"],this)};an.prototype.onAdd=function(t){this._map=t,this._container=s.create(\"div\",\"mapboxgl-ctrl\");var e=s.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._container},an.prototype.onRemove=function(){s.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo)},an.prototype.getDefaultPosition=function(){return\"bottom-left\"},an.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},an.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}};var on=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};on.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},on.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},on.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},on.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var sn=t.default.HTMLImageElement,ln=t.default.HTMLElement,cn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,transformRequest:null,fadeDuration:300},un=function(r){function n(e){if(null!=(e=t.extend({},cn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var n=new Br(e.minZoom,e.maxZoom,e.renderWorldCopies);r.call(this,n,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new on;var i=e.transformRequest;if(this._transformRequest=i?function(t,e){return i(t,e)||{url:t}}:function(t){return{url:t}},\"string\"==typeof e.container){var a=t.default.document.getElementById(e.container);if(!a)throw new Error(\"Container '\"+e.container+\"' not found.\");this._container=a}else{if(!(e.container instanceof ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\",\"_update\",\"_render\",\"_onData\",\"_onDataLoading\"],this),this._setupContainer(),this._setupPainter(),this.on(\"move\",this._update.bind(this,!1)),this.on(\"zoom\",this._update.bind(this,!0)),void 0!==t.default&&(t.default.addEventListener(\"online\",this._onWindowOnline,!1),t.default.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var r=t.getCanvasContainer(),n=null,i=!1;for(var a in en)t[a]=new en[a](t,e),e.interactive&&e[a]&&t[a].enable(e[a]);s.addEventListener(r,\"mouseout\",function(e){t.fire(new Vr(\"mouseout\",t,e))}),s.addEventListener(r,\"mousedown\",function(r){i=!0;var n=new Vr(\"mousedown\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(r),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(r),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(r))}),s.addEventListener(r,\"mouseup\",function(e){var r=t.dragRotate.isActive();n&&!r&&t.fire(new Vr(\"contextmenu\",t,n)),n=null,i=!1,t.fire(new Vr(\"mouseup\",t,e))}),s.addEventListener(r,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var n=e.toElement||e.target;n&&n!==r;)n=n.parentNode;n===r&&t.fire(new Vr(\"mousemove\",t,e))}}),s.addEventListener(r,\"mouseover\",function(e){for(var n=e.toElement||e.target;n&&n!==r;)n=n.parentNode;n===r&&t.fire(new Vr(\"mouseover\",t,e))}),s.addEventListener(r,\"touchstart\",function(r){var n=new Ur(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),s.addEventListener(r,\"touchmove\",function(e){t.fire(new Ur(\"touchmove\",t,e))},{passive:!1}),s.addEventListener(r,\"touchend\",function(e){t.fire(new Ur(\"touchend\",t,e))}),s.addEventListener(r,\"touchcancel\",function(e){t.fire(new Ur(\"touchcancel\",t,e))}),s.addEventListener(r,\"click\",function(e){t.fire(new Vr(\"click\",t,e))}),s.addEventListener(r,\"dblclick\",function(e){var r=new Vr(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),s.addEventListener(r,\"contextmenu\",function(e){var r=t.dragRotate.isActive();i||r?i&&(n=e):t.fire(new Vr(\"contextmenu\",t,e)),e.preventDefault()}),s.addEventListener(r,\"wheel\",function(e){var r=new qr(\"wheel\",t,e);t.fire(r),r.defaultPrevented||t.scrollZoom.onWheel(e)},{passive:!1})}(this,e),this._hash=e.hash&&(new jr).addTo(this),this._hash&&this._hash._onHashChange()||this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),this.resize(),e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new nn),this.addControl(new an,e.logoPosition),this.on(\"style.load\",function(){this.transform.unmodified&&this.jumpTo(this.style.stylesheet)}),this.on(\"data\",this._onData),this.on(\"dataloading\",this._onDataLoading)}r&&(n.__proto__=r),n.prototype=Object.create(r&&r.prototype),n.prototype.constructor=n;var i={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return n.prototype.addControl=function(t,e){void 0===e&&t.getDefaultPosition&&(e=t.getDefaultPosition()),void 0===e&&(e=\"top-right\");var r=t.onAdd(this),n=this._controlPositions[e];return-1!==e.indexOf(\"bottom\")?n.insertBefore(r,n.firstChild):n.appendChild(r),this},n.prototype.removeControl=function(t){return t.onRemove(this),this},n.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e))},n.prototype.getBounds=function(){var e=new W(this.transform.pointLocation(new t.default$1(0,this.transform.height)),this.transform.pointLocation(new t.default$1(this.transform.width,0)));return(this.transform.angle||this.transform.pitch)&&(e.extend(this.transform.pointLocation(new t.default$1(this.transform.size.x,0))),e.extend(this.transform.pointLocation(new t.default$1(0,this.transform.size.y)))),e},n.prototype.getMaxBounds=function(){return this.transform.latRange&&2===this.transform.latRange.length&&this.transform.lngRange&&2===this.transform.lngRange.length?new W([this.transform.lngRange[0],this.transform.latRange[0]],[this.transform.lngRange[1],this.transform.latRange[1]]):null},n.prototype.setMaxBounds=function(t){if(t){var e=W.convert(t);this.transform.lngRange=[e.getWest(),e.getEast()],this.transform.latRange=[e.getSouth(),e.getNorth()],this.transform._constrain(),this._update()}else null==t&&(this.transform.lngRange=null,this.transform.latRange=null,this._update());return this},n.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},n.prototype.getMinZoom=function(){return this.transform.minZoom},n.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},n.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},n.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update(),this},n.prototype.getMaxZoom=function(){return this.transform.maxZoom},n.prototype.project=function(t){return this.transform.locationPoint(G.convert(t))},n.prototype.unproject=function(e){return this.transform.pointLocation(t.default$1.convert(e))},n.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},n.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isActive()},n.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},n.prototype.on=function(t,e,n){var i,a=this;if(void 0===n)return r.prototype.on.call(this,t,e);var o=function(){if(\"mouseenter\"===t||\"mouseover\"===t){var r=!1;return{layer:e,listener:n,delegates:{mousemove:function(i){var o=a.getLayer(e)?a.queryRenderedFeatures(i.point,{layers:[e]}):[];o.length?r||(r=!0,n.call(a,new Vr(t,a,i.originalEvent,{features:o}))):r=!1},mouseout:function(){r=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:n,delegates:{mousemove:function(r){(a.getLayer(e)?a.queryRenderedFeatures(r.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,n.call(a,new Vr(t,a,r.originalEvent)))},mouseout:function(e){o&&(o=!1,n.call(a,new Vr(t,a,e.originalEvent)))}}}}return{layer:e,listener:n,delegates:(i={},i[t]=function(t){var r=a.getLayer(e)?a.queryRenderedFeatures(t.point,{layers:[e]}):[];r.length&&(t.features=r,n.call(a,t),delete t.features)},i)}}();for(var s in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(o),o.delegates)a.on(s,o.delegates[s]);return this},n.prototype.off=function(t,e,n){if(void 0===n)return r.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===n){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},n.prototype.queryRenderedFeatures=function(e,r){var n;return 2===arguments.length?(e=arguments[0],r=arguments[1]):1===arguments.length&&((n=arguments[0])instanceof t.default$1||Array.isArray(n))?(e=arguments[0],r={}):1===arguments.length?(e=void 0,r=arguments[0]):(e=void 0,r={}),this.style?this.style.queryRenderedFeatures(this._makeQueryGeometry(e),r,this.transform):[]},n.prototype._makeQueryGeometry=function(e){var r,n=this;if(void 0===e&&(e=[t.default$1.convert([0,0]),t.default$1.convert([this.transform.width,this.transform.height])]),e instanceof t.default$1||\"number\"==typeof e[0])r=[t.default$1.convert(e)];else{var i=[t.default$1.convert(e[0]),t.default$1.convert(e[1])];r=[i[0],new t.default$1(i[1].x,i[0].y),i[1],new t.default$1(i[0].x,i[1].y),i[0]]}return{viewport:r,worldCoordinate:r.map(function(t){return n.transform.pointCoordinate(t)})}},n.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},n.prototype.setStyle=function(e,r){if((!r||!1!==r.diff&&!r.localIdeographFontFamily)&&this.style&&e&&\"object\"==typeof e)try{return this.style.setState(e)&&this._update(!0),this}catch(e){t.warnOnce(\"Unable to perform style diff: \"+(e.message||e.error||e)+\".  Rebuilding the style from scratch.\")}return this.style&&(this.style.setEventedParent(null),this.style._remove()),e?(this.style=new Je(this,r||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof e?this.style.loadURL(e):this.style.loadJSON(e),this):(delete this.style,this)},n.prototype.getStyle=function(){if(this.style)return this.style.serialize()},n.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},n.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0),this},n.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},n.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},n.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},n.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0),this},n.prototype.getSource=function(t){return this.style.getSource(t)},n.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var o=n.sdf;if(void 0===o&&(o=!1),r instanceof sn){var s=a.getImageData(r),l=s.width,c=s.height,u=s.data;this.style.addImage(e,{data:new t.RGBAImage({width:l,height:c},u),pixelRatio:i,sdf:o})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var f=r.width,h=r.height,p=r.data;this.style.addImage(e,{data:new t.RGBAImage({width:f,height:h},p.slice(0)),pixelRatio:i,sdf:o})}},n.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},n.prototype.removeImage=function(t){this.style.removeImage(t)},n.prototype.loadImage=function(e,r){t.getImage(this._transformRequest(e,t.ResourceType.Image),r)},n.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0),this},n.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0),this},n.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0),this},n.prototype.getLayer=function(t){return this.style.getLayer(t)},n.prototype.setFilter=function(t,e){return this.style.setFilter(t,e),this._update(!0),this},n.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0),this},n.prototype.getFilter=function(t){return this.style.getFilter(t)},n.prototype.setPaintProperty=function(t,e,r){return this.style.setPaintProperty(t,e,r),this._update(!0),this},n.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},n.prototype.setLayoutProperty=function(t,e,r){return this.style.setLayoutProperty(t,e,r),this._update(!0),this},n.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},n.prototype.setLight=function(t){return this.style.setLight(t),this._update(!0),this},n.prototype.getLight=function(){return this.style.getLight()},n.prototype.getContainer=function(){return this._container},n.prototype.getCanvasContainer=function(){return this._canvasContainer},n.prototype.getCanvas=function(){return this._canvas},n.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.offsetWidth||400,e=this._container.offsetHeight||300),[t,e]},n.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSContainer=s.create(\"div\",\"mapboxgl-missing-css\",t)).innerHTML=\"Missing Mapbox GL JS CSS\";var e=this._canvasContainer=s.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=s.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var r=this._containerDimensions();this._resizeCanvas(r[0],r[1]);var n=this._controlContainer=s.create(\"div\",\"mapboxgl-control-container\",t),i=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){i[t]=s.create(\"div\",\"mapboxgl-ctrl-\"+t,n)})},n.prototype._resizeCanvas=function(e,r){var n=t.default.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},n.prototype._setupPainter=function(){var r=t.extend({failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer},e.webGLContextAttributes),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?this.painter=new zr(n,this.transform):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},n.prototype._contextLost=function(e){e.preventDefault(),this._frameId&&(a.cancelFrame(this._frameId),this._frameId=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},n.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},n.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!(!this.style||!this.style.loaded())},n.prototype._update=function(t){this.style&&(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this._rerender())},n.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},n.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},n.prototype._render=function(){this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=a.now();this.style.zoomHistory.update(r,n);var i=new t.default$16(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),o=i.crossFadingFactor();1===o&&o===this._crossFadingFactor||(e=!0,this._crossFadingFactor=o),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),(this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty)&&this._rerender(),this},n.prototype.remove=function(){this._hash&&this._hash.remove(),a.cancelFrame(this._frameId),this._renderTaskQueue.clear(),this._frameId=null,this.setStyle(null),void 0!==t.default&&(t.default.removeEventListener(\"resize\",this._onWindowResize,!1),t.default.removeEventListener(\"online\",this._onWindowOnline,!1));var e=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");e&&e.loseContext(),fn(this._canvasContainer),fn(this._controlContainer),fn(this._missingCSSContainer),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},n.prototype._rerender=function(){var t=this;this.style&&!this._frameId&&(this._frameId=a.frame(function(){t._frameId=null,t._render()}))},n.prototype._onWindowOnline=function(){this._update()},n.prototype._onWindowResize=function(){this._trackResize&&this.stop().resize()._update()},i.showTileBoundaries.get=function(){return!!this._showTileBoundaries},i.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},i.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},i.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},i.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},i.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},i.repaint.get=function(){return!!this._repaint},i.repaint.set=function(t){this._repaint=t,this._update()},i.vertices.get=function(){return!!this._vertices},i.vertices.set=function(t){this._vertices=t,this._update()},n.prototype._onData=function(e){this._update(\"style\"===e.dataType),this.fire(new t.Event(e.dataType+\"data\",e))},n.prototype._onDataLoading=function(e){this.fire(new t.Event(e.dataType+\"dataloading\",e))},Object.defineProperties(n.prototype,i),n}(rn);function fn(t){t.parentNode&&t.parentNode.removeChild(t)}var hn={showCompass:!0,showZoom:!0},pn=function(e){var r=this;this.options=t.extend({},hn,e),this._container=s.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom In\",function(){return r._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom Out\",function(){return r._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset North\",function(){return r._map.resetNorth()}),this._compassArrow=s.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function dn(t,e,r){if(t=new G(t.lng,t.lat),e){var n=new G(t.lng-360,t.lat),i=new G(t.lng+360,t.lat),a=r.locationPoint(t).distSqr(e);r.locationPoint(n).distSqr(e)<a?t=n:r.locationPoint(i).distSqr(e)<a&&(t=i)}for(;Math.abs(t.lng-r.center.lng)>180;){var o=r.locationPoint(t);if(o.x>=0&&o.y>=0&&o.x<=r.width&&o.y<=r.height)break;t.lng>r.center.lng?t.lng-=360:t.lng+=360}return t}pn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},pn.prototype.onAdd=function(t){return this._map=t,this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Yr(t,{button:\"left\",element:this._compass}),this._handler.enable()),this._container},pn.prototype.onRemove=function(){s.remove(this._container),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.disable(),delete this._handler),delete this._map},pn.prototype._createButton=function(t,e,r){var n=s.create(\"button\",t,this._container);return n.type=\"button\",n.setAttribute(\"aria-label\",e),n.addEventListener(\"click\",r),n};var gn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function vn(t,e,r){var n=t.classList;for(var i in gn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var mn=function(e){if((arguments[0]instanceof t.default.HTMLElement||2===arguments.length)&&(e=t.extend({element:e},arguments[1])),t.bindAll([\"_update\",\"_onMapClick\"],this),this._anchor=e&&e.anchor||\"center\",this._color=e&&e.color||\"#3FB1CE\",e&&e.element)this._element=e.element,this._offset=t.default$1.convert(e&&e.offset||[0,0]);else{this._defaultMarker=!0,this._element=s.create(\"div\");var r=s.createNS(\"http://www.w3.org/2000/svg\",\"svg\");r.setAttributeNS(null,\"height\",\"41px\"),r.setAttributeNS(null,\"width\",\"27px\"),r.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var n=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");n.setAttributeNS(null,\"stroke\",\"none\"),n.setAttributeNS(null,\"stroke-width\",\"1\"),n.setAttributeNS(null,\"fill\",\"none\"),n.setAttributeNS(null,\"fill-rule\",\"evenodd\");var i=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");i.setAttributeNS(null,\"fill-rule\",\"nonzero\");var a=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");a.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),a.setAttributeNS(null,\"fill\",\"#000000\");for(var o=0,l=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];o<l.length;o+=1){var c=l[o],u=s.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");u.setAttributeNS(null,\"opacity\",\"0.04\"),u.setAttributeNS(null,\"cx\",\"10.5\"),u.setAttributeNS(null,\"cy\",\"5.80029008\"),u.setAttributeNS(null,\"rx\",c.rx),u.setAttributeNS(null,\"ry\",c.ry),a.appendChild(u)}var f=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");f.setAttributeNS(null,\"fill\",this._color);var h=s.createNS(\"http://www.w3.org/2000/svg\",\"path\");h.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),f.appendChild(h);var p=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"opacity\",\"0.25\"),p.setAttributeNS(null,\"fill\",\"#000000\");var d=s.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),p.appendChild(d);var g=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),g.setAttributeNS(null,\"fill\",\"#FFFFFF\");var v=s.createNS(\"http://www.w3.org/2000/svg\",\"g\");v.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var m=s.createNS(\"http://www.w3.org/2000/svg\",\"circle\");m.setAttributeNS(null,\"fill\",\"#000000\"),m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"cx\",\"5.5\"),m.setAttributeNS(null,\"cy\",\"5.5\"),m.setAttributeNS(null,\"r\",\"5.4999962\");var y=s.createNS(\"http://www.w3.org/2000/svg\",\"circle\");y.setAttributeNS(null,\"fill\",\"#FFFFFF\"),y.setAttributeNS(null,\"cx\",\"5.5\"),y.setAttributeNS(null,\"cy\",\"5.5\"),y.setAttributeNS(null,\"r\",\"5.4999962\"),v.appendChild(m),v.appendChild(y),i.appendChild(a),i.appendChild(f),i.appendChild(p),i.appendChild(g),i.appendChild(v),r.appendChild(i),this._element.appendChild(r),this._offset=t.default$1.convert(e&&e.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._popup=null};mn.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this._update(),this._map.on(\"click\",this._onMapClick),this},mn.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),delete this._map),s.remove(this._element),this._popup&&this._popup.remove(),this},mn.prototype.getLngLat=function(){return this._lngLat},mn.prototype.setLngLat=function(t){return this._lngLat=G.convert(t),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},mn.prototype.getElement=function(){return this._element},mn.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},mn.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},mn.prototype.getPopup=function(){return this._popup},mn.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},mn.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=dn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),s.setTransform(this._element,gn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"),vn(this._element,this._anchor,\"marker\"))},mn.prototype.getOffset=function(){return this._offset},mn.prototype.setOffset=function(e){return this._offset=t.default$1.convert(e),this._update(),this};var yn,xn={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},bn=function(e){function r(r){e.call(this),this.options=t.extend({},xn,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(e){var r;return this._map=e,this._container=s.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),r=this._setupUI,void 0!==yn?r(yn):void 0!==t.default.navigator.permissions?t.default.navigator.permissions.query({name:\"geolocation\"}).then(function(t){yn=\"denied\"!==t.state,r(yn)}):(yn=!!t.default.navigator.geolocation,r(yn)),this._container},r.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.default.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker.remove(),s.remove(this._container),this._map=void 0},r.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},r.prototype._updateCamera=function(t){var e=new G(t.coords.longitude,t.coords.latitude),r=t.coords.accuracy;this._map.fitBounds(e.toBounds(r),this.options.fitBoundsOptions,{geolocateSource:!0})},r.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},r.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},r.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},r.prototype._setupUI=function(e){var r=this;!1!==e&&(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=s.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=s.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new mn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==r._watchState||(r._watchState=\"BACKGROUND\",r._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),r._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),r.fire(new t.Event(\"trackuserlocationend\")))}))},r.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.default.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.default.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},r.prototype._clearWatch=function(){t.default.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},r}(t.Evented),_n={maxWidth:100,unit:\"metric\"},wn=function(e){this.options=t.extend({},_n,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function kn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,f=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var h=3.2808*f;h>5280?Mn(e,c,h/5280,\"mi\"):Mn(e,c,h,\"ft\")}else r&&\"nautical\"===r.unit?Mn(e,c,f/1852,\"nm\"):Mn(e,c,f,\"m\")}function Mn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:1)),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}wn.prototype.getDefaultPosition=function(){return\"bottom-left\"},wn.prototype._onMove=function(){kn(this._map,this._container,this.options)},wn.prototype.onAdd=function(t){return this._map=t,this._container=s.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},wn.prototype.onRemove=function(){s.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},wn.prototype.setUnit=function(t){this.options.unit=t,kn(this._map,this._container,this.options)};var An=function(){this._fullscreen=!1,t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.default.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.default.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.default.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.default.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};An.prototype.onAdd=function(e){return this._map=e,this._mapContainer=this._map.getContainer(),this._container=s.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._container.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._container},An.prototype.onRemove=function(){s.remove(this._container),this._map=null,t.default.document.removeEventListener(this._fullscreenchange,this._changeIcon)},An.prototype._checkFullscreenSupport=function(){return!!(t.default.document.fullscreenEnabled||t.default.document.mozFullScreenEnabled||t.default.document.msFullscreenEnabled||t.default.document.webkitFullscreenEnabled)},An.prototype._setupUI=function(){var e=this._fullscreenButton=s.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._container);e.setAttribute(\"aria-label\",\"Toggle fullscreen\"),e.type=\"button\",this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.default.document.addEventListener(this._fullscreenchange,this._changeIcon)},An.prototype._isFullscreen=function(){return this._fullscreen},An.prototype._changeIcon=function(){(t.default.document.fullscreenElement||t.default.document.mozFullScreenElement||t.default.document.webkitFullscreenElement||t.default.document.msFullscreenElement)===this._mapContainer!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"))},An.prototype._onClickFullscreen=function(){this._isFullscreen()?t.default.document.exitFullscreen?t.default.document.exitFullscreen():t.default.document.mozCancelFullScreen?t.default.document.mozCancelFullScreen():t.default.document.msExitFullscreen?t.default.document.msExitFullscreen():t.default.document.webkitCancelFullScreen&&t.default.document.webkitCancelFullScreen():this._mapContainer.requestFullscreen?this._mapContainer.requestFullscreen():this._mapContainer.mozRequestFullScreen?this._mapContainer.mozRequestFullScreen():this._mapContainer.msRequestFullscreen?this._mapContainer.msRequestFullscreen():this._mapContainer.webkitRequestFullscreen&&this._mapContainer.webkitRequestFullscreen()};var Tn={closeButton:!0,closeOnClick:!0},Sn=function(e){function r(r){e.call(this),this.options=t.extend(Object.create(Tn),r),t.bindAll([\"_update\",\"_onClickClose\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.addTo=function(e){return this._map=e,this._map.on(\"move\",this._update),this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._update(),this.fire(new t.Event(\"open\")),this},r.prototype.isOpen=function(){return!!this._map},r.prototype.remove=function(){return this._content&&s.remove(this._content),this._container&&(s.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),delete this._map),this.fire(new t.Event(\"close\")),this},r.prototype.getLngLat=function(){return this._lngLat},r.prototype.setLngLat=function(t){return this._lngLat=G.convert(t),this._pos=null,this._update(),this},r.prototype.setText=function(e){return this.setDOMContent(t.default.document.createTextNode(e))},r.prototype.setHTML=function(e){var r,n=t.default.document.createDocumentFragment(),i=t.default.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},r.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},r.prototype._createContent=function(){this._content&&s.remove(this._content),this._content=s.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=s.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},r.prototype._update=function(){if(this._map&&this._lngLat&&this._content){this._container||(this._container=s.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=s.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content)),this._map.transform.renderWorldCopies&&(this._lngLat=dn(this._lngLat,this._pos,this._map.transform));var e=this._pos=this._map.project(this._lngLat),r=this.options.anchor,n=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.default$1(0,0),top:new t.default$1(0,r),\"top-left\":new t.default$1(n,n),\"top-right\":new t.default$1(-n,n),bottom:new t.default$1(0,-r),\"bottom-left\":new t.default$1(n,-n),\"bottom-right\":new t.default$1(-n,-n),left:new t.default$1(r,0),right:new t.default$1(-r,0)}}if(r instanceof t.default$1||Array.isArray(r)){var i=t.default$1.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.default$1.convert(r.center||[0,0]),top:t.default$1.convert(r.top||[0,0]),\"top-left\":t.default$1.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.default$1.convert(r[\"top-right\"]||[0,0]),bottom:t.default$1.convert(r.bottom||[0,0]),\"bottom-left\":t.default$1.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.default$1.convert(r[\"bottom-right\"]||[0,0]),left:t.default$1.convert(r.left||[0,0]),right:t.default$1.convert(r.right||[0,0])}}return e(new t.default$1(0,0))}(this.options.offset);if(!r){var i,a=this._container.offsetWidth,o=this._container.offsetHeight;i=e.y+n.bottom.y<o?[\"top\"]:e.y>this._map.transform.height-o?[\"bottom\"]:[],e.x<a/2?i.push(\"left\"):e.x>this._map.transform.width-a/2&&i.push(\"right\"),r=0===i.length?\"bottom\":i.join(\"-\")}var l=e.add(n[r]).round();s.setTransform(this._container,gn[r]+\" translate(\"+l.x+\"px,\"+l.y+\"px)\"),vn(this._container,r,\"popup\")}},r.prototype._onClickClose=function(){this.remove()},r}(t.Evented),Cn={version:\"0.45.0\",supported:e,workerCount:Math.max(Math.floor(a.hardwareConcurrency/2),1),setRTLTextPlugin:t.setRTLTextPlugin,Map:un,NavigationControl:pn,GeolocateControl:bn,AttributionControl:nn,ScaleControl:wn,FullscreenControl:An,Popup:Sn,Marker:mn,Style:Je,LngLat:G,LngLatBounds:W,Point:t.default$1,Evented:t.Evented,config:v,get accessToken(){return v.ACCESS_TOKEN},set accessToken(t){v.ACCESS_TOKEN=t},workerUrl:\"\"};return Cn}),n})}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],f=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;f.push(a[u[s]].slice())}c.push(f)}return c}},{\"convex-hull\":119}],414:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),f=i(),h=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(f,u),f[3]=0,f[7]=0,f[11]=0,f[15]=1,Math.abs(o(f)<1e-8))return!1;var y,x,b,_,w,k,M,A=u[3],T=u[7],S=u[11],C=u[12],E=u[13],L=u[14],z=u[15];if(0!==A||0!==T||0!==S){if(h[0]=A,h[1]=T,h[2]=S,h[3]=z,!s(f,f))return!1;l(f,f),y=v,b=f,_=(x=h)[0],w=x[1],k=x[2],M=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*M,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*M,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*M,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*M}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=C,e[1]=E,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":415,\"gl-mat4/clone\":250,\"gl-mat4/create\":251,\"gl-mat4/determinant\":252,\"gl-mat4/invert\":256,\"gl-mat4/transpose\":266,\"gl-vec3/cross\":320,\"gl-vec3/dot\":325,\"gl-vec3/length\":335,\"gl-vec3/normalize\":342}],415:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],416:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=f(),c=f(),u=f();function f(){return{translate:h(),scale:h(1),skew:h(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function h(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,f){if(0===o(e)||0===o(r))return!1;var h=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!h||!p||(n(u.translate,l.translate,c.translate,f),n(u.skew,l.skew,c.skew,f),n(u.scale,l.scale,c.scale,f),n(u.perspective,l.perspective,c.perspective,f),s(u.quaternion,l.quaternion,c.quaternion,f),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":252,\"gl-vec3/lerp\":336,\"mat4-decompose\":414,\"mat4-recompose\":417,\"quat-slerp\":469}],417:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":251,\"gl-mat4/fromRotationTranslation\":254,\"gl-mat4/identity\":255,\"gl-mat4/multiply\":258,\"gl-mat4/scale\":264,\"gl-mat4/translate\":265}],418:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],419:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),f=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),h=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],h=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)h[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&h[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=h[c];else i(o,h,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],f(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||h,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":80,\"gl-mat4/invert\":256,\"gl-mat4/lookAt\":257,\"gl-mat4/rotateX\":261,\"gl-mat4/rotateY\":262,\"gl-mat4/rotateZ\":263,\"gl-mat4/scale\":264,\"gl-mat4/translate\":265,\"gl-vec3/normalize\":342,\"mat4-interpolate\":416}],420:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),f=0,i=0,h=o.length;i<h;++i)r[f++]=o[i];for(var p=s.length-2;p>0;--p)r[f++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":488}],421:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function f(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function h(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",f),t.addEventListener(\"keyup\",h),t.addEventListener(\"keydown\",h),t.addEventListener(\"keypress\",h),t!==window&&(window.addEventListener(\"blur\",f),window.addEventListener(\"keyup\",h),window.addEventListener(\"keydown\",h),window.addEventListener(\"keypress\",h)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",f),t.removeEventListener(\"keyup\",h),t.removeEventListener(\"keydown\",h),t.removeEventListener(\"keypress\",h),t!==window&&(window.removeEventListener(\"blur\",f),window.removeEventListener(\"keyup\",h),window.removeEventListener(\"keydown\",h),window.removeEventListener(\"keypress\",h)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":423}],422:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],423:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],424:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":517}],425:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function f(t){return\"p\"+t}function h(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var T=t.arrayArguments||1;T<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var C=t.getters||[],E=new Array(T),L=0;L<T;++L)C.indexOf(L)>=0?E[L]=!0:E[L]=!1;return function(t,e,r,T,S,C){var E=C.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var z=\"extractContour\"+S.join(\"_\"),O=[],I=[],D=[],P=0;P<E;++P)D.push(i(P));for(var P=0;P<T;++P)D.push(u(P));for(var P=0;P<L;++P)I.push(s(P)+\"=\"+i(0)+\".shape[\"+P+\"]|0\");for(var P=0;P<E;++P){I.push(a(P)+\"=\"+i(P)+\".data\",c(P)+\"=\"+i(P)+\".offset|0\");for(var R=0;R<L;++R)I.push(l(P,R)+\"=\"+i(P)+\".stride[\"+R+\"]|0\")}for(var P=0;P<E;++P){I.push(f(P)+\"=\"+c(P)),I.push(o(P,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(P,B));I.push(h(P,R)+\"=(\"+F.join(\"\")+\")|0\"),I.push(o(P,R)+\"=0\")}}for(var P=0;P<E;++P)for(var R=0;R<L;++R){var N=[l(P,S[R])];R>0&&N.push(l(P,S[R-1])+\"*\"+s(S[R-1])),I.push(d(P,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var P=0;P<L;++P)I.push(p(P)+\"=0\");I.push(_+\"=0\");for(var j=[\"2\"],P=L-2;P>=0;--P)j.push(s(S[P]));I.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),I.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var V=[],U=[],B=0;B<L;++B)R&1<<B&&(0===U.length?V.push(\"1\"):V.unshift(U.join(\"*\"))),U.push(s(S[B]));var q=\"\";V[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);I.push(m(H)+\"=(-\"+V.join(\"-\")+\")|0\",v(H)+\"=(\"+q+V.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function W(t){for(var e=0;e<E;++e)O.push(f(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function Y(){for(var t=1;t<1<<L;++t)O.push(M,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",M,\";\")}I.push(y(0)+\"=0\",M+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<E;++e)C[e]?O.push(o(e,0),\"=\",a(e),\".get(\",f(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",f(e),\"];\");for(var r=[],e=0;e<E;++e)r.push(o(e,0));for(var e=0;e<T;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<E;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)C[e]?O.push(o(e,n),\"=\",a(e),\".get(\",f(e),\"+\",h(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",f(e),\"+\",h(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<T;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],M=d;M>0;M=M-1&d)w.push(x+\"[\"+k+\"+\"+m(M)+\"]\");w.push(y(0));for(var M=0;M<E;++M)1&n?w.push(o(M,l),o(M,d)):w.push(o(M,d),o(M,l));1&n?w.push(c,v):w.push(v,c);for(var M=0;M<T;++M)w.push(u(M));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<E;++e)C[e]?r.push(a(e)+\".get(\"+f(e)+\")\"):r.push(a(e)+\"[\"+f(e)+\"]\");for(var e=0;e<T;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)W(e);for(var n=0;n<E;++n)O.push(f(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<E;++n)O.push(f(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),Y());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),Y());W(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",z,\"(\",D.join(),\"){\",\"var \",I.join(),\";\",O.join(\"\"),\"}\",\"return \",z].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,E)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",M=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":523}],426:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":138}],427:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,f=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var h=s.slice(),p=s.slice();e[l]<0?h[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",h.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",f,\",src.pick(\",h.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",f,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",f,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",f,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",f,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var f=[],h=0;h<r;++h)s&1<<h&&f.push(h+1);for(var p=0;p<1<<f.length;++p){for(var d=f.slice(),h=0;h<f.length;++h)p&1<<h&&(d[h]=-d[h]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":135,dup:156}],428:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":267,\"ndarray-warp\":435}],429:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],f=a&&c?t.get(n,s):0,h=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*f+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*h+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],f=0<=l+1&&l+1<t.shape[1],h=Math.floor(n),p=n-h,d=0<=h&&h<t.shape[2],g=0<=h+1&&h+1<t.shape[2],v=o&&u&&d?t.get(i,l,h):0,m=o&&f&&d?t.get(i,l+1,h):0,y=s&&u&&d?t.get(i+1,l,h):0,x=s&&f&&d?t.get(i+1,l+1,h):0,b=o&&u&&g?t.get(i,l,h+1):0,_=o&&f&&g?t.get(i,l+1,h+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,h+1):0))+c*((1-a)*_+a*(s&&f&&g?t.get(i+1,l+1,h+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,f=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}f+=c*t.data[u]}return f}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],430:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var f=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var h=[\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":135}],431:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":432,ndarray:436}],432:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":135}],433:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var f=-1,h=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(f>0?s.push([\"d\",d,\"=s\",d,\"-d\",f,\"*n\",f].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),f=d),0!=(p=t.length-1-l)&&(h>0?s.push([\"e\",p,\"=s\",p,\"-e\",h,\"*n\",h,\",f\",p,\"=\",c[p],\"-f\",h,\"*n\",h].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),h=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function f(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function h(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",f(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",f(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(h(\"dptr\",f(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(h(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+f(\"ptr\"),\"while((j--\\x3eleft)&&(\"+f(\"cptr-s0\")+\">scratch)){\",h(\"cptr\",f(\"cptr-s0\")),\"cptr-=s0\",\"}\",h(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var f=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var h=[],p=1;p<t.length;++p)h.push(\"n\"+p),f.push(\"i\"+p);for(p=0;p<8;++p)f.push(\"b_ptr\"+p);f.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+h.join(\"*\")),c?f.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):f.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else f.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function M(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function T(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function C(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+f.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),M(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),M(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),T(\"left\",\"(less-1)\",1),T(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),C(\"less\",1,\"++less\"),C(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),M(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":523}],434:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":433}],435:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":138,\"ndarray-linear-interpolate\":429}],436:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),f=o.map(function(t){return\"b\"+t}).join(\",\"),h=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+f+\",\"+h+\",d){this.data=a\",\"this.shape=[\"+f+\"]\",\"this.stride=[\"+h+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var f=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),h=c[f];h.length<=o+1;)h.push(l(f,h.length-1));return(0,h[o+1])(t,e,r,n)}},{\"iota-array\":402,\"is-buffer\":404}],437:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":153}],438:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,f,h,p){if(p)k=p[0],M=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(f=(d=l(f,h,-o)).x))/2,v=(e-(h=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+f)/2,w=b*-a*g/r+(e+h)/2,k=Math.asin(((e-w)/a).toFixed(9)),M=Math.asin(((h-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(M=f<_?n-M:M)<0&&(M=2*n+M),u&&k>M&&(k-=2*n),!u&&M>k&&(M-=2*n)}if(Math.abs(M-k)>i){var A=M,T=f,S=h;M=k+i*(u&&M>k?1:-1);var C=s(f=_+r*Math.cos(M),h=w+a*Math.sin(M),r,a,o,0,u,T,S,[M,A,_,w])}var E=Math.tan((M-k)/4),L=4/3*r*E,z=4/3*a*E,O=[2*t-(t+L*Math.sin(k)),2*e-(e-z*Math.cos(k)),f+L*Math.sin(M),h-z*Math.cos(M),f,h];if(p)return O;C&&(O=O.concat(C));for(var I=0;I<O.length;){var D=l(O[I],O[I+1],o);O[I++]=D.x,O[I++]=D.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,f=null,h=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(f=2*p-f,h=2*d-h):(f=p,h=d),m=o(p,d,f,h,m[1],m[2]);break;case\"Q\":f=m[1],h=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],439:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],f=0;f<s.length;++f){l=c,c=u,u=s[(f+1)%s.length];for(var h=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=h[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var M=0;for(x=0;x<3;++x)M+=b[x]*b[x];if(M>a)for(_=1/Math.sqrt(M),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),f=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],f[c]=l[2][c]-l[0][c];var h=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;h[c]=u[d]*f[g]-u[g]*f[d],p+=h[c]*h[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)h[c]*=p;i[o]=h}return i}},{}],440:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(f>0){var f=Math.sqrt(u+1);t[0]=.5*(o-l)/f,t[1]=.5*(s-n)/f,t[2]=.5*(r-a)/f,t[3]=.5*f}else{var h=Math.max(e,a,c),f=Math.sqrt(2*h-u+1);e>=h?(t[0]=.5*f,t[1]=.5*(i+r)/f,t[2]=.5*(s+n)/f,t[3]=.5*(o-l)/f):a>=h?(t[0]=.5*(r+i)/f,t[1]=.5*f,t[2]=.5*(l+o)/f,t[3]=.5*(s-n)/f):(t[0]=.5*(n+s)/f,t[1]=.5*(o+l)/f,t[2]=.5*f,t[3]=.5*(r-i)/f)}return t}},{}],442:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new f(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function f(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var h=f.prototype;h.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},h.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,f=0;f<3;++f)c+=r[l+4*f]*i[f];r[12+l]=-c}},h.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},h.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},h.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},h.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=l(u-=a*p,f-=o*p,h-=s*p);u/=d,f/=d,h/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*f+m*h,b=l(g-=y*a+x*u,v-=y*o+x*f,m-=y*s+x*h);g/=b,v/=b,m/=b;var _=u*e+a*r,w=f*e+o*r,k=h*e+s*r;this.center.move(t,_,w,k);var M=Math.exp(this.computedRadius[0]);M=Math.max(1e-4,M+n),this.radius.set(t,Math.log(M))},h.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],f=i[5],h=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*f,y=e*s+r*h,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var M=this.computedRotation,A=M[0],T=M[1],S=M[2],C=M[3],E=A*w+C*x+T*_-S*b,L=T*w+C*b+S*x-A*_,z=S*w+C*_+A*b-T*x,O=C*w-A*x-T*b-S*_;if(n){x=p,b=d,_=g;var I=Math.sin(n)/l(x,b,_);x*=I,b*=I,_*=I,O=O*(w=Math.cos(e))-(E=E*w+O*x+L*_-z*b)*x-(L=L*w+O*b+z*x-E*_)*b-(z=z*w+O*_+E*b-L*x)*_}var D=c(E,L,z,O);D>1e-6?(E/=D,L/=D,z/=D,O/=D):(E=L=z=0,O=1),this.rotation.set(t,E,L,z,O)},h.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},h.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},h.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var f=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*f,l-n[6]*f,c-n[10]*f),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},h.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},h.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},h.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},h.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},h.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":441,\"filtered-vector\":216,\"gl-mat4/fromQuat\":253,\"gl-mat4/invert\":256,\"gl-mat4/lookAt\":257}],443:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":481}],444:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"(?![0-9]))\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\");return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\"),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],445:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":451}],446:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],447:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],448:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:468}],449:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":523}],450:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":401,\"typedarray-pool\":523}],451:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var f=a;f<c.length;f++)l[c[f]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],452:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var f=0;f<2;++f)for(var h=a[f][r],p=0;p<h.length;++p){var d=h[p],g=d[1^f],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=f)}return i?s:(o&&c(o,l),s)}function f(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],f=t,h=o[1],p=u(l,f,!0);if(n(e[l],e[f],e[h],e[p])<0)break;o.push(t),s=u(l,f)}return o}function h(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=f(o,p);h(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":116}],453:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var f=u[s];0==--a[f]&&o.push(f)}}for(var h=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;h[s]=c,p.push(e[s])}else h[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([h[g[0]],h[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":158}],454:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var f=(e=r[1]).length,h=(t.length,n(t,e.length)),p=0;p<f;++p)if(h[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),f=o(l[0],a[1]),h=o(l[0],l[1]);n=s(n,s(s(c,u),s(f,h)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],M=k.length,A=0;A<M;++A){var T=b(e[k[A]]);if(0!==T){T<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],C=y[2],w=0;w<g;++w)C[w]&&(v[w]=S);for(var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)E[p].push(v[p]),E[v[p]].push(p);for(var L={},z=u(f,!1),p=0;p<g;++p)for(var k=d[p],M=k.length,w=0;w<M;++w){var O=k[w],I=k[(w+1)%M],D=Math.min(O,I)+\":\"+Math.max(O,I);if(D in L){var P=L[D];E[P].push(p),E[p].push(P),z[O]=z[I]=!0}else L[D]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!z[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=E[N];l(j,function(t,e){return t-e});var V,U=j.length,q=B[N];if(0===q){var k=d[N];V=[k]}for(var p=0;p<U;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),V.push(k))}}0===q&&r.push(V)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":453,\"edges-to-adjacency-list\":158,\"planar-dual\":452,\"point-in-big-polygon\":458,\"robust-sum\":493,\"two-product\":521,uniq:525}],455:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":457}],456:[function(t,e,r){arguments[4][100][0].apply(r,arguments)},{dup:100}],457:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),f=t(\"dtype\"),h=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(f(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var f=l.length;o++;if(o>r){for(var h=0;h<a.length;h++)l.push(a[h]),c.push(s),u.push(null,null,null,null);return f}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),f;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var M=1,A=a.length;M<A;M++){var T=a[M],S=g[2*T],C=g[2*T+1];S<d?C<v?m.push(T):_.push(T):C<v?w.push(T):k.push(T)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return f}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var M=y[k];if(d.set)d.set(M,w);else for(var A=0,T=M.length;A<T;A++)d[A+w]=M[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var f=a.apply(void 0,r),d=[Math.min(f.x,f.x+f.width),Math.min(f.y,f.y+f.height),Math.max(f.x,f.x+f.width),Math.max(f.y,f.y+f.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),M=k[0],A=k[1],T=k[2],S=k[3],E=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-h(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-h(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=C(t,e,s),f=C(r,i,s),h=n.ge(l,u),p=n.gt(l,f,h,l.length-1);o[s]=[h+c,p+c]}return o}(M,A,T,S,E);var z=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(M>l||A>c||T<r||S<n||a>=E||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var f=o;f<s;f++){var h=u[f],p=t[2*h],d=t[2*h+1];p>=g&&p<=m&&d>=v&&d<=w&&z.push(h)}var b=x[a],_=b[4*o+0],k=b[4*o+1],C=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),I=.5*i,D=a+1;e(r,n,I,D,_,k||C||L||O),e(r,n+I,I,D,k,C||L||O),e(r+I,n,I,D,C,L||O),e(r+I,n+I,I,D,L,O)}}}(0,0,1,0,0,1),z},d;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":54,\"binary-search-bounds\":456,clamp:104,defined:150,dtype:155,\"flatten-vertex-data\":217,\"is-obj\":407,\"math-log2\":418,\"parse-rect\":445,\"pick-by-alias\":451}],458:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],f=u.length,h=f-1,p=0;p<f;h=p++){var d=u[h],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},f=Object.keys(e);for(r=0;r<f.length;++r){var h=e[f[r]];u[f[r]]=a(h)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":80,\"interval-tree-1d\":400,\"robust-orientation\":488,\"slab-decomposition\":504}],459:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,f=a();function h(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return f.epsilon(t)},segments:function(t){var e=o(!0,f,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,f,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,f,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,f,t)},union:function(t,e){return h(t,e,n.selectUnion)},intersect:function(t,e){return h(t,e,n.selectIntersect)},difference:function(t,e){return h(t,e,n.selectDifference)},differenceRev:function(t,e){return h(t,e,n.selectDifferenceRev)},xor:function(t,e){return h(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":460,\"./lib/epsilon\":461,\"./lib/geojson\":462,\"./lib/intersecter\":463,\"./lib/segment-chainer\":465,\"./lib/segment-selector\":466}],460:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],461:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],f=e[1]-n[1],h=(s*f-l*u)/c,p=(a*f-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+h*a,e[1]+h*o]};return d.alongA=h<=-t?-2:h<t?-1:h-1<=-t?0:h-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],462:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function f(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(h(t.children[r]))}function h(t){for(var e=0;e<t.children.length;e++)f(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)f(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],463:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var f=e.linesIntersect(o,s,c,u);if(!1===f){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var h=e.pointsSame(o,c),p=e.pointsSame(s,u);if(h&&p)return n;var d=!h&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(h)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===f.alongA&&(-1===f.alongB?l(t,c):0===f.alongB?l(t,f.pt):1===f.alongB&&l(t,u)),0===f.alongB&&(-1===f.alongA?l(n,o):0===f.alongA?l(n,f.pt):1===f.alongA&&l(n,s));return!1}for(var f=[];!a.isEmpty();){var h=a.getHead();if(r&&r.vert(h.pt[0]),h.isStart){r&&r.segmentNew(h.seg,h.primary);var p=c(h),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(h,d);if(t)return t}return!!g&&u(h,g)}r&&r.tempStatus(h.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=h.seg.myFill,r&&r.segmentUpdate(x.seg),h.other.remove(),h.remove();if(a.getHead()!==h){r&&r.rewind(h.seg);continue}t?(y=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below,h.seg.myFill.below=g?g.seg.myFill.above:i,h.seg.myFill.above=y?!h.seg.myFill.below:h.seg.myFill.below):null===h.seg.otherFill&&(m=g?h.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:h.primary?o:i,h.seg.otherFill={above:m,below:m}),r&&r.status(h.seg,!!d&&d.seg,!!g&&g.seg),h.other.status=p.insert(n.node({ev:h}))}else{var b=h.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!h.primary){var _=h.seg.myFill;h.seg.myFill=h.seg.otherFill,h.seg.otherFill=_}f.push(h.seg)}a.getHead().remove()}return r&&r.done(),f}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":464}],464:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],465:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var f=(v=n[u])[0],h=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(f,a)){if(M(u,!0,!0))break}else if(e.pointsSame(f,o)){if(M(u,!0,!1))break}else if(e.pointsSame(h,a)){if(M(u,!1,!0))break}else if(e.pointsSame(h,o)&&M(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),T(_,w)):(A(w),T(w,_)):T(w,_):l.matches_head?T(_,w):k?(A(_),T(w,_)):(A(w),T(_,w))}function M(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function T(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],466:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],467:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,f=0,h=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,f+=v*v,h+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*f-u*u),M=u*p-f*h,A=u*h-c*p;if(M+A<=k)if(M<0)A<0&&h<0?(A=0,-h>=c?(M=1,y=c+2*h+d):y=h*(M=-h/c)+d):(M=0,p>=0?(A=0,y=d):-p>=f?(A=1,y=f+2*p+d):y=p*(A=-p/f)+d);else if(A<0)A=0,h>=0?(M=0,y=d):-h>=c?(M=1,y=c+2*h+d):y=h*(M=-h/c)+d;else{var T=1/k;y=(M*=T)*(c*M+u*(A*=T)+2*h)+A*(u*M+f*A+2*p)+d}else M<0?(b=f+p)>(x=u+h)?(_=b-x)>=(w=c-2*u+f)?(M=1,A=0,y=c+2*h+d):y=(M=_/w)*(c*M+u*(A=1-M)+2*h)+A*(u*M+f*A+2*p)+d:(M=0,b<=0?(A=1,y=f+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/f)+d):A<0?(b=c+h)>(x=u+p)?(_=b-x)>=(w=c-2*u+f)?(A=1,M=0,y=f+2*p+d):y=(M=1-(A=_/w))*(c*M+u*A+2*h)+A*(u*M+f*A+2*p)+d:(A=0,b<=0?(M=1,y=c+2*h+d):h>=0?(M=0,y=d):y=h*(M=-h/c)+d):(_=f+p-u-h)<=0?(M=0,A=1,y=f+2*p+d):_>=(w=c-2*u+f)?(M=1,A=0,y=c+2*h+d):y=(M=_/w)*(c*M+u*(A=1-M)+2*h)+A*(u*M+f*A+2*p)+d;var S=1-M-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+M*e[l]+A*r[l];return y<0?0:y}},{}],468:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],f=!1,h=-1;function p(){f&&c&&(f=!1,c.length?u=c.concat(u):h=-1,u.length&&d())}function d(){if(!f){var t=l(p);f=!0;for(var e=u.length;e;){for(c=u,u=[];++h<e;)c&&c[h].run();h=-1,e=u.length}c=null,f=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||f||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],469:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":282}],470:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,f=0,h=[];s=function(t){if(0===h.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=h.slice(0);h.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return h.push({handle:++f,callback:t,cancelled:!1}),f},l=function(t){for(var e=0;e<h.length;e++)h[e].handle===t&&(h[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":448}],471:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":64}],472:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":67}],473:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":67,\"big-rat/mul\":76}],474:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":78}],475:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":101,\"compare-cell\":117,\"compare-oriented-cell\":118}],476:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,f=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:h}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision mediump float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:h.length}),s(b,{update:k,draw:_,destroy:M,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&M(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=f(e.scale),e.translateFract=f(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var h=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*h),_=new Uint8Array(4*h),w=new Float32Array(4*h);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(f(v)),d(_),g(w)}}}function M(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var h=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":54,\"color-normalize\":109,\"flatten-vertex-data\":217,\"object-assign\":440,\"pick-by-alias\":451,\"to-float32\":516,\"update-diff\":527}],477:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),f=t(\"to-float32\"),h=f.float32,p=f.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,f){var d=e.passes[f];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[f]=d={id:f,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,f<v.maxLines&&(d.depth=2*(v.maxLines-1-f%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],M={},A=0,T=0,S=0,C=d.count;T<C;T++){var E=m[2*T],L=m[2*T+1];isNaN(E)||isNaN(L)||null==E||null==L?(E=m[2*A],L=m[2*A+1],M[T]=A):A=T,k[S++]=E,k[S++]=L}for(var z=c(k,d.hole||[]),O=0,I=z.length;O<I;O++)null!=M[z[O]]&&(z[O]=M[z[O]]);d.triangles=z}var D=new Float64Array(m);u(D,2,w);var P=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(P[0]=D[2*y-4],P[1]=D[2*y-3]):(P[0]=D[2*y-2],P[1]=D[2*y-1]):(P[0]=D[0],P[1]=D[1]),P.set(D,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(P[2*y+2]=D[2],P[2*y+3]=D[3],d.count-=1):(P[2*y+2]=D[0],P[2*y+3]=D[1],P[2*y+4]=D[2],P[2*y+5]=D[3]):(P[2*y+2]=D[2*y-2],P[2*y+3]=D[2*y-1],P[2*y+4]=D[2*y-2],P[2*y+5]=D[2*y-1]),d.positionBuffer(h(P)),d.positionFractBuffer(p(P))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var V,U=0;if(!t.dashes||t.dashes.length<2)U=1,V=new Uint8Array([255,255,255,255,255,255,255,255]);else{U=0;for(var q=0;q<t.dashes.length;++q)U+=t.dashes[q];V=new Uint8Array(U*v.dashMult);for(var H=0,G=255,W=0;W<2;W++)for(var Y=0;Y<t.dashes.length;++Y){for(var X=0,Z=t.dashes[Y]*v.dashMult*.5;X<Z;++X)V[H++]=G;G^=255}}d.dashLength=U,d.dashTexture({channels:1,data:V,width:V.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var $=d.count,J=t.color;J||(J=\"transparent\");var K=new Uint8Array(4*$+4);if(Array.isArray(J)&&\"number\"!=typeof J[0]){for(var Q=0;Q<$;Q++){var tt=n(J[Q],\"uint8\");K.set(tt,4*Q)}K.set(n(J[0],\"uint8\"),4*$)}else for(var et=n(J,\"uint8\"),rt=0;rt<$+1;rt++)K.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:K})}}else e.passes[f]=null}),t.length<this.passes.length){for(var f=t.length;f<this.passes.length;f++){var d=e.passes[f];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":54,\"array-normalize\":55,\"color-normalize\":109,earcut:157,\"es6-weak-map\":210,\"flatten-vertex-data\":217,glslify:395,\"object-assign\":440,\"parse-rect\":445,\"pick-by-alias\":451,\"to-float32\":516}],478:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),f=t(\"pick-by-alias\"),h=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var f=[],h=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=h.length;m--;){var y=n(h[m],2),x=y[0],b=y[1];f.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return f},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=f(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(h(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),f=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=f),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:f}):n&&n.length&&(e.tree=n),e.tree){var h={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(h):e.elements=s.elements(h)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var f={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](f):i[u]=s.buffer(f),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,M=_.borderSize,A=_.sizeBuffer,T=new Uint8Array(2*w);if(k.length||M.length)for(var S=0;S<w;S++)T[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),T[2*S+1]=Math.round(255*(null==M[S]?M:M[S])/u);A({data:T,usage:\"dynamic\"})}if(b){var C,E=n,L=E.count,z=E.color,O=E.borderColor,I=E.colorBuffer;if(t.tooManyColors){if(z.length||O.length){C=new Uint8Array(8*L);for(var D=0;D<L;D++){var P=z[D];C[8*D]=m[4*P],C[8*D+1]=m[4*P+1],C[8*D+2]=m[4*P+2],C[8*D+3]=m[4*P+3];var R=O[D];C[8*D+4]=m[4*R],C[8*D+5]=m[4*R+1],C[8*D+6]=m[4*R+2],C[8*D+7]=m[4*R+3]}}}else if(z.length||O.length){C=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=z[F]&&(C[4*F]=z[F]%d,C[4*F+1]=Math.floor(z[F]/d)),null!=O[F]&&(C[4*F+2]=O[F]%d,C[4*F+3]=Math.floor(O[F]/d))}I({data:C||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var f=t[u];f=a(f,\"uint8\");var h=s(f,!1);if(null==e[h]){var p=r.length;e[h]=Math.floor(p/4),r[p]=f[0],r[p+1]=f[1],r[p+2]=f[2],r[p+3]=f[3]}i[u]=e[h]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":54,\"color-id\":107,\"color-normalize\":109,\"flatten-vertex-data\":217,glslify:395,\"is-iexplorer\":405,\"object-assign\":440,\"parse-rect\":445,\"pick-by-alias\":451,\"point-cluster\":455,\"to-float32\":516,\"update-diff\":527}],479:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function f(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function h(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var M=0;M<g;M++)if((s.diagonal||M!==k)&&(s.upper||!(k>M))&&(s.lower||!(k<M))){var A=f(s.id,k,M),T=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?T.positions={x:{buffer:s.buffer,offset:M,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:T.positions={x:{buffer:s.buffer,offset:M*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},T.bounds=h(s.bounds,k,M)),o.domain||o.viewport||o.data){var S=d?h(s.padding,k,M):s.padding;if(s.domain){var C=h(s.domain,k,M),E=C[0],L=C[1],z=C[2],O=C[3];T.viewport=[x+E*m+S[0],b+L*y+S[1],x+z*m-S[2],b+O*y-S[3]]}else T.viewport=[x+M*_+_*S[0],b+k*w+w*S[1],x+(M+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(T.color=s.color),o.size&&(T.size=s.size),o.marker&&(T.marker=s.marker),o.borderSize&&(T.borderSize=s.borderSize),o.borderColor&&(T.borderColor=s.borderColor),o.opacity&&(T.opacity=s.opacity),o.range&&(T.range=n?h(s.range,k,M):s.range||T.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],f=u.passes,h=u.passOffset;f=f.map(function(t,e){n[h+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":54,\"array-range\":56,\"flatten-vertex-data\":217,\"parse-rect\":445,\"pick-by-alias\":451,raf:470,\"regl-scatter2d\":478}],480:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,f=!1,h=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(h=s.onDone),\"profile\"in s&&(f=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:f,onDone:h,onDestroy:p}:(p(),h(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||Y(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|$[Object.prototype.toString.call(t)]}function f(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function h(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,f(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):Y(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(Y(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,h(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||Y(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=K[e.usage]),\"type\"in e&&(s=J[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),Y(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);f(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||Y(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),h(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var f=u;u||Y(i)&&(!l(i)||Y(i.data))||(f=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,f,3)}else t.bufferData(34963,c,a),n.buffer.dtype=f||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(f=u,!u){switch(n.buffer.dtype){case 5121:case 5120:f=5121;break;case 5123:case 5122:f=5123;break;case 5125:case 5124:f=5125}n.buffer.dtype=f}n.type=f,0>(i=s)&&(i=n.buffer.byteLength,5123===f?i>>=1:5125===f&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var f=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),f.primType=4,f.vertCount=0|t,f.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,h=0;Array.isArray(t)||Y(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=K[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(h=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===h||5122===h?o*=2:5125!==h&&5124!==h||(o*=4))),a(f,e,r,n,i,o,h)}else c(),f.primType=4,f.vertCount=0,f.type=5121;return s}var c=r.create(null,34963,!0),f=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=f,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(f)},s},createStream:function(t){var e=f.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){f.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||Y(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function M(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=W[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in J&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function f(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function h(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(Y(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|$[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|$[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,f,h=r.stride;3===a.length?(c=a[2],f=h[2]):f=c=1,o=a[0],s=a[1],a=h[0],h=h[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=f,r=r.offset,c=t.width,f=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*f*s),d=0,m=0;m<f;++m)for(var k=0;k<c;++k)for(var M=0;M<s;++M)p[d++]=n[a*k+h*m+o*M+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,h=t.channels,h=v(r[0][0])?h||r[0][0].length:h||1,o=Z.shape(r),c=1,f=0;f<o.length;++f)c*=o[f];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=h,t.format=t.internalformat=ot[h],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,h=e.type,p=e.width,d=e.height;f(e),s?t.texSubImage2D(r,o,i,a,u,h,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,h,l)}function m(){return dt.pop()||new h}function M(t){t.needsFree&&G.freeType(t.data),h.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function T(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function C(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,h=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;f(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,h,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function E(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&M(e[r]),e[r]=null;gt.push(t)}function z(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=U[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=V[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function I(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function D(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new z,o.profile&&(this.stats={size:0})}function P(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},V={nearest:9728,linear:9729},U=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},V),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},W={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},J={};e.ext_srgb&&(W.srgb=35904,W.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(W,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(J,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(J,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(J,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(J[\"rgb etc1\"]=36196);var K=Array.prototype.slice.call(t.getParameter(34467));Object.keys(J).forEach(function(t){var e=J[t];0<=K.indexOf(e)&&(W[t]=e)});var Q=Object.keys(W);r.textureFormats=Q;var tt=[];Object.keys(W).forEach(function(t){tt[W[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(V).forEach(function(t){rt[V[t]]=t});var nt=[];Object.keys(U).forEach(function(t){nt[U[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=W[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(D.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;z.call(r);var a=E();return\"number\"==typeof t?T(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):T(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,P(i),C(a,3553),I(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new D(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,P(i),d(o,3553,e,r,a),R(),M(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,P(i);for(var l,c=i.channels,u=i.type,f=0;i.mipmask>>f;++f){var h=a>>f,p=s>>f;if(!h||!p)break;l=G.zero.allocType(u,h*p*c),t.texImage2D(3553,f,i.format,h,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function f(t,e,r,n,i,a){var s,l=h.texInfo;for(z.call(l),s=0;6>s;++s)g[s]=E();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(h,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],h),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)T(g[s],t,t);for(c(h,g[0]),h.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,h.internalformat=g[0].internalformat,f.width=g[0].width,f.height=g[0].height,P(h),s=0;6>s;++s)C(g[s],34069+s);for(I(l,34067),R(),o.profile&&(h.stats.size=k(h.internalformat,h.type,f.width,f.height,l.genMipmaps,!0)),f.format=tt[h.internalformat],f.type=et[h.type],f.mag=rt[l.magFilter],f.min=nt[l.minFilter],f.wrapS=it[l.wrapS],f.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return f}var h=new D(34067);mt[h.id]=h,a.cubeCount++;var g=Array(6);return f(e,r,n,i,s,l),f.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,h),a.width=0,a.height=0,p(a,e),a.width=a.width||(h.width>>i)-r,a.height=a.height||(h.height>>i)-n,P(h),d(a,34069+t,r,n,i),R(),M(a),f},f.resize=function(e){if((e|=0)!==h.width){f.width=h.width=e,f.height=h.height=e,P(h);for(var r=0;6>r;++r)for(var n=0;h.mipmask>>n;++n)t.texImage2D(34069+r,n,h.format,e>>n,e>>n,0,h.format,h.type,null);return R(),o.profile&&(h.stats.size=k(h.internalformat,h.type,f.width,f.height,!1,!0)),f}},f._reglType=\"textureCube\",f._texture=h,o.profile&&(f.stats=h.stats),f.destroy=function(){h.decRef()},f},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);I(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function f(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function h(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,M[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete M[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,M=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(M=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,T=null,S=null,C=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=f(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?T=u(x):s&&!c&&(T=f(a,o,M,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=f(a,o,!1,\"stencil\",\"uint8\")),k?C=u(k):!x&&!w&&c&&s&&(C=f(a,o,M,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(T),l(S),l(C),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=T,n.stencilAttachment=S,n.depthStencilAttachment=C,r.color=A.map(h),r.depth=h(T),r.stencil=h(S),r.depthStencil=h(C),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,M={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(M).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(M).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function T(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var f=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=f);var h=r.uniforms;for(l=0;l<f;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(h,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(h,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(f=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=f),h=r.attributes,l=0;l<f;++l)(c=t.getActiveAttrib(u,l))&&a(h,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},f={},h=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return h.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return h.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},h.forEach(function(e){t.deleteProgram(e.program)}),h.length=0,f={},r.shaderCount=0},program:function(t,e,n){var i=f[e];i||(i=f[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,h.push(a)),a},restore:function(){c={},u={};for(var t=0;t<h.length;++t)l(h[t])},shader:o,frag:-1,vert:-1}}function C(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return Y(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function E(t){return Array.prototype.slice.call(t)}function L(t){return E(t).join(\"\")}function z(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,E(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,E(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,E(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,E(arguments)),this},else:function(){return n.apply(n,E(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||Y(t)||l(t)}function I(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function P(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new D(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,f,h,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=z(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return P(a)&&P(o)?(s=f.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new D(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?P(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new D(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?P(a)?a?s?new D(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new D(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function M(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,f=0|r.stride,h=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=J[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=h,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=f,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,f=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",f,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",f,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",f,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[$[t],$[t]]:\"object\"==typeof t?[$[t.rgb],$[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Mt[e.fail||\"keep\"],Mt[e.zfail||\"keep\"],Mt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),f=s.viewport;return f&&(c.viewport=f),(s=s[f=m(\"scissor.box\")])&&(c[f]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=M(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function T(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function C(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,f;if(!((e=m(e))in r.state))if(e in s){n=s[e],f=o[e];var h=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(h.map(function(t,e){return t+\"!==\"+f+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",h,\");\",h.map(function(t,e){return f+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),h=t.cond(n,\"!==\",l,\".\",e),u(h),e in it?h(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):h(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function E(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;I(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];P(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var f=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return f+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(h,\".count+=\",i,\";\"):t(h,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",h,\");\"))}function s(t){t(h,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",h,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,f=t.shared,h=t.stats,p=f.current,g=f.timer;if(r=r.profile){if(P(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(f=t.block()),e(\"if(\",r,\"){\",f,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",f,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),K&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+h[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",h,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+h[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var f=i.buffer,h=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Tt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var f,h=(g=i[u]).name,p=g.info.type,d=n.uniforms[h],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(P(d)){if(h=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(h._texture||h.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",h=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(h)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(h)?Array.prototype.slice.call(h):h,\");\")}continue}f=d.append(t,r)}else{if(!o(Tt))continue;f=r.def(l.uniforms,\"[\",e.id(h),\"]\")}switch(35678===p?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===p&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),h=1,p){case 35678:case 35680:p=r.def(f,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",h=2;break;case 35668:case 35672:s=\"3i\",h=3;break;case 35669:case 35673:s=\"4i\",h=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",h=2;break;case 35665:s=\"3f\",h=3;break;case 35666:s=\"4f\",h=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<h?a(h,function(t){return f+\"[\"+t+\"]\"}):f);r(\");\")}}function V(t,e,r,n){function i(i){var a=h[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(f,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,f=c.draw,h=n.draw,p=function(){var i=h.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=h.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");K&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=h.elements&&P(h.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),K&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),V(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),V(t,e,e,r)}function W(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&T(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),E(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),V(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function Y(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;T(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),I(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(U.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(U.isDynamic(r))\"function\"==typeof r&&(r=n[e]=U.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new U.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];U.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,$={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&($.min=32775,$.max=32776);var K=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:h,elements:o,buffer:i,shader:f,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:$,stencilOps:Mt,glTypes:J,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),K&&(o=t.link(K));for(var f=0;f<n.maxAttributes;++f){var h=r.def(s.attributes,\"[\",f,\"]\"),p=t.cond(h,\".buffer\");p.then(l,\".enableVertexAttribArray(\",f,\");\",l,\".bindBuffer(\",34962,\",\",h,\".buffer.buffer);\",l,\".vertexAttribPointer(\",f,\",\",h,\".size,\",h,\".type,\",h,\".normalized,\",h,\".stride,\",h,\".offset);\").else(l,\".disableVertexAttribArray(\",f,\");\",l,\".vertexAttrib4f(\",f,\",\",h,\".x,\",h,\".y,\",h,\".z,\",h,\".w);\",h,\".buffer=null;\"),r(p),K&&r(o,\".vertexAttribDivisorANGLE(\",f,\",\",h,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,f=at[n],h=tt[n],p=t.block();p(l,\".\",f,\"(\"),v(h)?(f=h.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(f,function(t){return o+\"[\"+t+\"]\"}),\");\",a(f,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(f,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),T(t,r,e.context),S(t,r,e.framebuffer),C(t,r,e),E(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),Y(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(T(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),C(t,n,e),E(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)W(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)W(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(W,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,U={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},Y=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],f=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,f,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},$={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},J={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},K={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ft=m(\"HTMLImageElement\"),ht=m(\"HTMLVideoElement\"),pt=Object.keys($).concat([lt,ct,ut,ft,ht]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Mt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Tt=new D(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),f();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(z,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),$.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),P.restore(),I.restore(),R.restore(),F.restore(),V.restore(),w&&w.restore(),G.procs.refresh(),r(),J.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];U.isDynamic(i)?r[n]=U.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=Y.viewport,e=Y.scissor_box;t[0]=t[1]=e[0]=e[1]=0,z.viewportWidth=z.framebufferWidth=z.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,z.viewportHeight=z.framebufferHeight=z.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function f(){z.tick+=1,z.time=g(),u(),G.procs.poll()}function h(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var f=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[f],f=c[f],(u=c[u])===f?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=f,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),E=v.drawingBufferWidth,L=v.drawingBufferHeight,z={tick:0,time:0,viewportWidth:E,viewportHeight:L,framebufferWidth:E,framebufferHeight:L,drawingBufferWidth:E,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=W(v,_),I=(E=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new T;return{Record:T,scope:{},state:e}}(v,_,O),p(v,b,t,E)),D=d(v,_,I,b),P=S(v,x,b,t),R=M(v,_,O,function(){G.procs.poll()},z,b,t),F=mt(v,_,0,b,t),V=A(v,_,O,R,F,b),G=B(v,x,_,O,I,D,0,V,{},E,P,{elements:null,primitive:4,count:-1,offset:0,instances:-1},z,w,t),Y=(x=C(v,V,G.procs.poll,z),G.next),X=v.canvas,Z=[],$=[],J=[],K=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=V.setFBO=s({framebuffer:U.define.call(null,1,\"framebuffer\")});return h(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:U.define.bind(null,1),context:U.define.bind(null,2),this:U.define.bind(null,3),draw:s({}),buffer:function(t){return I.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:V.create,framebufferCube:V.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=$;break;case\"restore\":r=J;break;case\"destroy\":r=K}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),P.clear(),V.clear(),F.clear(),R.clear(),D.clear(),I.clear(),w&&w.clear(),K.forEach(function(t){t()})},_gl:v,_refresh:h,poll:function(){f(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],481:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],482:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],483:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],484:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<s;)f.push(u(f.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,f.concat([f,u])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{\"robust-compress\":483,\"robust-scale\":490,\"robust-sum\":493,\"two-product\":521}],485:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":493,\"two-product\":521}],486:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function f(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(f(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,f(l(s,u))):r.push.apply(r,f(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",h(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":490,\"robust-subtract\":492,\"robust-sum\":493,\"two-product\":521}],487:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":484}],488:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),f=[],h=0;h<t;++h)0==(1&h)?e.push.apply(e,u(l(s,h))):r.push.apply(r,u(l(s,h))),f.push(\"m\"+h);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",f.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var h=f(3),p=f(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:h(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],f=e[2]-n[2],h=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+f*(v-m)+h*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(f)+(Math.abs(y)+Math.abs(x))*Math.abs(h));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(f(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=f(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":490,\"robust-subtract\":492,\"robust-sum\":493,\"two-product\":521}],489:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":490,\"robust-sum\":493}],490:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var f=s[1];i(f,l[0],s),s[0]&&(o[c++]=s[0]);var h=l[1],p=s[1],d=h+p,g=d-h,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":521,\"two-sum\":522}],491:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],f=Math.min(c,u),h=Math.max(c,u);if(h<s||l<f)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":488}],492:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=-e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],493:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],494:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],495:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":84,\"reduce-simplicial-complex\":475}],496:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,f=0;f<e;++f)for(var h=0;h<f;++h){var p=u[h],d=u[f];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var f=o[2*u],h=o[2*u+1];if(r[f]!==r[h]){var p=e[f],d=e[h];o[2*c]=f,o[2*c+1]=h,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),f=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),h=o(s)(t,c.data,f,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(f),{cells:h,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":497,ndarray:436,\"ndarray-sort\":434,\"typedarray-pool\":523}],497:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":413,\"typedarray-pool\":523}],498:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var f=e.slice(0);f.sort();for(var h=0;h<r;++h)if(n=u[h]-f[h])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],f=u.length,h=1,p=1<<f;h<p;++h){s.length=n.popCount(h);for(var d=0,g=0;g<f;++g)h&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function f(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,f=0;f<o.length;++f)l&1<<f&&(c[u++]=o[f]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(f(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=f,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(f(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),h=o+1;h<a.length;++h)r.link(u,c(e,[a[h]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":81,\"union-find\":524}],499:[function(t,e,r){arguments[4][81][0].apply(r,arguments)},{dup:81}],500:[function(t,e,r){arguments[4][498][0].apply(r,arguments)},{\"bit-twiddle\":499,dup:498,\"union-find\":501}],501:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],502:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),f=0;f<a;++f)s[f]=l[f]=-1,c[f]=1/0,u[f]=!1;for(var f=0;f<o;++f){var h=t[f];if(2!==h.length)throw new Error(\"Input must be a graph\");var p=h[1],d=h[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,f=s[t],h=l[t];return f<0||h<0?1/0:(r=e[t],i=e[f],a=e[h],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=M[t],n=M[e];M[t]=n,M[e]=r,A[r]=e,A[n]=t}function m(t){return c[M[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=M[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=M[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var M=[],A=new Array(a),f=0;f<a;++f){var T=c[f]=g(f);T<1/0?(A[f]=M.length,M.push(f)):A[f]=-1}for(var S=M.length,f=S>>1;f>=0;--f)x(f);for(;;){var C=_();if(C<0||c[C]>r)break;k(C)}for(var E=[],f=0;f<a;++f)u[f]||(A[f]=E.length,E.push(e[f].slice()));E.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var z=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&z.push([n,i])}}),i.unique(i.normalize(z)),{positions:E,edges:z}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":488,\"simplicial-complex\":500}],503:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var f=n(i,r,a);return f||((f=n(i,r,o))||o-i)}},{\"robust-orientation\":488}],504:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new f(l[0][0],l,c,a),n[2*a+1]=new f(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var h=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):h=y.create?h.insert(y.segment,y.index):h.remove(y.segment)}p.push(h.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function f(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var f=this.horizontal[e];if(f.length>0){var h=n.ge(f,t[1],l);if(h<f.length){var p=f[h];if(t[1]===p.y){if(p.closed)return p.index;for(;h<f.length-1&&f[h+1].y===t[1];)if((p=f[h+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((h+=1)>=f.length)return i;p=f[h]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":503,\"binary-search-bounds\":80,\"functional-red-black-tree\":220,\"robust-orientation\":488}],505:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var f=o(s,u,l,i);r.push(f),n.push(f.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":485,\"robust-sum\":493}],506:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,f,h,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(f=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||f&&!s.sign?h=\"\":(h=f?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(h+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?h+i+l:\"0\"===c?h+l+i:l+h+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],507:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:444}],508:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,f=[],h=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=f.length,x===e){l.length=d;break}}f.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];h.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<h.length;l++){var d=h[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);h[l]=c}}return{components:f,adjacencyList:h}}},{}],509:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var f=[],h=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),h=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){f.length>0&&h.push(\"}}\");var p=\"vExtra\"+f.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),h=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],f.push(h)}h.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var M=[],b=0;b<r;++b)if(0===d[b].length)M.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var T=d[b].length/y*.5,S=.5+m[b]/y*.5;M.push(\"d\"+b+\"-\"+S+\"-\"+T+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}h.push(\"a.push([\",M.join(),\"]);\",\"break;\")}a.push(\"}},\"),f.length>0&&h.push(\"}}\");for(var C=[],c=0;c<1<<r-1;++c)C.push(\"v\"+c);C.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",C.join(),\"){\");var E=i(r-1);a.push(\"if(p0){b.push(\",E.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",E.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<f.length;++c)a.push(f[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":425,\"triangulate-hypercube\":519,\"zero-crossings\":552}],510:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494,n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,f=t.ry,h=t.xAxisRotation,p=void 0===h?0:h,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===f)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),f=Math.abs(f);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(f,2);k>1&&(u*=Math.sqrt(k),f*=Math.sqrt(k));var M=function(t,e,r,n,a,o,l,c,u,f,h,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(h,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*h,_=f*x-u*b+(t+r)/2,w=u*x+f*b+(e+n)/2,k=(h-x)/a,M=(p-b)/o,A=(-h-x)/a,T=(-p-b)/o,S=s(1,0,k,M),C=s(k,M,A,T);return 0===c&&C>0&&(C-=i),1===c&&C<0&&(C+=i),[_,w,S,C]}(e,r,l,c,u,f,g,m,x,b,_,w),A=n(M,4),T=A[0],S=A[1],C=A[2],E=A[3],L=Math.abs(E)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var z=Math.max(Math.ceil(L),1);E/=z;for(var O=0;O<z;O++)y.push(o(C,E)),C+=E;return y.map(function(t){var e=a(t[0],u,f,b,x,T,S),r=e.x,n=e.y,i=a(t[1],u,f,b,x,T,S),o=i.x,s=i.y,l=a(t[2],u,f,b,x,T,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],511:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":49,assert:57,\"is-svg-path\":410,\"normalize-svg-path\":512,\"parse-svg-path\":446}],512:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,f=null,h=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:h,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=h,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*h-u,f=2*p-f):(u=h,f=p),v=a(h,p,u,f,v[1],v[2]);break;case\"Q\":u=v[1],f=v[2],v=a(h,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(h,p,v[1],v[2]);break;case\"H\":v=i(h,p,v[1],p);break;case\"V\":v=i(h,p,h,v[1]);break;case\"Z\":v=i(h,p,l,c)}e=m,h=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=h,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":510}],513:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,f;e.shape?(r=e.shape[0],f=e.shape[1]):(r=c.width=e.w||e.width||200,f=c.height=e.h||e.height||200);var h=Math.min(r,f),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),f/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,f),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*f),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*h})}},{\"bitmap-sdf\":82,\"draw-svg-path\":154,\"is-svg-path\":410,\"parse-svg-path\":446,\"svg-path-bounds\":511}],514:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,f=0,h=0;h<l.length;++h)c[h]=t(e,l[h]),u+=c[h].data.length,f+=c[h].shape,h>0&&(f+=.02);for(var p=new Float32Array(u),d=0,g=-.5*f,h=0;h<c.length;++h){for(var v=c[h].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[h].shape+.02}s=o[r]={data:p,shape:f}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:468,\"vectorize-text\":528}],515:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,f=!1,h=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(V(e.r)&&V(e.g)&&V(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},f=!0,h=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):V(e.h)&&V(e.s)&&V(e.v)?(l=D(e.s),c=D(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),f=!0,h=\"hsv\"):V(e.h)&&V(e.s)&&V(e.l)&&(l=D(e.s),u=D(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),f=!0,h=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=E(a),{ok:f,format:e.format||h,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function f(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function h(t,e,r,n){var i=[I(a(t).toString(16)),I(a(e).toString(16)),I(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[I(P(n)),I(a(t).toString(16)),I(a(e).toString(16)),I(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=z(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=z(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=z(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=z(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function M(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function T(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=E(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=f(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=f(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return h(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[I(a(t).toString(16)),I(a(e).toString(16)),I(a(r).toString(16)),I(P(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(C[h(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(T,arguments)},splitcomplement:function(){return this._applyCombination(M,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:D(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},C=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function E(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function z(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function I(t){return 1==t.length?\"0\"+t:\"\"+t}function D(t){return t<=1&&(t=100*t+\"%\"),t}function P(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function V(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],516:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],517:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":447}],518:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>f&&(f=l[0]),l[1]<u&&(u=l[1]),l[1]>h&&(h=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,f=-c,h=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>f&&(f=l[0]),l[1]<u&&(u=l[1]),l[1]>h&&(h=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,f,h]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var f=c+1;f<l;++f){var h,p=s[c],d=s[f];(h=r[p])[o=u(h,d)]!==d&&h.splice(o,0,d),(h=r[d])[o=u(h,p)]!==p&&h.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,f=t[0],h=f[0]=Math.round((f[0]-a)/o),p=f[1]=Math.round((f[1]-s)/l);i<u;++i)f=t[i],r=Math.round((f[0]-a)/o),n=Math.round((f[1]-s)/l),r===h&&n===p||((e=t[c++])[0]=r-h,h=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],519:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:221,\"permutation-parity\":449,\"permutation-rank\":450}],520:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||f(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=f(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new h(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function f(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function h(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=h.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var f=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=f;var h=this.computedToward;o(h,e,r),s(h,h);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,M=-v*x,A=-m*x,T=y,S=this.computedEye,C=this.computedMatrix;for(a=0;a<3;++a){var E=_*r[a]+w*h[a]+k*e[a];C[4*a+1]=M*r[a]+A*h[a]+T*e[a],C[4*a+2]=E,C[4*a+3]=0}var L=C[1],z=C[5],O=C[9],I=C[2],D=C[6],P=C[10],R=z*P-O*D,F=O*I-L*P,B=L*D-z*I,N=c(R,F,B);R/=N,F/=N,B/=N,C[0]=R,C[4]=F,C[8]=B;for(a=0;a<3;++a)S[a]=b[a]+C[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=C[a+4*j]*S[j];C[12+a]=-u}C[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=c(u-=a*p,f-=o*p,h-=s*p),g=(u/=d)*e+a*r,v=(f/=d)*e+o*r,m=(h/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],f=e[a+8];if(n){var h=Math.abs(s),p=Math.abs(l),d=Math.abs(f),g=Math.max(h,p,d);h===g?(s=s<0?-1:1,l=f=0):d===g?(f=f<0?-1:1,s=l=0):(l=l<0?-1:1,s=f=0)}else{var v=c(s,l,f);s/=v,l/=v,f/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*f,k=c(x-=s*w,b-=l*w,_-=f*w),M=l*(_/=k)-f*(b/=k),A=f*(x/=k)-s*_,T=s*b-l*x,S=c(M,A,T);if(M/=S,A/=S,T/=S,this.center.jump(t,H,G,W),this.radius.idle(t),this.up.jump(t,s,l,f),this.right.jump(t,x,b,_),2===a){var C=e[1],E=e[5],L=e[9],z=C*x+E*b+L*_,O=C*M+E*A+L*T;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,z)}else{var I=e[2],D=e[6],P=e[10],R=I*s+D*l+P*f,F=I*x+D*b+P*_,B=I*M+D*A+P*T;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],V=e[10],U=this.computedMatrix;i(U,e);var q=U[15],H=U[12]/q,G=U[13]/q,W=U[14]/q,Y=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*Y,G-j*Y,W-V*Y)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],f=e[1]-r[1],h=e[2]-r[2],p=c(l,f,h);if(!(p<1e-6)){l/=p,f/=p,h/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*h-o*f,v=o*l-i*h,m=i*f-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),M=i*l+a*f+o*h,A=g*l+v*f+m*h,T=(b/=k)*l+(_/=k)*f+(w/=k)*h,S=Math.asin(u(M)),C=Math.atan2(T,A),E=this.angle._state,L=E[E.length-1],z=E[E.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-C),I=Math.abs(L-C),D=Math.abs(L-2*Math.PI-C);O<I&&(L+=2*Math.PI),D<I&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,z),this.angle.set(t,C,S)}}}}},{\"filtered-vector\":216,\"gl-mat4/invert\":256,\"gl-mat4/rotate\":260,\"gl-vec3/cross\":320,\"gl-vec3/dot\":325,\"gl-vec3/normalize\":342}],521:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,f=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=f,r[1]=i,r;return[f,i]};var n=+(Math.pow(2,27)+1)},{}],522:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],523:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function f(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function h(t){return new Uint8Array(f(t),0,t)}function p(t){return new Uint16Array(f(2*t),0,t)}function d(t){return new Uint32Array(f(4*t),0,t)}function g(t){return new Int8Array(f(t),0,t)}function v(t){return new Int16Array(f(2*t),0,t)}function m(t){return new Int32Array(f(4*t),0,t)}function y(t){return new Float32Array(f(4*t),0,t)}function x(t){return new Float64Array(f(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(f(t),0,t):h(t)}function _(t){return new DataView(f(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return f(t);switch(e){case\"uint8\":return h(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=f,r.mallocUint8=h,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":81,buffer:94,dup:156}],524:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],526:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],527:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],528:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":529}],529:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(f,h,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,M,A,T,S=_.split(\"\\n\"),C=S.length,E=Math.round(a*n),L=n,z=2*n,O=0,I=C*E+z;t.height<I&&(t.height=I),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var D=0,P=\"\";function R(){if(\"\"!==P){var t=e.measureText(P).width;e.fillText(P,L+M,z+A),M+=t}}function F(){return Math.round(T)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),T*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*E*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),f=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=f>-1?parseInt(r[1+f]):0;p!==g&&(n=n.replace(F(),\"?px \"),T*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*E*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(h)>-1,b=r.indexOf(h)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<C;++w){var N=S[w]+\"\\n\";for(M=0,A=w*E,T=n,P=\"\",k=0;k<N.length;++k){var j=k+D<b.length?b[k+D]:b[b.length-1];s===j?P+=N[k]:(R(),P=N[k],void 0!==j&&(B(s,j),s=j))}R(),D+=N.length;var V=0|Math.round(M+2*L);O<V&&(O=V)}var U=O,q=z+E*C;return i(e.getImageData(0,0,U,q).data,[q,U,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",f=\"i\",h=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var f=c;f<u+s;++f)if(f<c+o||f>=u)n[f]=null,r=r.substr(0,f)+\" \"+r.substr(f+1);else if(null!==n[f]){var h=n[f].indexOf(e[0]);-1===h?n[f]+=e:l&&(n[f]=n[f].substr(0,h+1)+(1+parseInt(n[f][h+1]))+n[f].substr(h+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var f=0;switch(n){case\"center\":f=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":f=-o[0];break;case\"left\":case\"start\":f=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var h=0;switch(i){case\"hanging\":case\"top\":h=-a[1];break;case\"middle\":h=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":h=-3*r;break;case\"bottom\":h=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+f),p*(t[1]+h)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var f=l(c,a),h=new Array(f.length),p=0;p<f.length;++p){for(var d=f[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}h[p]=g}return h}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:95,\"clean-pslg\":105,ndarray:436,\"planar-graph-to-polyline\":454,\"simplify-planar-graph\":502,\"surface-nets\":509}],530:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),f=new Uint8Array(u);crypto.getRandomValues(f),c=l+\"rand:\"+Array.prototype.map.call(f,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var h=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return h(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],531:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":532}],532:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],533:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":531}],534:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":222}],535:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),f[t-f[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=h[o-h[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var f=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(f/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=f[t-f[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=f[o.year-f[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=h[o.year-h[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=h[i.year-h[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=h[a.year-h[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=f[a.year-f[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),f=this.isIntercalaryMonth(c,s),h=a&&f?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);h!==u&&l.month(h)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var f=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],h=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":549,\"object-assign\":440}],536:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":549,\"object-assign\":440}],537:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":549,\"object-assign\":440}],538:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":549,\"object-assign\":440}],539:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":549,\"object-assign\":440}],540:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":549,\"object-assign\":440}],541:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":549,\"object-assign\":440}],542:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":549,\"object-assign\":440}],543:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":549,\"object-assign\":440}],544:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":549,\"object-assign\":440}],545:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),f=t-this.toJD(l,u,1)+1;return this.newDate(l,u,f)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":549,\"object-assign\":440}],546:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":549,\"object-assign\":440}],547:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":549,\"object-assign\":440}],548:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":549,\"object-assign\":440}],549:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":440}],550:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,f=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]:\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,f=-1,h=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;T+n<t.length&&t.charAt(T+n)===e;)n++;return T+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},M=function(){if(e.charAt(A)!==t.charAt(T))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,T=0;T<t.length;T++)if(m)\"'\"!==t.charAt(T)||y(\"'\")?M():m=!1;else switch(t.charAt(T)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=T;v=!y(\"y\",2),T=S,h=x(\"y\",2);break;case\"Y\":h=x(\"Y\",2);break;case\"J\":f=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":f=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":f=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?M():m=!0;break;default:M()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===h?h=this.today().year():h<100&&v&&(h+=-1===n?1900:this.today().year()-this.today().year()%100-(h<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,h,p)),g>-1){p=1,d=g;for(var C=this.daysInMonth(h,p);d>C;C=this.daysInMonth(h,p))p++,d-=C}return f>-1?this.fromJD(f):this.newDate(h,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":549,\"object-assign\":440}],551:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":135}],552:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":551}],553:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],554:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":732,\"../../plots/cartesian/constants\":748,\"../../plots/font_attributes\":769,\"./arrow_paths\":553}],555:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],f=t[\"_\"+a+\"padminus\"],h={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+h,g=p-h,v=3*t.startarrowsize*t.arrowwidth||0,m=v+h,y=v-h;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(f,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(f,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"./draw\":560}],556:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,f=[],h=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?h:p:f).push(r);break}n===d&&i.visible&&\"onout\"===a&&h.push(r)}return{on:f,off:h,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),f={},h=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",h[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(f,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",h[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(f,s.getUpdateObj());return i.call(\"update\",t,{},f)}}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../registry\":825}],557:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var f,h,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(f=a(\"arrowhead\"),h=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",f),a(\"startarrowsize\",h)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":694,\"../color\":571}],558:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,f=e._id.charAt(0),h=0;h<u.length;h++)l=u[h],c=\"annotations[\"+h+\"].\",l[f+\"ref\"]===e._id&&p(f),l[\"a\"+f+\"ref\"]===e._id&&p(\"a\"+f);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":720,\"fast-isnumeric\":215}],559:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,f=[\"x\",\"y\"],h=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=f[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?h[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../../plots/cartesian/axes\":742,\"./attributes\":554,\"./common_defaults\":557}],560:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{};m(t,r,e,!1,s.getFromId(t,r.xref),s.getFromId(t,r.yref))}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,M=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var T=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},C=+e.textangle||0,E=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=E.append(\"g\").classed(\"annotation-text-g\",!0),z=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||z,I=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(h,\"pointer\").on(\"click\",function(){t._dragging=!1;var i={index:r,annotation:e._input,fullAnnotation:e,event:n.event};a&&(i.subplotId=a),t.emit(\"plotly_clickannotation\",i)});e.hovertext&&I.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var D=e.borderwidth,P=e.borderpad,R=D+P,F=I.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",D+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+T).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",T).append(\"rect\"),N.exit().remove();var j=e.font,V=x.meta?o.templateString(e.text,{meta:x.meta}):e.text,U=I.append(\"text\").classed(\"annotation-text\",!0).text(V);_.annotationText?U.call(f.makeEditable,{delegate:I,gd:t}).call(q).on(\"edit\",function(r){e.text=r,this.call(q),M(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):U.call(q)}else n.selectAll(\"#\"+T).remove();function q(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),f.convertToTspans(r,t,H),r}function H(){var r=U.selectAll(\"a\");1===r.size()&&r.text()===U.text()&&I.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=I.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:U).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,P=Math.round(w+2*R),j=Math.round(O+2*R);function V(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var q=!1,H=[\"x\",\"y\"],G=0;G<H.length;G++){var W,Y,X,Z,$,J=H[G],K=e[J+\"ref\"]||J,Q=e[\"a\"+J+\"ref\"],tt={x:s,y:v}[J],et=(C+(\"x\"===J?0:-90))*Math.PI/180,rt=P*Math.cos(et),nt=j*Math.sin(et),it=Math.abs(rt)+Math.abs(nt),at=e[J+\"anchor\"],ot=e[J+\"shift\"]*(\"x\"===J?1:-1),st=S[J];if(tt){var lt=tt.r2fraction(e[J]);(lt<0||lt>1)&&(Q===K?((lt=tt.r2fraction(e[\"a\"+J]))<0||lt>1)&&(q=!0):q=!0),W=tt._offset+tt.r2p(e[J]),Z=.5}else\"x\"===J?(X=e[J],W=b.l+b.w*X):(X=1-e[J],W=b.t+b.h*X),Z=e.showarrow?.5:X;if(e.showarrow){st.head=W;var ct=e[\"a\"+J];$=rt*V(.5,e.xanchor)-nt*V(.5,e.yanchor),Q===K?(st.tail=tt._offset+tt.r2p(ct),Y=$):(st.tail=W+ct,Y=$+ct),st.text=st.tail+$;var ut=x[\"x\"===J?\"width\":\"height\"];if(\"paper\"===K&&(st.head=o.constrain(st.head,1,ut-1)),\"pixel\"===Q){var ft=-Math.max(st.tail-3,st.text),ht=Math.min(st.tail+3,st.text)-ut;ft>0?(st.tail+=ft,st.text+=ft):ht>0&&(st.tail-=ht,st.text-=ht)}st.tail+=ot,st.head+=ot}else Y=$=it*V(Z,at),st.text=W+$;st.text+=ot,$+=ot,Y+=ot,e[\"_\"+J+\"padplus\"]=it/2+Y,e[\"_\"+J+\"padminus\"]=it/2-Y,e[\"_\"+J+\"size\"]=it,e[\"_\"+J+\"shift\"]=$}if(t._dragging||!q){var pt=0,dt=0;if(\"left\"!==e.align&&(pt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(dt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+pt-1,y:R+dt}).call(c.setClipUrl,B?T:null,t);else{var gt=R+dt-d.top,vt=R+pt-d.left;U.call(f.positionText,vt,gt).call(c.setClipUrl,B?T:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,D/2,D/2,P-D,j-D),I.call(c.setTranslate,Math.round(S.x.text-P/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+C+\",\"+S.x.text+\",\"+S.y.text+\")\"});var mt,yt=function(r,n){E.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,f=S.y.head,h=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(C,m,y),w=o.apply2DTransform(x),T=o.apply2DTransform2(x),z=+F.attr(\"width\"),O=+F.attr(\"height\"),D=m-.5*z,P=D+z,R=y-.5*O,B=R+O,N=[[D,R,D,B],[D,B,P,B],[P,B,P,R],[P,R,D,R]].map(T);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,f,u+1e6,f+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(h,d,u,f,t[0],t[1],t[2],t[3]);e&&(h=e.x,d=e.y)});var j=e.arrowwidth,V=e.arrowcolor,U=e.arrowside,q=E.append(\"g\").style({opacity:l.opacity(V)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+h+\",\"+d+\"L\"+u+\",\"+f).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(V));if(g(H,U,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,W=f;if(e.standoff){var Y=Math.sqrt(Math.pow(u-h,2)+Math.pow(f-d,2));G+=e.standoff*(h-u)/Y,W+=e.standoff*(d-f)/Y}var X,Z,$=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(h-G)+\",\"+(d-W),transform:\"translate(\"+G+\",\"+W+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:$.node(),gd:t,prepFn:function(){var t=c.getTranslate(I);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;I.call(c.setTranslate,i,a),M(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),M(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&M(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&M(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+C+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&yt(0,0),z)p.init({element:I.node(),gd:t,prepFn:function(){mt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?M(\"ax\",s.p2r(s.r2p(e.ax)+t)):M(\"ax\",e.ax+t),e.ayref===e.yref?M(\"ay\",v.p2r(v.r2p(e.ay)+r)):M(\"ay\",e.ay+r),yt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,f=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(f-r/b.h,u,0,1,e.yanchor)}M(\"x\",i),M(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+mt}),h(I,n)},doneFn:function(){h(I),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else I.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":694,\"../../lib/setcursor\":714,\"../../lib/svg_text_utils\":718,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/axes\":742,\"../../plots/plots\":806,\"../../registry\":825,\"../color\":571,\"../dragelement\":589,\"../drawing\":592,\"../fx\":610,\"./draw_arrow_head\":561,d3:149}],561:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),f=a[r.arrowhead||0],h=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=f.backoff*p+r.standoff,y=h.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void z();if(m){if(m*m>x*x+b*b)return void z();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void z();var k=y*Math.cos(l),M=y*Math.sin(l);o.x-=k,o.y-=M,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),T=\"\";if(A<m+y)return void z();var S=u.getPointAtLength(0),C=u.getPointAtLength(.1);l=Math.atan2(S.y-C.y,S.x-C.x),o=u.getPointAtLength(Math.min(y,A)),T=\"0px,\"+y+\"px,\";var E=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(E.y-L.y,E.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),T+=A-(T?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",T)}function z(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(h,o,l,d),v&&O(f,s,c,p)}},{\"../color\":571,\"./arrow_paths\":553,d3:149}],562:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":753,\"./attributes\":554,\"./calc_autorange\":555,\"./click\":556,\"./convert_coords\":558,\"./defaults\":559,\"./draw\":560}],563:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":725,\"../../plot_api/plot_template\":732,\"../annotations/attributes\":554}],564:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742}],565:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../../plots/cartesian/axes\":742,\"../annotations/common_defaults\":557,\"./attributes\":563}],566:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var f=a[u],h=l[f],p=e[f+\"axis\"].r2fraction(h);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":794,\"../annotations/draw\":560}],567:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":694,\"../../registry\":825,\"./attributes\":563,\"./convert\":564,\"./defaults\":565,\"./draw\":566}],568:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":535,\"world-calendars/dist/calendars/coptic\":536,\"world-calendars/dist/calendars/discworld\":537,\"world-calendars/dist/calendars/ethiopian\":538,\"world-calendars/dist/calendars/hebrew\":539,\"world-calendars/dist/calendars/islamic\":540,\"world-calendars/dist/calendars/julian\":541,\"world-calendars/dist/calendars/mayan\":542,\"world-calendars/dist/calendars/nanakshahi\":543,\"world-calendars/dist/calendars/nepali\":544,\"world-calendars/dist/calendars/persian\":545,\"world-calendars/dist/calendars/taiwan\":546,\"world-calendars/dist/calendars/thai\":547,\"world-calendars/dist/calendars/ummalqura\":548,\"world-calendars/dist/main\":549,\"world-calendars/dist/plus\":550}],569:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",f={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var h={};function p(t){var e=h[t];return e||(e=h[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,h=Math.floor((e+.05)/s)+o,d=p(r).fromJD(h),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=f[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":671,\"../../lib\":694,\"./calendars\":568}],570:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],571:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":570,\"fast-isnumeric\":215,tinycolor2:515}],572:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/cartesian/layout_attributes\":755,\"../../plots/font_attributes\":769}],573:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"../colorscale/helpers\").flipScale;e.exports=function(t,e,r){if(\"function\"==typeof r)return r(t,e);var a=e[0].trace,o=\"cb\"+a.uid;r=Array.isArray(r)?r:[r];for(var s=0;s<r.length;s++){var l=r[s].container,c=l?a[l]:a;if(t._fullLayout._infolayer.selectAll(\".\"+o).remove(),c&&c.showscale){var u=e[0].t.cb=n(t,o),f=c.reversescale?i(c.colorscale):c.colorscale;return void u.fillgradient(f).zrange([c[r[s].min],c[r[s].max]]).options(c.colorbar)()}}}},{\"../colorscale/helpers\":582,\"./draw\":576}],574:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],575:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function f(t,e){return n.coerce(u,c,l,t,e)}var h=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===h?30/(r.width-r.margin.l-r.margin.r):30);var p=f(\"lenmode\");f(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),f(\"x\"),f(\"xanchor\"),f(\"xpad\"),f(\"y\"),f(\"yanchor\"),f(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\"),a(u,c,f,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,f,\"linear\",d),o(u,c,f,\"linear\",d),f(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(f,\"title.font\",r.font),f(\"title.side\")}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/tick_label_defaults\":762,\"../../plots/cartesian/tick_mark_defaults\":763,\"../../plots/cartesian/tick_value_defaults\":764,\"./attributes\":572}],576:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../lib/setcursor\"),h=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../../constants/alignment\"),m=v.LINE_SPACING,y=v.FROM_TL,x=v.FROM_BR,b=t(\"../../plots/cartesian/axis_defaults\"),_=t(\"../../plots/cartesian/position_defaults\"),w=t(\"../../plots/cartesian/layout_attributes\"),k=t(\"./attributes\"),M=t(\"./constants\").cn;e.exports=function(t,e){var r={};for(var v in k)r[v]=null;function A(){var v=t._fullLayout,k=v._size;if(\"function\"==typeof r.fillcolor||\"function\"==typeof r.line.color||r.fillgradient){var C,E,L=r.zrange||n.extent((\"function\"==typeof r.fillcolor?r.fillcolor:r.line.color).domain()),z=[],O=[],I=\"function\"==typeof r.line.color?r.line.color:function(){return r.line.color},D=\"function\"==typeof r.fillcolor?r.fillcolor:function(){return r.fillcolor},P=r.levels.end+r.levels.size/100,R=r.levels.size,F=1.001*L[0]-.001*L[1],B=1.001*L[1]-.001*L[0];for(E=0;E<1e5&&(C=r.levels.start+E*R,!(R>0?C>=P:C<=P));E++)C>F&&C<B&&z.push(C);if(r.fillgradient)O=[0];else if(\"function\"==typeof r.fillcolor)if(r.filllevels)for(P=r.filllevels.end+r.filllevels.size/100,R=r.filllevels.size,E=0;E<1e5&&(C=r.filllevels.start+E*R,!(R>0?C>=P:C<=P));E++)C>L[0]&&C<L[1]&&O.push(C);else(O=z.map(function(t){return t-r.levels.size/2})).push(O[O.length-1]+r.levels.size);else r.fillcolor&&\"string\"==typeof r.fillcolor&&(O=[0]);r.levels.size<0&&(z.reverse(),O.reverse());var N,j=k.h,V=k.w,U=Math.round(r.thickness*(\"fraction\"===r.thicknessmode?V:1)),q=U/k.w,H=Math.round(r.len*(\"fraction\"===r.lenmode?j:1)),G=H/k.h,W=r.xpad/k.w,Y=(r.borderwidth+r.outlinewidth)/2,X=r.ypad/k.h,Z=Math.round(r.x*k.w+r.xpad),$=r.x-q*({middle:.5,right:1}[r.xanchor]||0),J=r.y+G*(({top:-.5,bottom:.5}[r.yanchor]||0)-.5),K=Math.round(k.h*(1-J)),Q=K-H,tt={type:\"linear\",range:L,tickmode:r.tickmode,nticks:r.nticks,tick0:r.tick0,dtick:r.dtick,tickvals:r.tickvals,ticktext:r.ticktext,ticks:r.ticks,ticklen:r.ticklen,tickwidth:r.tickwidth,tickcolor:r.tickcolor,showticklabels:r.showticklabels,tickfont:r.tickfont,tickangle:r.tickangle,tickformat:r.tickformat,exponentformat:r.exponentformat,separatethousands:r.separatethousands,showexponent:r.showexponent,showtickprefix:r.showtickprefix,tickprefix:r.tickprefix,showticksuffix:r.showticksuffix,ticksuffix:r.ticksuffix,title:r.title,showline:!0,anchor:\"free\",side:\"right\",position:1},et={type:\"linear\",_id:\"y\"+e},rt={letter:\"y\",font:v.font,noHover:!0,noTickson:!0,calendar:v.calendar};if(b(tt,et,yt,rt,v),_(tt,et,yt,rt),et.position=r.x+W+q,A.axis=et,-1!==[\"top\",\"bottom\"].indexOf(r.title.side)&&(et.title.side=r.title.side,et.titlex=r.x+W,et.titley=J+(\"top\"===r.title.side?G-X:X)),r.line.color&&\"auto\"===r.tickmode){et.tickmode=\"linear\",et.tick0=r.levels.start;var nt=r.levels.size,it=c.constrain((K-Q)/50,4,15)+1,at=(L[1]-L[0])/((r.nticks||it)*nt);if(at>1){var ot=Math.pow(10,Math.floor(Math.log(at)/Math.LN10));nt*=ot*c.roundUp(at/ot,[2,5,10]),(Math.abs(r.levels.start)/r.levels.size+1e-6)%1<2e-6&&(et.tick0=0)}et.dtick=nt}et.domain=[J+X,J+G-X],et.setScale();var st=c.ensureSingle(v._infolayer,\"g\",e,function(t){t.classed(M.colorbar,!0).each(function(){var t=n.select(this);t.append(\"rect\").classed(M.cbbg,!0),t.append(\"g\").classed(M.cbfills,!0),t.append(\"g\").classed(M.cblines,!0),t.append(\"g\").classed(M.cbaxis,!0).classed(M.crisp,!0),t.append(\"g\").classed(M.cbtitleunshift,!0).append(\"g\").classed(M.cbtitle,!0),t.append(\"rect\").classed(M.cboutline,!0),t.select(\".cbtitle\").datum(0)})});st.attr(\"transform\",\"translate(\"+Math.round(k.l)+\",\"+Math.round(k.t)+\")\");var lt=st.select(\".cbtitleunshift\").attr(\"transform\",\"translate(-\"+Math.round(k.l)+\",-\"+Math.round(k.t)+\")\"),ct=st.select(\".cbaxis\"),ut=0;if(-1!==[\"top\",\"bottom\"].indexOf(r.title.side)){var ft,ht=k.l+(r.x+W)*k.w,pt=et.title.font.size;ft=\"top\"===r.title.side?(1-(J+G-X))*k.h+k.t+3+.75*pt:(1-(J+X))*k.h+k.t-3-.25*pt,xt(et._id+\"title\",{attributes:{x:ht,y:ft,\"text-anchor\":\"start\"}})}var dt,gt,vt,mt=c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(r.title.side)){var a=st.select(\".cbtitle\"),o=a.select(\"text\"),l=[-r.outlinewidth/2,r.outlinewidth/2],u=a.select(\".h\"+et._id+\"title-math-group\").node(),f=15.6;if(o.node()&&(f=parseInt(o.node().style.fontSize,10)*m),u?(ut=h.bBox(u).height)>f&&(l[1]-=(ut-f)/2):o.node()&&!o.classed(M.jsPlaceholder)&&(ut=h.bBox(o.node()).height),ut){if(ut+=5,\"top\"===r.title.side)et.domain[1]-=ut/k.h,l[1]*=-1;else{et.domain[0]+=ut/k.h;var p=g.lineCount(o);l[1]+=(1-p)*f}a.attr(\"transform\",\"translate(\"+l+\")\"),et.setScale()}}st.selectAll(\".cbfills,.cblines\").attr(\"transform\",\"translate(0,\"+Math.round(k.h*(1-et.domain[1]))+\")\"),ct.attr(\"transform\",\"translate(0,\"+Math.round(-k.t)+\")\");var d=st.select(\".cbfills\").selectAll(\"rect.cbfill\").data(O);d.enter().append(\"rect\").classed(M.cbfill,!0).style(\"stroke\",\"none\"),d.exit().remove();var y=L.map(et.c2p).map(Math.round).sort(function(t,e){return t-e});d.each(function(a,o){var s=[0===o?L[0]:(O[o]+O[o-1])/2,o===O.length-1?L[1]:(O[o]+O[o+1])/2].map(et.c2p).map(Math.round);s[1]=c.constrain(s[1]+(s[1]>s[0])?1:-1,y[0],y[1]);var l=n.select(this).attr({x:Z,width:Math.max(U,2),y:n.min(s),height:Math.max(n.max(s)-n.min(s),2)});if(r.fillgradient)h.gradient(l,t,e,\"vertical\",r.fillgradient,\"fill\");else{var u=D(a).replace(\"e-\",\"\");l.attr(\"fill\",i(u).toHexString())}});var x=st.select(\".cblines\").selectAll(\"path.cbline\").data(r.line.color&&r.line.width?z:[]);return x.enter().append(\"path\").classed(M.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+Z+\",\"+(Math.round(et.c2p(t))+r.line.width/2%1)+\"h\"+U).call(h.lineGroupStyle,r.line.width,I(t),r.line.dash)}),ct.selectAll(\"g.\"+et._id+\"tick,path\").remove(),c.syncOrAsync([function(){var e=Z+U+(r.outlinewidth||0)/2-(\"outside\"===r.ticks?1:0),n=s.calcTicks(et),i=s.makeTransFn(et),a=s.makeLabelFns(et,e),o=s.getTickSigns(et)[2];return s.drawTicks(t,et,{vals:\"inside\"===et.ticks?s.clipEnds(et,n):n,layer:ct,path:s.makeTickPath(et,e,o),transFn:i}),s.drawLabels(t,et,{vals:n,layer:ct,transFn:i,labelXFn:a.labelXFn,labelYFn:a.labelYFn,labelAnchorFn:a.labelAnchorFn})},function(){if(-1===[\"top\",\"bottom\"].indexOf(r.title.side)){var e=et.title.font.size,i=et._offset+et._length/2,a=k.l+(et.position||0)*k.w+(\"right\"===et.side?10+e*(et.showticklabels?1:.5):-10-e*(et.showticklabels?.5:0));xt(\"h\"+et._id+\"title\",{avoid:{selection:n.select(t).selectAll(\"g.\"+et._id+\"tick\"),side:r.title.side,offsetLeft:k.l,offsetTop:0,maxShift:v.width},attributes:{x:a,y:i,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}}])},a.previousPromises,function(){var n=U+r.outlinewidth/2+h.bBox(ct.node()).width;if((N=lt.select(\"text\")).node()&&!N.classed(M.jsPlaceholder)){var i,o=lt.select(\".h\"+et._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(r.title.side)?h.bBox(o).width:h.bBox(lt.node()).right-Z-k.l,n=Math.max(n,i)}var s=2*r.xpad+n+r.borderwidth+r.outlinewidth/2,l=K-Q;st.select(\".cbbg\").attr({x:Z-r.xpad-(r.borderwidth+r.outlinewidth)/2,y:Q-Y,width:Math.max(s,2),height:Math.max(l+2*Y,2)}).call(p.fill,r.bgcolor).call(p.stroke,r.bordercolor).style({\"stroke-width\":r.borderwidth}),st.selectAll(\".cboutline\").attr({x:Z,y:Q+r.ypad+(\"top\"===r.title.side?ut:0),width:Math.max(U,2),height:Math.max(l-2*r.ypad-ut,2)}).call(p.stroke,r.outlinecolor).style({fill:\"None\",\"stroke-width\":r.outlinewidth});var c=({center:.5,right:1}[r.xanchor]||0)*s;st.attr(\"transform\",\"translate(\"+(k.l-c)+\",\"+k.t+\")\");var u={},f=y[r.yanchor],d=x[r.yanchor];\"pixels\"===r.lenmode?(u.y=r.y,u.t=l*f,u.b=l*d):(u.t=u.b=0,u.yt=r.y+r.len*f,u.yb=r.y-r.len*d);var g=y[r.xanchor],v=x[r.xanchor];if(\"pixels\"===r.thicknessmode)u.x=r.x,u.l=s*g,u.r=s*v;else{var m=s-U;u.l=m*g,u.r=m*v,u.xl=r.x-r.thickness*g,u.xr=r.x+r.thickness*v}a.autoMargin(t,e,u)}],t);if(mt&&mt.then&&(t._promises||[]).push(mt),t._context.edits.colorbarPosition)l.init({element:st.node(),gd:t,prepFn:function(){dt=st.attr(\"transform\"),f(st)},moveFn:function(t,e){st.attr(\"transform\",dt+\" translate(\"+t+\",\"+e+\")\"),gt=l.align($+t/k.w,q,0,1,r.xanchor),vt=l.align(J-e/k.h,G,0,1,r.yanchor);var n=l.getCursor(gt,vt,r.xanchor,r.yanchor);f(st,n)},doneFn:function(){if(f(st),void 0!==gt&&void 0!==vt){var e={};e[S(\"x\")]=gt,e[S(\"y\")]=vt,o.call(\"_guiRestyle\",t,e,T().index)}}});return mt}function yt(t,e){return c.coerce(tt,et,w,t,e)}function xt(e,r){var n={propContainer:et,propName:S(\"title\"),traceIndex:T().index,placeholder:v._dfltTitle.colorbar,containerGroup:st.select(\".cbtitle\")},i=\"h\"===e.charAt(0)?e.substr(1):\"h\"+e;st.selectAll(\".\"+i+\",.\"+i+\"-math-group\").remove(),d.draw(t,e,u(n,r||{}))}v._infolayer.selectAll(\"g.\"+e).remove()}function T(){for(var r=e.substr(2),n=0;n<t._fullData.length;n++){var i=t._fullData[n];if(i.uid===r)return i}}function S(t){var e=\"colorbar.\",r=T()._module.colorbar.container;return r&&(e=r+\".\"+e),e+t}return r.fillcolor=null,r.line={color:null,width:null,dash:null},r.levels={start:null,end:null,size:null},r.filllevels=null,r.fillgradient=null,r.zrange=null,Object.keys(r).forEach(function(t){A[t]=function(e){return arguments.length?(r[t]=c.isPlainObject(r[t])?c.extendFlat(r[t],e):e,A):r[t]}}),A.options=function(t){for(var e in t)\"function\"==typeof A[e]&&A[e](t[e]);return A},A._opts=r,A}},{\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/extend\":684,\"../../lib/setcursor\":714,\"../../lib/svg_text_utils\":718,\"../../plots/cartesian/axes\":742,\"../../plots/cartesian/axis_defaults\":744,\"../../plots/cartesian/layout_attributes\":755,\"../../plots/cartesian/position_defaults\":758,\"../../plots/plots\":806,\"../../registry\":825,\"../color\":571,\"../dragelement\":589,\"../drawing\":592,\"../titles\":659,\"./attributes\":572,\"./constants\":574,d3:149,tinycolor2:515}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":694}],578:[function(t,e,r){\"use strict\";var n=t(\"./scales.js\").scales;Object.keys(n);function i(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,a=(e=e||{}).cLetter||\"c\",o=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),s=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===a,l=\"string\"==typeof e.colorscaleDflt?n[e.colorscaleDflt]:null,c=e.editTypeOverride||\"\",u=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):i(u+(r={z:\"z\",c:\"color\"}[a]));var f=a+\"auto\",h=a+\"min\",p=a+\"max\",d=(i(u+h),i(u+p),{});d[h]=d[p]=void 0;var g={};g[f]=!1;var v={};return\"color\"===r&&(v.color={valType:\"color\",arrayOk:!0,editType:c||\"style\"},e.anim&&(v.color.anim=!0)),v[f]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:d},v[h]={valType:\"number\",dflt:null,editType:c||\"plot\",impliedEdits:g},v[p]={valType:\"number\",dflt:null,editType:c||\"plot\",impliedEdits:g},v.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:l,impliedEdits:{autocolorscale:!1}},v.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},v.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},o||(v.showscale={valType:\"boolean\",dflt:s,editType:\"calc\"}),v}},{\"./scales.js\":586}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i=t._fullLayout,a=r.vals,o=r.containerStr,s=r.cLetter,l=o?n.nestedProperty(e,o).get():e,c=s+\"min\",u=s+\"max\",f=l[s+\"auto\"],h=l[c],p=l[u],d=l.colorscale;!1===f&&void 0!==h||(h=n.aggNums(Math.min,null,a)),!1===f&&void 0!==p||(p=n.aggNums(Math.max,null,a)),h===p&&(h-=.5,p+=.5),l[\"_\"+c]=l[c]=h,l[\"_\"+u]=l[u]=p,l.autocolorscale&&(d=h*p<0?i.colorscale.diverging:h>=0?i.colorscale.sequential:i.colorscale.sequentialminus,l._colorscale=l.colorscale=d)}},{\"../../lib\":694}],580:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale;e.exports=function(t){function e(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function r(t,r){var i=r.container?n.nestedProperty(t,r.container).get():t;if(i){var a=i.zauto||i.cauto,o=r.min,s=r.max;(a||void 0===i[o])&&e(i,o),(a||void 0===i[s])&&e(i,s),i.autocolorscale&&e(i,\"colorscale\")}}for(var a=0;a<t.length;a++){var o=t[a],s=o._module;s.colorbar&&r(o,s.colorbar),i(o,\"marker.line\")&&r(o,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"}),i(o,\"line\")&&r(o,{container:\"line\",min:\"cmin\",max:\"cmax\"})}}},{\"../../lib\":694,\"./helpers\":582}],581:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid;function l(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function(t,e,r,i,c){var u=c.prefix,f=c.cLetter,h=l(t,u),p=l(e,u),d=l(e._template||{},u)||{},g=h[f+\"min\"],v=h[f+\"max\"];i(u+f+\"auto\",!(n(g)&&n(v)&&g<v)),i(u+f+\"min\"),i(u+f+\"max\");var m,y,x=h.colorscale,b=d.colorscale;(void 0!==x&&(m=!s(x)),void 0!==b&&(m=!s(b)),i(u+\"autocolorscale\",m),i(u+\"colorscale\"),i(u+\"reversescale\"),c.noScale||\"marker.line.\"===u)||(u&&(y=a(h)),i(u+\"showscale\",y)&&o(h,p,r))}},{\"../../lib\":694,\"../colorbar/defaults\":575,\"../colorbar/has_colorbar\":577,\"./scales\":586,\"fast-isnumeric\":215}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;function c(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function u(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractScale:function(t,e){for(var r=e.cLetter,n=t.reversescale?c(t.colorscale):t.colorscale,i=t[r+\"min\"],a=t[r+\"max\"],o=n.length,s=new Array(o),l=new Array(o),u=0;u<o;u++){var f=n[u];s[u]=i+f[0]*(a-i),l[u]=f[1]}return{domain:s,range:l}},flipScale:c,makeColorScaleFunc:function(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),f=0;f<l;f++){var h=i(o[f]).toRgb();c[f]=[h.r,h.g,h.b,h.a]}var p,d=n.scale.linear().domain(r).range(c).clamp(!0),g=e.noNumericCheck,v=e.returnArray;return(p=g&&v?d:g?function(t){return u(d(t))}:v?function(t){return a(t)?d(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?u(d(t)):i(t).isValid()?t:s.defaultLine}).domain=d.domain,p.range=function(){return o},p}}},{\"../../lib\":694,\"../color\":571,\"./scales\":586,d3:149,\"fast-isnumeric\":215,tinycolor2:515}],583:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,flipScale:i.flipScale,extractScale:i.extractScale,makeColorScaleFunc:i.makeColorScaleFunc}},{\"./attributes\":578,\"./calc\":579,\"./cross_trace_defaults\":580,\"./defaults\":581,\"./helpers\":582,\"./layout_attributes\":584,\"./layout_defaults\":585,\"./scales\":586}],584:[function(t,e,r){\"use strict\";var n=t(\"./scales\").scales;e.exports={editType:\"calc\",sequential:{valType:\"colorscale\",dflt:n.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:n.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:n.RdBu,editType:\"calc\"}}},{\"./scales\":586}],585:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../../plot_api/plot_template\");e.exports=function(t,e){var r=t.colorscale,o=a.newContainer(e,\"colorscale\");function s(t,e){return n.coerce(r,o,i,t,e)}s(\"sequential\"),s(\"sequentialminus\"),s(\"diverging\")}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"./layout_attributes\":584}],586:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:515}],587:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],588:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":694}],589:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../plots/cartesian/constants\"),c=t(\"../../constants/interactions\"),u=e.exports={};u.align=t(\"./align\"),u.getCursor=t(\"./cursor\");var f=t(\"./unhover\");function h(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function p(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}u.unhover=f.wrapped,u.unhoverRaw=f.raw,u.init=function(t){var e,r,n,f,d,g,v,m,y=t.gd,x=1,b=c.DBLCLICKDELAY,_=t.element;y._mouseDownTime||(y._mouseDownTime=0),_.style.pointerEvents=\"all\",_.onmousedown=k,a?(_._ontouchstart&&_.removeEventListener(\"touchstart\",_._ontouchstart),_._ontouchstart=k,_.addEventListener(\"touchstart\",k,{passive:!1})):_.ontouchstart=k;var w=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function k(a){y._dragged=!1,y._dragging=!0;var o=p(a);e=o[0],r=o[1],v=a.target,g=a,m=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-y._mouseDownTime<b?x+=1:(x=1,y._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!m?(d=h()).style.cursor=window.getComputedStyle(_).cursor:i||(d=document,f=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(_).cursor),document.addEventListener(\"mouseup\",A),document.addEventListener(\"touchend\",A),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",M),document.addEventListener(\"touchmove\",M))}function M(n){n.preventDefault();var i=p(n),a=t.minDrag||l.MINDRAG,o=w(i[0]-e,i[1]-r,a),s=o[0],c=o[1];(s||c)&&(y._dragged=!0,u.unhover(y)),y._dragged&&t.moveFn&&!m&&t.moveFn(s,c)}function A(e){if(!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",M),document.removeEventListener(\"touchmove\",M)),document.removeEventListener(\"mouseup\",A),document.removeEventListener(\"touchend\",A),i?s.removeElement(d):f&&(d.documentElement.style.cursor=f,f=null),y._dragging){if(y._dragging=!1,(new Date).getTime()-y._mouseDownTime>b&&(x=Math.max(x-1,1)),y._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(x,g),!m){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=p(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}v.dispatchEvent(r)}!function(t){t._dragging=!1,t._replotPending&&o.call(\"plot\",t)}(y),y._dragged=!1}else y._dragged=!1}},u.coverSlip=h},{\"../../constants/interactions\":670,\"../../lib\":694,\"../../plots/cartesian/constants\":748,\"../../registry\":825,\"./align\":587,\"./cursor\":588,\"./unhover\":590,\"has-hover\":396,\"has-passive-events\":397,\"mouse-event-offset\":422}],590:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/get_graph_div\"),o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/events\":683,\"../../lib/get_graph_div\":690,\"../../lib/throttle\":719,\"../fx/constants\":604}],591:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],592:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../constants/xmlns_namespaces\"),h=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,o=a.xcalendar,s=a.ycalendar,l=\"bar\"===a.type?\".bartext\":\".point,.textpoint\";t.selectAll(l).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,o,s)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),M={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,f=M[i],h=new Array(u),p=0;p<u;p++)f.reversed?h[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:h[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+h.join(\";\")],c.identity);g.exit().remove(),g.enter().append(f.node).each(function(){var t=n.select(this);f.attrs&&t.attr(f.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(h);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,\"url(#\"+d+\")\").style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var f,h,p,d=!1;if(t.so)p=o.outlierwidth,h=o.outliercolor,f=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,h=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(f=s.defaultLine,d=!0),f=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(f=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,f).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],M[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,f]],\"fill\")}else s.fill(e,f);p&&s.stroke(e,h)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,f=s.opacity,h=void 0!==u,d=void 0!==f;(c.isArrayOrTypedArray(l)||h||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?h?u:e:d?f:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.colorscale,i=r.color;if(n&&c.isArrayOrTypedArray(i))return l.makeColorScaleFunc(l.extractScale(r,{cLetter:\"c\"}))}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function T(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*h+1,f=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+f+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),f=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,f).text(o).call(u.convertToTspans,r).call(T,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),T(i,o,l,t.mrc2||t.mrc)})}};var C=.5;function E(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,C/2),u=Math.pow(s*s+l*l,C/2),f=(u*u*a-c*c*s)*i,h=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&f/p),2),n.round(e[1]+(p&&h/p),2)],[n.round(e[0]-(d&&f/d),2),n.round(e[1]-(d&&h/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(E(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[E(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(E(t[r-1],t[r],t[r+1],e));for(a.push(E(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},z=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||z;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(f.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function I(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}v.bBox=function(t,e,r){var i,a,o;if(r||(r=I(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=I(s)){var l=+s.getAttribute(\"x\")||0,f=+s.getAttribute(\"y\")||0,h=s.getAttribute(\"transform\");if(!h){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),f&&(p.top+=f,p.bottom+=f),p}if(r+=\"~\"+l+\"~\"+f+\"~\"+h,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){if(e){var n=r._context,i=n._exportedPlot?\"\":n._baseUrl||\"\";t.attr(\"clip-path\",\"url(\"+i+\"#\"+e+\")\")}else t.attr(\"clip-path\",null)},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var P=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(P);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":666,\"../../constants/interactions\":670,\"../../constants/xmlns_namespaces\":672,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../registry\":825,\"../../traces/scatter/make_bubble_size_func\":1064,\"../../traces/scatter/subtypes\":1071,\"../color\":571,\"../colorscale\":583,\"./symbol_defs\":593,d3:149,\"fast-isnumeric\":215,tinycolor2:515}],593:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:149}],594:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],595:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),f=0;f<t.length;f++){var h=t[f],p=h.i;if(void 0===p)p=f;else if(null===p)continue;var d=h[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=h[i+\"s\"]=d-g[0],m=h[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"./compute_error\":596,\"fast-isnumeric\":215}],596:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],597:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),f=t[c]||{};function h(t,e){return a.coerce(f,u,s,t,e)}if(!1!==h(\"visible\",void 0!==f.array||void 0!==f.value||\"sqrt\"===f.type)){var p=h(\"type\",\"array\"in f?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=h(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in f))),\"data\"===p?(h(\"array\"),h(\"traceref\"),d||(h(\"arrayminus\"),h(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(h(\"value\"),d||h(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&h(g,!(f.color||n(f.thickness)||n(f.width)));l.inherit&&u[g]||(h(\"color\",r),h(\"thickness\"),h(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../registry\":825,\"./attributes\":594,\"fast-isnumeric\":215}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":694,\"../../plot_api/edit_types\":725,\"./attributes\":594,\"./calc\":595,\"./compute_error\":596,\"./defaults\":597,\"./plot\":599,\"./style\":600}],599:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var f,h=e[0].trace,p=h.error_x||{},d=h.error_y||{};h.ids&&(f=function(t){return t.id});var g=o.hasMarkers(h)&&h.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=d.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var h=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!h.size()?h=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(h=h.transition().duration(s.duration).ease(s.easing)),h.attr(\"d\",a)}else h.remove()}})}})}},{\"../../traces/scatter/subtypes\":1071,\"../drawing\":592,d3:149,\"fast-isnumeric\":215}],600:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":571,d3:149}],601:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\");e.exports={hoverlabel:{bgcolor:{valType:\"color\",arrayOk:!0,editType:\"none\"},bordercolor:{valType:\"color\",arrayOk:!0,editType:\"none\"},font:n({arrayOk:!0,editType:\"none\"}),namelength:{valType:\"integer\",min:-1,arrayOk:!0,editType:\"none\"},editType:\"calc\"}}},{\"../../plots/font_attributes\":769}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"))}}}},{\"../../lib\":694,\"../../registry\":825}],603:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":825,\"./hover\":607}],604:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],605:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},o.hoverlabel)}},{\"../../lib\":694,\"./attributes\":601,\"./hoverlabel_defaults\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),f=new Array(r.length),h=0;h<r.length;h++)f[h]=o(u,r[h]);t[c]=f}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":694}],607:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),f=t(\"../color\"),h=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),M=!1,L=0;L<_;L++){var z=l[L],O=v[z];if(O)M=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var I=u[z]._subplot;w[L]=I.xaxis,k[L]=I.yaxis}}var D=e.hovermode||u.hovermode;D&&!M&&(D=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(D)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return h.unhoverRaw(t,e);var P,R,F,B,N,j,V,U,q,H,G,W,Y,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,$=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(D=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(J.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(J.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return h.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,P=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(P[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),h.unhoverRaw(t,e)}var it=1/0;for(B=0;B<J.length;B++)if((N=J[B])&&N[0]&&N[0].trace&&!0===N[0].trace.visible&&(j=N[0].trace,-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name))){if(\"splom\"===j.type?V=l[U=0]:(V=g.getSubplot(j),U=l.indexOf(V)),q=D,W={cd:N,trace:j,xa:w[U],ya:k[U],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:f.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[V]&&(W.subplot=u[V]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(W.scene=u._splomScenes[j.uid]),Y=$.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(W.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=P[U],G=R[U];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(W,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&$.push(S(st,D))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===D&&$.length>Y&&($.splice(0,Y),it=$[0].distance),y&&0!==Z&&0===$.length){W.distance=Z,W.index=!1;var ct=j._module.hoverPoints(W,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ft=ct.filter(function(t){return t.xa.showspikes});if(ft.length){var ht=ft[0];i(ht.x0)&&i(ht.y0)&&(ut=vt(ht),(!K.vLinePoint||K.vLinePoint.spikeDistance>ut.spikeDistance)&&(K.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!K.hLinePoint||K.hLinePoint.spikeDistance>ut.spikeDistance)&&(K.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==$.length){var bt=$.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);K.hLinePoint=vt(_t);var wt=$.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);K.vLinePoint=vt(kt)}if(0===$.length){var Mt=h.unhoverRaw(t,e);return!y||null===K.hLinePoint&&null===K.vLinePoint||E(yt)&&C(K,mt),Mt}y&&E(yt)&&C(K,mt);$.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Tt=[];for(F=0;F<$.length;F++){var St=$[F],Ct=g.makeEventData(St,St.trace,St.cd),Et=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Et=St.cd[St.index].ht),$[F].hovertemplate=Et||St.trace.hovertemplate||!1,$[F].eventData=[Ct],Tt.push(Ct)}t._hoverdata=Tt;var Lt=\"y\"===D&&(J.length>1||$.length>1)||\"closest\"===D&&Q&&$.length>1,zt=f.combine(u.plot_bgcolor||f.background,u.paper_bgcolor),Ot={hovermode:D,rotateLabels:Lt,bgColor:zt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},It=A($,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,f=1,h=t.map(function(t,n){var i=t[e],a=\"x\"===i._id.charAt(0),o=i.range;return!n&&o&&o[0]>o[1]!==a&&(f=-1),[{i:n,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(a?x:1)/2,pmin:0,pmax:a?r.width:r.height}]}).sort(function(t,e){return t[0].posref-e[0].posref||f*(e[0].traceIndex-t[0].traceIndex)});function p(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(;!n&&u<=t.length;){for(u++,n=!0,o=0;o<h.length-1;){var d=h[o],g=h[o+1],v=d[d.length-1],m=g[0];if((i=v.pos+v.dp+v.size-m.pos-m.dp+m.size)>.01&&v.pmin===m.pmin&&v.pmax===m.pmax){for(s=g.length-1;s>=0;s--)g[s].dp+=i;for(d.push.apply(d,g),h.splice(o+1,1),c=0,s=d.length-1;s>=0;s--)c+=d[s].dp;for(a=c/d.length,s=d.length-1;s>=0;s--)d[s].dp-=a;n=!1}else o++}h.forEach(p)}for(o=h.length-1;o>=0;o--){var y=h[o];for(s=y.length-1;s>=0;s--){var b=y[s],_=t[b.i];_.offset=b.dp,_.del=b.del}}}($,Lt?\"xa\":\"ya\",u),T(It,Lt),e.target&&e.target.tagName){var Dt=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Tt);c(n.select(e.target),Dt?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:P,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r={color:t.color||f.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1},i=n.select(e.container),a=e.outerContainer?n.select(e.outerContainer):i,o={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||f.background,container:i,outerContainer:a},s=A([r],o,e.gd);return T(s,o.rotateLabels),s.node()},r.multiHovers=function(t,e){Array.isArray(t)||(t=[t]);var r=t.map(function(t){return{color:t.color||f.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),i=n.select(e.container),a=e.outerContainer?n.select(e.outerContainer):i,o={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||f.background,container:i,outerContainer:a},s=A(r,o,e.gd),l=0;return s.sort(function(t,e){return t.y0-e.y0}).each(function(t){var e=t.y0-t.by/2;t.offset=e-5<l?l-e+5:0,l=e+t.by+t.offset}),T(s,o.rotateLabels),s.node()};var M=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=e.hovermode,a=e.rotateLabels,s=e.bgColor,c=e.container,h=e.outerContainer,p=e.commonLabelOpts||{},d=e.fontFamily||v.HOVERFONT,g=e.fontSize||v.HOVERFONTSIZE,y=t[0],x=y.xa,b=y.ya,_=\"y\"===i?\"yLabel\":\"xLabel\",A=y[_],T=(String(A)||\"\").split(\" \")[0],S=h.node().getBoundingClientRect(),C=S.top,E=S.width,L=S.height,z=void 0!==A&&y.distance<=e.hoverdistance&&(\"x\"===i||\"y\"===i);if(z){var O,I,D=!0;for(O=0;O<t.length;O++)if(D&&void 0===t[O].zLabel&&(D=!1),I=t[O].hoverinfo||t[O].trace.hoverinfo){var P=Array.isArray(I)?I:I.split(\"+\");if(-1===P.indexOf(\"all\")&&-1===P.indexOf(i)){z=!1;break}}D&&(z=!1)}var R=c.selectAll(\"g.axistext\").data(z?[0]:[]);R.enter().append(\"g\").classed(\"axistext\",!0),R.exit().remove(),R.each(function(){var e=n.select(this),a=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=p.bgcolor||f.defaultLine,h=p.bordercolor||f.contrast(c),v=f.contrast(c);a.style({fill:c,stroke:h}),s.text(A).call(u.font,p.font.family||d,p.font.size||g,p.font.color||v).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var m=s.node().getBoundingClientRect();if(\"x\"===i){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===x.side?C-m.bottom-w-k:C-m.top+w+k);var M=\"top\"===x.side?\"-\":\"\";a.attr(\"d\",\"M0,0L\"+w+\",\"+M+w+\"H\"+(k+m.width/2)+\"v\"+M+(2*k+m.height)+\"H-\"+(k+m.width/2)+\"V\"+M+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(x._offset+(y.x0+y.x1)/2)+\",\"+(b._offset+(\"top\"===x.side?0:b._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===b.side?\"start\":\"end\").call(l.positionText,(\"right\"===b.side?1:-1)*(k+w),C-m.top-m.height/2);var S=\"right\"===b.side?\"\":\"-\";a.attr(\"d\",\"M0,0L\"+S+w+\",\"+w+\"V\"+(k+m.height/2)+\"h\"+S+(2*k+m.width)+\"V-\"+(k+m.height/2)+\"H\"+S+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(x._offset+(\"right\"===b.side?x._length:0))+\",\"+(b._offset+(y.y0+y.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[_]||\"\").split(\" \")[0]===T})});var F=c.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return F.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(f.fill,f.addOpacity(s,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,d,g)}),F.exit().remove(),F.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),c=\"\",h=\"\",p=t.bgcolor||t.color,v=f.combine(f.opacity(p)?p:f.defaultLine,s),y=f.combine(f.opacity(t.color)?t.color:f.defaultLine,s),x=t.borderColor||f.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(c=l.plainText(t.name||\"\",{len:t.nameLength,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})),void 0!==t.zLabel?(void 0!==t.xLabel&&(h+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(h+=\"y: \"+t.yLabel+\"<br>\"),h+=(h?\"z: \":\"\")+t.zLabel):z&&t[i+\"Label\"]===A?h=t[(\"x\"===i?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&(h=t.yLabel):h=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(h+=(h?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(h+=(h?\"<br>\":\"\")+t.extraText),\"\"===h&&(\"\"===c&&e.remove(),h=c);var b=t.hovertemplate||!1,_=t.hovertemplateLabels||t,T=t.eventData[0]||{};b&&(h=(h=o.hovertemplateString(b,_,T)).replace(M,function(t,e){return c=e,\"\"}));var S=e.select(\"text.nums\").call(u.font,t.fontFamily||d,t.fontSize||g,t.fontColor||x).text(h).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),O=e.select(\"text.name\"),I=0,D=0;if(c&&c!==h){O.call(u.font,t.fontFamily||d,t.fontSize||g,y).text(c).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var P=O.node().getBoundingClientRect();I=P.width+2*k,D=P.height+2*k}else O.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:x});var R,F,B=S.node().getBoundingClientRect(),N=t.xa._offset+(t.x0+t.x1)/2,j=t.ya._offset+(t.y0+t.y1)/2,V=Math.abs(t.x1-t.x0),U=Math.abs(t.y1-t.y0),q=B.width+w+k+I;t.ty0=C-B.top,t.bx=B.width+2*k,t.by=Math.max(B.height+2*k,D),t.anchor=\"start\",t.txwidth=B.width,t.tx2width=I,t.offset=0,a?(t.pos=N,R=j+U/2+q<=L,F=j-U/2-q>=0,\"top\"!==t.idealAlign&&R||!F?R?(j+=U/2,t.anchor=\"start\"):t.anchor=\"middle\":(j-=U/2,t.anchor=\"end\")):(t.pos=j,R=N+V/2+q<=E,F=N-V/2-q>=0,\"left\"!==t.idealAlign&&R||!F?R?(N+=V/2,t.anchor=\"start\"):t.anchor=\"middle\":(N-=V/2,t.anchor=\"end\")),S.attr(\"text-anchor\",t.anchor),I&&O.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+N+\",\"+j+\")\"+(a?\"rotate(\"+m+\")\":\"\"))}),F}function T(t,e){t.each(function(t){var r=n.select(this);if(t.del)r.remove();else{var i=\"end\"===t.anchor?-1:1,a=r.select(\"text.nums\"),o={start:1,end:-1,middle:0}[t.anchor],s=o*(w+k),c=s+o*(t.txwidth+k),f=0,h=t.offset;\"middle\"===t.anchor&&(s-=t.tx2width/2,c+=t.txwidth/2+k),e&&(h*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===t.anchor?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(h-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(i*w+f)+\",\"+(w+h)+\"v\"+(t.by/2-w)+\"h\"+i*t.bx+\"v-\"+t.by+\"H\"+(i*w+f)+\"V\"+(h-w)+\"Z\"),a.call(l.positionText,s+f,h+t.ty0-t.by/2+k),t.tx2width&&(r.select(\"text.name\").call(l.positionText,c+o*k+f,h+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,c+(o-1)*t.tx2width/2+f,h-t.by/2-1,t.tx2width,t.by+2))}})}function S(t,e){var r=t.index,n=t.trace||{},i=t.cd[0],a=t.cd[r]||{},s=Array.isArray(r)?function(t,e){return o.castOption(i,r,t)||o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(a,n,t,e)};function l(e,r,n){var i=s(r,n);i&&(t[e]=i)}if(l(\"hoverinfo\",\"hi\",\"hoverinfo\"),l(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),l(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),l(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),l(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),l(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),l(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var c=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+c+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+c,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var u=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+u+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+u,\"y\"===e&&(t.distance+=1)}var f=t.hoverinfo||t.trace.hoverinfo;return f&&\"all\"!==f&&(-1===(f=Array.isArray(f)?f:f.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===f.indexOf(\"y\")&&(t.yLabel=void 0),-1===f.indexOf(\"z\")&&(t.zLabel=void 0),-1===f.indexOf(\"text\")&&(t.text=void 0),-1===f.indexOf(\"name\")&&(t.name=void 0)),t}function C(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var h=f.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,h)<1.5?f.contrast(h):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:h}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var M,A,T=t.vLinePoint;r=T&&T.xa,n=T&&T.ya,\"cursor\"===r.spikesnap?(M=s.pointerX,A=s.pointerY):(M=r._offset+T.x,A=n._offset+T.y);var S,C,E=a.readability(T.color,h)<1.5?f.contrast(h):T.color,L=r.spikemode,z=r.spikethickness,O=r.spikecolor||E,I=r._boundingBox,D=(I.top+I.bottom)/2<A?I.bottom:I.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=D,C=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],C=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:M,x2:M,y1:S,y2:C,\"stroke-width\":z,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,z)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:M,x2:M,y1:S,y2:C,\"stroke-width\":z+2,stroke:h}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:M,cy:D-(\"top\"!==r.side?z:-z),r:z,fill:O}).classed(\"spikeline\",!0)}}}function E(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}},{\"../../lib\":694,\"../../lib/events\":683,\"../../lib/override_cursor\":705,\"../../lib/svg_text_utils\":718,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"../color\":571,\"../dragelement\":589,\"../drawing\":592,\"./constants\":604,\"./helpers\":606,d3:149,\"fast-isnumeric\":215,tinycolor2:515}],608:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font)}},{\"../../lib\":694}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"none\"}}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,multiHovers:l.multiHovers,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":694,\"../dragelement\":589,\"./attributes\":601,\"./calc\":602,\"./click\":603,\"./constants\":604,\"./defaults\":605,\"./helpers\":606,\"./hover\":607,\"./layout_attributes\":611,\"./layout_defaults\":612,\"./layout_global_defaults\":613,d3:149}],611:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":769,\"./constants\":604}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t){for(var e=!0,r=0;r<t.length;r++){var n=t[r];if(\"h\"!==n.orientation){e=!1;break}}return e}(r),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":694,\"./layout_attributes\":611}],613:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":694,\"./hoverlabel_defaults\":608,\"./layout_attributes\":611}],614:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),f=u*(1-o),h=0;h<i;h++){var p=c+u*h;l[a?i-1-h:h]=[p,p+f]}return l}function f(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,f,h=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;h?(o=r.subplots.length,f=r.subplots[0].length):(d&&(o=a.length),p&&(f=i.length));var v=s.newContainer(e,\"grid\"),m=M(\"rows\",o),y=M(\"columns\",f);if(m*y>1){h||p||d||\"independent\"===M(\"pattern\")&&(h=!0),v._hasSubplotGrid=h;var x,b,_=\"top to bottom\"===M(\"roworder\"),w=h?.2:.1,k=h?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",M,w,x,y),y:u(\"y\",M,k,b,m,_)}}else delete e.grid}function M(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,h=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=h.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,h,\"x\"),M=c(e,h,\"y\");r.xaxes=f(k,p.xaxis,v,y,\"x\"),r.yaxes=f(M,p.yaxis,g,y,\"y\")}var A=r._anchors={},T=\"top to bottom\"===r.roworder;for(var S in y){var C,E,L,z=S.charAt(0),O=r[z+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===z){if(\"t\"===O.charAt(0)===T?(C=0,E=1,L=g):(C=g-1,E=-1,L=-1),d){var I=y[S];for(n=C;n!==L;n+=E)if((s=l[n][I])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=C;n!==L;n+=E)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(C=0,E=1,L=v):(C=v-1,E=-1,L=-1),d){var D=y[S];for(n=C;n!==L;n+=E)if((s=l[D][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=C;n!==L;n+=E)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":694,\"../../lib/regex\":710,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/constants\":748,\"../../plots/domain\":768}],615:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":732,\"../../plots/cartesian/constants\":748}],616:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,f=e._id.charAt(0),h=0;h<u.length;h++)if(c=\"images[\"+h+\"].\",(l=u[h])[f+\"ref\"]===e._id){var p=l[f],d=l[\"size\"+f],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+f,g),a(c+\"size\"+f,v)}}},{\"../../lib/to_log_range\":720,\"fast-isnumeric\":215}],617:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var f=c[u],h=i.coerceRef(t,e,l,f,\"paper\");if(\"paper\"!==h)i.getFromId(l,h)._imgIndices.push(e._index);i.coercePosition(e,l,a,h,f,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../../plots/cartesian/axes\":742,\"./attributes\":615}],618:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var f=s.images[r];if(f.visible)if(\"below\"===f.layer&&\"paper\"!==f.xref&&\"paper\"!==f.yref){e=f.xref+f.yref;var h=s._plots[e];if(!h){u.push(f);continue}h.mainplot&&(e=h.mainplot.id),c[e]||(c[e]=[]),c[e].push(f)}else\"above\"===f.layer?l.push(f):u.push(f)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,f=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,h=u*p.x[e.xanchor].offset,d=f*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+h,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:f,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":672,\"../../plots/cartesian/axes\":742,\"../drawing\":592,d3:149}],619:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":753,\"./attributes\":615,\"./convert_coords\":616,\"./defaults\":617,\"./draw\":618}],620:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":769,\"../color/attributes\":570}],621:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],622:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,f,h,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,f=\"left\",u=1.1,h=\"bottom\"):(c=0,f=\"left\",u=-.1,h=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"x\",c),w(\"xanchor\",f),w(\"y\",u),w(\"yanchor\",h),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../plots/layout_attributes\":797,\"../../registry\":825,\"./attributes\":620,\"./helpers\":626}],623:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\"),g=t(\"../../constants/alignment\"),v=g.LINE_SPACING,m=g.FROM_TL,y=g.FROM_BR,x=t(\"./get_legend_data\"),b=t(\"./style\"),_=t(\"./helpers\"),w=d.DBLCLICKDELAY;function k(t,e,r,n,i){var a=r.data()[0][0].trace,o={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(o.group=a._group),\"pie\"===a.type&&(o.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",o))if(1===n)e._clickTimeout=setTimeout(function(){h(r,t,n)},w);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",o)&&h(r,t,n)}}function M(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie\"),u=s.index,h=l?n.label:s.name,d=e._context.edits.legendText&&!l,g=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){f.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*v;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),h=f.lineCount(u),d=u.node();n=s*h,i=d?c.bBox(d).width:0;var g=s*(.3+(1-h)/2);f.positionText(u,p.textOffsetX,g)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}g.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(d?A(h,r):h),f.positionText(g,p.textOffsetX,0),d?g.call(f.makeEditable,{gd:e,text:h}).call(m).on(\"edit\",function(t){this.text(A(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],f=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");f.set(n.trace._group,t),s=f.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(g)}function A(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=1,o=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});o.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<w?a+=1:(a=1,e._legendMouseDownTime=r)}),o.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>w&&(a=Math.max(a-1,1)),k(e,r,t,a,n.event)}})}function S(t,e,r){var i=t._fullLayout,a=i.legend,o=a.borderwidth,s=_.isGrouped(a),l=0;if(a._width=0,a._height=0,_.isVertical(a))s&&e.each(function(t,e){c.setTranslate(this,0,e*a.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,o,5+o+a._height+r/2),a._height+=r,a._width=Math.max(a._width,n)}),a._width+=45+2*o,a._height+=10+2*o,s&&(a._height+=(a._lgroupsLength-1)*a.tracegroupgap),l=40;else if(s){for(var u=[a._width],f=e.data(),h=0,p=f.length;h<p;h++){var d=f[h].map(function(t){return t[0].width}),g=40+Math.max.apply(null,d);a._width+=a.tracegroupgap+g,u.push(a._width)}e.each(function(t,e){c.setTranslate(this,u[e],0)}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+o+e+r/2),e+=r}),a._height=Math.max(a._height,e)}),a._height+=10+2*o,a._width+=2*o}else{var v=0,m=0,y=0,x=0,b=0,w=a.tracegroupgap||5;r.each(function(t){y=Math.max(40+t[0].width,y),b+=40+t[0].width+w});var k=i._size.w>o+b-w;r.each(function(t){var e=t[0],r=k?40+t[0].width:y;o+x+w+r>i._size.w&&(x=0,v+=m,a._height+=m,m=0),c.setTranslate(this,o+x,5+o+e.height/2+v),a._width+=w+r,x+=w+r,m=Math.max(e.height,m)}),k?a._height=m:a._height+=m,a._width+=2*o,a._height+=10+2*o}a._width=Math.ceil(a._width),a._height=Math.ceil(a._height);var M=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(M?0:a._width)+l,e.height)})}function C(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*m[r],r:e._width*y[r],b:e._height*y[n],t:e._height*m[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,f=e.showlegend&&x(t.calcdata,s),h=e.hiddenlabels||[];if(!e.showlegend||!f.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<f.length;g++)for(var v=0;v<f[g].length;v++){var _=f[g][v][0],w=_.trace,A=o.traceIs(w,\"pie\")?_.label:w.name;d=Math.max(d,A&&A.length||0)}var E=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),E=!0}),z=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var I=i.ensureSingle(L,\"g\",\"scrollbox\"),D=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),P=I.selectAll(\"g.groups\").data(f);P.enter().append(\"g\").attr(\"class\",\"groups\"),P.exit().remove();var R=P.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie\")?-1!==h.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(M,t,d).call(T,t)}).call(b,t),i.syncOrAsync([a.previousPromises,function(){E&&(S(t,P,R),C(t));var u=e.width,f=e.height;S(t,P,R),s._height>f?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*m[r],r:e._width*y[r],b:0,t:0})}(t):C(t);var h=e._size,d=h.l+h.w*s.x,g=h.t+h.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var v=s._width,x=h.w;v>x?(d=h.l,v=x):(d+v>u&&(d=u-v),d<0&&(d=0),v=Math.min(u-d,s._width));var b,_,w,M,A=s._height,T=h.h;if(A>T?(g=h.t,A=T):(g+A>f&&(g=f-A),g<0&&(g=0),A=Math.min(f-g,s._height)),c.setTranslate(L,d,g),D.on(\".drag\",null),L.on(\"wheel\",null),s._height<=A||t._context.staticPlot)O.attr({width:v-s.borderwidth,height:A-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(I,0,0),z.select(\"rect\").attr({width:v-2*s.borderwidth,height:A-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(I,r,t),c.setRect(D,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,A*A/s._height),j=A-N-2*p.scrollBarMargin,V=s._height-A,U=j/V,q=Math.min(s._scrollY||0,V);O.attr({width:v-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:A-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),z.select(\"rect\").attr({width:v-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:A-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(I,r,t),G(q,N,U),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*V,0,V),N,U),0!==q&&q!==V&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/U+B,0,V),N,U)});D.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(I,0,-e),c.setRect(D,v,p.scrollBarMargin+e*n,p.scrollBarWidth,r),z.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);w=t.x,M=t.y},moveFn:function(t,e){var r=w+t,n=M+e;c.setTranslate(L,r,n),b=l.align(r,0,h.l,h.l+h.w,s.xanchor),_=l.align(n,0,h.t+h.h,h.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==_&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":_})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&k(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":666,\"../../constants/interactions\":670,\"../../lib\":694,\"../../lib/events\":683,\"../../lib/svg_text_utils\":718,\"../../plots/plots\":806,\"../../registry\":825,\"../color\":571,\"../dragelement\":589,\"../drawing\":592,\"./constants\":621,\"./get_legend_data\":624,\"./handle_click\":625,\"./helpers\":626,\"./style\":628,d3:149}],624:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function f(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var h=t[r],p=h[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie\"))for(c[g]||(c[g]={}),a=0;a<h.length;a++){var v=h[a].label;c[g][v]||(f(g,{label:v,color:h[a].color,i:h[a].i,trace:d,pts:h[a].pts}),c[g][v]=!0)}else f(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":825,\"./helpers\":626}],625:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){if(!e._dragged&&!e._editing){var o,s,l,c,u,f=e._fullLayout.hiddenlabels?e._fullLayout.hiddenlabels.slice():[],h=t.data()[0][0],p=e._fullData,d=h.trace,g=d.legendgroup,v={},m=[],y=[],x=[];if(1===r&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,i.traceIs(d,\"pie\")){var b=h.label,_=f.indexOf(b);1===r?-1===_?f.push(b):f.splice(_,1):2===r&&(f=[],e.calcdata[0].forEach(function(t){b!==t.label&&f.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===f.length&&-1===_&&(f=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",f)}else{var w,k=g&&g.length,M=[];if(k)for(o=0;o<p.length;o++)(w=p[o]).visible&&w.legendgroup===g&&M.push(o);if(1===r){var A;switch(d.visible){case!0:A=\"legendonly\";break;case!1:A=!1;break;case\"legendonly\":A=!0}if(k)for(o=0;o<p.length;o++)!1!==p[o].visible&&p[o].legendgroup===g&&O(p[o],A);else O(d,A)}else if(2===r){var T,S,C=!0;for(o=0;o<p.length;o++)if(!(p[o]===d)&&!(T=k&&p[o].legendgroup===g)&&!0===p[o].visible&&!i.traceIs(p[o],\"notLegendIsolatable\")){C=!1;break}for(o=0;o<p.length;o++)if(!1!==p[o].visible&&!i.traceIs(p[o],\"notLegendIsolatable\"))switch(d.visible){case\"legendonly\":O(p[o],!0);break;case!0:S=!!C||\"legendonly\",T=p[o]===d||k&&p[o].legendgroup===g,O(p[o],!!T||S)}}for(o=0;o<y.length;o++)if(l=y[o]){var E=l.constructUpdate(),L=Object.keys(E);for(s=0;s<L.length;s++)c=L[s],(v[c]=v[c]||[])[x[o]]=E[c]}for(u=Object.keys(v),o=0;o<u.length;o++)for(c=u[o],s=0;s<m.length;s++)v[c].hasOwnProperty(s)||(v[c][s]=void 0);i.call(\"_guiRestyle\",e,v,m)}}function z(t,e,r){var n=m.indexOf(t),i=v[e];return i||(i=v[e]=[]),-1===m.indexOf(t)&&(m.push(t),n=m.length-1),i[n]=r,n}function O(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=y[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),y[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),x[r.index]=z(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;z(r.index,\"visible\",c)}}}},{\"../../lib\":694,\"../../registry\":825}],626:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],627:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":620,\"./defaults\":622,\"./draw\":623,\"./style\":628}],628:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\");e.exports=function(t,e){t.each(function(t){var r=n.select(this),i=a.ensureSingle(r,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=e._fullLayout.legend.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=e.marker||{},a=r.line||{},o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbar\").data(i.traceIs(e,\"bar\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbar\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),o.exit().remove(),o.each(function(t){var e=n.select(this),i=t[0],o=(i.mlw+1||a.width+1)-1;e.style(\"stroke-width\",o+\"px\").call(s.fill,i.mc||r.color),o&&e.call(s.stroke,i.mlc||a.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(e,\"box-violin\")&&e.visible?[t]:[]);r.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),r.exit().remove(),r.each(function(){var t=e.line.width,r=n.select(this);r.style(\"stroke-width\",t+\"px\").call(s.fill,e.fillcolor),t&&s.stroke(r,e.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendpie\").data(i.traceIs(e,\"pie\")&&e.visible?[t]:[]);r.enter().append(\"path\").classed(\"legendpie\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),r.exit().remove(),r.size()&&r.call(c,t[0],e)}).each(function(t){var r=t[0].trace,i=r.visible&&r.fill&&\"none\"!==r.fill,a=l.hasLines(r),s=r.contours,c=!1,u=!1;if(s){var f=s.coloring;\"lines\"===f?c=!0:a=\"none\"===f||\"heatmap\"===f||s.showlines,\"constraint\"===s.type?i=\"=\"!==s._operation:\"fill\"!==f&&\"heatmap\"!==f||(u=!0)}var h=l.hasMarkers(r)||l.hasText(r),p=i||u,d=a||c,g=h||!p?\"M5,0\":d?\"M5,-2\":\"M5,-3\",v=n.select(this),m=v.select(\".legendfill\").selectAll(\"path\").data(i||u?[t]:[]);m.enter().append(\"path\").classed(\"js-fill\",!0),m.exit().remove(),m.attr(\"d\",g+\"h30v6h-30z\").call(i?o.fillGroupStyle:function(t){if(t.size()){var n=\"legendfill-\"+r.uid;o.gradient(t,e,n,\"horizontalreversed\",r.colorscale,\"fill\")}});var y=v.select(\".legendlines\").selectAll(\"path\").data(a||c?[t]:[]);y.enter().append(\"path\").classed(\"js-line\",!0),y.exit().remove(),y.attr(\"d\",g+(c?\"l30,0.0001\":\"h30\")).call(a?o.lineGroupStyle:function(t){if(t.size()){var n=\"legendline-\"+r.uid;o.lineGroupStyle(t),o.gradient(t,e,n,\"horizontalreversed\",r.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),f=l.hasText(c),h=l.hasLines(c);function p(t,e,r){var n=a.nestedProperty(c,t).get(),i=a.isArrayOrTypedArray(n)&&e?e(n):n;if(r){if(i<r[0])return r[0];if(i>r[1])return r[1]}return i}function d(t){return t[0]}if(u||f||h){var g={},v={};if(u){g.mc=p(\"marker.color\",d),g.mx=p(\"marker.symbol\",d),g.mo=p(\"marker.opacity\",a.mean,[.2,1]),g.mlc=p(\"marker.line.color\",d),g.mlw=p(\"marker.line.width\",a.mean,[0,5]),v.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var m=p(\"marker.size\",a.mean,[2,16]);g.ms=m,v.marker.size=m}h&&(v.line={width:p(\"line.width\",d,[0,10])}),f&&(g.tx=\"Aa\",g.tp=p(\"textposition\",d),g.ts=10,g.tc=p(\"textfont.color\",d),g.tf=p(\"textfont.family\",d)),r=[a.minExtend(s,g)],(i=a.minExtend(c,v)).selectedpoints=null}var y=n.select(this).select(\"g.legendpoints\"),x=y.selectAll(\"path.scatterpts\").data(u?r:[]);x.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),x.exit().remove(),x.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var b=y.selectAll(\"g.pointtext\").data(f?r:[]);b.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),b.exit().remove(),b.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=e[r?\"increasing\":\"decreasing\"],a=i.line.width,o=n.select(this);o.style(\"stroke-width\",a+\"px\").call(s.fill,i.fillcolor),a&&s.stroke(o,i.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=e[r?\"increasing\":\"decreasing\"],a=i.line.width,l=n.select(this);l.style(\"fill\",\"none\").call(o.dashLine,i.line.dash,a),a&&s.stroke(l,i.line.color)})})}},{\"../../lib\":694,\"../../registry\":825,\"../../traces/pie/style_one\":1033,\"../../traces/scatter/subtypes\":1071,\"../color\":571,\"../drawing\":592,d3:149}],629:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../../build/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},f=a.list(t,null,!0),h=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<f.length;i++)if(!(r=f[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==h||r._showSpikeInitial||(h=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=h}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<f.length;i++)r=f[i],\"on\"!==h||r.showspikes||(h=\"off\");c._cartesianSpikesEnabled=h}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function f(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function h(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,s={},l=0;l<a.length;l++){var c=a[l],u=c+\".camera\",f=i[c]._scene;\"resetDefault\"===r?s[u]=null:\"resetLastSave\"===r&&(s[u]=o.extendDeep({},f.cameraInitial))}n.call(\"_guiRelayout\",t,s)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],f=i[u],h=u+\".hovermode\";s[h]=f.hovermode,l[h]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=f[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var f=u.projection.scale,h=\"in\"===a?2*f:.5*f;n.call(\"_guiRelayout\",t,c+\".projection.scale\",h)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var f=c[u];a[s+\".\"+f]=l[f]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){e[t]&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:f},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:f},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:f},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:f},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:h},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:h},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),h(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../../build/ploticon\":2,\"../../lib\":694,\"../../plots/cartesian/axis_ids\":745,\"../../plots/plots\":806,\"../../registry\":825}],630:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":631}],631:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t,e,r,o){var l=t._fullLayout,c=t._fullData,u=l._has(\"cartesian\"),f=l._has(\"gl3d\"),h=l._has(\"geo\"),p=l._has(\"pie\"),d=l._has(\"gl2d\"),g=l._has(\"ternary\"),v=l._has(\"mapbox\"),m=l._has(\"polar\"),y=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(l),x=[];function b(t){if(t.length){for(var r=[],n=0;n<t.length;n++){var i=t[n];-1===e.indexOf(i)&&r.push(s[i])}x.push(r)}}var _=[\"toImage\"];o&&_.push(\"sendDataToCloud\");b(_);var w=[],k=[],M=[],A=[];(u||d||p||g)+h+f+v+m>1?(k=[\"toggleHover\"],M=[\"resetViews\"]):h?(w=[\"zoomInGeo\",\"zoomOutGeo\"],k=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):f?(k=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):v?(k=[\"toggleHover\"],M=[\"resetViewMapbox\"]):k=d?[\"hoverClosestGl2d\"]:p?[\"hoverClosestPie\"]:[\"toggleHover\"];u&&(k=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);!u&&!d||y||(w=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));f?A=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||d)&&!y||g?A=[\"zoom2d\",\"pan2d\"]:v||h?A=[\"pan2d\"]:m&&(A=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(c)&&A.push(\"select2d\",\"lasso2d\");return b(A),b(w.concat(M)),b(k),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(x,r)}(t,r.modeBarButtonsToRemove,r.modeBarButtonsToAdd,r.showSendToCloud),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":745,\"../../registry\":825,\"../../traces/scatter/subtypes\":1071,\"./buttons\":629,\"./modebar\":632}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../../build/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i,\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var f=this.getLogo();r.watermark&&(f.className=f.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.prepend(f):this.element.appendChild(f),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._paperdiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../../build/ploticon\":2,\"../../lib\":694,d3:149,\"fast-isnumeric\":215}],633:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":732,\"../../plots/font_attributes\":769,\"../color/attributes\":570}],634:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,f){var h=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(h,p,s,t,e)}if(d(\"visible\",o(h,p,{name:\"buttons\",handleItemDefaults:c,calendar:f}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../plots/array_container_defaults\":738,\"../color\":571,\"./attributes\":633,\"./constants\":634}],636:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../../constants/alignment\"),h=f.LINE_SPACING,p=f.FROM_TL,d=f.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){var i;l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text((i=r,i.label?i.label:\"all\"===i.step?\"all\":i.count+i.step.charAt(0))).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,f=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));f.enter().append(\"g\").classed(\"button\",!0),f.exit().remove(),f.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,f=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*h,a=Math.max(i*c.lineCount(e),16)+3;f=Math.max(f,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*h,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:f}),c.positionText(i,p/2,f/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=f,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=f/2,_=\"middle\");u=Math.ceil(u),f=Math.ceil(f),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:f*d[_],t:f*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,f,u,o._name,r)})}},{\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plots/cartesian/axis_ids\":745,\"../../plots/plots\":806,\"../../registry\":825,\"../color\":571,\"../drawing\":592,\"./constants\":634,\"./get_update_object\":637,d3:149}],637:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:149}],638:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":633,\"./defaults\":635,\"./draw\":636}],639:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":570}],640:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":741,\"../../plots/cartesian/axis_ids\":745,\"./constants\":641}],641:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],642:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,f,h=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(h.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=h[y]||{},f=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=h}}function _(t,e){return n.coerce(h,p,o,t,e)}function w(t,e){return n.coerce(u,f,s,t,e)}}},{\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/axis_ids\":745,\"./attributes\":639,\"./oppaxis_attributes\":646}],643:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),f=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,h=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);h.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),h.order(),h.exit().remove(),h.each(function(t,o){var s=n.select(this),h=0===o,p=f.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};h?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[f.id2name(r.anchor)],u=s[f.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e.margin,A=e._size,T=r.domain,S=s._tickHeight,C=s._oppBottom;s._width=A.w*(T[1]-T[0]);var E=Math.round(M.l+A.w*T[0]),L=Math.round(A.t+A.h*(1-C)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+E+\",\"+L+\")\");var z=r.r2l(s.range[0]),O=r.r2l(s.range[1]),I=O-z;if(s.p2d=function(t){return t/s._width*I+z},s.d2p=function(t){return(t-z)/I*s._width},s._rl=[z,O],\"match\"!==u.rangemode){var D=l.r2l(u.range[0]),P=l.r2l(u.range[1])-D;s.d2pOppAxis=function(t){return(t-D)/P*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,f=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=h.coverSlip();function x(t){var u,h,x,b=+t.clientX-d;switch(f){case s:x=\"ew-resize\",u=v+b,h=m+b;break;case l:x=\"col-resize\",u=v+b,h=m;break;case c:x=\"col-resize\",u=v,h=m+b;break;default:x=\"ew-resize\",u=g,h=g+b}if(h<u){var _=h;h=u,u=_}a._pixelMin=u,a._pixelMax=h,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var f=l(n.d2p(r._rl[0])),h=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",f).attr(\"width\",h-f),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",f),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",h).attr(\"width\",n._width-h),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",f).attr(\"height\",p).attr(\"width\",h-f),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",f).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",h-f),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(f-s))-.5,m=Math.round(u(h-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":694,\"../../lib/setcursor\":714,\"../../plots/cartesian\":754,\"../../plots/cartesian/axis_ids\":745,\"../../plots/plots\":806,\"../../registry\":825,\"../color\":571,\"../dragelement\":589,\"../drawing\":592,\"../titles\":659,\"./constants\":641,d3:149}],644:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var f=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=f,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+f,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":745,\"./constants\":641}],645:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":694,\"./attributes\":639,\"./calc_autorange\":640,\"./defaults\":642,\"./draw\":643,\"./helpers\":644,\"./oppaxis_attributes\":646}],646:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],647:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":684,\"../../plot_api/plot_template\":732,\"../../traces/scatter/attributes\":1047,\"../annotations/attributes\":554,\"../drawing/attributes\":591}],648:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var f=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],h=n.aggNums(Math.max,null,f),p=n.aggNums(Math.min,null,f),d=p<0?Math.abs(p)+c:c,g=h>0?h+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,f,h=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((f=s(u[c]))<h&&(h=f),f>p&&(p=f)));return p>=h?[h,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,f,h=r[o];if(h._extremes={},\"paper\"!==h.xref){var p=\"pixel\"===h.xsizemode?h.xanchor:h.x0,d=\"pixel\"===h.xsizemode?h.xanchor:h.x1;(f=u(c=i.getFromId(t,h.xref),p,d,h.path,a.paramIsX))&&(h._extremes[c._id]=i.findExtremes(c,f,s(h)))}if(\"paper\"!==h.yref){var g=\"pixel\"===h.ysizemode?h.yanchor:h.y0,v=\"pixel\"===h.ysizemode?h.yanchor:h.y1;(f=u(c=i.getFromId(t,h.yref),g,v,h.path,a.paramIsY))&&(h._extremes[c._id]=i.findExtremes(c,f,l(h)))}}}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"./constants\":649,\"./helpers\":652}],649:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],650:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),f=[\"x\",\"y\"],h=0;h<2;h++){var p,d,g,v=f[h],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],M=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=M}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../../plots/cartesian/axes\":742,\"./attributes\":647,\"./helpers\":652}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),f=t(\"./constants\"),h=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,M,A,T,S,C,E,L,z,O,I=10,D=10,P=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,V=a.getFromId(t,r.xref),U=a.getFromId(t,r.yref),q=h.getDataToPixel(t,V),H=h.getDataToPixel(t,U,!0),G=h.getPixelToData(t,V),W=h.getPixelToData(t,U,!0),Y=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:P?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:P?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:Y.node(),gd:t,prepFn:function(n){P&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?z=r.path:(m=P?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=P?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,E=\"x0\",T=x,L=\"x1\"):(A=x,E=\"x1\",T=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",M=b,C=\"y1\"):(k=b,S=\"y1\",M=y,C=\"y0\");Z(n),K(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?$:J},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>I&&i>D&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function $(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;P?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},V&&\"date\"===V.type&&(o=h.encodeDate(o))),R?j(\"yanchor\",r.yanchor=W(w+i)):(s=function(t){return W(H(t)+i)},U&&\"date\"===U.type&&(s=h.encodeDate(s))),j(\"path\",r.path=v(z,o,s))}else P?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=W(w+i)):(j(\"y0\",r.y0=W(y+i)),j(\"y1\",r.y1=W(b+i)));e.attr(\"d\",g(t,r)),K(p,r)}function J(n,i){if(B){var a=function(t){return t},o=a,s=a;P?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},V&&\"date\"===V.type&&(o=h.encodeDate(o))),R?j(\"yanchor\",r.yanchor=W(w+i)):(s=function(t){return W(H(t)+i)},U&&\"date\"===U.type&&(s=h.encodeDate(s))),j(\"path\",r.path=v(z,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=P?l:G(l)),j(\"y0\",r.y0=R?c:W(c))}else if(\"resize-over-end-point\"===O){var u=x+n,f=R?b-i:b+i;j(\"x1\",r.x1=P?u:G(u)),j(\"y1\",r.y1=R?f:W(f))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?M+i:M,Y=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?T+n:T;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=M-i),(!R&&N-d>D||R&&d-N>D)&&(j(S,r[S]=R?d:W(d)),j(C,r[C]=R?N:W(N))),X-Y>I&&(j(E,r[E]=P?Y:G(Y)),j(L,r[L]=P?X:G(X)))}e.attr(\"d\",g(t,r)),K(p,r)}function K(t,e){(P||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(P?e.xanchor:i.midRange(r?[e.x0,e.x1]:h.extractPathCoords(e.path,f.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:h.extractPathCoords(e.path,f.paramIsY)));if(a=h.roundPositionForSharpStrokeRendering(a,1),o=h.roundPositionForSharpStrokeRendering(o,1),P&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(P){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),Y.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=h.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=h.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=h.decodeDate(n)),v&&\"date\"===v.type&&(s=h.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(f.segmentRE,function(t){var n=0,c=t.charAt(0),u=f.paramIsX[c],h=f.paramIsY[c],p=f.numParams[c],d=t.substr(1).replace(f.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):h[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),M=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+M+\" 0 1,1 \"+(b+\",\"+(_-k))+M+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(f.segmentRE,function(t){var n=0,i=t.charAt(0),a=f.paramIsX[i],o=f.paramIsY[i],s=f.numParams[i];return i+t.substr(1).replace(f.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":694,\"../../lib/setcursor\":714,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"../color\":571,\"../dragelement\":589,\"../drawing\":592,\"./constants\":649,\"./helpers\":652}],652:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":694,\"./constants\":649}],653:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":753,\"./attributes\":647,\"./calc_autorange\":648,\"./defaults\":650,\"./draw\":651}],654:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plot_api/plot_template\":732,\"../../plots/animation_attributes\":737,\"../../plots/font_attributes\":769,\"../../plots/pad_attributes\":805,\"./constants\":655}],655:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],656:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var f=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=f[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"./attributes\":654,\"./constants\":655}],657:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),f=t(\"../../constants/alignment\"),h=f.LINE_SPACING,p=f.FROM_TL,d=f.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var f=e._dims={};f.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var h=t._fullLayout._size;f.lx=h.l+h.w*e.x,f.ly=h.t+h.h*(1-e.y),\"fraction\"===e.lenmode?f.outerLength=Math.round(h.w*e.len):f.outerLength=e.len,f.inputAreaStart=0,f.inputAreaLength=Math.round(f.outerLength-e.pad.l-e.pad.r);var v=(f.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(f.labelStride=Math.max(1,Math.ceil(m/v)),f.labelHeight=c,f.currentValueMaxWidth=0,f.currentValueHeight=0,f.currentValueTotalHeight=0,f.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);f.currentValueMaxWidth=Math.max(f.currentValueMaxWidth,Math.ceil(n.width)),f.currentValueHeight=Math.max(f.currentValueHeight,Math.ceil(n.height)),f.currentValueMaxLines=Math.max(f.currentValueMaxLines,i)}),f.currentValueTotalHeight=f.currentValueHeight+e.currentvalue.offset,x.remove()}f.height=f.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+f.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(f.lx-=f.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(f.lx-=f.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(f.ly-=f.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(f.ly-=f.height/2,w=\"middle\"),f.outerLength=Math.ceil(f.outerLength),f.height=Math.ceil(f.height),f.lx=Math.round(f.lx),f.ly=Math.round(f.ly);var k={y:e.y,b:f.height*d[w],t:f.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=f.outerLength*p[_],k.r=f.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),f=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)f+=r;else f+=e.steps[e.active].label;e.currentvalue.suffix&&(f+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(f).call(l.convertToTspans,e._gd);var p=l.lineCount(c),d=(a.currentValueMaxLines+1-p)*e.currentvalue.font.size*h;return l.positionText(c,n,d),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})});return n.call(o.font,r.font).text(e.step.label).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*h+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(T,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function M(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=C(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=C(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function T(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function C(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function E(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var f=r[c];m(t,f)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(E,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(T,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plot_api/plot_template\":732,\"../../plots/plots\":806,\"../color\":571,\"../drawing\":592,\"./constants\":655,d3:149}],658:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":654,\"./constants\":655,\"./defaults\":656,\"./draw\":657}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,M=!1,A=d.title,T=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},C=S.family,E=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var z=t._context.edits[p];\"\"===T?k=0:T.replace(h,\" % \")===v.replace(h,\" % \")&&(k=.2,M=!0,z||(T=\"\"));w.meta&&(T=s.templateString(T,{meta:w.meta}));var O=T||z;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var I=_.selectAll(\"text\").data(O?[0]:[]);if(I.enter().append(\"text\"),I.text(T).attr(\"class\",e),I.exit().remove(),!O)return _;function D(t){s.syncOrAsync([P,R],t)}function P(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":C,\"font-size\":n.round(E,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&T){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),f={left:0,top:0,right:w.width,bottom:w.height},h=y.maxShift||(f[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(h<0)r=h;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(h,r)}if(r>0||h<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}I.call(D),z&&(T?I.on(\".opacity\",null):(k=0,M=!0,I.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(f.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(f.HIDE_PLACEHOLDER).style(\"opacity\",0)})),I.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(D)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return I.classed(\"js-placeholder\",M),_}};var h=/ [XY][0-9]* /},{\"../../constants/interactions\":670,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plots/plots\":806,\"../../registry\":825,\"../color\":571,\"../drawing\":592,d3:149,\"fast-isnumeric\":215}],660:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plot_api/plot_template\":732,\"../../plots/font_attributes\":769,\"../../plots/pad_attributes\":805,\"../color/attributes\":570}],661:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],662:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"./attributes\":660,\"./constants\":661}],663:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,f=t(\"./constants\"),h=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(f.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,f.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(f.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",f.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||f.blankHeaderOpts,h={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(T,i,h,p),s.ensureSingle(e,\"text\",f.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(f.arrowSymbol[i.direction])}).attr({x:l.headerWidth-f.arrowOffsetX+i.pad.l,y:l.headerHeight/2+f.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(f.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?f.dropdownButtonClassName:f.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),h=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(h.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+f.gapButtonHeader:d=m.headerWidth+f.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-f.gapButtonHeader+f.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-f.gapButtonHeader+f.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:f.gapButton,xPad:f.gapButton,index:0},M={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(T,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(M.w=Math.max(m.openWidth,m.headerWidth),M.h=b.y-M.t):(M.w=b.x-M.l,M.h=Math.max(m.openHeight,m.headerHeight)),M.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,h=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=h.heights[l]+f.gapButton;else for(o=0,l=0;l<p;l++)o+=h.widths[l]+f.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,M):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",f.itemRectClassName,function(t){t.attr({rx:f.rx,ry:f.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){s.ensureSingle(t,\"text\",f.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}).call(o.font,e.font).text(r.label).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.activeColor)})}function w(t){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.hoverColor)}function k(t,e){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,e.bgcolor)}function M(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+f.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(f.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var h=s.select(\".\"+f.itemTextClassName),p=h.node()&&o.bBox(h.node()).width,d=Math.max(p+f.textPadX,f.minWidth),g=e.font.size*u,v=l.lineCount(h),m=Math.max(g*v,f.minHeight)+f.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+f.gapButton,r.openHeight+=m+f.gapButton):(r.totalWidth+=d+f.gapButton,r.openWidth+=d+f.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=f.gapButton:r.totalWidth-=f.gapButton,r.headerWidth=r.width1+f.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=f.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=f.arrowPadX),a.remove();var h=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=h,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=h/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:h*({right:1,center:.5}[g]||0),r:h*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return f.autoMarginIdRoot+t._index}function T(t,e,r,n){n=n||{};var i=t.select(\".\"+f.itemRectClassName),a=t.select(\".\"+f.itemTextClassName),s=e.borderwidth,c=r.index,h=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?h.heights[c]:h.height1);i.attr({x:0,y:0,width:n.width||(p?h.width1:h.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,f.textOffsetX,d/2-v+f.textOffsetY),p?r.y+=h.heights[c]+r.yPad:r.x+=h.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(f.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+f.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[f.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+f.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+f.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(f.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",f.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];M(t,y)}var x=\"updatemenus\"+e._uid,b=new h(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plot_api/plot_template\":732,\"../../plots/plots\":806,\"../color\":571,\"../drawing\":592,\"./constants\":661,\"./scrollbox\":665,d3:149}],664:[function(t,e,r){arguments[4][658][0].apply(r,arguments)},{\"./attributes\":660,\"./constants\":661,\"./defaults\":662,\"./draw\":663,dup:658}],665:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,f,h,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(f=(u=d)+w,x?(h=v,k=(p=Math.min(h+k,c))-h):k=(p=v+k)-(h=Math.max(p-k,0))):(p=(h=v)+k,b?w=(f=d+w)-(u=Math.max(f-w,0)):(u=d,w=(f=Math.min(u+w,l))-u)),this._box={l:u,t:h,w:w,h:k};var M=g>w,A=s.barLength+2*s.barPad,T=s.barWidth+2*s.barPad,S=d,C=v+m;C+T>c&&(C=c-T);var E=this.container.selectAll(\"rect.scrollbar-horizontal\").data(M?[0]:[]);E.exit().on(\".drag\",null).remove(),E.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),M?(this.hbar=E.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:C,width:A,height:T}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,z=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,I=d+g,D=v;I+z>l&&(I=l-z);var P=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);P.exit().on(\".drag\",null).remove(),P.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=P.attr({rx:s.barRadius,ry:s.barRadius,x:I,y:D,width:z,height:O}),this._vbarYMin=D+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?f+z+.5:f+.5,N=h-.5,j=M?p+T+.5:p+.5,V=o._topdefs.selectAll(\"#\"+R).data(M||L?[0]:[]);if(V.exit().remove(),V.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),M||L?(this._clipRect=V.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),M||L){var U=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(U);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));M&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":694,\"../color\":571,\"../drawing\":592,d3:149}],666:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],667:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],668:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],669:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],670:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DBLCLICKDELAY:300,DESELECTDIM:.2}},{}],671:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],672:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],673:[function(t,e,r){\"use strict\";r.version=\"1.44.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"../build/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"../build/ploticon\":2,\"./components/annotations\":562,\"./components/annotations3d\":567,\"./components/colorscale\":583,\"./components/errorbars\":598,\"./components/fx\":610,\"./components/grid\":614,\"./components/images\":619,\"./components/legend\":627,\"./components/rangeselector\":638,\"./components/rangeslider\":645,\"./components/shapes\":653,\"./components/sliders\":658,\"./components/updatemenus\":664,\"./fonts/mathjax_config\":674,\"./lib/queue\":709,\"./locale-en\":723,\"./locale-en-us\":722,\"./plot_api\":727,\"./plot_api/plot_schema\":731,\"./plots/plots\":806,\"./registry\":825,\"./snapshot\":830,\"./traces/scatter\":1059,d3:149,\"es6-promise\":204}],674:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],675:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],676:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-15}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function f(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,f,h,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,f=o,h=s):r<n?(u=r,h=n):(u=n,h=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(h-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,f,0)+x(d,h,0)+\"Z\":\"M\"+v(p,u)+x(p,f,0)+x(p,h,0)+\"ZM\"+v(d,u)+x(d,f,1)+x(d,h,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,h,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,h,0)+\"L\"+v(p,h)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return f(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return f(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return f(t,e,r,n,i,a,1)}}},{\"./mod\":701}],677:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,f=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,f?t!==i.constructor&&(t=!1):t=i.constructor),f+=o);if(!f)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(f)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(f),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":671,\"fast-isnumeric\":215}],679:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],680:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],681:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,f=t(\"./array\").isArrayOrTypedArray;function h(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&f(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){f(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,f,h,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],f=m?p.length:g?p[s].length:c.length,l=0;l<f;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(h=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=h);else for(s=0;s<y;s++)void 0!==(h=a(t[s],g?p[s]:p,n[s]))&&(d[s]=h);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!h(t[a][o],n?r[a][o]:r))return!1}else if(!h(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&f(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!h(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)f(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=h},{\"../components/colorscale/scales\":586,\"../constants/interactions\":670,\"../plots/attributes\":739,\"./array\":677,\"./mod\":701,\"./nested_property\":702,\"./regex\":710,\"fast-isnumeric\":215,tinycolor2:515}],682:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,f=c.ONEDAY,h=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var M=k[1],A=k[3]||\"1\",T=Number(k[5]||1),S=Number(k[7]||0),C=Number(k[9]||0),E=Number(k[11]||0);if(c){if(2===M.length)return u;var L;M=Number(M);try{var z=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=z.newDate(M,z.toMonthIndex(M,A,O),T)}else L=z.newDate(M,Number(A),T)}catch(t){return u}return L?(L.toJD()-g)*f+S*h+C*p+E*d:u}M=2===M.length?(Number(M)+2e3-b)%100+b:Number(M),A-=1;var I=new Date(Date.UTC(2e3,A,T,S,C));return I.setUTCFullYear(M),I.getUTCMonth()!==A?u:I.getUTCDate()!==T?u:I.getTime()+E*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*f,M=3*h,A=5*p;function T(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/f)+g,C=Math.floor(l(t,f));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(C/h):0,s=e<k?Math.floor(C%h/p):0,c=e<M?Math.floor(C%p/d):0,y=e<A?C%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<M?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return T(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+f&&t<=i-f))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return T(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function C(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var E=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,f),n=w(Math.floor(r/h),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),E[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+C(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return C(e,t,n,i)};var L=3*f;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,f);if(t=Math.round(t-n),r)try{var i=Math.round(t/f)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*f+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%f))if(c)try{1===(r=c.fromJD(n/f+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var h=t.length-l;return{exactYears:i/h,exactMonths:a/h,exactDays:s/h}}},{\"../constants/numerical\":671,\"../registry\":825,\"./loggers\":698,\"./mod\":701,d3:149,\"fast-isnumeric\":215}],683:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:93}],684:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,f,h,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(f=i(u)))?(f?(f=!1,h=c&&i(c)?c:[]):h=c&&n(c)?c:{},p[l]=a([h,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":695}],685:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],686:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){return!0===t[0].trace.visible}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],687:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};r.locationToFeature=function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n=function(t,e){return(0,o[t])(e)}(t,e);if(n){for(var a=0;a<r.length;a++){var s=r[a];if(s.id===n)return s}i.log([\"Location with id\",n,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}},{\"../lib\":694,\"country-regex\":123}],688:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":671}],689:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,f=n-e,h=a-e,p=s-a,d=l*p-u*f;if(0===d)return null;var g=(c*p-u*h)/d,v=(c*f-l*h)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+f*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,f=n-e,h=o-i,p=c-a,d=u*u+f*f,g=h*h+p*p,v=Math.min(l(u,f,d,i-t,a-e),l(u,f,d,o-t,c-e),l(h,p,g,t-i,e-a),l(h,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),f=t.getPointAtLength(o(r,e)),h={x:(4*f.x+l.x+c.x)/6,y:(4*f.y+l.y+c.y)/6,theta:u};return n[r]=h,h},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),f=u;function h(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,f=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+f*f)}for(var p=h(c);p;){if((c+=p+r)>f)return;p=h(c)}for(p=h(f);p;){if(c>(f-=p+r))return;p=h(f)}return{min:c,max:f,len:f-c,total:u,isClosed:0===c&&f===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,f=0,h=0,p=s;f<c;){if(i=(h+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:h=i,f++}return a}},{\"./mod\":701}],690:[function(t,e,r){\"use strict\";e.exports=function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t}},{}],691:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function f(t,e){var r=t;return r[3]*=e,r}function h(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=[];if(n=void 0!==t.colorscale?o.makeColorScaleFunc(o.extractScale(t,{cLetter:\"c\"})):h,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:h,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var b=0;b<r;b++)d=i(v,b),g=s(e,b),x[b]=f(d,g);else x=f(a(v),e);return x},parseColorScale:function(t,e){return void 0===e&&(e=1),(t.reversescale?o.flipScale(t.colorscale):t.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":570,\"../components/colorscale\":583,\"./array\":677,\"color-normalize\":109,\"fast-isnumeric\":215,tinycolor2:515}],692:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":693}],693:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],694:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var f=t(\"./coerce\");l.valObjectMeta=f.valObjectMeta,l.coerce=f.coerce,l.coerce2=f.coerce2,l.coerceFont=f.coerceFont,l.coerceHoverinfo=f.coerceHoverinfo,l.coerceSelectionMarkerOpacity=f.coerceSelectionMarkerOpacity,l.validate=f.validate;var h=t(\"./dates\");l.dateTime2ms=h.dateTime2ms,l.isDateTime=h.isDateTime,l.ms2DateTime=h.ms2DateTime,l.ms2DateTimeLocal=h.ms2DateTimeLocal,l.cleanDate=h.cleanDate,l.isJSDate=h.isJSDate,l.formatDate=h.formatDate,l.incrementMonth=h.incrementMonth,l.dateTick0=h.dateTick0,l.dfltRange=h.dfltRange,l.findExactDates=h.findExactDates,l.MIN_MS=h.MIN_MS,l.MAX_MS=h.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");function k(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear,l.getGraphDiv=t(\"./get_graph_div\"),l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var f=parseInt(c,n);return e&&e[c]||f!==1/0&&f>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r){if(l.isArrayOrTypedArray(t))for(var n=Math.min(t.length,e.length),i=0;i<n;i++)e[i][r]=t[i]},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=k(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,f=r?r[u]:u;void 0!==(i=f)&&i<t.length&&(t[f].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=k(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isPlotDiv=function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},l.removeElement=function(t){var e=t&&t.parentNode;e&&e.removeChild(t)},l.addStyleRule=function(t,e){l.addRelatedStyleRule(\"global\",t,e)},l.addRelatedStyleRule=function(t,e,r){var n=\"plotly.js-style-\"+t,i=document.getElementById(n);i||((i=document.createElement(\"style\")).setAttribute(\"id\",n),i.appendChild(document.createTextNode(\"\")),document.head.appendChild(i));var a=i.sheet;a.insertRule?a.insertRule(e+\"{\"+r+\"}\",0):a.addRule?a.addRule(e,r,0):l.warn(\"addStyleRule failed\")},l.deleteRelatedStyleRule=function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&l.removeElement(r)},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var M=/^([^\\[\\.]+)\\.(.+)?/,A=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(M))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(A))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l};var T=/%{([^\\s%{}:]*)(:[^}]*)?}/g,S=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(T,function(t,n){return S.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var C=/^:/,E=0;l.hovertemplateString=function(t,e){var r=arguments,i={};return t.replace(T,function(t,a,o){var s,c,u;for(u=2;u<r.length;u++){if((s=r[u]).hasOwnProperty(a)){c=s[a];break}if(S.test(a)||(c=i[a]||l.nestedProperty(s,a).get())&&(i[a]=c),void 0!==c)break}return void 0===c&&(E<10&&(l.warn(\"Variable '\"+a+\"' in hovertemplate could not be found!\"),c=t),10===E&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),E++),o?c=n.format(o.replace(C,\"\"))(c):e.hasOwnProperty(a+\"Label\")&&(c=e[a+\"Label\"]),c})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var L=2e9;l.seedPseudoRandom=function(){L=2e9},l.pseudoRandom=function(){var t=L;return L=(69069*L+1)%4294967296,Math.abs(L-t)<429496729?l.pseudoRandom():L/4294967296}},{\"../constants/numerical\":671,\"./anchor_utils\":675,\"./angles\":676,\"./array\":677,\"./clean_number\":678,\"./clear_responsive\":680,\"./coerce\":681,\"./dates\":682,\"./extend\":684,\"./filter_unique\":685,\"./filter_visible\":686,\"./geometry2d\":689,\"./get_graph_div\":690,\"./identity\":693,\"./is_plain_object\":695,\"./keyed_container\":696,\"./localize\":697,\"./loggers\":698,\"./make_trace_groups\":699,\"./matrix\":700,\"./mod\":701,\"./nested_property\":702,\"./noop\":703,\"./notifier\":704,\"./push_unique\":708,\"./regex\":710,\"./relative_attr\":711,\"./relink_private\":712,\"./search\":713,\"./stats\":716,\"./throttle\":719,\"./to_log_range\":720,d3:149,\"fast-isnumeric\":215}],695:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],696:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var f=i.test(a),h={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(f?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,f?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,h},get:function(t){if(s){var e=u[t];return void 0===e?void 0:f?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?h:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,h)},remove:function(t){var e=u[t];if(void 0===e)return h;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],h.set(t,null);if(f){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return h},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=f?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return h}},{\"./nested_property\":702}],697:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":825}],698:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":730}],699:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});return n.exit().remove(),n.enter().append(\"g\").attr(\"class\",r),n.order(),n}},{}],700:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],701:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],702:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,f=t,h=\"\",p=[[t,h]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(f))throw\"array index but container is not an array\";if(-1===a){if(d=!c(f,e.slice(s+1),n,r))break;return}if(!u(f,a,e[s+1],d))break;if(\"object\"!=typeof(f=f[a])||null===f)throw\"container is not an object\";h=l(h,a),p.push([f,h])}if(d){if(s===e.length-1&&(delete f[e[s]],Array.isArray(f)&&+e[s]==f.length-1))for(;f.length&&void 0===f[f.length-1];)f.pop()}else f[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,f=r,h=n.replace(\"-1\",0),p=!l&&o(r,h),d=e[0];for(a=0;a<t.length;a++)h=n.replace(\"-1\",a),l&&(p=o(f=r[a%r.length],h)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(f);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":677,\"fast-isnumeric\":215}],703:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],704:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:149,\"fast-isnumeric\":215}],705:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":714}],706:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,f=r[0];for(e=1;e<r.length;e++)if(f[0]!==r[e][0]||f[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,f,h,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(f=v,h=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(f,v))||l>Math.max(f,v)||c>Math.max(h,m)))if(c<Math.min(h,m))l!==p&&y++;else{if(c===(d=v===f?c:h+(l-f)*(m-h)/(v-f)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}};var o=a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),f=Math.sqrt(u),h=[-c[1]/f,c[0]/f];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,h))>i)return!0;return!1};a.filter=function(t,e){var r=[t[0]],n=0,i=0;function a(a){t.push(a);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||o(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&a(t.pop());return{addPt:a,raw:t,filtered:r}}},{\"../constants/numerical\":671,\"./matrix\":700}],707:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":715,regl:480}],708:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],709:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":694,\"../plot_api/plot_config\":730}],710:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],711:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],712:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":677,\"./is_plain_object\":695}],713:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,f=0,h=e.length,p=0,d=h>1?(e[h-1]-e[0])/(h-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);f<h&&p++<100;)u(e[a=Math.floor((f+h)/2)],t)?f=a+1:h=a;return p>90&&i.log(\"Long binary search...\"),f-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":693,\"./loggers\":698,\"fast-isnumeric\":215}],714:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],715:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":571}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":677,\"fast-isnumeric\":215}],717:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":109}],718:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,T){var S=t.text(),E=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var z=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return z+=\"-math\",L.selectAll(\"svg.\"+z).remove(),L.selectAll(\"g.\"+z+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),E?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(E[2],a,function(n,i,a){L.selectAll(\"svg.\"+z).remove(),L.selectAll(\"g.\"+z+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(z+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:z,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\";o.select(\"g\").attr({fill:c,stroke:c});var u=s(o,\"width\"),f=s(o,\"height\"),h=+t.attr(\"x\")-u*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],p=-(r||s(t,\"height\"))/4;\"y\"===z[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-u/2,p-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===z[0]?o.attr({x:t.attr(\"x\"),y:p-f/2}):\"a\"===z[0]?o.attr({x:0,y:p}):o.attr({x:h,y:+t.attr(\"y\")+p-f/2}),T&&T.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(z=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+z).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)T(i[s])}function T(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var f=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(f);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=h[i],r.appendChild(f),r.appendChild(g)}else r.appendChild(f);n.select(f).attr(o),r=t.node=f,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function E(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),z=0;z<L.length;z++){var O=L[z],I=O.match(y),D=I&&I[2].toLowerCase(),P=f[D];if(\"br\"===D)u();else if(void 0===P)S(r,C(O));else if(I[1])E(D);else{var R=I[4],F={type:D},B=M(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),P&&(B+=\";\"+P)):P&&(B=P),B&&(F.style=B),\"a\"===D){s=!0;var N=M(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=M(R,w)||\"_blank\",F.popup=M(R,k))}}T(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),T&&T.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var f={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},h={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function M(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&C(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],f=u.match(y),h=f&&f[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(o.push(u),s=h);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var T={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function C(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):T[e])||t})}function E(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=C,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(E(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(E(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":666,\"../constants/xmlns_namespaces\":672,\"../lib\":694,d3:149}],719:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],720:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":215}],721:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":771,\"topojson-client\":518}],722:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],723:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],724:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":825}],725:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function f(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=h(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function h(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e,\"from-root\")}return a}return f(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:f}},{\"../lib\":694}],726:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=l.cleanId,u=l.getFromTrace,f=t(\"../components/color\");function h(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=c(r,n))}function p(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function d(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function g(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function m(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,u=(s.subplotsRegistry.ternary||{}).attrRegex,d=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var y=t[v];y.anchor&&\"free\"!==y.anchor&&(y.anchor=c(y.anchor)),y.overlaying&&(y.overlaying=c(y.overlaying)),y.type||(y.isdate?y.type=\"date\":y.islog?y.type=\"log\":!1===y.isdate&&!1===y.islog&&(y.type=\"linear\")),\"withzero\"!==y.autorange&&\"tozero\"!==y.autorange||(y.autorange=!0,y.rangemode=\"tozero\"),delete y.islog,delete y.isdate,delete y.categories,m(y,\"domain\")&&delete y.domain,void 0!==y.autotick&&(void 0===y.tickmode&&(y.tickmode=y.autotick?\"auto\":\"linear\"),delete y.autotick),p(y)}else if(l&&l.test(v)){p(t[v].radialaxis)}else if(u&&u.test(v)){var x=t[v];p(x.aaxis),p(x.baxis),p(x.caxis)}else if(d&&d.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],M=_[2],A=i([],w),T=[];for(n=0;n<3;++n)T[n]=k[n]+M*A[2+4*n];b.camera={eye:{x:T[0],y:T[1],z:T[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}p(b.xaxis),p(b.yaxis),p(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var C=t.annotations[e];o.isPlainObject(C)&&(C.ref&&(\"paper\"===C.ref?(C.xref=\"paper\",C.yref=\"paper\"):\"data\"===C.ref&&(C.xref=\"x\",C.yref=\"y\"),delete C.ref),h(C,\"xref\"),h(C,\"yref\"))}var E=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<E;e++){var L=t.shapes[e];o.isPlainObject(L)&&(h(L,\"xref\"),h(L,\"yref\"))}var z=t.legend;return z&&(z.x>3?(z.x=1.02,z.xanchor=\"left\"):z.x<-2&&(z.x=-.02,z.xanchor=\"right\"),z.y>3?(z.y=1.02,z.yanchor=\"bottom\"):z.y<-2&&(z.y=-.02,z.yanchor=\"top\")),p(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),f.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=f.defaults,u=i.error_y.color||(a.traceIs(i,\"bar\")?f.defaultLine:l[e%l.length]);i.error_y.color=f.addOpacity(f.rgb(u),f.opacity(u)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!a.traceIs(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=c(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=c(i.yaxis,\"y\")),a.traceIs(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!a.traceIs(i,\"pie\")&&!a.traceIs(i,\"bar\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=v(i.textposition[n]);else i.textposition&&(i.textposition=v(i.textposition));var h=a.getModule(i);if(h&&h.colorbar){var y=h.colorbar.container,x=y?i[y]:i;x&&x.colorscale&&(\"YIGnBu\"===x.colorscale&&(x.colorscale=\"YlGnBu\"),\"YIOrRd\"===x.colorscale&&(x.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var b=[\"x\",\"y\",\"z\"];for(n=0;n<b.length;n++){var _=i.contours[b[n]];o.isPlainObject(_)&&(_.highlightColor&&(_.highlightcolor=_.highlightColor,delete _.highlightColor),_.highlightWidth&&(_.highlightwidth=_.highlightWidth,delete _.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var w=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,M=d(i.increasing),A=d(i.decreasing);if(!1!==M&&!1!==A){var T=g(M,A,w,k);T&&(i.name=T)}else!M&&!A||i.name||(i.name=M||A)}if(Array.isArray(i.transforms)){var S=i.transforms;for(n=0;n<S.length;n++){var C=S[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var E=C.styles,L=Object.keys(E);C.styles=[];for(var z=0;z<L.length;z++)C.styles.push({target:L[z],value:E[L[z]]})}}}}m(i,\"line\")&&delete i.line,\"marker\"in i&&(m(i.marker,\"line\")&&delete i.marker.line,m(i,\"marker\")&&delete i.marker),f.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),p(i),i.colorbar&&p(i.colorbar),i.marker&&i.marker.colorbar&&p(i.marker.colorbar),i.line&&i.line.colorbar&&p(i.line.colorbar),i.aaxis&&p(i.aaxis),i.baxis&&p(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var y=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function x(t){var e=t.search(y);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=x(e);r;){if(r in t)return!0;r=x(r)}return!1};var b=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=u(t,i,b[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var f=l+\".type\";void 0===r[l]&&void 0===r[f]&&o.nestedProperty(t.layout,f).set(null)}}}},{\"../components/color\":571,\"../lib\":694,\"../plots/cartesian/axis_ids\":745,\"../plots/plots\":806,\"../registry\":825,\"fast-isnumeric\":215,\"gl-mat4/fromQuat\":253}],727:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":827,\"./plot_api\":729,\"./template_api\":734,\"./to_image\":735,\"./validate\":736}],728:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var f=e.astr,h=s.getComponentMethod(f,\"supplyLayoutDefaults\"),p=s.getComponentMethod(f,\"draw\"),d=s.getComponentMethod(f,\"drawOne\"),g=n.replot||n.recalc||h===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",f);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",f,y),!0;e.set(y)}return!g&&(h(v,m),p(t),!0)}var x,b,_,w,k,M,A,T,S=Object.keys(r).map(Number).sort(o),C=e.get(),E=C||[],L=u(m,f).get(),z=[],O=-1,I=E.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),M=w[\"\"],A=l(M),_<0||_>E.length-(A?0:1))a.warn(\"index out of range\",f,_);else if(void 0!==M)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",f,_),c(M)?z.push(_):A?(\"add\"===M&&(M={}),E.splice(_,0,M),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",f,_,M),-1===O&&(O=_);else for(b=0;b<k.length;b++)T=f+\"[\"+_+\"].\",u(E[_],k[b],T).set(w[k[b]]);for(x=z.length-1;x>=0;x--)E.splice(z[x],1),L&&L.splice(z[x],1);if(E.length?C||e.set(E):e.set(null),g)return!1;if(h(v,m),d!==i){var D;if(-1===O)D=S;else{for(I=Math.max(E.length,I),D=[],x=0;x<S.length&&!((_=S[x])>=O);x++)D.push(_);for(x=O;x<I;x++)D.push(x)}for(x=0;x<D.length;x++)d(t,D[x])}else p(t);return!0}},{\"../lib/is_plain_object\":695,\"../lib/loggers\":698,\"../lib/noop\":703,\"../lib/search\":713,\"../registry\":825,\"./container_array_match\":724}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),f=t(\"./plot_schema\"),h=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../components/colorbar/connect\"),y=t(\"../plots/cartesian/graph_interact\").initInteractions,x=t(\"../constants/xmlns_namespaces\"),b=t(\"../lib/svg_text_utils\"),_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),M=t(\"./subroutines\"),A=t(\"./edit_types\"),T=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function E(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){E(t,v.combine(e,\"white\"))}function z(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=E),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var f=c.scrollZoom,h=c._scrollZoom={};if(!0===f)h.cartesian=1,h.gl3d=1,h.geo=1,h.mapbox=1;else if(\"string\"==typeof f){var p=f.split(\"+\");for(i=0;i<p.length;i++)h[p[i]]=1}else!1!==f&&(h.gl3d=1,h.geo=1,h.mapbox=1)}function O(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function P(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,f,h=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=O(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);f=h?n[d][g]:n,i(f)||(f=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(f)})}return p}(t,e,r,n),c={},u={},f=0;f<l.length;f++){var h=l[f].prop,p=l[f].maxp,d=a(l[f].target,l[f].insert,p);h.set(d[0]),Array.isArray(c[h.astr])||(c[h.astr]=[]),c[h.astr].push(d[1]),Array.isArray(u[h.astr])||(u[h.astr]=[]),u[h.astr].push(l[f].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var f=[];u.fullReplot?f.push(r.plot):(f.push(h.previousPromises),h.supplyDefaults(t),u.markerSize&&(h.doCalcdata(t),G(f)),u.style&&f.push(M.doTraceStyle),u.colorbars&&f.push(M.doColorBars),f.push(C)),f.push(h.rehover),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(f,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){j((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},f=o.extendFlat({},c,u);for(var h in f)j(t+\".\"+h,c[h],u[h],n)}else void 0===n[t]&&(n[t]=B(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=N(i._preGUI,c),g=o.extendDeepAll({},e);U(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function M(t){return\"LAYOUT\"+t+\".range\"}function T(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(i._tracePreGUI[T(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==a&&s.set(a)}}function C(t){return function(e){return a[e][t]}}function E(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\"and a parent attribute simultaneously\");var z,O,I,D,P,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(E(L)):!1===F?r.map(C(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(z=l[r[n]],O=T(r[n]),D=(I=N(i._tracePreGUI[O._fullInput.uid],c)(z,L)).get(),void 0!==(P=Array.isArray(F)?F[n%F.length]:F)){var j=I.parts[I.parts.length-1],V=L.substr(0,L.length-j.length-1),q=V?V+\".\":\"\",H=V?s(O,V).get():O;if((R=f.getTraceValObject(O,I.parts))&&R.impliedEdits&&null!==P)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||D===P||\"fraction\"!==P&&\"pixels\"!==P||!H){if(\"type\"===L&&\"pie\"===P!=(\"pie\"===D)){var W=\"x\",Y=\"y\";\"bar\"!==P&&\"bar\"!==D||\"h\"!==z.orientation||(W=\"y\",Y=\"x\"),o.swapAttrs(z,[\"?\",\"?src\"],\"labels\",W),o.swapAttrs(z,[\"d?\",\"?0\"],\"label\",W),o.swapAttrs(z,[\"?\",\"?src\"],\"values\",Y),\"pie\"===D?(s(z,\"marker.color\").set(s(z,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(z,\"cartesian\")&&s(z,\"marker.colors\").set(s(z,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,$=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===j){var J=$?X.h:X.w;S(q+\"thickness\",H.thickness*(\"fraction\"===P?1/J:J),n)}else{var K=$?X.w:X.h;S(q+\"len\",H.len*(\"fraction\"===P?1/K:K),n)}}x[L][n]=B(D);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){I.set(P);var Q=z.x&&!z.y?\"h\":\"v\";if((I.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(z.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(z),m.calc=m.clearAxisTypes=!0}else-1!==h.dataArrayContainers.indexOf(I.parts[0])?(k.manageArrayContainers(I,P,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(P)||o.isArrayOrTypedArray(D))?m.calc=!0:A.update(m,R):m.calc=!0,I.set(P))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(M),[0,1],0)}}else I=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(I.get())],I.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function U(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=Z(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[h.previousPromises];a.layoutReplot?s.push(M.layoutReplot):Object.keys(n).length&&(H(t,a,i)||h.supplyDefaults(t),a.legend&&s.push(M.doLegend),a.layoutstyle&&s.push(M.layoutStyles),a.axrange&&G(s,i.rangesAltered),a.ticks&&s.push(M.doTicksRelayout),a.modebar&&s.push(M.doModeBar),a.camera&&s.push(M.doCamera),s.push(C)),s.push(h.rehover),c.add(t,q,[t,i.undoit],q,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function H(t,e,r){var n;if(!e.axrange)return!1;for(n in e)if(\"axrange\"!==n&&e[n])return!1;for(n in r.rangesAltered){var i=d.id2name(n),a=t.layout[i],o=t._fullLayout[i];o.autorange=a.autorange,o.range=a.range.slice(),o.cleanRange()}return!0}function G(t,e){var r=e?function(t){var r={skipTitle:!0};for(var n in e)if(d.getFromId(t,n).automargin){r={};break}return d.draw(t,Object.keys(e),r)}:function(t){return d.draw(t,\"redraw\")};t.push(M.doAutoRangeAndConstraints,r,M.drawData,M.finalDraw)}r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),z(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var f=0===(t.data||[]).length&&Array.isArray(e);if(Array.isArray(e)&&(k.cleanData(e),f?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!f||(t.layout=k.cleanLayout(i)),t._dragging&&!t._transitioning)return t._replotPending=!0,Promise.reject();t._replotPending=!1,h.supplyDefaults(t);var v=t._fullLayout,x=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e);r&&(t.layout=r);p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(b.convertToTspans,t)},f=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,f.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(b.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};f.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),h.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,f&&st(t),t.framework!==st&&(t.framework=st,st(t)),g.initGradients(t),f&&d.saveShowSpikeInitial(t);var _=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;_&&h.doCalcdata(t);for(var w=0;w<t.calcdata.length;w++)t.calcdata[w][0].trace=t._fullData[w];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){h.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var A=JSON.stringify(v._size),T=0;function S(){var e,r,n,i=t.calcdata;for(h.clearAutoMarginIds(t),M.drawMarginPushers(t),d.allowAutoMargin(t),e=0;e<i.length;e++){var a=(n=(r=i[e])[0].trace)._module.colorbar;!0===n.visible&&a?m(t,r,a):h.autoMargin(t,\"cb\"+n.uid)}return h.doAutoMargin(t),h.previousPromises(t)}function E(){t._transitioning||(M.doAutoRangeAndConstraints(t),f&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var L=[h.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,width:\"100%\",height:\"100%\",overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!T)return o.log(a+\" Clearing graph and plotting again.\"),h.cleanPlot([],{},t._fullData,v),h.supplyDefaults(t),v=t._fullLayout,h.doCalcdata(t),T++,e();o.error(a)}}return h.previousPromises(t)},S,function(){if(JSON.stringify(v._size)!==A)return o.syncOrAsync([S,M.layoutStyles],t)}];x&&L.push(function(){if(_)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),E],t);E()}),L.push(M.layoutStyles),x&&L.push(function(){return d.draw(t,f?\"\":\"redraw\")}),L.push(M.drawData,M.finalDraw,y,h.addLinks,h.rehover,h.doAutoMargin,h.previousPromises);var O=o.syncOrAsync(L,t);return O&&O.then||(O=Promise.resolve()),O.then(function(){return C(t),t})},r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),h.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),h.purge(t),r.plot(t,e,n,i)},r.extendTraces=function t(e,n,i,a){var s=P(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=R(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.prependTraces=function t(e,n,i,a){var s=P(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=R(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,f=t,h=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,h,f,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,h,f,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,f=[e,s,n],h=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=O(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,f,u,h),p},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,f=t,h=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=O(n,e.data.length-1),i=O(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,h,f,p),d},r.restyle=F,r._storeDirectGUIEdit=function(t,e,r){for(var n in r){j(n,s(t,n).get(),r[n],e)}},r.relayout=q;var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,Y=/^[xyz]axis[0-9]*\\.autorange$/,X=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function Z(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,h=N(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(U(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),M={},S={};function C(t,r){if(Array.isArray(t))t.forEach(function(t){C(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=h(a,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var E,L={};function z(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\"and a parent attribute simultaneously\");for(var I=h(a,O),D=e[O],P=I.parts.length-1;P>0&&\"string\"!=typeof I.parts[P];)P--;var R=I.parts[P],F=I.parts[P-1]+\".\"+R,j=I.parts.slice(0,P).join(\".\"),V=s(t.layout,j).get(),q=s(l,j).get(),H=I.get();if(void 0!==D){M[O]=D,S[O]=\"reverse\"===R?D:B(H);var G=f.getLayoutValObject(l,I.parts);if(G&&G.impliedEdits&&null!==D)for(var Z in G.impliedEdits)C(o.relativeAttr(O,Z),G.impliedEdits[Z]);if(-1!==[\"width\",\"height\"].indexOf(O))if(D){C(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";C(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)C(\"width\",D?null:l.width),C(\"height\",D?null:l.height);else if(F.match(W))z(F),s(l,j+\"._inputRange\").set(null);else if(F.match(Y)){z(F),s(l,j+\"._inputRange\").set(null);var K=s(l,j).get();K._inputDomain&&(K._input.domain=K._inputDomain.slice())}else F.match(X)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){var Q=V,tt=\"linear\"===q.type&&\"log\"===D,et=\"log\"===q.type&&\"linear\"===D;if(tt||et){if(Q&&Q.range)if(q.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&C(j+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),C(j+\".range[0]\",Math.log(rt)/Math.LN10),C(j+\".range[1]\",Math.log(nt)/Math.LN10)):(C(j+\".range[0]\",Math.pow(10,rt)),C(j+\".range[1]\",Math.pow(10,nt)))}else C(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[I.parts[0]]&&\"radialaxis\"===I.parts[1]&&delete l[I.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,D,C),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,D,C)}else C(j+\".autorange\",!0),C(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(T)){var it=s(l,O).get(),at=(D||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,C),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,C)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(D)?S[O]=null:w.isRemoveVal(D)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=D,delete e[O]}else\"reverse\"===R?(V.range?V.range.reverse():(C(j+\".autorange\",!0),V.range=[1,0]),q.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===D||\"select\"===D)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:G?A.update(_,G):_.calc=!0,I.set(D))}}for(r in m){w.applyContainerArrayChanges(t,h(a,r),m[r],_,h)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(E in L)for(n=0;n<ut.length;n++){var ft=ut[n];if(ft[E])for(var ht in _.calc=!0,ft)L[ht]||(d.getFromId(t,ht)._constraintShrinkable=!0)}return($(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:M,eventData:v}}function $(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&h.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function J(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=Z(t,o.extendFlat({},n)),f=u.flags;(l.calc||f.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];if(l.fullReplot&&f.layoutReplot){var d=t.data,g=t.layout;t.data=void 0,t.layout=void 0,p.push(function(){return r.plot(t,d,g)})}else l.fullReplot?p.push(r.plot):f.layoutReplot?p.push(M.layoutReplot):(p.push(h.previousPromises),H(t,f,u)||h.supplyDefaults(t),l.style&&p.push(M.doTraceStyle),l.colorbars&&p.push(M.doColorBars),f.legend&&p.push(M.doLegend),f.layoutstyle&&p.push(M.layoutStyles),f.axrange&&G(p,u.rangesAltered),f.ticks&&p.push(M.doTicksRelayout),f.modebar&&p.push(M.doModeBar),f.camera&&p.push(M.doCamera),p.push(C));p.push(h.rehover),c.add(t,J,[t,s.undoit,u.undoit,s.traces],J,[t,s.redoit,u.redoit,s.traces]);var v=o.syncOrAsync(p,t);return v&&v.then||(v=Promise.resolve(t)),v.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function K(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}r.update=J,r._guiRestyle=K(F),r._guiRelayout=K(q),r._guiUpdate=K(J);var Q=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return e[r].uid?-1:r}function at(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,f=n.immutable,h=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;h&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[h],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||Y.test(l))&&(u.rangesAltered[r[0]]=1),X.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),M=Array.isArray(m);if(k&&M){var T=\"_input_\"+a,S=t[T],C=e[T];if(Array.isArray(S)&&S===C)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var E=[],L=!1;h||(u.arrays[a]=E);var z=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(z!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<z;b++)ot(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=z;b<O;b++)E.push(b)}else!_&&o.isPlainObject(v)?ot(v,m,y,n):w?k&&M?(f&&(u.calc=!0),(f||n.newDataRevision)&&d()):k!==M?u.calc=!0:d():k&&M&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function st(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(x.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._toppaper.append(\"g\").classed(\"hoverlayer\",!0),t.emit(\"plotly_framework\")}r.react=function(t,e,n,i){var a,l;var c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,z(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,f,h,p,d=n._preGUI,g=[],v={};for(i in d){if(u=et(i,Q)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&rt(a,e))&&c===l&&(null===(f=d[i])&&(f=void 0),at(p=(h=s(e,i)).get(),f))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),h.set(B(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],M=null;for(i in k){if(!M){var A=nt(_,r);if(A<0){delete b[_];break}var T=it(_,t,(w=r[A]._fullInput).index);if(T<0){delete b[_];break}M=t[T]}if(u=et(i,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=w.uirevision,void 0===(c=M.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(f=k[i])&&(f=void 0),at(p=(h=s(M,i)).get(),f))){h.set(B(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),h.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,ot(e,r,[],{getValObject:function(t){return f.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0);i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\");return a}(t,p,y,x,b),w=_.newDataRevision,T=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){return f.getTraceValObject(l,t)},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,h.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,m,x,b,w);$(t)&&(_.layoutReplot=!0),T.calc||_.calc?t.calcdata=void 0:h.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},h.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(T.anim||_.anim))h.doCalcdata(t),M.doAutoRangeAndConstraints(t),S.push(function(){return h.transitionFromReact(t,T,_,p)});else if(T.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var O=u.getComponentMethod(E,\"drawOne\");if(O!==o.noop)for(var I=0;I<L.length;I++)O(t,L[I]);else{var D=u.getComponentMethod(E,\"draw\");if(D===o.noop)throw new Error(\"cannot draw components: \"+E);D(t)}}}S.push(h.previousPromises),T.style&&S.push(M.doTraceStyle),T.colorbars&&S.push(M.doColorBars),_.legend&&S.push(M.doLegend),_.layoutstyle&&S.push(M.layoutStyles),_.axrange&&G(S),_.ticks&&S.push(M.doTicksRelayout),_.modebar&&S.push(M.doModeBar),_.camera&&S.push(M.doCamera),S.push(C)}S.push(h.rehover),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=h.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function f(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,h.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&f()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:m(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var M=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){M=d;break}if(M>0&&M<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>M)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?h.computeFrame(t,e[i].name):e[i].data;var f=l(i),d=s(i);d.duration=Math.min(d.duration,f.duration);var g={frame:o,name:e[i].name,frameOpts:f,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var f=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:h.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:f+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=h.modifyFrames,k=h.modifyFrames,M=[t,b],A=[t,x];return c&&c.add(t,w,M,k,A),h.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice(0)).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=h.modifyFrames,u=h.modifyFrames,f=[t,s],p=[t,a];return c&&c.add(t,l,f,u,p),h.modifyFrames(t,a)},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return h.cleanPlot([],{},r,e),h.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t}},{\"../components/color\":571,\"../components/colorbar/connect\":573,\"../components/drawing\":592,\"../constants/xmlns_namespaces\":672,\"../lib\":694,\"../lib/events\":683,\"../lib/queue\":709,\"../lib/svg_text_utils\":718,\"../plots/cartesian/axes\":742,\"../plots/cartesian/constants\":748,\"../plots/cartesian/graph_interact\":752,\"../plots/plots\":806,\"../plots/polar/legacy\":814,\"../registry\":825,\"./edit_types\":725,\"./helpers\":726,\"./manage_arrays\":728,\"./plot_config\":730,\"./plot_schema\":731,\"./subroutines\":733,d3:149,\"fast-isnumeric\":215,\"has-hover\":396}],730:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],731:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),f=t(\"../plots/polar/legacy/axis_attributes\"),h=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=\"_isSubplotObj\",m=\"_isLinkedToArray\",y=[v,m,\"_arrayAttrRegexps\",\"_deprecated\"];function x(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(b(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!b(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!b(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!b(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function b(t){return t===Math.round(t)&&t>=0}function _(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[m];if(!n)return;delete t[m],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function w(t,e,r){var n=i.nestedProperty(t,r),a=d({},e.layoutAttributes);a[v]=!0,n.set(a)}function k(t,e,r){var n=i.nestedProperty(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=v,r.IS_LINKED_TO_ARRAY=m,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=y,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,o;\"area\"===t?(e={attributes:u},o={}):(e=n.modules[t]._module,o=e.basePlotModule);var s={type:null},l=d({},a),c=d({},e.attributes);r.crawl(c,function(t,e,r,n,a){i.nestedProperty(l,a).set(void 0),void 0===t&&i.nestedProperty(c,a).set(void 0)}),d(s,l),d(s,c),o.attributes&&d(s,o.attributes);s.type=t;var f={meta:e.meta||{},attributes:_(s)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),f.layoutAttributes=_(h)}return f}(e)});var e,g={};return Object.keys(n.transformsRegistry).forEach(function(t){g[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){k(r,i.schema.transforms[t][e],e)})}),{attributes:_(r)}}(t)}),{defs:{valObjects:i.valObjectMeta,metaKeys:y.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:h.traces,layout:h.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)w(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;w(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:f.radialaxis,angularaxis:f.angularaxis}),p(t,f.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else e.layoutAttributes&&k(r,e.layoutAttributes,e.name)}return{layoutAttributes:_(r)}}(),transforms:g,frames:(e={frames:i.extendDeepAll({},s)},_(e),e.frames),animation:_(l),config:_(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===y.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,o=[],s=[],l=[];function c(t,r,a,c){s=s.slice(0,c).concat([r]),l=l.slice(0,c).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===s[c-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var c=e[s[r]];var u=a+s[r];if(r===s.length-1)i.isArrayOrTypedArray(c)&&o.push(n+u);else if(l[r]){if(Array.isArray(c))for(var f=0;f<c.length;f++)i.isPlainObject(c[f])&&t(c[f],r+1,u+\"[\"+f+\"].\")}else i.isPlainObject(c)&&t(c,r+1,u+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,c),t._module&&t._module.attributes&&r.crawl(t._module.attributes,c);var u=t.transforms;if(u)for(var f=0;f<u.length;f++){var h=u[f],p=h._module;p&&(n=\"transforms[\"+f+\"].\",e=h,r.crawl(p.attributes,c))}return o},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!b(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var f=t._module;if(f||(f=(n.modules[t.type||a.type.dflt]||{})._module),!f)return!1;if(!(i=(r=f.attributes)&&r[o])){var h=f.basePlotModule;h&&h.attributes&&(i=h.attributes[o])}i||(i=a[o])}return x(i,e,s)},r.getLayoutValObject=function(t,e){return x(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var h=t._modules;if(h)for(r=0;r<h.length;r++)if((s=h[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry)if(!(a=n.componentsRegistry[i]).schema&&e===a.name)return a.layoutAttributes;if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return f[e];return f.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":694,\"../plots/animation_attributes\":737,\"../plots/attributes\":739,\"../plots/frame_attributes\":770,\"../plots/layout_attributes\":797,\"../plots/polar/legacy/area_attributes\":812,\"../plots/polar/legacy/axis_attributes\":813,\"../registry\":825,\"./edit_types\":725,\"./plot_config\":730}],732:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function f(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function h(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:f,getUpdateObj:h,applyUpdate:function(e,r){e&&f(e,r);var i=h();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":694,\"../plots/attributes\":739}],733:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),f=t(\"../components/modebar\"),h=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=h.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),f.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],M=[],T=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var C=a.xaxis.domain,E=a.yaxis.domain,L=a.plotgroup;if(_(C,E,T)){var z=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");z.insertBefore(O.node(),z.childNodes[0]),M.push(i)}else L.select(\"rect.bg\").remove(),T.push([C,E]),S||(w.push(i),M.push(i))}var I,D,P,R,F,B,N,j,V,U,q,H,G,W=g._bgLayer.selectAll(\".bg\").data(w);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<M.length;e++)a=g._plots[M[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var Y,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",$=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=$.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(Y=null,X=Z):(Y=Z,X=null),c.setClipUrl(a.plot,Y,t),a.layerClipId=X}function J(t){return\"M\"+I+\",\"+t+\"H\"+D}function K(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),I=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),D=u._offset+u._length+(B?m+B:0),P=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[P,R]),rt=et(u,J,K),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=J(P)+J(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),V=x(d,u,\"left\"),U=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[V,U]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(V)+Q(U)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return h.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function M(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(M(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&M(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},f=u._module||{},h=f.arraysToCalcdata;h&&h(l,u);var p=f.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){for(var e=0;e<t.calcdata.length;e++){var r=t.calcdata[e][0];if((r.t||{}).cb){var n=r.trace,o=r.t.cb;i.traceIs(n,\"contour\")&&o.line({width:!1!==n.contours.showlines?n.line.width:0,dash:n.line.dash,color:\"line\"===n.contours.coloring?o._opts.line.color:n.line.color});var s=n._module.colorbar.container,l=(s?n[s]:n).colorbar;o.options(l)()}}return a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return h.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setCamera(i.camera)}},r.drawData=function(t){var e,n=t._fullLayout,o=t.calcdata;for(e=0;e<o.length;e++){var l=o[e][0].trace;!0===l.visible&&l._module.colorbar||n._infolayer.select(\".cb\"+l.uid).remove()}s(t);var c=n._basePlotModules;for(e=0;e<c.length;e++)c[e].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),n._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e=h.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];v(t,n),n.setScale(),m(t,n)}g(t)},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t)}},{\"../components/color\":571,\"../components/drawing\":592,\"../components/modebar\":630,\"../components/titles\":659,\"../constants/alignment\":666,\"../lib\":694,\"../lib/clear_gl_canvases\":679,\"../plots/cartesian/autorange\":741,\"../plots/cartesian/axes\":742,\"../plots/cartesian/constraints\":750,\"../plots/plots\":806,\"../registry\":825,d3:149}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var f=o.defaultItems();for(a=0;a<f.length;a++)r.push(f[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],h=t[c];if(c in e?s(h,e[c],c):e[c]=h,f(c)===c)for(var p in e){var d=f(p);p===d||d!==c||p in t||s(h,e[p],c)}}}function f(t){return t.replace(/[0-9]+$/,\"\")}function h(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=f(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))h(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(h(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var M=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);h(w,e,r,A,p(u,x,g));var T=n.nestedProperty(e,A);n.nestedProperty(e,M).set(T.get()),T.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};h(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),h(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var f=r.template;if(i(f)){var p,d,g,v,m,y,x=f.layout;i(x)&&u(x,l.layout);var b=f.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var h=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=f(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(h,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:h},\"\"),u.length)return u.map(g)}},{\"../lib\":694,\"../plots/attributes\":739,\"../plots/plots\":806,\"./plot_config\":730,\"./plot_schema\":731,\"./plot_template\":732}],735:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\"),i=t(\"../lib\"),a=t(\"../snapshot/helpers\"),o=t(\"../snapshot/tosvg\"),s=t(\"../snapshot/svgtoimg\"),l={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}},c=/^data:image\\/\\w+;base64,/;e.exports=function(t,e){var r,u,f;function h(t){return!(t in e)||i.validate(e[t],l[t])}if(e=e||{},i.isPlainObject(t)?(r=t.data||[],u=t.layout||{},f=t.config||{}):(t=i.getGraphDiv(t),r=i.extendDeep([],t.data),u=i.extendDeep({},t.layout),f=t._context),!h(\"width\")||!h(\"height\"))throw new Error(\"Height and width should be pixel values.\");if(!h(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var p={};function d(t,r){return i.coerce(e,p,l,t,r)}var g=d(\"format\"),v=d(\"width\"),m=d(\"height\"),y=d(\"scale\"),x=d(\"setBackground\"),b=d(\"imageDataOnly\"),_=document.createElement(\"div\");_.style.position=\"absolute\",_.style.left=\"-5000px\",document.body.appendChild(_);var w=i.extendFlat({},u);v&&(w.width=v),m&&(w.height=m);var k=i.extendFlat({},f,{_exportedPlot:!0,staticPlot:!0,setBackground:x}),M=a.getRedrawFunc(_);function A(){return new Promise(function(t){setTimeout(t,a.getDelay(_._fullLayout))})}function T(){return new Promise(function(t,e){var r=o(_,g,y),a=_._fullLayout.width,l=_._fullLayout.height;if(n.purge(_),document.body.removeChild(_),\"svg\"===g)return t(b?r:\"data:image/svg+xml,\"+encodeURIComponent(r));var c=document.createElement(\"canvas\");c.id=i.randstr(),s({format:g,width:a,height:l,scale:y,canvas:c,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){n.plot(_,r,w,k).then(M).then(A).then(T).then(function(e){t(function(t){return b?t.replace(c,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":694,\"../snapshot/helpers\":829,\"../snapshot/svgtoimg\":831,\"../snapshot/tosvg\":833,\"./plot_api\":729}],736:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var f=Object.keys(t),h=0;h<f.length;h++){var v=f[h];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var M,A,T,S,C,E=x.length,L=Array.isArray(k);if(L&&(E=Math.min(E,k.length)),2===b.dimensions)for(A=0;A<E;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var z=x[A].length;for(M=0;M<(L?Math.min(z,k[A].length):z);M++)T=L?k[A][M]:k,S=y[A][M],C=x[A][M],n.validate(S,T)?C!==S&&C!==+S&&i.push(p(\"dynamic\",a,m.concat(A,M),S,C)):i.push(p(\"value\",a,m.concat(A,M),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<E;A++)T=L?k[A]:k,S=y[A],C=x[A],n.validate(S,T)?C!==S&&C!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,C)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,I,D=k[Object.keys(k)[0]],P=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((I=m.slice()).push(R),s(y[R])&&s(x[O])){P.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,I)):u(F,B,D,i,a,I)}}for(O=0;O<y.length;O++)(I=m.slice()).push(O),s(y[O])?-1===P.indexOf(O)&&i.push(p(\"unused\",a,I)):i.push(p(\"object\",a,I,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,f=a.get(),h=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],h.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&h.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=f.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&h.push(p(\"invisible\",x)),u(y,b,w,h,x);var k=y.transforms,M=b.transforms;if(k){l(k)||h.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var T=[\"transforms\",A],S=k[A].type;if(s(k[A])){var C=f.transforms[S]?f.transforms[S].attributes:{};C.type={valType:\"enumerated\",values:Object.keys(f.transforms)},u(k[A],M[A],C,h,x,T)}else h.push(p(\"object\",x,T))}}}else h.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(f,g),h,\"layout\"),0===h.length?void 0:h};var f={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":h(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":h(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return h(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return h(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[h(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?h(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[h(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function h(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=f[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":694,\"../plots/plots\":806,\"./plot_config\":730,\"./plot_schema\":731}],737:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],738:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],f=e[s]=[],h=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=h.newItem(p):(o=h.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),f.push(o)}var d=h.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=f.length,r.handleItemDefaults({},o,e,r,{}),f.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,f.length);for(a=0;a<g;a++)n.relinkPrivateKeys(f[a],c[a])}return f}},{\"../lib\":694,\"../plot_api/plot_template\":732}],739:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":601}],740:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,f=s.max;if(0===u.length||0===f.length)return i.simpleMap(e.range,e.r2l);var h=u[0].val,p=f[0].val;for(r=1;r<u.length&&h===p;r++)h=Math.min(h,u[r].val);for(r=1;r<f.length&&h===p;r++)p=Math.max(p,f[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,M=\"nonnegative\"===w,A=e._length,T=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<f.length;n++)(_=(m=f[n]).val-v.val)>0&&((b=A-o(v)-o(m))>T?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(h===p){var C=h-1,E=h+1;if(k)if(0===h)a=[0,1];else{var L=(h>0?f:u).reduce(function(t,e){return Math.max(t,o(e))},0),z=h/(1-Math.min(.5,L/A));a=h>0?[0,z]:[z,0]}else a=M?[Math.max(0,C),Math.max(1,E)]:[C,E]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):M&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function h(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],f(c,i.val,i.pad,{extrapad:i.extrapad})}}}return h(o,e._traceIndices),h(s.annotations||[],e._annIndices||[]),h(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){h(t,e,r,n,d)}function f(t,e,r,n){h(t,e,r,n,g)}function h(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,h,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function M(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),T=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=M(r.vpadplus||r.vpad),C=M(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var E={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(h=A(r),d=T(r),g=s-C(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,E),p(c)&&f(y,c,h,E))}var z=Math.min(6,x);for(i=0;i<z;i++)L(i);for(i=x-1;i>=z;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../registry\":825,\"fast-isnumeric\":215}],742:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,M=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var T=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var C=t(\"./autorange\");A.getAutoRange=C.getAutoRange,A.findExtremes=C.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var f=r[A.id2name(e[u])][a],h=0;h<f.length;h++){var p=f[h];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var E=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:T(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:z,c2d:z}:{d2c:L,c2d:L}};function L(t){return+t}function z(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return E(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var f;if(r)f=(u-c)/r;else{var h=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(h.minDiff)/Math.LN10)),g=d*s.roundUp(h.minDiff/d,[.9,1.9,4.9,9.9],!0);f=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(f)||(f=1)}A.autoTicks(l,f)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var f=0;f<e.length;f++)e[f]%1==0?l++:i(e[f])||c++,u(e[f])&&o++,u(e[f]+r.dtick/2)&&s++;var h=e.length-c;if(l===h&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*h&&(o>.3*h||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var f=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var h=0;h<e.length;h++){var p=f(e[h]);p>l&&p<c&&(void 0===r[h]?n[u]=A.tickText(t,p):n[u]=V(t,p,String(r[h])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],i=e[1]<e[0];if(t._tmin<r!==i)return[];var a=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=i?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var o=null,l=Math.max(1e3,t._length||0),c=t._tmin;(i?c>=n:c<=n)&&!(a.length>l||c===o);c=A.tickIncrement(c,t.dtick,i,t.calendar))o=c,a.push(c);et(t)&&360===Math.abs(e[1]-e[0])&&a.pop(),t._tmax=a[a.length-1],t._prevDateHead=\"\",t._inCalcTicks=!0;for(var u=new Array(a.length),f=0;f<a.length;f++)u[f]=A.tickText(t,a[f]);return t._inCalcTicks=!1,u};var O=[2,5,10],I=[1,2,3,6,12],D=[1,2,5,10,15,30],P=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function V(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,I)):a>m?(t.dtick=N(e,m,P),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,I):a>x?t.dtick=N(e,x,D):a>b?t.dtick=N(e,b,D):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):et(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,f=t+.01*o,h=s.roundUp(s.mod(f,1),u,r);return Math.floor(f)+Math.log(n.round(Math.pow(10,h),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var f=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(f=s.constrain(f,0,t._categories.length-1)),f}var h=c.charAt(0),p=Number(c.substr(1));if(\"M\"===h){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=h+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===h)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===h){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r){var n,a=V(t,e),o=\"array\"===t.tickmode,l=r||o,c=t.type,u=\"category\"===c?t.d2l_noadd:t.d2l;if(o&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),h=Math.abs(f[1]-f[0])/1e4;for(n=0;n<t.ticktext.length&&!(Math.abs(e-u(t.tickvals[n]))<h);n++);if(n<t.ticktext.length)return a.text=String(t.ticktext[n]),a}function p(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var d=r?\"never\":\"none\"!==t.exponentformat&&p(t.showexponent)?\"hide\":\"\";if(\"date\"===c?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,a,r,l):\"log\"===c?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var f=Math.round(l),h=Math.abs(f),p=t.exponentformat;\"power\"===p||q(p)&&H(f)?(e.text=0===f?1:1===f?\"10\":\"10<sup>\"+(f>1?\"\":_)+h+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&h>2?e.text=\"1\"+p+(f>0?\"+\":_)+h:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,a,0,l,d):\"category\"===c?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,a):\"multicategory\"===c?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,a,r):et(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,a,r,l,d):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,a,0,l,d),t.tickprefix&&!p(t.showtickprefix)&&(a.text=t.tickprefix+a.text),t.ticksuffix&&!p(t.showticksuffix)&&(a.text+=t.ticksuffix),\"boundaries\"===t.tickson||t.showdividers){var g=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};a.xbnd=[g(a.x-.5),g(a.x+t.dtick-.5)]}return a},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var U=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),f=e.separatethousands;if(n){var h={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(h),o=(Number(h._tickround)||0)+4,c=h._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,f)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=U[c/3+5]));return a?_+t:t}function W(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=Z(this),e=f.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function Y(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function Z(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function $(t){return t._id+\".automargin\"}function J(t){return t._id+\".rangeslider\"}function K(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function Q(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(h),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],f=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==f.indexOf(d)&&-1!==f.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==f.indexOf(g)&&-1!==f.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),tt(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function tt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function et(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function f(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&f(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var h=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=h._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,T,C=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);T=A.clipEnds(e,E),k=\"inside\"===e.ticks?T:E}else T=A.clipEnds(e,_),k=\"inside\"===e.ticks?T:_;var L=e._gridVals=T,z=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!h._hasOnlyLargeSploms){var O={};for(n=0;n<b.length;n++){i=b[n];var I=(l=h._plots[i])[g+\"axis\"],D=I._mainAxis._id;if(!O[D]){O[D]=1;var P=\"x\"===d?\"M0,\"+I._offset+\"v\"+I._length:\"M\"+I._offset+\",0h\"+I._length;A.drawGrid(t,e,{vals:L,counterAxis:I,layer:l.gridlayer.select(\".\"+p),path:P,transFn:C}),A.drawZeroLine(t,e,{counterAxis:I,layer:l.zerolinelayer,path:P,transFn:C})}}}var R=A.getTickSigns(e),F=[];if(e.ticks){var B,N,j,U=A.makeTickPath(e,m,R[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(B=A.makeTickPath(e,y,R[3]),N=U+B):(B=\"\",N=U),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var q={};for(n=0;n<z.length;n++)q[z[n].x]=1;j=function(t){return q[t.x]?B:N}}else j=N;A.drawTicks(t,e,{vals:k,layer:x,path:j,transFn:C}),F=Object.keys(e._linepositions||{})}for(n=0;n<F.length;n++){i=F[n],l=h._plots[i];var H=e._linepositions[i]||[],G=A.makeTickPath(e,H[0],R[0])+A.makeTickPath(e,H[1],R[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:G,transFn:C})}var X=[];if(X.push(function(){var r=A.makeLabelFns(e,m);return A.drawLabels(t,e,{vals:_,layer:x,transFn:C,labelXFn:r.labelXFn,labelYFn:r.labelYFn,labelAnchorFn:r.labelAnchorFn})}),\"multicategory\"===e.type){var Z=0,K={x:2,y:10}[d],Q=R[2]*(\"inside\"===e.ticks?-1:1);X.push(function(){Z+=W(e,p+\"tick\")+K,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*M:0;var r=m+Z*Q,n=A.makeLabelFns(e,r);return A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(V(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:C,labelXFn:n.labelXFn,labelYFn:n.labelYFn,labelAnchorFn:n.labelAnchorFn})}),X.push(function(){return Z+=W(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,Y);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",f.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:z,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:C})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return X.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=h._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=h._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n;tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,J(e),n);var i=e.side.charAt(0);!e.automargin||tt&&\"b\"===i||(r={x:0,y:0,r:0,l:0,t:0,b:0},\"x\"===d?(r.y=\"free\"===e.anchor?e.position:e._anchorAxis.domain[\"t\"===i?1:0],r[i]+=e._boundingBox.height):(r.x=\"free\"===e.anchor?e.position:e._anchorAxis.domain[\"r\"===i?1:0],r[i]+=e._boundingBox.width),e.title.text!==h._dfltTitle[d]&&(r[i]+=e.title.font.size)),a.autoMargin(t,$(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||X.push(function(){return function(t,e){var r,n,i,a,o,s,l=t._fullLayout,u=e._id,h=u.charAt(0),p=l._size,d=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*d+(e.linewidth?e.linewidth-1:0)}\"x\"===h?(i=\"free\"===e.anchor?{_offset:p.t+(1-(e.position||0))*p.h,_length:0}:S.getFromId(t,e.anchor),a=e._offset+e._length/2,o=\"top\"===e.side?-r-d*(e.showticklabels?1:0):i._length+r+d*(e.showticklabels?1.5:.5),o+=i._offset):(i=\"free\"===e.anchor?{_offset:p.l+(e.position||0)*p.w,_length:0}:S.getFromId(t,e.anchor),o=e._offset+e._length/2,a=\"right\"===e.side?i._length+r+d*(e.showticklabels?1:.5):-r-d*(e.showticklabels?.5:0),a+=i._offset,n={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var g=e._selections[e._id+\"tick\"];if(s={selection:g,side:e.side},g&&g.node()&&g.node().parentNode){var v=f.getTranslate(g.node().parentNode);s.offsetLeft=v.x,s.offsetTop=v.y}}return c.draw(t,u+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:l._dfltTitle[h],avoid:s,transform:n,attributes:{x:a,y:o,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(X)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=(t.linewidth||1)/2,o=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,l=o?t.ticklen:0,c=0;if(r&&\"outside\"===t.ticks){var u=s.deg2rad(r);l=t.ticklen*Math.cos(u)+1,c=t.ticklen*Math.sin(u)}t.showticklabels&&(o||t.showline)&&(l+=.2*t.tickfont.size);var f,h,p,d,g={labelStandoff:l,labelShift:c};return\"x\"===n?(d=\"bottom\"===t.side?1:-1,f=c*d,h=e+(l+a)*d,p=\"bottom\"===t.side?1:-.2,g.labelXFn=function(t){return t.dx+f},g.labelYFn=function(t){return t.dy+h+t.fontSize*p},g.labelAnchorFn=function(t){return i(t)&&0!==t&&180!==t?t*d<0?\"end\":\"start\":\"middle\"}):\"y\"===n&&(d=\"right\"===t.side?1:-1,f=l+a,h=-c*d,p=90===Math.abs(t.tickangle)?.5:0,g.labelXFn=function(t){return t.dx+e+(f+t.fontSize*p)*d},g.labelYFn=function(t){return t.dy+h+t.fontSize*k},g.labelAnchorFn=function(e){return i(e)&&90===Math.abs(e)?\"middle\":\"right\"===t.side?\"start\":\"end\"}),g},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],Y);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",f.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,Y);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=f.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",f.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,h=r.labelXFn,p=r.labelYFn,d=r.labelAnchorFn,g=r.secondary?0:e.tickangle,v=(e._tickAngles||{})[c],m=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],Y),y=[];function x(t,a){t.each(function(t){var s=n.select(this),c=s.select(\".text-math-group\"),u=d(a,t),g=r.transFn.call(s.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+h(t)+\",\"+(p(t)-t.fontSize/2)+\")\":\"\"),v=function(t,r,n){var i=(t-1)*r;if(\"x\"===o){if(n<-60||60<n)return-.5*i;if(\"top\"===e.side)return-i}else{if((n*=\"left\"===e.side?1:-1)<-30)return-i;if(n<30)return-.5*i}return 0}(l.lineCount(s),M*t.fontSize,i(a)?+a:0);if(v&&(g+=\" translate(0, \"+v+\")\"),c.empty())s.select(\"text\").attr({transform:g,\"text-anchor\":u});else{var m=f.bBox(c.node()).width*{end:-.5,start:.5}[u];c.attr(\"transform\",g+(m?\"translate(\"+m+\",0)\":\"\"))}})}m.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,h(e),p(e)).call(f.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then(function(){x(r,g)})):x(r,g)}),m.exit().remove(),r.repositionOnUpdate&&m.each(function(t){n.select(this).select(\"text\").call(l.positionText,h(t),p(t))}),x(m,v||g),e._selections&&(e._selections[c]=m);var b=s.syncOrAsync([function(){return y.length&&Promise.all(y)},function(){x(m,g);var t=null;if(u.length&&\"x\"===o&&!i(g)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(m.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=Z(this),i=f.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var h=u.length,p=Math.abs((u[h-1].x-u[0].x)*e._m)/(h-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=p?90:30;break}}else{var d=2;for(e.ticks&&(d+=e.tickwidth/2),n=0;n<l.length;n++){var v=u[n].xbnd,y=l[n];if(null!==v[0]&&y.left-e.l2p(v[0])<d||null!==v[1]&&e.l2p(v[1])-y.right<d){t=90;break}}}t&&x(m,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(g)?g:0:t)}]);return b&&b.then&&t._promises.push(b),b},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(X(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var f=A.list(t,s),h=0;h<f.length;h++){var p=f[h];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n&&(o.traceIs(s,\"bar\")&&s.orientation==={x:\"h\",y:\"v\"}[i]||s.fill&&s.fill.charAt(s.fill.length-1)===i))return!0}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return X(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,$(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,J(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],K(c.x,l.x),K(c.y,l.y);K(c.x,[o]),K(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)Q(t,r[n].x,r[n].y)}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../../components/titles\":659,\"../../constants/alignment\":666,\"../../constants/numerical\":671,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plots/plots\":806,\"../../registry\":825,\"./autorange\":741,\"./axis_autotype\":743,\"./axis_ids\":745,\"./clean_ticks\":747,\"./layout_attributes\":755,\"./set_convert\":761,d3:149,\"fast-isnumeric\":215}],743:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":671,\"../../lib\":694,\"fast-isnumeric\":215}],744:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),f=t(\"./set_convert\");e.exports=function(t,e,r,h,p){var d=h.letter,g=h.font||{},v=h.splomStash||{},m=r(\"visible\",!h.cheateronly),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",h.calendar);if(f(e,p),!r(\"autorange\",!e.isValidRange(t.range))||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,h),\"category\"===y||h.noHover||r(\"hoverformat\"),!m)return e;var x=r(\"color\"),b=x!==a.color.dflt?x:g.color;r(\"title.text\",v.label||p._dfltTitle[d]),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:b}),o(t,e,r,y),l(t,e,r,y,h),s(t,e,r,h),u(t,e,r,{dfltColor:x,bgColor:h.bgColor,showGrid:h.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),h.automargin&&r(\"automargin\");var _,w=\"multicategory\"===e.type;h.noTickson||\"category\"!==e.type&&!w||!e.ticks&&!e.showgrid||(w&&(_=\"boundaries\"),r(\"tickson\",_));w&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":694,\"../../registry\":825,\"./category_order_defaults\":746,\"./layout_attributes\":755,\"./line_grid_defaults\":757,\"./set_convert\":761,\"./tick_label_defaults\":762,\"./tick_mark_defaults\":763,\"./tick_value_defaults\":764}],745:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)}},{\"../../registry\":825,\"./constants\":748}],746:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],747:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":671,\"../../lib\":694,\"fast-isnumeric\":215}],748:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":710}],749:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name;e.exports=function(t,e,r,a,o){var s=o._axisConstraintGroups,l=e._id,c=l.charAt(0);if(!e.fixedrange&&(r(\"constrain\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===c?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===c?\"center\":\"middle\"}},\"constraintoward\"),t.scaleanchor)){var u=function(t,e,r,n){var a,o,s,l,c=n[i(e)].type,u=[];for(o=0;o<r.length;o++)(s=r[o])!==e&&((l=n[i(s)]).type!==c||l.fixedrange||u.push(s));for(a=0;a<t.length;a++)if(t[a][e]){var f=t[a],h=[];for(o=0;o<u.length;o++)s=u[o],f[s]||h.push(s);return{linkableAxes:h,thisGroup:f}}return{linkableAxes:u,thisGroup:null}}(s,l,a,o),f=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:u.linkableAxes}},\"scaleanchor\");if(f){var h=r(\"scaleratio\");h||(h=e.scaleratio=1),function(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var f=s[n];for(o=0;o<u.length;o++)l=u[o],s[l]=f*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}(s,u.thisGroup,l,f,h)}else-1!==a.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the targetaxis has fixed range.')}}},{\"../../lib\":694,\"./axis_ids\":745}],750:[function(t,e,r){\"use strict\";var n=t(\"./axis_ids\").id2name,i=t(\"./scale_zoom\"),a=t(\"./autorange\").makePadFn,o=t(\"./autorange\").concatExtremes,s=t(\"../../constants/numerical\").ALMOST_EQUAL,l=t(\"../../constants/alignment\").FROM_BL;function c(t,e){var r=t._inputDomain,n=l[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.enforce=function(t){var e,r,l,u,f,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[l=m[r]]=u=d[n(l)],u._inputDomain?u.domain=u._inputDomain.slice():u._inputDomain=u.domain.slice(),u._inputRange||(u._inputRange=u.range.slice()),u.setScale(),_[l]=f=Math.abs(u._m)/v[l],y=Math.min(y,f),\"domain\"!==u.constrain&&u._constraintShrinkable||(b=Math.min(b,f)),delete u._constraintShrinkable,x=Math.max(x,f),\"domain\"===u.constrain&&(k=!0);if(!(y>s*x)||k)for(r=0;r<m.length;r++)if(f=_[l=m[r]],h=(u=w[l]).constrain,f!==b||\"domain\"===h)if(p=f/b,\"range\"===h)i(u,p);else{var M=u._inputDomain,A=(u.domain[1]-u.domain[0])/(M[1]-M[0]),T=(u.r2l(u.range[1])-u.r2l(u.range[0]))/(u.r2l(u._inputRange[1])-u.r2l(u._inputRange[0]));if((p/=A)*T<1){u.domain=u._input.domain=M.slice(),i(u,p);continue}if(T<1&&(u.range=u._input.range=u._inputRange.slice(),p*=T),u.autorange){var S=u.r2l(u.range[0]),C=u.r2l(u.range[1]),E=(S+C)/2,L=E,z=E,O=Math.abs(C-E),I=E-O*p*1.0001,D=E+O*p*1.0001,P=a(u);c(u,p);var R,F,B=Math.abs(u._m),N=o(t,u),j=N.min,V=N.max;for(F=0;F<j.length;F++)(R=j[F].val-P(j[F])/B)>I&&R<L&&(L=R);for(F=0;F<V.length;F++)(R=V[F].val+P(V[F])/B)<D&&R>z&&(z=R);p/=(z-L)/(2*O),L=u.l2r(L),z=u.l2r(z),u.range=u._input.range=S<C?[L,z]:[z,L]}c(u,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":666,\"../../constants/numerical\":671,\"./autorange\":741,\"./axis_ids\":745,\"./scale_zoom\":759}],751:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../../components/fx\"),h=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),M=t(\"./constants\"),A=M.MINDRAG,T=M.MINZOOM,S=!0;function C(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function E(t,e,r,i,a,o,s){var l=C(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function z(t,e,r,n,i){var a,o,s,l;for(a=0;a<t.length;a++)(o=t[a]).fixedrange||(s=o._rl[0],l=o._rl[1]-s,o.range=[o.l2r(s+l*e),o.l2r(s+l*r)],n[o._name+\".range[0]\"]=o.range[0],n[o._name+\".range[1]\"]=o.range[1]);if(i&&i.length){var c=(e+(1-r))/2;z(i,c,1-c,n)}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function I(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function D(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function P(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function V(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,T)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function U(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function q(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,C){var F,H,G,W,Y,X,Z,$,J,K,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut=t._fullLayout._zoomlayer,ft=S+C===\"nsew\",ht=1===(S+C).length;function pt(){if(F=e.xaxis,H=e.yaxis,J=F._length,K=H._length,Z=F._offset,$=H._offset,(G={})[F._id]=F,(W={})[H._id]=H,S&&C)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;G[i._id]=i;var a=r[n].yaxis;W[a._id]=a}Y=q(G),X=q(W),tt=L(Y,C),et=L(X,S),rt=!et&&!tt,Q=function(t,e,r){for(var n,i,a,o,l=t._fullLayout._axisConstraintGroups,c=!1,u={},f={},h=0;h<l.length;h++){var p=l[h];for(n in e)if(p[n]){for(a in p)(\"x\"===a.charAt(0)?e:r)[a]||(u[a]=1);for(i in r)p[i]&&(c=!0)}for(i in r)if(p[i])for(o in p)(\"x\"===o.charAt(0)?e:r)[o]||(f[o]=1)}c&&(s.extendFlat(u,f),f={});var d={},g=[];for(a in u){var v=x(t,a);g.push(v),d[v._id]=v}var m={},y=[];for(o in f){var b=x(t,o);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,isSubplotConstrained:c}}(t,G,W),nt=Q.isSubplotConstrained,it=C||nt,at=S||nt;var o=t._fullLayout;ot=o._has(\"scattergl\"),st=o._has(\"splom\"),lt=o._has(\"svg\")}pt();var dt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(et+tt,t._fullLayout.dragmode,ft),gt=E(e,S+C+\"drag\",dt,r,a,c,p);if(rt&&!ft)return gt.onmousedown=null,gt.style.pointerEvents=\"none\",gt;var vt,mt,yt,xt,bt,_t,wt,kt,Mt,At,Tt={element:gt,gd:t,plotinfo:e};function St(){Tt.plotinfo.selection=!1,_(ut)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||ht||function(){if(!t._transitioningWithDuration){var e,r,n,i=t._context.doubleClick,a=(tt?Y:[]).concat(et?X:[]),s={};if(\"reset+autosize\"===i)for(i=\"autosize\",r=0;r<a.length;r++)if((e=a[r])._rangeInitial&&(e.range[0]!==e._rangeInitial[0]||e.range[1]!==e._rangeInitial[1])||!e._rangeInitial&&!e.autorange){i=\"reset\";break}if(\"autosize\"===i)for(r=0;r<a.length;r++)(e=a[r]).fixedrange||(s[e._name+\".autorange\"]=!0);else if(\"reset\"===i)for((tt||nt)&&(a=a.concat(Q.xaxes)),et&&!nt&&(a=a.concat(Q.yaxes)),nt&&(tt?et||(a=a.concat(X)):a=a.concat(Y)),r=0;r<a.length;r++)(e=a[r]).fixedrange||(e._rangeInitial?(n=e._rangeInitial,s[e._name+\".range[0]\"]=n[0],s[e._name+\".range[1]\"]=n[1]):s[e._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,Y,X,e.id,Tt),a.indexOf(\"event\")>-1&&f.click(t,i,e.id);else if(1===r&&ht){var s=S?H:F,c=\"s\"===S||\"w\"===C?0:1,u=s._name+\".range[\"+c+\"]\",h=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===C&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(gt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(h),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Et(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min(J,e+vt)),i=Math.max(0,Math.min(K,r+mt)),a=Math.abs(n-vt),o=Math.abs(i-mt);function s(){wt=\"\",yt.r=yt.l,yt.t=yt.b,Mt.attr(\"d\",\"M0,0Z\")}yt.l=Math.min(vt,n),yt.r=Math.max(vt,n),yt.t=Math.min(mt,i),yt.b=Math.max(mt,i),nt?a>T||o>T?(wt=\"xy\",a/J>o/K?(o=a*K/J,mt>i?yt.t=mt-o:yt.b=mt+o):(a=o*J/K,vt>n?yt.l=vt-a:yt.r=vt+a),Mt.attr(\"d\",V(yt))):s():!et||o<Math.min(Math.max(.6*a,A),T)?a<A||!tt?s():(yt.t=0,yt.b=K,wt=\"x\",Mt.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-T-.5)+\"h-3v\"+(2*T+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-T-.5)+\"h3v\"+(2*T+1)+\"h-3Z\"}(yt,mt))):!tt||a<Math.min(.6*o,T)?(yt.l=0,yt.r=J,wt=\"y\",Mt.attr(\"d\",function(t,e){return\"M\"+(e-T-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*T+1)+\"v3ZM\"+(e-T-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*T+1)+\"v-3Z\"}(yt,vt))):(wt=\"xy\",Mt.attr(\"d\",V(yt))),yt.w=yt.r-yt.l,yt.h=yt.b-yt.t,wt&&(At=!0),t._dragged=At,R(kt,Mt,yt,bt,_t,xt),_t=!0}function Lt(){if(ct={},Math.min(yt.h,yt.w)<2*A)return B(t);\"xy\"!==wt&&\"x\"!==wt||z(Y,yt.l/J,yt.r/J,ct,Q.xaxes),\"xy\"!==wt&&\"y\"!==wt||z(X,(K-yt.b)/K,(K-yt.t)/K,ct,Q.yaxes),B(t),Nt(),N(t)}Tt.prepFn=function(e,r,n){var a=Tt.dragmode,o=t._fullLayout.dragmode;o!==a&&(Tt.dragmode=o),pt(),rt||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),Tt.minDrag=\"lasso\"===o?1:void 0,j(o)?(Tt.xaxes=Y,Tt.yaxes=X,b(e,r,n,Tt,o)):(Tt.clickFn=Ct,j(a)&&St(),rt||(\"zoom\"===o?(Tt.moveFn=Et,Tt.doneFn=Lt,Tt.minDrag=1,function(e,r,n){var a=gt.getBoundingClientRect();vt=r-a.left,mt=n-a.top,yt={l:vt,r:vt,w:0,t:mt,b:mt,h:0},xt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),_t=!1,wt=\"xy\",At=!1,kt=D(ut,xt,Z,$,bt=\"M0,0H\"+J+\"V\"+K+\"H0V0\"),Mt=P(ut,Z,$)}(0,r,n)):\"pan\"===o&&(Tt.moveFn=Ft,Tt.doneFn=Nt)))},d.init(Tt);var zt,Ot,It=[0,0,J,K],Dt=null,Pt=M.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===tt||\"ns\"===et)return tt&&O(Y,e),et&&O(X,r),jt([tt?-e:0,et?-r:0,J,K]),void Bt();if(nt&&tt&&et){var n=\"w\"===tt==(\"n\"===et)?1:-1,i=(e/J+n*r/K)/2;e=i*J,r=n*i*K}\"w\"===tt?e=l(Y,0,e):\"e\"===tt?e=l(Y,1,-e):tt||(e=0),\"n\"===et?r=l(X,1,r):\"s\"===et?r=l(X,0,-r):et||(r=0);var a=\"w\"===tt?e:0,o=\"n\"===et?r:0;if(nt){var s;if(!tt&&1===et.length){for(s=0;s<Y.length;s++)Y[s].range=Y[s]._r.slice(),k(Y[s],1-r/K);a=(e=r*J/K)/2}if(!et&&1===tt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-e/J);o=(r=e*K/J)/2}}jt([a,o,J-e,K-r]),Bt()}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/I(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(it&&(n(Y),n(Q.xaxes)),at&&(n(X),n(Q.yaxes)),ct={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);h.drawOne(t,a,{skipTitle:!0}),ct[a._name+\".range[0]\"]=a.range[0],ct[a._name+\".range[1]\"]=a.range[1]}h.redrawComponents(t,r)}function Nt(){jt([0,0,J,K]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ct)}],t)}function jt(e){var r,n,i,a,l=t._fullLayout,c=l._plots,f=l._subplots.cartesian;if(st&&o.subplotsRegistry.splom.drag(t),ot)for(r=0;r<f.length;r++)if(i=(n=c[f[r]]).xaxis,a=n.yaxis,n._scene){var h=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((st||ot)&&(v(t),m(t)),lt){var d=e[2]/F._length,g=e[3]/H._length;for(r=0;r<f.length;r++){i=(n=c[f[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=it&&!i.fixedrange&&G[i._id],k=at&&!a.fixedrange&&W[a._id];if(w?(y=d,b=C?e[0]:qt(i,y)):b=Ut(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:qt(a,x)):_=Ut(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var M=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,M,A).call(u.setScale,1/y,1/x),y===zt&&x===Ot||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),zt=y,Ot=x}}}}function Vt(t,e,r){return t.fixedrange?0:it&&Q.xaHash[t._id]?e:at&&(nt?Q.xaHash:Q.yaHash)[t._id]?r:0}function Ut(t,e){return e?(t.range=t._r.slice(),k(t,e),qt(t,e)):0}function qt(t,e){return t._length*(1-e)*g[t.constraintoward||\"middle\"]}return S.length*C.length!=1&&U(gt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(St(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();pt(),clearTimeout(Dt);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(it){for(C||(o=.5),n=0;n<Y.length;n++)c(Y[n],o,i);It[2]*=i,It[0]+=It[2]*o*(1/i-1)}if(at){for(S||(l=.5),n=0;n<X.length;n++)c(X[n],l,i);It[3]*=i,It[1]+=It[3]*(1-l)*(1/i-1)}jt(It),Bt(),Dt=setTimeout(function(){It=[0,0,J,K],Nt()},Pt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),gt},makeDragger:C,makeRectDragger:E,makeZoombox:D,makeCorners:P,updateZoombox:R,xyCorners:V,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:U}},{\"../../components/color\":571,\"../../components/dragelement\":589,\"../../components/drawing\":592,\"../../components/fx\":610,\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/clear_gl_canvases\":679,\"../../lib/setcursor\":714,\"../../lib/svg_text_utils\":718,\"../../plot_api/subroutines\":733,\"../../registry\":825,\"../plots\":806,\"./axes\":742,\"./axis_ids\":745,\"./constants\":748,\"./scale_zoom\":759,\"./select\":760,d3:149,\"has-passive-events\":397,tinycolor2:515}],752:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var f=o._mainLinePosition;\"top\"===o.side&&(f-=l),s(t,n,o._offset+.1*o._length,f,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,f,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,f,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var h=c._mainLinePosition;\"right\"!==c.side&&(h-=l),s(t,n,h,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,h,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,h,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":589,\"../../components/fx\":610,\"../../lib/setcursor\":714,\"./constants\":748,\"./dragbox\":751,d3:149}],753:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,f=l.cartesian,h=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){h||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&f.push(g+v)}}}}}},{\"../../lib\":694,\"../../registry\":825}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),f=t(\"../../constants/xmlns_namespaces\"),h=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,f,h,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;h=(f=l(r,w))[0],r=f[1],h.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:h}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),\"scatterlayer\"!==l&&\"barlayer\"!==l&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),h=l(r,c)[0],c.plot(t,e,h)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(\".scatterlayer, .barlayer\").selectAll(\".trace\")),m.length)){var M=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=M.selectAll(\"path.point\"),e.zoomScaleTxt=M.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,f=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,h(s.overlinesBelow,\"path\",f),h(s.overlinesBelow,\"path\",d),h(s.overaxesBelow,\"g\",f),h(s.overaxesBelow,\"g\",d),e.plot=h(s.overplot,\"g\",n),h(s.overlinesAbove,\"path\",f),h(s.overlinesAbove,\"path\",d),h(s.overaxesAbove,\"g\",f),h(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+f),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+f),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.xaxislayer=h(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=h(r,\"g\",\"yaxislayer-above\");else{var g=h(r,\"g\",\"layer-subplot\");e.shapelayer=h(g,\"g\",\"shapelayer\"),e.imagelayer=h(g,\"g\",\"imagelayer\"),e.gridlayer=h(r,\"g\",\"gridlayer\"),e.zerolinelayer=h(r,\"g\",\"zerolinelayer\"),h(r,\"path\",\"xlines-below\"),h(r,\"path\",\"ylines-below\"),e.overlinesBelow=h(r,\"g\",\"overlines-below\"),h(r,\"g\",\"xaxislayer-below\"),h(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=h(r,\"g\",\"overaxes-below\"),e.plot=h(r,\"g\",\"plot\"),e.overplot=h(r,\"g\",\"overplot\"),e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.overlinesAbove=h(r,\"g\",\"overlines-above\"),h(r,\"g\",\"xaxislayer-above\"),h(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=h(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,f=o.cartesian,h=f.concat(o.gl2d||[]),p={},d={};for(r=0;r<h.length;r++){var g=h[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),f.push(n+i),h.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),f.push(n+i),h.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!h.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),f.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(null!==e){if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],f=[],h=0;h<s.length;h++){var p=s[h],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===f.indexOf(l)&&f.push(l),f.push(p)),l=p)}d(t,u,f,r,n)}}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var f=n._has&&n._has(\"gl\"),h=e._has&&e._has(\"gl\");if(f&&!h)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],f=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var h=a._mainAxis,p=o._mainAxis,d=h._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,f.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(f),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=h(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:f.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":592,\"../../constants/xmlns_namespaces\":672,\"../../lib\":694,\"../../registry\":825,\"../get_data\":779,\"../plots\":806,\"./attributes\":740,\"./axis_ids\":745,\"./constants\":748,\"./graph_interact\":752,\"./layout_attributes\":755,\"./layout_defaults\":756,\"./transition_axes\":765,d3:149}],755:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=t(\"./constants\");e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":570,\"../../components/drawing/attributes\":591,\"../../lib/extend\":684,\"../../plot_api/plot_template\":732,\"../font_attributes\":769,\"./constants\":748}],756:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraint_defaults\"),f=t(\"./position_defaults\"),h=t(\"./axis_ids\"),p=h.id2name,d=h.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var h,g,x={},b={},_={},w={},k={};for(h=0;h<r.length;h++){var M=r[h];if(v(M,\"cartesian\")||v(M,\"gl2d\")){var A,T;if(M.xaxis)y(x,A=p(M.xaxis),M);else if(M.xaxes)for(g=0;g<M.xaxes.length;g++)y(x,p(M.xaxes[g]),M);if(M.yaxis)y(x,T=p(M.yaxis),M);else if(M.yaxes)for(g=0;g<M.yaxes.length;g++)y(x,p(M.yaxes[g]),M);if(v(M,\"carpet\")&&(\"carpet\"!==M.type||M._cheater)||A&&(_[A]=1),\"carpet\"===M.type&&M._cheater&&A&&(b[A]=1),v(M,\"2dMap\")&&(w[A]=1,w[T]=1),v(M,\"oriented\"))k[\"h\"===M.orientation?T:A]=1}}var S=e._subplots,C=S.xaxis,E=S.yaxis,L=n.simpleMap(C,p),z=n.simpleMap(E,p),O=L.concat(z),I=i.background;C.length&&E.length&&(I=n.coerce(t,e,o,\"plot_bgcolor\"));var D,P,R,F,B=i.combine(I,e.paper_bgcolor);function N(t,e){return n.coerce(R,F,s,t,e)}function j(t,e){return n.coerce2(R,F,s,t,e)}function V(t){return\"x\"===t?E:C}var U={x:V(\"x\"),y:V(\"y\")};function q(e,r){for(var n=\"x\"===e?L:z,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(h=0;h<O.length;h++){P=(D=O[h]).charAt(0),n.isPlainObject(t[D])||(t[D]={}),R=t[D],F=a.newContainer(e,D,P+\"axis\");var H=x[D]||[];F._traceIndices=H.map(function(t){return t._expandedIndex}),F._annIndices=[],F._shapeIndices=[],F._imgIndices=[],F._subplotsWith=[],F._counterAxes=[],F._name=F._attr=D;var G=F._id=d(D),W=q(P,D),Y={letter:P,font:e.font,outerTicks:w[D],showGrid:!k[D],data:H,bgColor:B,calendar:e.calendar,automargin:!0,cheateronly:\"x\"===P&&b[D]&&!_[D],splomStash:((e._splomAxes||{})[P]||{})[G]};N(\"uirevision\",e.uirevision),l(R,F,N,Y),c(R,F,N,Y,e);var X=j(\"spikecolor\"),Z=j(\"spikethickness\"),$=j(\"spikedash\"),J=j(\"spikemode\"),K=j(\"spikesnap\");N(\"showspikes\",!!(X||Z||$||J||K))||(delete F.spikecolor,delete F.spikethickness,delete F.spikedash,delete F.spikemode,delete F.spikesnap);var Q={letter:P,counterAxes:U[P],overlayableAxes:W,grid:e.grid};f(R,F,N,Q),F._input=R}var tt=m(\"rangeslider\",\"handleDefaults\"),et=m(\"rangeselector\",\"handleDefaults\");for(h=0;h<L.length;h++)D=L[h],R=t[D],F=e[D],tt(t,e,D),\"date\"===F.type&&et(R,F,e,z,F.calendar),N(\"fixedrange\");for(h=0;h<z.length;h++){D=z[h],R=t[D],F=e[D];var rt=e[p(F.anchor)];N(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(rt))}e._axisConstraintGroups=[];var nt=U.x.concat(U.y);for(h=0;h<O.length;h++)P=(D=O[h]).charAt(0),R=t[D],F=e[D],u(R,F,N,nt,e)}},{\"../../components/color\":571,\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../registry\":825,\"../layout_attributes\":797,\"./axis_defaults\":744,\"./axis_ids\":745,\"./constraint_defaults\":749,\"./layout_attributes\":755,\"./position_defaults\":758,\"./type_defaults\":766}],757:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var f=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),h=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!f||!!h)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":570,\"../../lib\":694,tinycolor2:515}],758:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],f=a.overlayableAxes||[],h=a.letter,p=a.grid;p&&(s=p._domains[h][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[h+\"side\"].split(\" \")[0],c=p.domain[h][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===h?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===h?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(f.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(f),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":694,\"fast-isnumeric\":215}],759:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":666}],760:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib/polygon\"),l=t(\"../../lib/throttle\"),c=t(\"../../components/fx/helpers\").makeEventData,u=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),h=t(\"../../plot_api/subroutines\").redrawReglTraces,p=t(\"./constants\"),d=p.MINSELECT,g=s.filter,v=s.tester;function m(t){return t._id}function y(t,e,r,n,i,a,o){var s,l,c,u,f,h,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){w(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=M(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(h=T(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);S(e,s),k(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==h?h:T(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=_(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(f=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<f.length;b++)y.push(f[b]);else y=f;S(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&A(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function x(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function b(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function _(t){for(var e=[],r=x(t[0])?0:t[0][0][0],n=r,i=x(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(x(t[o]))e.push(b(t[o]));else{var l=s.tester(t[o]);l.subtract=t[o].subtract,e.push(l),r=Math.min(r,l.xmin),n=Math.max(n,l.xmax),i=Math.min(i,l.ymin),a=Math.max(a,l.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function w(t,e,r){var n=e._fullLayout,i=n._zoomlayer,a=r.plotinfo,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===a.id,s=t.shiftKey||t.altKey;o&&s&&a.selection&&a.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=a.selection.selectionDefs,r.mergedPolygons=a.selection.mergedPolygons):s&&a.selection||k(r),o||(E(i),n._lastSelectedSubplot=a.id)}function k(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function M(t,e,r,n){var i,a,o,s=[],l=e.map(m),c=r.map(m);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var f=h(a._module,i,e[0],r[0]);f.scene=t._fullLayout._splomScenes[a.uid],s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(h(a._module,i,u(t,a.xaxis),u(t,a.yaxis)))}else s.push(h(a._module,i,e[0],r[0]));return s;function h(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function A(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function T(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function S(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid];void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var p=u[n],d=p.data,g=p.fullData;p.pointIndices?([].push.apply(d.selectedpoints,p.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,p.pointIndices)):(d.selectedpoints.push(p.pointIndex),s._fullInput!==s&&g.selectedpoints.push(p.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&y(t,o)}v&&(f(t),h(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=c(t[i],n,r);return t}function E(t){t.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,s){var c,u,f,h,m,x,b,T=i.gd,E=T._fullLayout,L=E._zoomlayer,z=i.element.getBoundingClientRect(),O=i.plotinfo,I=O.xaxis._offset,D=O.yaxis._offset,P=e-z.left,R=r-z.top,F=P,B=R,N=\"M\"+P+\",\"+R,j=i.xaxes[0]._length,V=i.yaxes[0]._length,U=i.xaxes.concat(i.yaxes),q=t.altKey;w(t,T,i),\"lasso\"===s&&(c=g([[P,R]],p.BENDPX));var H=L.selectAll(\"path.select-outline-\"+O.id).data([1,2]);H.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+O.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",N+\"Z\");var G,W=L.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),Y=E._uid+p.SELECTID,X=[],Z=M(T,i.xaxes,i.yaxes,i.subplot);function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return t.p2d(r[e])}}function J(t,e){return t-e}G=O.fillRangeItems?O.fillRangeItems:\"select\"===s?function(t,e){var r=t.range={};for(m=0;m<U.length;m++){var n=U[m],i=n._id.charAt(0);r[n._id]=[n.p2d(e[i+\"min\"]),n.p2d(e[i+\"max\"])].sort(J)}}:function(t,e,r){var n=t.lassoPoints={};for(m=0;m<U.length;m++){var i=U[m];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){F=Math.max(0,Math.min(j,t+P)),B=Math.max(0,Math.min(V,e+R));var r=Math.abs(F-P),a=Math.abs(B-R);if(\"select\"===s){var o=E.selectdirection;\"h\"===(o=\"any\"===E.selectdirection?a<Math.min(.6*r,d)?\"h\":r<Math.min(.6*a,d)?\"v\":\"d\":E.selectdirection)?((h=[[P,0],[P,V],[F,V],[F,0]]).xmin=Math.min(P,F),h.xmax=Math.max(P,F),h.ymin=Math.min(0,V),h.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+h.xmin+\",\"+(R-d)+\"h-4v\"+2*d+\"h4ZM\"+(h.xmax-1)+\",\"+(R-d)+\"h4v\"+2*d+\"h-4Z\")):\"v\"===o?((h=[[0,R],[0,B],[j,B],[j,R]]).xmin=Math.min(0,j),h.xmax=Math.max(0,j),h.ymin=Math.min(R,B),h.ymax=Math.max(R,B),W.attr(\"d\",\"M\"+(P-d)+\",\"+h.ymin+\"v-4h\"+2*d+\"v4ZM\"+(P-d)+\",\"+(h.ymax-1)+\"v4h\"+2*d+\"v-4Z\")):\"d\"===o&&((h=[[P,R],[P,B],[F,B],[F,R]]).xmin=Math.min(P,F),h.xmax=Math.max(P,F),h.ymin=Math.min(R,B),h.ymax=Math.max(R,B),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===s&&(c.addPt([F,B]),h=c.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,h,q),h.subtract=q,u=_(i.selectionDefs.concat([h]))):(f=[h],u=v(h)),A(f,H),l.throttle(Y,p.SELECTDELAY,function(){var t;X=[];var e,r=[];for(m=0;m<Z.length;m++)if(e=(x=Z[m])._module.selectPoints(x,u),r.push(e),t=C(e,x),X.length)for(var n=0;n<t.length;n++)X.push(t[n]);else X=t;S(T,Z,b={points:X}),G(b,h,c),i.gd.emit(\"plotly_selecting\",b)})},i.clickFn=function(t,e){var r=E.clickmode;W.remove(),l.done(Y).then(function(){if(l.clear(Y),2===t){for(H.remove(),m=0;m<Z.length;m++)(x=Z[m])._module.selectPoints(x,!1);S(T,Z),k(i),T.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&y(e,T,i.xaxes,i.yaxes,i.subplot,i,H),\"event\"===r&&T.emit(\"plotly_selected\",void 0);o.click(T,e)})},i.doneFn=function(){W.remove(),l.done(Y).then(function(){l.clear(Y),i.gd.emit(\"plotly_selected\",b),h&&i.selectionDefs&&(h.subtract=q,i.selectionDefs.push(h),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f))})}},clearSelect:E,selectOnClick:y}},{\"../../components/color\":571,\"../../components/fx\":610,\"../../components/fx/helpers\":606,\"../../lib/clear_gl_canvases\":679,\"../../lib/polygon\":706,\"../../lib/throttle\":719,\"../../plot_api/subroutines\":733,\"../../registry\":825,\"./axis_ids\":745,\"./constants\":748,polybooljs:459}],761:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,f=t(\"../../constants/numerical\"),h=f.FP_SAFE,p=f.BADNUM,d=f.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=(t._id||\"x\").charAt(0);function f(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function x(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function b(e,r,n){return s(e,r,n||t.calendar)}function _(e){return t._categories[Math.round(e)]}function w(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function k(e){if(t._categoriesMap)return t._categoriesMap[e]}function M(t){var e=k(t);return void 0!==e?e:i(t)?+t:void 0}function A(e){return i(e)?n.round(t._b+t._m*e,2):p}function T(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?f:c,t.l2c=\"log\"===t.type?m:c,t.l2p=A,t.p2l=T,t.c2p=\"log\"===t.type?function(t,e){return A(f(t,e))}:A,t.p2c=\"log\"===t.type?function(t){return m(T(t))}:T,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=T,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return f(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=f,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(T(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=T,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=x,t.c2d=t.c2r=t.l2d=t.l2r=b,t.d2p=t.r2p=function(e,r,n){return t.l2p(x(e,0,n))},t.p2d=t.p2r=function(t,e,r){return b(T(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=w,t.r2d=t.c2d=t.l2d=_,t.d2r=t.d2l_noadd=M,t.r2c=function(e){var r=M(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=M,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return _(T(t))},t.r2p=t.d2p,t.p2r=T,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=_,t.d2r=t.d2l_noadd=M,t.r2c=function(e){var r=M(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=k,t.l2r=t.c2r=c,t.r2l=M,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return _(T(t))},t.r2p=t.d2p,t.p2r=T,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(e){var n,i,o=t._traceIndices,s=t._multicatSeen=[[0,{}],[0,{}]],l=t._multicatList=[];for(n=0;n<o.length;n++){var c=e[o[n]];if(r in c){var f=c[r],h=c._length||a.minRowLength(f);if(u(f[0])&&u(f[1]))for(i=0;i<h;i++){var p=f[0][i],d=f[1][i];y(p)&&y(d)&&(l.push([p,d]),p in s[0][1]||(s[0][1][p]=s[0][0]++),d in s[1][1]||(s[1][1][d]=s[1][0]++))}}}for(l.sort(function(t,e){var r=s[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=s[1][1];return i[t[1]]-i[e[1]]}),n=0;n<l.length;n++)w(l[n])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,n){n||(n={}),e||(e=\"range\");var o,s,l=a.nestedProperty(t,e).get();if(s=(s=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===r?g.DFLTRANGEY:n.dfltRange||g.DFLTRANGEX).slice(),l&&2===l.length)for(\"date\"===t.type&&(l[0]=a.cleanDate(l[0],p,t.calendar),l[1]=a.cleanDate(l[1],p,t.calendar)),o=0;o<2;o++)if(\"date\"===t.type){if(!a.isDateTime(l[o],t.calendar)){t[e]=s;break}if(t.r2l(l[0])===t.r2l(l[1])){var c=a.constrain(t.r2l(l[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);l[0]=t.l2r(c-1e3),l[1]=t.l2r(c+1e3);break}}else{if(!i(l[o])){if(!i(l[1-o])){t[e]=s;break}l[o]=l[1-o]*(o?10:.1)}if(l[o]<-h?l[o]=-h:l[o]>h&&(l[o]=h),l[0]===l[1]){var u=Math.max(1,Math.abs(1e-6*l[0]));l[0]-=u,l[1]+=u}}else a.nestedProperty(t,e).set(s)},t.setScale=function(n){var i=e._size;if(t.overlaying){var a=v.getFromId({_fullLayout:e},t.overlaying);t.domain=a.domain}var o=n&&t._r?\"_r\":\"range\",s=t.calendar;t.cleanRange(o);var l=t.r2l(t[o][0],s),c=t.r2l(t[o][1],s);if(\"y\"===r?(t._offset=i.t+(1-t.domain[1])*i.h,t._length=i.h*(t.domain[1]-t.domain[0]),t._m=t._length/(l-c),t._b=-t._m*c):(t._offset=i.l+t.domain[0]*i.w,t._length=i.w*(t.domain[1]-t.domain[0]),t._m=t._length/(c-l),t._b=-t._m*l),!isFinite(t._m)||!isFinite(t._b))throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=k([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,f=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*f}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,n){var i=t.c2l(e[r],null,n),a=t.r2l(t.range[0]),o=t.r2l(t.range[1]);return a<o?a<=i&&i<=o:o<=i&&i<=a},t.clearCalc=function(){t._categories=(t._initialCategories||[]).slice(),t._categoriesMap={};for(var e=0;e<t._categories.length;e++)t._categoriesMap[t._categories[e]]=e};var S=e._d3locale;\"date\"===t.type&&(t._dateFormat=S?S.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=S?S.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":671,\"../../lib\":694,\"./axis_ids\":745,\"./constants\":748,d3:149,\"fast-isnumeric\":215}],762:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,s,l){var c=function(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}(t);if(r(\"tickprefix\")&&r(\"showtickprefix\",c),r(\"ticksuffix\",l.tickSuffixDflt)&&r(\"showticksuffix\",c),r(\"showticklabels\")){var u=l.font||{},f=e.color,h=f&&f!==i.color.dflt?f:u.color;if(n.coerceFont(r,\"tickfont\",{family:u.family,size:u.size,color:h}),r(\"tickangle\"),\"category\"!==s){var p=r(\"tickformat\"),d=t.tickformatstops;Array.isArray(d)&&d.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:o}),p||\"date\"===s||(r(\"showexponent\",c),r(\"exponentformat\"),r(\"separatethousands\"))}}}},{\"../../lib\":694,\"../array_container_defaults\":738,\"./layout_attributes\":755}],763:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":694,\"./layout_attributes\":755}],764:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":747}],765:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,f,h;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(h),h=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),h=window.requestAnimationFrame(function n(){f=Date.now();for(var a=Math.min(1,(f-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);f-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),h=window.cancelAnimationFrame(n)):h=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,f=e.yr0,h=e.yr1,p=s._length,d=!!c,g=!!h,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=f[1]-f[0],b=h[1]-h[0];v[1]=(f[1]*(1-r)+r*h[1]-f[1])/(f[0]-f[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=f[0]*(1-r)+r*h[0],s.range[1]=f[1]*(1-r)+r*h[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,M=g?v[1]:0,A=d?v[0]/v[2]*u:0,T=g?v[1]/v[3]*p:0,S=i._offset-A,C=s._offset-T;n.clipRect.call(a.setTranslate,k,M).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,C).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":592,\"../../registry\":825,\"./axes\":742,d3:149}],766:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",f=l[u],h={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==f&&(f=void 0))}t.type=i(d,f,h)}else if(\"splom\"===l.type){var v=l.dimensions,m=l._diag;for(c=0;c<v.length;c++){var y=v[c];if(y.visible&&(m[c][0]===r||m[c][1]===r)){t.type=i(y.values,f,h);break}}}else t.type=i(l[s]||[l[s+\"0\"]],f,h)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":825,\"./axis_autotype\":743}],767:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a;if(Array.isArray(i)){var o=Math.min(i.length,t.data.length);r&&(o=Math.min(o,r.length)),a=[];for(var l=0;l<o;l++)a[l]=r?r[l]:l}else a=r?r.slice(0):null;if(null===a)Array.isArray(i)&&(i=i[0]);else if(Array.isArray(a)){if(!Array.isArray(i)){var c=i;i=[];for(var u=0;u<a.length;u++)i[u]=c}i.length=Math.min(a.length,i.length)}s.push({type:\"data\",prop:e,traces:a,value:i})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],f=0;f<u.length;f++)t._internalOn(u[f],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var f=r.computeAPICommandBindings(t,c,u);if(1!==f.length)return!1;if(a){if((s=f[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var h=0;h<a.traces.length;h++)if(a.traces[h]!==s.traces[h])return!1}else if(s.prop!==a.prop)return!1}else a=f[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=f[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":694,\"../registry\":825}],768:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":684}],769:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],770:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],771:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),f=t(\"../../components/dragelement\"),h=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=v.getTopojsonName(i);null===n.topojson||a!==n.topojsonName?(n.topojsonName=a,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial||this.saveViewInitial(r),this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var f=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],h=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(h.range,p.range);u.fitExtent(f,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var M=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(M[0]-y[0]),y[1]+(M[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),T=u.translate();u.translate([T[0]-(A[0]-T[0]),T[1]-(A[1]-T[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function u(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var h=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return u(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),p=r.framework.selectAll(\".layer\").data(h,String);p.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),p.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):u(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),p.order(),p.each(function(t){var r=l[t],a=g.layerNameToAdjective[t];\"frame\"===t?r.datum(g.sphereSVG):u(t)||f(t)?r.datum(m(i,i.objects[t])):c(t)&&r.datum(function(t,e){var r=e[t].dtick,i=g.scopeDefaults[e.scope],a=i.lonaxisRange,o=i.lataxisRange,s=\"lonaxis\"===t?[r]:[0,r];return n.geo.graticule().extent([[a[0],o[0]],[a[1],o[1]]]).step(s)}(t,e)).call(o.stroke,e[t].gridcolor).call(s.dashLine,\"\",e[t].gridwidth),u(t)?r.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(t)&&r.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){h(t,e,r,g,s)},f.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return f.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||f.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":571,\"../../components/dragelement\":589,\"../../components/drawing\":592,\"../../components/fx\":610,\"../../lib\":694,\"../../lib/topojson_utils\":721,\"../../registry\":825,\"../cartesian/axes\":742,\"../cartesian/select\":760,\"../plots\":806,\"./constants\":771,\"./projections\":777,\"./zoom\":778,d3:149,\"topojson-client\":518}],773:[function(t,e,r){\"use strict\";var n=t(\"./geo\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex,o=\"geo\";r.name=o,r.attr=o,r.idRoot=o,r.idRegex=r.attrRegex=a(o),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,a=e._subplots.geo;void 0===window.PlotlyGeoAssets&&(window.PlotlyGeoAssets={topojson:{}});for(var s=0;s<a.length;s++){var l=a[s],c=i(r,o,l),u=e[l]._subplot;u||(u=n({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.geo||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}}},{\"../../lib\":694,\"../../plots/get_data\":779,\"./geo\":772,\"./layout/attributes\":774,\"./layout/defaults\":775,\"./layout/layout_attributes\":776}],774:[function(t,e,r){\"use strict\";e.exports={geo:{valType:\"subplotid\",dflt:\"geo\",editType:\"calc\"}}},{}],775:[function(t,e,r){\"use strict\";var n=t(\"../../subplot_defaults\"),i=t(\"../constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,f=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var h=0;h<o.length;h++){var p,d=o[h],g=[30,10][h];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[h]);p=[y-m,y+m]}var x=r(d+\".range\",p);r(d+\".tick0\",x[0]),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var b=e.lonaxis.range,_=e.lataxis.range,w=b[0],k=b[1];w>0&&k<0&&(k+=360);var M,A,T,S=(w+k)/2;if(!c){var C=u?s.projRotate:[S,0,0];M=r(\"projection.rotation.lon\",C[0]),r(\"projection.rotation.lat\",C[1]),r(\"projection.rotation.roll\",C[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(A=-96.6,T=38.7):(A=u?S:M,T=(_[0]+_[1])/2),r(\"center.lon\",A),r(\"center.lat\",T),f)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../../subplot_defaults\":820,\"../constants\":771,\"./layout_attributes\":776}],776:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color/attributes\"),i=t(\"../../domain\").attributes,a=t(\"../constants\"),o=t(\"../../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\"},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../../components/color/attributes\":570,\"../../../plot_api/edit_types\":725,\"../../domain\":768,\"../constants\":771}],777:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],f=t[s],h=f[0],p=f[1];u>n^p>n&&r<(h-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var f=1e-6,h=f*f,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>f;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var f=o[c];if(f[0][0]<=t&&t<f[1][0]&&f[0][1]<=a&&a<f[1][1]){var h=e.invert(t-e(s[c][1][0],0)[0],a);return h[0]+=s[c][1][0],l(i(h[0],h[1]),[t,a])?h:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<f&&Math.abs(t[1]-e[1])<f}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,f=180*o[2][0]/p,h=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[f-e,u-e],[f-e,h+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,f=180*o[2][0]/p,h=180*o[2][1]/p;r.push(s([[f-e,h-e],[f-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return M;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function M(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function T(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>f&&--i>0);return e/2}}M.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,T.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(T)}).raw=T,S(p);var C=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(C)}).raw=C,E.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>f&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(E)}).raw=E;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function z(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],f=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(f-s)/2+a*a*(f-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function I(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function D(t,e){var r=I(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),z.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,f=2*(Math.abs(r)-s)/c,p=u/c,m=f*(1-p*f*(1-2*p*f));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>h&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(z)}).raw=z,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,I.invert=function(t,e){if(!(t*t+4*e*e>p*p+f)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),h=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*h-2*x*c*s),M=.25*a*(h*s-x*c*g*o),A=a*(d*l+x*v*u),T=k*M-A*w;if(!T)break;var S=(_*k-b*A)/T,C=(b*M-_*w)/T;r-=S,n-=C}while((Math.abs(S)>f||Math.abs(C)>f)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(I)}).raw=I,D.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,h=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(h*l/4-x*s*g),M=.125*a*(l*g-x*s*u*h),A=.5*a*(c*p+x*v*o)+.5,T=k*M-A*w,S=(_*k-b*A)/T,C=(b*M-_*w)/T;r-=S,n-=C}while((Math.abs(S)>f||Math.abs(C)>f)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(D)}).raw=D}},{}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function f(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],f={},h={};function p(t,e){f[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,f);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),h[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",h)}function h(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render()}).on(\"zoomend\",function(){n.select(this).style(c),f(t,e,i)}),r}function p(t,e){var r,i,a,o,s,h,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(h=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(h)&&(d=y(h),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=h),g=!0,t.render()}).on(\"zoomend\",function(){n.select(this).style(c),g&&f(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),h=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,f,m,b,_,w,k,M,A,T=n.mouse(this),S=e.rotate(),C=S,E=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,f=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(f),M=Math.cos(f),[b*w*M+m*_*k,m*w*M-b*_*k,b*_*M+m*w*k,b*w*k-m*_*M]);r=g(e,T),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,f,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(E);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],f=a[0],p=a[1],d=a[2],m=a[3],[o*f-l*p-c*d-u*m,o*p+l*f+c*m-u*d,o*d-l*m+c*f+u*p,o*m+l*d-c*p+u*f])),M=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],f=n[1],h=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(f)>d?(a=(f>0?90:-90)-p,i=0):(a=Math.asin(f/d)*s-p,i=Math.sqrt(d*d-f*f));var g=180-a-2*p,m=(Math.atan2(h,u)-Math.atan2(c,i))*s,x=(Math.atan2(h,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,C);isFinite(M[0])&&isFinite(M[1])&&isFinite(M[2])||(M=C),e.rotate(M),C=M}}else r=g(e,T=b);h.of(this,arguments)({type:\"zoom\"})}),A=h.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=h.of(this,arguments),--p||r({type:\"zoomend\"}),f(t,e,m)}).on(\"zoom.redraw\",function(){t.render()}),n.rebind(a,h,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?h:e._isClipped?d:p)(t,r)}},{\"../../lib\":694,\"../../registry\":825,d3:149}],779:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var f=0;f<t.length;f++)a=t[f],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":825,\"./cartesian/constants\":748}],780:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function f(e,n,i){var a,s,l=t.calcDataBox(),f=r.viewBox,h=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=f[3]-f[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(f[2]-f[0])*(l[2]-l[0])+l[0],y=i/(f[3]-f[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(h-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,f),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);f(0,r[0],r[1]),f(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);f(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){f(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),f=o/(a[2]-a[0])*(i[2]-i[0])+i[0],h=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-f)*l+f,i[2]=(i[2]-f)*l+f,i[1]=(i[1]-h)*l+h,i[3]=(i[3]-h)*l+h,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":748,\"has-passive-events\":397,\"mouse-change\":421,\"mouse-event-offset\":422,\"mouse-wheel\":424}],781:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=!1,this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,f,h,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),h=0;h<2;++h){var d=(e=s[h]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[h+p]=!1,this.labels[h+p]=n,this.labelColor[h+p]=i(r.title.font.color),this.labelFont[h+p]=r.title.font.family,this.labelSize[h+p]=r.title.font.size,this.labelPad[h+p]=this.getLabelPad(e,r),this.tickEnable[h+p]=!1,this.tickColor[h+p]=i((r.tickfont||{}).color),this.tickAngle[h+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[h+p]=this.getTickPad(r),this.tickMarkLength[h+p]=0,this.tickMarkWidth[h+p]=r.tickwidth||0,this.tickMarkColor[h+p]=i(r.tickcolor),this.borderLineEnable[h+p]=!1,this.borderLineColor[h+p]=i(r.linecolor),this.borderLineWidth[h+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,f=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[h]=!0:l&&(this.labelEnable[h+2]=!0),o?this.tickEnable[h]=r.showticklabels:l&&(this.tickEnable[h+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[h]=r.showline),(l||u)&&(this.borderLineEnable[h+2]=r.showline),(o||f)&&(this.tickMarkLength[h]=this.getTickMarkLength(r)),(l||f)&&(this.tickMarkLength[h+2]=this.getTickMarkLength(r)),this.gridLineEnable[h]=r.showgrid,this.gridLineColor[h]=i(r.gridcolor),this.gridLineWidth[h]=r.gridwidth,this.zeroLineEnable[h]=r.zeroline,this.zeroLineColor[h]=i(r.zerolinecolor),this.zeroLineWidth[h]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":717,\"../cartesian/axes\":742}],782:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":611,\"../../constants/xmlns_namespaces\":672,\"../../plot_api/edit_types\":725,\"../cartesian\":754,\"../cartesian/attributes\":740,\"../cartesian/constants\":748,\"../get_data\":779,\"../layout_attributes\":797,\"./scene2d\":783}],783:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),f=t(\"webgl-context\"),h=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=h(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=f({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=f({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),h},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,f=this.xaxis.domain,h=this.yaxis.domain;for(o.viewBox=[u.l+f[0]*u.w,u.b+h[0]*u.h,i-u.r-(1-f[1])*u.w,a-u.t-(1-h[1])*u.h],this.mouseContainer.style.width=u.w*(f[1]-f[0])+\"px\",this.mouseContainer.style.height=u.h*(h[1]-h[0])+\"px\",this.mouseContainer.height=u.h*(h[1]-h[0]),this.mouseContainer.style.left=u.l+f[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-h[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var f=i._size,h=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+f.l+h[0]*f.w,l/t.pixelRatio-(f.t+(1-p[1])*f.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":610,\"../../lib/show_no_webgl_msg\":715,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"../cartesian/autorange\":741,\"../cartesian/constants\":748,\"../cartesian/constraints\":750,\"./camera\":780,\"./convert\":781,\"gl-plot2d\":277,\"gl-select-box\":288,\"gl-spikes2d\":297,\"webgl-context\":534}],784:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1});var g=0,v=0,m={shift:!1,control:!1,alt:!1,meta:!1};function y(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,h=!!a.control,p=!!a.alt,y=!!a.shift,x=!!(1&e),b=!!(2&e),_=!!(4&e),w=1/t.clientHeight,k=w*(r-g),M=w*(i-v),A=d.flipX?1:-1,T=d.flipY?1:-1,S=n(),C=Math.PI*d.rotateSpeed;if((s&&x&&!h&&!p&&!y||x&&!h&&!p&&y)&&c.rotate(S,A*C*k,-T*C*M,0),(l&&x&&!h&&!p&&!y||b||x&&h&&!p&&!y)&&c.pan(S,-d.translateSpeed*k*f,d.translateSpeed*M*f,0),u&&x&&!h&&!p&&!y||_||x&&!h&&p&&!y){var E=-d.zoomSpeed*M/window.innerHeight*(S-c.lastT())*100;c.pan(S,0,0,f*(Math.exp(E)-1))}return g=r,v=i,m=a,!0}}return d.mouseListener=a(t,y),t.addEventListener(\"touchstart\",function(e){var r=s(e.changedTouches[0],t);y(0,r[0],r[1],m),y(1,r[0],r[1],m),e.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(e){var r=s(e.changedTouches[0],t);y(1,r[0],r[1],m),e.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){y(0,g,v,m),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else{var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,f*(Math.exp(o)-1))}}},!0),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":46,\"has-passive-events\":397,\"mouse-change\":421,\"mouse-event-offset\":422,\"mouse-wheel\":424,\"right-now\":482}],785:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var l=n[i],c=o(r,\"gl3d\",l),u=e[l],f=u._scene;f||(f=new a({id:l,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),u._scene=f),f.cameraInitial||(f.cameraInitial=s.extendDeep({},u.camera)),f.plot(c,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":611,\"../../constants/xmlns_namespaces\":672,\"../../lib\":694,\"../../plot_api/edit_types\":725,\"../get_data\":779,\"./layout/attributes\":786,\"./layout/defaults\":790,\"./layout/layout_attributes\":791,\"./scene\":795}],786:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],787:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":571,\"../../../lib/extend\":684,\"../../../plot_api/edit_types\":725,\"../../cartesian/layout_attributes\":755}],788:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,f;function h(t,e){return i.coerce(u,f,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(f=a.newContainer(e,d))._id=d[0]+r.scene,f._name=d,s(u,f,h,r),l(u,f,h,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),h(\"gridcolor\",n(f.color,r.bgColor,13600/187).toRgbString()),h(\"title.text\",d[0]),f.setScale=i.noop,h(\"showspikes\")&&(h(\"spikesides\"),h(\"spikethickness\"),h(\"spikecolor\",f.color)),h(\"showaxeslabels\"),h(\"showbackground\")&&h(\"backgroundcolor\")}}},{\"../../../lib\":694,\"../../../plot_api/plot_template\":732,\"../../cartesian/axis_defaults\":744,\"../../cartesian/type_defaults\":766,\"./axis_attributes\":787,tinycolor2:515}],789:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t.meta?i.templateString(o.title.text,{meta:t.meta}):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":694,\"../../../lib/str2rgbarray\":717}],790:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function f(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),f=[\"up\",\"center\",\"eye\"],h=0;h<f.length;h++)r(\"camera.\"+f[h]+\".x\"),r(\"camera.\"+f[h]+\".y\"),r(\"camera.\"+f[h]+\".z\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:f,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":571,\"../../../lib\":694,\"../../../registry\":825,\"../../get_data\":779,\"../../subplot_defaults\":820,\"./axis_defaults\":788,\"./layout_attributes\":791}],791:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":694,\"../../../lib/extend\":684,\"../../domain\":768,\"./axis_attributes\":787}],792:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":717}],793:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var f=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var h=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/h)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=f}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":694,\"../../cartesian/axes\":742}],794:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],795:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\"),o=t(\"webgl-context\"),s=t(\"has-passive-events\"),l=t(\"../../registry\"),c=t(\"../../lib\"),u=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),h=t(\"../../lib/str2rgbarray\"),p=t(\"../../lib/show_no_webgl_msg\"),d=t(\"./camera\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r){var l=t.graphDiv,c={canvas:e,gl:r,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=o({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=a(c)}catch(e){return p(t)}var h=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=M(t.camera),t.saveCamera(l.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};if(t.glplot.canvas.addEventListener(\"mouseup\",function(){h(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){l._context._scrollZoom.gl3d&&h(t)},!!s&&{passive:!1}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){l&&l.emit&&l.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),!t.camera){var v=t.fullSceneLayout.camera;t.camera=d(t.container,{center:[v.center.x,v.center.y,v.center.z],eye:[v.eye.x,v.eye.y,v.eye.z],up:[v.up.x,v.up.y,v.up.z],zoomMin:.1,zoomMax:100,mode:\"orbit\"})}return t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.svgContainer,n=t.container.getBoundingClientRect(),i=n.width,a=n.height;r.setAttributeNS(null,\"viewBox\",\"0 0 \"+i+\" \"+a),r.setAttributeNS(null,\"width\",i),r.setAttributeNS(null,\"height\",a),y(t),t.glplot.axes.update(t.axesOptions);for(var o,s=Object.keys(t.traces),l=null,c=t.glplot.selection,h=0;h<s.length;++h)\"skip\"!==(e=t.traces[s[h]]).data.hoverinfo&&e.handlePick(c)&&(l=e),e.setContourLevels&&e.setContourLevels();function p(e,r){var n=t.fullSceneLayout[e];return u.tickText(n,n.d2l(r),\"hover\").text}if(null!==l){var d=g(t.glplot.cameraParams,c.dataCoordinate);e=l.data;var v,m=c.index,x=f.castHoverinfo(e,t.fullLayout,m),b=x.split(\"+\"),_=\"all\"===x,w=p(\"xaxis\",c.traceCoordinate[0]),k=p(\"yaxis\",c.traceCoordinate[1]),M=p(\"zaxis\",c.traceCoordinate[2]);_||(-1===b.indexOf(\"x\")&&(w=void 0),-1===b.indexOf(\"y\")&&(k=void 0),-1===b.indexOf(\"z\")&&(M=void 0),-1===b.indexOf(\"text\")&&(c.textLabel=void 0),-1===b.indexOf(\"name\")&&(l.name=void 0));var A=[];\"cone\"===e.type||\"streamtube\"===e.type?((_||-1!==b.indexOf(\"u\"))&&A.push(\"u: \"+p(\"xaxis\",c.traceCoordinate[3])),(_||-1!==b.indexOf(\"v\"))&&A.push(\"v: \"+p(\"yaxis\",c.traceCoordinate[4])),(_||-1!==b.indexOf(\"w\"))&&A.push(\"w: \"+p(\"zaxis\",c.traceCoordinate[5])),(_||-1!==b.indexOf(\"norm\"))&&A.push(\"norm: \"+c.traceCoordinate[6].toPrecision(3)),\"streamtube\"!==e.type||!_&&-1===b.indexOf(\"divergence\")||A.push(\"divergence: \"+c.traceCoordinate[7].toPrecision(3)),c.textLabel&&A.push(c.textLabel),v=A.join(\"<br>\")):\"isosurface\"===e.type?(A.push(\"value: \"+u.tickText(t.mockAxis,t.mockAxis.d2l(c.traceCoordinate[3]),\"hover\").text),c.textLabel&&A.push(c.textLabel),v=A.join(\"<br>\")):v=c.textLabel,t.fullSceneLayout.hovermode&&f.loneHover({x:(.5+.5*d[0]/d[3])*i,y:(.5-.5*d[1]/d[3])*a,xLabel:w,yLabel:k,zLabel:M,text:v,name:l.name,color:f.castHoverOption(e,m,\"bgcolor\")||l.color,borderColor:f.castHoverOption(e,m,\"bordercolor\"),fontFamily:f.castHoverOption(e,m,\"font.family\"),fontSize:f.castHoverOption(e,m,\"font.size\"),fontColor:f.castHoverOption(e,m,\"font.color\")},{container:r,gd:t.graphDiv});var T={x:c.traceCoordinate[0],y:c.traceCoordinate[1],z:c.traceCoordinate[2],data:e._input,fullData:e,curveNumber:e.index,pointNumber:m};e._module.eventData&&(T=e._module.eventData(T,c,e,{},m)),f.appendArrayPointValue(T,e,m);var S={points:[T]};c.buttons&&c.distance<5?t.graphDiv.emit(\"plotly_click\",S):t.graphDiv.emit(\"plotly_hover\",S),o=S}else f.loneUnhover(r),t.graphDiv.emit(\"plotly_unhover\",o);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=l.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=l.getComponentMethod(\"annotations3d\",\"draw\"),x(this)}var _=b.prototype;_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas;this.glplot.dispose(),requestAnimationFrame(function n(){e.isContextLost()?requestAnimationFrame(n):x(t,r,e)?t.plot.apply(t,t.plotArgs):c.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],u=e[o+\"calendar\"],f=e[\"_\"+o+\"length\"];if(c.isArrayOrTypedArray(l))for(var h,p=0;p<(f||l.length);p++)if(c.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)h=s.d2l(l[p][d],0,u),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else h=s.d2l(l[p],0,u),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],f-1)}}function M(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=h(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&k(this,n,f);var p=[1,1,1];for(o=0;o<3;++o)f[1][o]===f[0][o]?p[o]=1:p[o]=1/(f[1][o]-f[0][o]);for(this.dataScale=p,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=p[a],m[l].count+=1):m[l]={acc:p[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],M=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],M[0][a]/p[a]-A),g[1][a]=Math.max(g[1][a],M[1][a]/p[a]+A)}for(o=0;o<x.length;o++){var T=x[o];if(T.visible){var S=s.r2l(T[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var C=g[1][a]-g[0][a];g[0][a]-=C/32,g[1][a]+=C/32}if(\"reversed\"===s.autorange){var E=g[0][a];g[0][a]=g[1][a],g[1][a]=E}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*p[a],this.glplot.bounds[1][a]=g[1][a]*p[a]}var z=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];z[a]=Math.pow(O.acc,1/O.count)/p[a]}var I;if(\"auto\"===c.aspectmode)I=Math.max.apply(null,z)/Math.min.apply(null,z)<=4?z:[1,1,1];else if(\"cube\"===c.aspectmode)I=[1,1,1];else if(\"data\"===c.aspectmode)I=z;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var D=c.aspectratio;I=[D.x,D.y,D.z]}c.aspectratio.x=u.aspectratio.x=I[0],c.aspectratio.y=u.aspectratio.y=I[1],c.aspectratio.z=u.aspectratio.z=I[2],this.glplot.aspect=I;var P=c.domain||null,R=e._size||null;if(P&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+P.x[0]*R.w+\"px\",F.top=R.t+(1-P.y[1])*R.h+\"px\",F.width=R.w*(P.x[1]-P.x[0])+\"px\",F.height=R.h*(P.y[1]-P.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),M(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]])},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=c.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else for(var s=0;s<3;s++)for(var u=0;u<3;u++)if(!o(r,i,s,u)){a=!0;break}if(a){var f={};f[this.id+\".camera\"]=i,l.call(\"_storeDirectGUIEdit\",t,e._preGUI,f),n.set(r),c.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,u=a.up.z;if(u/Math.sqrt(o*o+s*s+u*u)>.999)return;var f=this.id+\".camera.up\",h={x:0,y:0,z:1},p={};p[f]=h;var d=n.layout;l.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=h,c.nestedProperty(d,f).set(h)}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),h},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];u.setConvert(e,this.fullLayout),e.setScale=c.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":610,\"../../lib\":694,\"../../lib/show_no_webgl_msg\":715,\"../../lib/str2rgbarray\":717,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"./camera\":784,\"./layout/convert\":789,\"./layout/spikes\":792,\"./layout/tick_marks\":793,\"./project\":794,\"gl-plot3d\":279,\"has-passive-events\":397,\"webgl-context\":534}],796:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],797:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"../components/colorscale/layout_attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=a.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},colorscale:o,datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"data_array\",editType:\"plot\"},transition:l({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":570,\"../components/colorscale/layout_attributes\":584,\"../lib/extend\":684,\"./animation_attributes\":737,\"./font_attributes\":769,\"./pad_attributes\":805}],798:[function(t,e,r){\"use strict\";e.exports={requiredVersion:\"0.45.0\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",controlContainerClassName:\"mapboxgl-control-container\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@0.45.0.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none\"}}},{}],799:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":694}],800:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"./mapbox\"),l=t(\"./constants\");for(var c in l.styleRules)i.addStyleRule(\".mapboxgl-\"+c,l.styleRules[c]);r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==l.requiredVersion)throw new Error(l.wrongVersionErrorMsg);var c=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=0;n<e.length;n++){var i=r[e[n]];if(i.accesstoken)return i.accesstoken}throw new Error(l.noAccessTokenErrorMsg)}(t,o);n.accessToken=c;for(var u=0;u<o.length;u++){var f=o[u],h=a(r,\"mapbox\",f),p=e[f],d=p._subplot;d||(d=s({gd:t,container:e._glcontainer.node(),id:f,fullLayout:e,staticPlot:t._context.staticPlot}),e[f]._subplot=d),d.viewInitial||(d.viewInitial={center:i.extendFlat({},p.center),zoom:p.zoom,bearing:p.bearing,pitch:p.pitch}),d.plot(h,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],s=a.domain,l=a._subplot,c=l.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":c,x:n.l+n.w*s.x[0],y:n.t+n.h*(1-s.y[1]),width:n.w*(s.x[1]-s.x[0]),height:n.h*(s.y[1]-s.y[0]),preserveAspectRatio:\"none\"}),l.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../constants/xmlns_namespaces\":672,\"../../lib\":694,\"../../plots/get_data\":779,\"./constants\":798,\"./layout_attributes\":802,\"./layout_defaults\":803,\"./mapbox\":804,\"mapbox-gl\":412}],801:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\");function a(t,e){this.mapbox=t,this.map=t.map,this.uid=t.uid+\"-layer\"+e,this.idSource=this.uid+\"-source\",this.idLayer=this.uid+\"-layer\",this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var o=a.prototype;function s(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||\"string\"==typeof e&&e.length>0)}function l(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}o.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=s(t)},o.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},o.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==t.below},o.updateSource=function(t){var e=this.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,s(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r&&(e=\"string\"==typeof n?\"url\":\"tiles\");return i[e]=n,i}(t);e.addSource(this.idSource,r)}},o.updateLayer=function(t){var e=this.map,r=l(t);this.removeLayer(),this.layerType=t.type,s(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,layout:r.layout,paint:r.paint},t.below)},o.updateStyle=function(t){if(s(t)){var e=l(t);this.mapbox.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.mapbox.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},o.removeLayer=function(){var t=this.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},o.dispose=function(){var t=this.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new a(t,e);return n.update(r),n}},{\"../../lib\":694,\"./convert_text_opts\":799}],802:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=o({});u.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],dflt:\"basic\"},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\"],dflt:\"circle\"},below:{valType:\"string\",dflt:\"\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},textfont:u,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":571,\"../../lib\":694,\"../../plot_api/edit_types\":725,\"../../plot_api/plot_template\":732,\"../../traces/scatter/attributes\":1047,\"../domain\":768,\"../font_attributes\":769}],803:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i=r(\"sourcetype\");r(\"source\"),\"vector\"===i&&r(\"sourcelayer\");var a=r(\"type\");r(\"below\"),r(\"color\"),r(\"opacity\"),\"circle\"===a&&r(\"circle.radius\"),\"line\"===a&&r(\"line.width\"),\"fill\"===a&&r(\"fill.outlinecolor\"),\"symbol\"===a&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":694,\"../array_container_defaults\":738,\"../subplot_defaults\":820,\"./layout_attributes\":802}],804:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../components/fx\"),a=t(\"../../lib\"),o=t(\"../../registry\"),s=t(\"../../components/dragelement\"),l=t(\"../cartesian/select\").prepSelect,c=t(\"../cartesian/select\").selectOnClick,u=t(\"./constants\"),f=t(\"./layout_attributes\"),h=t(\"./layers\");function p(t){this.id=t.id,this.gd=t.gd,this.container=t.container,this.isStatic=t.staticPlot;var e=t.fullLayout;this.uid=e._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(e),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[]}var d=p.prototype;function g(t){var e=f.style.values,r=f.style.dflt,n={};return a.isPlainObject(t)?(n.id=t.id,n.style=t):\"string\"==typeof t?(n.id=t,n.style=-1!==e.indexOf(t)?v(t):t):(n.id=r,n.style=v(r)),n.transition={duration:0,delay:0},n}function v(t){return u.styleUrlPrefix+t+\"-\"+u.styleUrlSuffix}function m(t){return[t.lon,t.lat]}e.exports=function(t){return new p(t)},d.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},d.createMap=function(t,e,r,a){var s=this,l=s.gd,f=e[s.id],h=s.styleObj=g(f.style);s.accessToken=f.accesstoken;var p=s.map=new n.Map({container:s.div,style:h.style,center:m(f.center),zoom:f.zoom,bearing:f.bearing,pitch:f.pitch,interactive:!s.isStatic,preserveDrawingBuffer:s.isStatic,doubleClickZoom:!1,boxZoom:!1}),d=u.controlContainerClassName,v=s.div.getElementsByClassName(d)[0];if(s.div.removeChild(v),p._canvas.style.left=\"0px\",p._canvas.style.top=\"0px\",s.rejectOnError(a),p.once(\"load\",function(){s.updateData(t),s.updateLayout(e),s.resolveOnRender(r)}),!s.isStatic){var y=!1;p.on(\"moveend\",function(t){if(s.map){if(t.originalEvent||y){var e=l._fullLayout[s.id];o.call(\"_storeDirectGUIEdit\",l.layout,l._fullLayout._preGUI,s.getViewEdits(e));var r=s.getView();e._input.center=e.center=r.center,e._input.zoom=e.zoom=r.zoom,e._input.bearing=e.bearing=r.bearing,e._input.pitch=e.pitch=r.pitch,l.emit(\"plotly_relayout\",s.getViewEdits(r))}y=!1}}),p.on(\"wheel\",function(){y=!0}),p.on(\"mousemove\",function(t){var e=s.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},s.xaxis.p2c=function(){return t.lngLat.lng},s.yaxis.p2c=function(){return t.lngLat.lat},i.hover(l,t,s.id)}),p.on(\"dragstart\",x),p.on(\"zoomstart\",x),p.on(\"dblclick\",function(){var t=l._fullLayout[s.id];o.call(\"_storeDirectGUIEdit\",l.layout,l._fullLayout._preGUI,s.getViewEdits(t));var e=s.viewInitial;p.setCenter(m(e.center)),p.setZoom(e.zoom),p.setBearing(e.bearing),p.setPitch(e.pitch);var r=s.getView();t._input.center=t.center=r.center,t._input.zoom=t.zoom=r.zoom,t._input.bearing=t.bearing=r.bearing,t._input.pitch=t.pitch=r.pitch,l.emit(\"plotly_doubleclick\",null),l.emit(\"plotly_relayout\",s.getViewEdits(r))}),s.clearSelect=function(){l._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},s.onClickInPanFn=function(t){return function(e){var r=l._fullLayout.clickmode;r.indexOf(\"select\")>-1&&c(e.originalEvent,l,[s.xaxis],[s.yaxis],s.id,t),r.indexOf(\"event\")>-1&&i.click(l,e.originalEvent)}}}function x(){i.loneUnhover(e._toppaper)}},d.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=g(o.style);i.styleObj.id!==s.id?(i.styleObj=s,a.setStyle(s.style),a.once(\"styledata\",function(){i.traceHash={},i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})):(i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)),this.gd._context._scrollZoom.mapbox?a.scrollZoom.enable():a.scrollZoom.disable()},d.updateData=function(t){var e,r,n,i,a=this.traceHash;for(n=0;n<t.length;n++){var o=t[n];(e=a[(r=o[0].trace).uid])?e.update(o):r._module&&(a[r.uid]=r._module.plot(this,o))}var s=Object.keys(a);t:for(n=0;n<s.length;n++){var l=s[n];for(i=0;i<t.length;i++)if(l===(r=t[i][0].trace).uid)continue t;(e=a[l]).dispose(),delete a[l]}},d.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(m(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize()},d.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},d.rejectOnError=function(t){var e=this.map;function r(){t(new Error(u.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},d.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t)},d.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,o=t.dragmode;i=\"select\"===o?function(t,r){(t.range={})[e.id]=[u([r.xmin,r.ymin]),u([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(u)};var c=e.dragOptions;e.dragOptions=a.extendDeep(c||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===o||\"lasso\"===o?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){l(t,r,n,e.dragOptions,o)},s.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function u(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},d.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},d.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(h(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},d.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},d.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},d.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},d.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},d.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},d.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n}},{\"../../components/dragelement\":589,\"../../components/fx\":610,\"../../lib\":694,\"../../registry\":825,\"../cartesian/select\":760,\"./constants\":798,\"./layers\":801,\"./layout_attributes\":802,\"mapbox-gl\":412}],805:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],806:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,f=t(\"../plots/cartesian/axis_ids\"),h=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){if(!((t=l.getGraphDiv(t)).data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),(t.calcdata||[]).forEach(function(t){t[0]&&t[0].t&&t[0].t.cb&&t[0].t.cb()}),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){function n(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}t&&!n(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||n(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var f=r.split(\"-\")[0];if(n||f===r)break;r=f}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],h=n?t._id+u:u+t._id;o||(o=h);var p=f.getFromId(r,u);if(s&&p.overlaying===s){a=h;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function M(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}function T(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}function S(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],f=t._fullData=[],h=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var M=!c.width||!c.height,T=s.autosize,S=m.autosizable;M&&(T||S)?v.plotAutoSize(t,c,s):M&&v.sanitizeMargins(s),!T&&M&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=h.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var C=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),E=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function f(t,e){c[e]=t,u[t]=1}function h(t,e){if(t&&\"string\"==typeof t&&!u[t])return f(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),h(p,r)||(r<s&&h(a[r].uid,r)||f(l.randstr(u),r))}return c}(u,h),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(h,f,c,s);var z=Object.keys(E.x),O=Object.keys(E.y);if(z.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<z.length;o++)l.pushUnique(C.xaxis,z[o]);for(o=0;o<O.length;o++)l.pushUnique(C.yaxis,O[o]);for(var I in L)l.pushUnique(C.cartesian,I)}if(s._has=v._hasPlotType.bind(s),u.length===f.length)for(o=0;o<f.length;o++)d(f[o],u[o]);v.supplyLayoutModuleDefaults(c,s,f,t._transitionData);var D=s._visibleModules,P=[];for(o=0;o<D.length;o++){var R=D[o].crossTraceDefaults;R&&l.pushUnique(P,R)}for(o=0;o<P.length;o++)P[o](f,s);a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(f,s),s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&z.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(f,s,u,i),v.cleanPlot(f,s,u,i),d(s,i),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<f.length;o++)N[F=f[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==f.length||v.supplyDefaultsUpdateCalc(p,f)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var f=r[i].uid;for(a=0;a<t.length;a++){if(f===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+f).remove()}n._zoomlayer&&n._zoomlayer.selectAll(\".select-outline\").remove()},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},h=c.cartesian.concat(c.gl2d||[]);for(i=0;i<h.length;i++){var p,d=h[i],g=o[d],v=f.getFromId(u,d,\"x\"),m=f.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=f.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=f.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:f.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(f.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,f=n._visibleModules,h=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(f,r),l.pushUnique(h,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=M(o,e,r,n),A=0;A<k.length;A++){var T=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===T.visible&&delete T.visible,v.supplyTraceDefaults(T,S,p,n,i),d(S,T),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=T,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var C=y[o.carpet];o._carpet=C,C&&C.visible?(o.xaxis=C.xaxis,o.yaxis=C.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,h,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,h.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,h.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function f(r,n){return l.coerce(t,e,v.attributes,r,n)}var h=f(\"visible\");f(\"type\"),f(\"name\",n._traceWord+\" \"+i),f(\"uirevision\",n.uirevision);var p,d,g,m=v.getModule(e);if(e._module=m,m){var y=m.basePlotModule,x=y.attr,b=y.attributes;if(x&&b){var _=n._subplots,w=\"\";if(\"gl2d\"!==y.name||h){if(Array.isArray(x))for(o=0;o<x.length;o++){var k=x[o],M=l.coerce(t,e,b,k);_[k]&&l.pushUnique(_[k],M),w+=M}else w=l.coerce(t,e,b,x);_[y.name]&&l.pushUnique(_[y.name],w)}}}return h&&(f(\"customdata\"),f(\"ids\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,f(\"showlegend\"),f(\"legendgroup\")):e._dfltShowLegend=!1,p=\"hoverlabel\",d=\"\",g=function(){a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)},m&&p in m.attributes&&void 0===m.attributes[p]||(g&&\"function\"==typeof g?g():f(p,d)),m&&(m.supplyDefaults(t,e,u,n),e.hovertemplate||l.coerceHoverinfo(t,e,n)),a.traceIs(e,\"noOpacity\")||f(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),m&&m.selectPoints&&f(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,f=o[c],h=f.type,p=m[h],d=!(f._module&&f._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+h+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(f,e,r,t)).type=h,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},f),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var f=1-2*s;n=Math.round(f*n),a=Math.round(f*a)}}var h=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<h&&(n=h),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,f=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var h in u.length||u.push(f),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),f.finalizeSubplots(t,e)),e._subplots)e._subplots[h].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._replotPending,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,f=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:f,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=JSON.stringify(r),o=e.margin,s=o.l,l=o.r,c=o.t,u=o.b,f=e._pushmargin,h=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var p in f)h[p]||delete f[p];for(var d in f.base={l:{val:0,size:s},r:{val:1,size:l},t:{val:1,size:c},b:{val:0,size:u}},f){var g=f[d].l||{},v=f[d].b||{},m=g.val,y=g.size,x=v.val,b=v.size;for(var _ in f){if(i(y)&&f[_].r){var w=f[_].r.val,k=f[_].r.size;if(w>m){var M=(y*w+(k-e.width)*m)/(w-m),T=(k*(1-m)+(y-e.width)*(1-w))/(w-m);M>=0&&T>=0&&M+T>s+l&&(s=M,l=T)}}if(i(b)&&f[_].t){var S=f[_].t.val,C=f[_].t.size;if(S>x){var E=(b*S+(C-e.height)*x)/(S-x),L=(C*(1-x)+(b-e.height)*(1-S))/(S-x);E>=0&&L>=0&&E+L>u+c&&(u=E,c=L)}}}}}if(r.l=Math.round(s),r.r=Math.round(l),r.t=Math.round(c),r.b=Math.round(u),r.p=Math.round(o.pad),r.w=Math.round(e.width)-r.l-r.r,r.h=Math.round(e.height)-r.t-r.b,!e._replotting&&\"{}\"!==n&&n!==JSON.stringify(e._size))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,f=l.extendDeepNoArrays({},e||{}),h=l.expandObjectPaths(f),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(h,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},h),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s=[],c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],f=t._fullData[u]._module;f&&(f.animatable&&s.push(u),t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o]))}var h=l.expandObjectPaths(l.extendDeepNoArrays({},r)),p=/^[xy]axis[0-9]*$/;for(var d in h)p.test(d)&&delete h[d].range;v.extendLayout(t.layout,h),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var g=l.expandObjectPaths(r);if(g){var m=t._fullLayout._plots;for(var y in m){var x,b,_,w,k=m[y],M=k.xaxis,A=k.yaxis,T=M.range.slice(),S=A.range.slice();Array.isArray(g[M._name+\".range\"])?x=g[M._name+\".range\"].slice():Array.isArray((g[M._name]||{}).range)&&(x=g[M._name].range.slice()),Array.isArray(g[A._name+\".range\"])?b=g[A._name+\".range\"].slice():Array.isArray((g[A._name]||{}).range)&&(b=g[A._name].range.slice()),T&&x&&(T[0]!==x[0]||T[1]!==x[1])&&(_={xr0:T,xr1:x}),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={yr0:S,yr1:b}),(_||w)&&c.push(l.extendFlat({plotinfo:k},_,w))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(u?((n=l.extendFlat({},a)).duration=0,s=null):n=a,i=0;i<o.length;i++)o[i].plot(t,s,n,e)},T(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,f=t[a],h=f.xaxis,p=f.yaxis,d=n[h._name].range.slice(),g=n[p._name].range.slice(),v=h.range.slice(),m=p.range.slice();h.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:f},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,f=[],h=0;h<c.length;h++)f.push(h);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=f,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=f,i=a,d())},T(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=f.list(t),h=t._fullData,p=t._fullLayout,d=new Array(h.length),g=(t.calcdata||[]).slice(0);for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},i=0;i<h.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<h.length;i++)(r=h[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);S(c,h);var y=!1;for(i=0;i<h.length;i++)if(!0===(r=h[i]).visible&&r.transforms){if((n=r._module)&&n.calc){var x=n.calc(t,r);x[0]&&x[0].t&&x[0].t._scene&&delete x[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var b=r.transforms[s];(n=m[b.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,b))}}function _(e,i){if(r=h[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(y&&S(c,h),i=0;i<h.length;i++)_(i,!0);for(i=0;i<h.length;i++)_(i,!1);!function(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var f=o[n],h=i._subplots[n];if(Array.isArray(h))for(e=0;e<h.length;e++){var p=h[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<f.length;r++)f[r](t,d,p)}else for(r=0;r<f.length;r++)f[r](t)}}(t),a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)},v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var f=a[u][0];f[0].trace.visible=!1,o[u]=[f]}for(var h in o){var p=o[h];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":571,\"../constants/numerical\":671,\"../lib\":694,\"../plot_api/plot_schema\":731,\"../plot_api/plot_template\":732,\"../plots/cartesian/axis_ids\":745,\"../registry\":825,\"./animation_attributes\":737,\"./attributes\":739,\"./command\":767,\"./font_attributes\":769,\"./frame_attributes\":770,\"./layout_attributes\":797,d3:149,\"fast-isnumeric\":215}],807:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],808:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=f(Math.sin(e)-Math.sin(t)),c=f(Math.cos(e)-Math.cos(t)),u=Math.tan(r),h=f(1/u),p=l/c,d=s-p*o;return h?l&&c?a=u*(i=d/(u-p)):c?(i=s*h,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,f=i.length,h=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,f)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(h.push(y),s=m,u=0;u<f;s++,u++){var x=i[g(s)];if(!v(x))break;h.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return h.push(_),h.push([0,0]),h.push(h[0].slice()),h}(t,e,r,i)}function f(t){return Math.abs(t)>1e-10?t:0}function h(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),f=i(u(l,n[0],n[1],a)),h=[t*Math.cos(e),t*Math.sin(e)];return f.contains(h)&&!c.contains(h)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:f,pathPolygon:function(t,e,r,n,i,a){return\"M\"+h(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=h(u(s,r,n,i),a,o);return\"M\"+h(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":694,\"../../lib/polygon\":706}],809:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],f=n[u]._subplot;if(!e[u]&&f)for(var h in f.framework.remove(),f.layers[\"radial-axis-title\"].remove(),f.clipPaths)f.clipPaths[h].remove();s&&f._scene&&(f._scene.destroy(),f._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":694,\"../cartesian\":754,\"../get_data\":779,\"./constants\":807,\"./layout_attributes\":810,\"./layout_defaults\":811,\"./polar\":818}],810:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var f={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(f,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:f,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":570,\"../../lib\":694,\"../../plot_api/edit_types\":725,\"../cartesian/layout_attributes\":755,\"../domain\":768}],811:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),f=t(\"../cartesian/category_order_defaults\"),h=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var M=0;M<m.length;M++){b=m[M],n.isPlainObject(t[b])||(t[b]={});var A=t[b],T=a.newContainer(e,b);T._id=T._name=b,T._attr=o.id+\".\"+b,T._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],C=x(A,T,k,_,S);f(A,T,k,{axData:_,dataAttr:S});var E,L,z=k(\"visible\");switch(g(T,e,w),k(\"uirevision\",e.uirevision),z&&(L=(E=k(\"color\"))===A.color?E:o.font.color),T._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!T.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==C&&\"-\"!==C||k(\"rangemode\"),\"reversed\"===O&&(T._m=-1),k(\"range\"),T.cleanRange(\"range\",{dfltRange:[0,1]}),z&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===C){n.log(\"Polar plots do not support date angular axes yet.\");for(var I=0;I<_.length;I++)_[I].visible=!1;C=A.type=T.type=\"linear\"}k(\"linear\"===C?\"thetaunit\":\"period\");var D=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[D])}if(z)l(A,T,k,T.type),u(A,T,k,T.type,{tickSuffixDflt:\"degrees\"===T.thetaunit?\"\\xb0\":void 0}),c(A,T,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),h(A,T,k,{dfltColor:E,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==C&&k(\"hoverformat\"),T._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":571,\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../cartesian/axis_autotype\":743,\"../cartesian/category_order_defaults\":746,\"../cartesian/line_grid_defaults\":757,\"../cartesian/tick_label_defaults\":762,\"../cartesian/tick_mark_defaults\":763,\"../cartesian/tick_value_defaults\":764,\"../get_data\":779,\"../subplot_defaults\":820,\"./constants\":807,\"./layout_attributes\":810,\"./set_convert\":819}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":684,\"../../../traces/scatter/attributes\":1047}],813:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":684,\"../../../plot_api/edit_types\":725,\"../../cartesian/layout_attributes\":755}],814:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":815,\"./micropolar_manager\":816}],815:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},f=n.dispatch(\"hover\"),h={};return h.render=function(c){return function(c){e=c||e;var f=l.data,h=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(f).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(h)};var f=0;c.forEach(function(t,e){t.color||(t.color=h.defaultColorRange[f],f=(f+1)%h.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(h.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2;x=Math.max(10,x);var b,_=[h.margin.left+x,h.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),h.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(h.radialAxis.domain!=o.DATAEXTENT&&h.radialAxis.domain?h.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),M=\"string\"==typeof k[0];M&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,T=null===h.needsEndSpacing?M||!A:h.needsEndSpacing,S=h.angularAxis.domain&&h.angularAxis.domain!=o.DATAEXTENT&&!M&&h.angularAxis.domain[0]>=0?h.angularAxis.domain:n.extent(k),C=Math.abs(k[1]-k[0]);A&&!M&&(C=0);var E=S.slice();T&&M&&(E[1]+=C);var L=h.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),h.angularAxis.ticksStep&&(L=(E[1]-E[0])/L);var z=h.angularAxis.ticksStep||(E[1]-E[0])/(L*(h.minorTicks+1));w&&(z=Math.max(Math.round(z),1)),E[2]||(E[2]=z);var O=n.range.apply(this,E);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(E.slice(0,2)).range(\"clockwise\"===h.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=T?C:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var I=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),D=this.appendChild(this.ownerDocument.importNode(I.documentElement,!0));t=n.select(D)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var P,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:h.tickColor},B={\"font-size\":h.font.size,\"font-family\":h.font.family,fill:h.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+h.font.outlineColor}).join(\",\")};if(h.showLegend){P=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,h.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:P,elements:N,reverseOrder:h.legend.reverseOrder})})();var j=P.node().getBBox();x=Math.min(h.width-j.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2,x=Math.max(10,x),_=[h.margin.left+x,h.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),P.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else P=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:h.width,height:h.height}).style({opacity:h.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var V=[(h.width-(h.margin.left+h.margin.right+2*x+(j?j.width:0)))/2,(h.height-(h.margin.top+h.margin.bottom+2*x))/2];if(V[0]=Math.max(0,V[0]),V[1]=Math.max(0,V[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+V+\")\"),h.title&&h.title.text){var U=t.select(\"g.title-group text\").style(B).text(h.title.text),q=U.node().getBBox();U.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(h.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var W=t.select(\"circle.background-circle\").attr({r:x}).style({fill:h.backgroundColor,stroke:h.stroke});function Y(t,e){return s(t)%360+h.orientation}if(h.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+h.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+h.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===h.radialAxis.tickOrientation?\"rotate(\"+-h.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),$=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+Y(t)+\")\"}}).style({display:h.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),$.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(h.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(h.minorTicks+1)==0)}).style(F),$.selectAll(\".minor\").style({stroke:h.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:h.tickLength?x-h.tickLength:0,x2:x}).style({display:h.angularAxis.gridLinesVisible?\"block\":\"none\"}),$.append(\"text\").classed(\"axis-text\",!0).style(B);var J=Z.select(\"text.axis-text\").attr({x:x+h.labelOffset,dy:a+\"em\",transform:function(t,e){var r=Y(t),n=x+h.labelOffset,i=h.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:h.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(h.minorTicks+1)!=0?\"\":w?w[t]+h.angularAxis.ticksSuffix:t+h.angularAxis.ticksSuffix}).style(B);h.angularAxis.rewriteTicks&&J.text(function(t,e){return e%(h.minorTicks+1)!=0?\"\":h.angularAxis.rewriteTicks(this.textContent,e)});var K=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));P.attr({transform:\"translate(\"+[x+K,h.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=h.orientation,n.direction=h.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!M){var ft=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(W).angle;ft.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-h.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ht=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(W).radius;ht.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(W).radius);var i=o.util.convertToCartesian(n,h.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ht.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};M&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,f=this.getBoundingClientRect(),h=t.node().getBoundingClientRect(),p=[f.left+f.width/2-V[0]-h.left,f.top+f.height/2-V[1]-h.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},h.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},h.getLiveConfig=function(){return u},h.getinputConfig=function(){return c},h.radialScale=function(t){return r},h.angularScale=function(t){return s},h.svg=function(){return t},n.rebind(h,f,\"on\"),h},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var f=e.angularScale.range(),h=Math.abs(f[1]-f[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-h/2}).endAngle(function(t){return h/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,f=u?e.height:c*o.length,h=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=h.enter().append(\"svg\").attr({width:300,height:f+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,f]);if(u){var m=h.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),h.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=h.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=h.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",f=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(f);var h=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*h+l,v=p.height+2*h;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*h]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":666,\"../../../lib\":694,d3:149}],816:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,f=new s;function h(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return h.isPolar=!0,h.svg=function(){return i.svg()},h.getConfig=function(){return e},h.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},h.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},h.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,f.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},h.undo=function(){f.undo()},h.redo=function(){f.redo()},h},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":571,\"../../../lib\":694,\"./micropolar\":815,\"./undo_manager\":817,d3:149}],817:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],818:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),f=t(\"../cartesian/set_convert\"),h=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,M=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),T=t(\"./helpers\"),S=o._,C=o.mod,E=o.deg2rad,L=o.rad2deg;function z(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=z.prototype;function I(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function D(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function P(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}function B(t){return Math.abs(t)<1e-10?0:t>0?1:-1}function N(t){return B(Math.cos(t))}function j(t){return B(Math.sin(t))}e.exports=function(t,e){return new z(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var f=this.framework.selectAll(\".polarsublayer\").data(l,String);f.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),f.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),f=this.yLength=n.h*(c[1]-c[0]),h=e.sector;this.sectorInRad=h.map(E);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=C(a,360),l=s+o,c=Math.cos(E(s)),u=Math.sin(E(s)),f=Math.cos(E(l)),h=Math.sin(E(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&h<=0?0:Math.max(u,h);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&f>=0?0:Math.min(c,f);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&h>=0?0:Math.min(u,h);n=l>=360?1:c<=0&&f<=0?0:Math.max(c,f);return[e,r,n,i]}(h),x=y[2]-y[0],b=y[3]-y[1],_=f/u,w=Math.abs(b/x);_>w?(p=u,m=(f-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=f,m=(u-(p=f/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],M=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,T=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=M+A*y[3],z=this.cxx=S-k,O=this.cyy=L-M;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[T/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var I=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",I).attr(\"transform\",R(z,O)),r.frontplot.attr(\"transform\",R(k,M)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",I).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return h(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);f(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,f=r.cy,h=e.radialaxis,p=C(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",h.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=I(h);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.makeLabelFns(d,0),_=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,_),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelXFn:b.labelXFn,labelYFn:b.labelYFn,labelAnchorFn:b.labelAnchorFn})}var w=r.radialAxisAngle=r.vangles?L(D(E(h.angle),r.vangles)):h.angle,k=R(c,f),M=k+F(-w);P(i[\"radial-axis\"],g&&(h.showticklabels||h.ticks),{transform:M}),P(i[\"radial-grid\"],g&&h.showgrid,{transform:k}),P(i[\"radial-line\"].select(\"line\"),g&&h.showline,{x1:l,y1:0,x2:a,y2:0,transform:M}).attr(\"stroke-width\",h.linewidth).call(s.stroke,h.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,f=E(u),h=Math.cos(f),p=Math.sin(f),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*h+d*p,y:o-i/2*p+d*h,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,f=r.cy,h=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",h.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),f-a*Math.sin(t))},v=u.makeLabelFns(p,0),m=v.labelStandoff,y=v.labelShift,x=\"outside\"!==h.ticks?.7:.5,b=(p.linewidth||1)/2,_=I(h);r.angularTickLayout!==_&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=_);var w,k=u.calcTicks(p);if(\"linear\"===e.gridshape?(w=k.map(d),o.angleDelta(w[0],w[1])<0&&(w=w.slice().reverse())):w=null,r.vangles=w,\"category\"===p.type&&(k=k.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var A=\"inside\"===p.ticks?-1:1;u.drawTicks(n,p,{vals:k,layer:i[\"angular-axis\"],path:\"M\"+A*b+\",0h\"+A*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:k,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,f-l*n]+\"L\"+[c+a*r,f-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:k,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelXFn:function(t){var e=d(t);return(0===j(e)?0:Math.cos(e)*(m+b+x*t.fontSize))+N(e)*(t.dx+m+b)},labelYFn:function(t){var e=d(t);return t.dy+t.fontSize*M-y+-Math.sin(e)*(m+b+x*t.fontSize)},labelAnchorFn:function(t,e){var r=d(e);return 0===j(r)?N(r)>0?\"start\":\"end\":\"middle\"}})}P(i[\"angular-line\"].select(\"path\"),h.showline,{d:r.pathSubplot(),transform:R(c,f)}).attr(\"stroke-width\",h.linewidth).call(s.stroke,h.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,f=e.innerRadius,h=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,M=e.radialAxis,S=T.clampTiny,C=T.findXYatLength,E=T.findEnclosingVertexAngles,L=A.cornerHalfWidth,z=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(h,p));var I,D,P,F,B,N,j,V,U,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function W(t,e){return Math.atan2(_-e,t-m)}function Y(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=z/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+Y(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+Y(s,a)+\"L\"+Y(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+Y(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=Y(t,r),s=Y(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,f=-1/u,h=C(L,u,l,c);i=C(z,f,h[0][0],h[0][1]),a=C(z,f,h[1][0],h[1][1])}else{var p,d;c?(p=z,d=L):(p=L,d=z),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function $(t,e){return e=Math.max(Math.min(e,u),f),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(P=t,F=e):(P=e,F=t),!0):(P=null,F=null,!1)}function J(t,e){t=t||B,e=e||\"M0,0Z\",V.attr(\"d\",t),U.attr(\"d\",e),d.transitionZoombox(V,U,N,j),N=!0}function K(t,r){var n,i,a=I+t,o=D+r,s=G(I,D),l=Math.min(G(a,o),u),c=W(I,D);$(s,l)&&(n=B+e.pathSector(F),P&&(n+=e.pathSector(P)),i=X(P,c)+X(F,c)),J(n,i)}function Q(t,e,r,n){var i=T.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=I+t,o=D+r,s=W(I,D),l=W(a,o),c=E(s,k),f=E(l,k);$(Q(I,D,c[0],c[1]),Math.min(Q(a,o,f[0],f[1]),u))&&(n=B+e.pathSector(F),P&&(n+=e.pathSector(P)),i=[Z(P,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),J(n,i)}function et(){if(d.removeZoombox(r),null!==P&&null!==F){d.showDoubleClickNotifier(r);var t=M._rl,n=(t[1]-t[0])/(1-f/u)/u,i=[t[0]+(P-f)*n,t[0]+(F-f)*n];a.call(\"_guiRelayout\",r,e.id+\".radialaxis.range\",i)}}function rt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(I=n-l.left,D=a-l.top,k){var c=T.findPolygonOffset(u,w[0],w[1],k);I+=m+c[0],D+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:K,q.clickFn=rt,q.doneFn=et,function(){P=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(V=d.makeZoombox(s,j,h,p,B)).attr(\"fill-rule\",\"evenodd\"),U=d.makeCorners(s,h,p),b(s)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,f=i.cx,h=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,M=E(i.radialAxisAngle),T=p._rl,S=T[0],C=T[1],z=T[r],O=.75*(T[1]-T[0])/(1-e.hole)/c;r?(y=f+(c+m)*Math.cos(M),x=h-(c+m)*Math.sin(M),_=\"radialdrag\"):(y=f+(u-m)*Math.cos(M),x=h-(u-m)*Math.sin(M),_=\"radialdrag-inner\");var I,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),V={element:j,gd:s};P(n.select(j),p.visible&&u<c,{transform:R(y,x)}),V.prepFn=function(){I=null,B=null,N=null,V.moveFn=U,V.doneFn=q,b(t._zoomlayer)},V.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(V)}function U(t,e){if(I)I(t,e);else{var r=[t,-e],n=[Math.cos(M),Math.sin(M)],i=Math.abs(o.dot(r,n)/Math.sqrt(o.dot(r,r)));isNaN(i)||(I=i<.5?H:G)}}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(h-a,n-f),i.vangles&&(B=D(B,i.vangles)),B=L(B);var o=R(f,h)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(M),Math.sin(M)]);if(N=z-O*n,O>0==(r?N>S:N<C)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var f in i.traceHash){var h=i.traceHash[f],d=o.filterVisible(h);h[0][0].trace._module.plot(s,i,d,c),a.traceIs(f,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,f=e.cy,h=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-h-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,f)).call(_,\"move\");var M,T,S,C,E,z,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),I=O.selectAll(\".point\"),D=O.selectAll(\".textpoint\");function P(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(M+t,T+s),m=L(v-z);if(C=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,h,p])),e.vangles){E=e.radialAxisAngle+m;var y=R(u,f)+F(-m),b=R(u,f)+F(-E);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,E)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(h,p)+F(m));I.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),D.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(C,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var P=e.traceHash[A],B=o.filterVisible(P);P[0][0].trace._module.plot(r,e,B,g),B.length&&(_=!0)}_&&(w(r),k(r))}function B(){D.select(\"text\").attr(\"transform\",null);var t={};t[e.id+\".angularaxis.rotation\"]=C,e.vangles&&(t[e.id+\".radialaxis.angle\"]=E),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(r,n,i){var a=t[e.id];S=a.angularaxis.rotation;var o=m.getBoundingClientRect();M=n-o.left,T=i-o.top,z=x(M,T),y.moveFn=P,y.doneFn=B,b(t._zoomlayer)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?T.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?T.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?T.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?T.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":571,\"../../components/dragelement\":589,\"../../components/drawing\":592,\"../../components/fx\":610,\"../../components/titles\":659,\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/clear_gl_canvases\":679,\"../../lib/setcursor\":714,\"../../plot_api/subroutines\":733,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"../cartesian/autorange\":741,\"../cartesian/dragbox\":751,\"../cartesian/select\":760,\"../cartesian/set_convert\":761,\"../plots\":806,\"./constants\":807,\"./helpers\":808,\"./set_convert\":819,d3:149,tinycolor2:515}],819:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",f=\"d\"+i,h=u in e?c(e[u]):0,p=e[f]?c(e[f]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=h+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,f=u.map(a),h={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return h*t+p},g=function(t){return(t-p)/h};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(f)?[u[0],u[0]+360]:f.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":694,\"../cartesian/set_convert\":761}],820:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,f=o.handleDefaults,h=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[h]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,f(s,l,v,o)}}},{\"../lib\":694,\"../plot_api/plot_template\":732,\"./domain\":768}],821:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":694,\"../../plots/get_data\":779,\"./layout_attributes\":822,\"./layout_defaults\":823,\"./ternary\":824}],822:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":570,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../cartesian/layout_attributes\":755,\"../domain\":768}],823:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),f=t(\"./layout_attributes\"),h=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var f=0;f<h.length;f++)s=t[o=h[f]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var h=o(\"color\"),p=h!==i.color.dflt?h:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:h,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":571,\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../cartesian/line_grid_defaults\":757,\"../cartesian/tick_label_defaults\":762,\"../cartesian/tick_mark_defaults\":763,\"../cartesian/tick_value_defaults\":764,\"../subplot_defaults\":820,\"./layout_attributes\":822}],824:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),f=t(\"../../lib/extend\").extendFlat,h=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),h.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,h=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,M=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,h.x0=r,h.y0=n,h.w=i,h.h=a,h.sum=b,h.xaxis={type:\"linear\",range:[_+2*M-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(h.xaxis,h.graphDiv._fullLayout),h.xaxis.setScale(),h.xaxis.isPtWithinRange=function(t){return t.a>=h.aaxis.range[0]&&t.a<=h.aaxis.range[1]&&t.b>=h.baxis.range[1]&&t.b<=h.baxis.range[0]&&t.c>=h.caxis.range[1]&&t.c<=h.caxis.range[0]},h.yaxis={type:\"linear\",range:[_,b-w-M],domain:[g-s/2,g+s/2],_id:\"y\"},u(h.yaxis,h.graphDiv._fullLayout),h.yaxis.setScale(),h.yaxis.isPtWithinRange=function(){return!0};var A=h.yaxis.domain[0],T=h.aaxis=f({},t.aaxis,{range:[_,b-w-M],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(T,h.graphDiv._fullLayout),T.setScale();var S=h.baxis=f({},t.baxis,{range:[b-_-M,w],side:\"bottom\",domain:h.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,h.graphDiv._fullLayout),S.setScale();var C=h.caxis=f({},t.caxis,{range:[b-_-w,M],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(C,h.graphDiv._fullLayout),C.setScale();var E=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";h.clipDef.select(\"path\").attr(\"d\",E),h.layers.plotbg.select(\"path\").attr(\"d\",E);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";h.clipDefRelative.select(\"path\").attr(\"d\",L);var z=\"translate(\"+r+\",\"+n+\")\";h.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",z),h.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";h.layers.baxis.attr(\"transform\",O),h.layers.bgrid.attr(\"transform\",O);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-T._offset+\")\";h.layers.aaxis.attr(\"transform\",I),h.layers.agrid.attr(\"transform\",I);var D=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-C._offset+\")\";h.layers.caxis.attr(\"transform\",D),h.layers.cgrid.attr(\"transform\",D),h.drawAxes(!0),h.layers.aline.select(\"path\").attr(\"d\",T.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,T.linecolor||\"#000\").style(\"stroke-width\",(T.linewidth||0)+\"px\"),h.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),h.layers.cline.select(\"path\").attr(\"d\",C.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,C.linecolor||\"#000\").style(\"stroke-width\",(C.linewidth||0)+\"px\"),h.graphDiv._context.staticPlot||h.initInteractions(),c.setClipUrl(h.layers.frontplot,h._hasClipOnAxisFalse?null:h.clipId,h.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),f=p.clipEnds(t,u),h=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?f:u,layer:s,path:b,transFn:h,crisp:!1}),p.drawGrid(r,t,{vals:f,layer:this.layers[i+\"grid\"],path:_,transFn:h,crisp:!1});var w=p.makeLabelFns(t,0,30);p.drawLabels(r,t,{vals:u,layer:s,transFn:h,labelXFn:w.labelXFn,labelYFn:w.labelYFn,labelAnchorFn:w.labelAnchorFn})};var M=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+M+\"v3h-\"+(M+5.2)+\"l\"+(M/2+2.6)+\",-\"+(.87*M+4.5)+\"l2.6,1.5l-\"+M/2+\",\"+.87*M+\"Z\",T=\"m0.87,.5h-\"+M+\"v3h\"+(M+5.2)+\"l-\"+(M/2+2.6)+\",-\"+(.87*M+4.5)+\"l-2.6,1.5l\"+M/2+\",\"+.87*M+\"Z\",S=\"m0,1l\"+M/2+\",\"+.87*M+\"l2.6,-1.5l-\"+(M/2+2.6)+\",-\"+(.87*M+4.5)+\"l-\"+(M/2+2.6)+\",\"+(.87*M+4.5)+\"l2.6,1.5l\"+M/2+\",-\"+.87*M+\"Z\",C=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",E=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,f,h,p,v,_,w=this,M=w.layers.plotbg.select(\"path\").node(),z=w.graphDiv,O=z._fullLayout._zoomlayer,I={element:M,gd:z,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){I.xaxes=[w.xaxis],I.yaxes=[w.yaxis];var c=z._fullLayout.dragmode;I.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(I.moveFn=N,I.clickFn=P,I.doneFn=j,function(a,o,s){var c=M.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,f=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),h=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:f>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",h),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(O)}(0,o,s)):\"pan\"===c?(I.moveFn=V,I.clickFn=P,I.doneFn=U,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(O)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,I,c)}};function D(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function P(t,e){var r=z._fullLayout.clickmode;L(z),2===t&&(z.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",z,D({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,z,[w.xaxis],[w.yaxis],w.id,I),r.indexOf(\"event\")>-1&&g.click(z,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,M=(1-l)*w.h,E=M-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",h),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",h+\"M\"+g+\",\"+M+\"H\"+m+\"L\"+y+\",\"+E+\"L\"+g+\",\"+M+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+C+\"M\"+g+\",\"+M+A+\"M\"+m+\",\"+M+T+\"M\"+y+\",\"+E+S)),p||(v.transition().style(\"fill\",f>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0)}function j(){L(z),u!==r&&(a.call(\"_guiRelayout\",z,D(u)),E&&z.data&&z._context.showTips&&(o.notifier(s(z,\"Double-click to zoom back out\"),\"long\"),E=!1))}function V(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var f=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",f);var h=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",h),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w)}function U(){a.call(\"_guiRelayout\",z,D(u))}M.onmousemove=function(t){g.hover(z,t,w.id),z._fullLayout._lasthover=M,z._fullLayout._hoversubplot=w.id},M.onmouseout=function(t){z._dragging||d.unhover(z,t)},d.init(I)}},{\"../../components/color\":571,\"../../components/dragelement\":589,\"../../components/drawing\":592,\"../../components/fx\":610,\"../../components/titles\":659,\"../../lib\":694,\"../../lib/extend\":684,\"../../registry\":825,\"../cartesian/axes\":742,\"../cartesian/constants\":748,\"../cartesian/select\":760,\"../cartesian/set_convert\":761,\"../plots\":806,d3:149,tinycolor2:515}],825:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/extend\"),l=t(\"./plots/attributes\"),c=t(\"./plots/layout_attributes\"),u=s.extendFlat,f=s.extendDeepAll;function h(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)x(i,t.name)}(t.basePlotModule);for(var o={},s=0;s<i.length;s++)o[i[s]]=!0,r.allCategories[i[s]]=!0;for(var l in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)m(l,e);t.layoutAttributes&&u(r.traceLayoutAttributes,t.layoutAttributes)}}function p(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),v(t)),r.modules)m(e,n);for(var i in r.subplotsRegistry)x(e,i);for(var o in r.transformsRegistry)y(e,o);t.schema&&t.schema.layout&&f(c,t.schema.layout)}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)y(s,t.name)}function g(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function m(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function b(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":h(n);break;case\"transform\":d(n);break;case\"component\":p(n);break;case\"locale\":g(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[b(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=b(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[l.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/extend\":684,\"./lib/is_plain_object\":695,\"./lib/loggers\":698,\"./lib/noop\":703,\"./lib/push_unique\":708,\"./plots/attributes\":739,\"./plots/layout_attributes\":797}],826:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.extendDeep;function o(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var n,s=t.data,l=t.layout,c=a([],s),u=a({},l,o(e.tileClass)),f=t._context||{};if(e.width&&(u.width=e.width),e.height&&(u.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){u.annotations=[];var h=Object.keys(u);for(r=0;r<h.length;r++)n=h[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(n.slice(0,5))>-1&&(u[h[r]].title={text:\"\"});for(r=0;r<c.length;r++){var p=c[r];p.showscale=!1,p.marker&&(p.marker.showscale=!1),\"pie\"===p.type&&(p.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)u.annotations.push(e.annotations[r]);var d=Object.keys(u).filter(function(t){return t.match(/^scene\\d*$/)});if(d.length){var g={};for(\"thumbnail\"===e.tileClass&&(g={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<d.length;r++){var v=u[d[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),i(v.xaxis,g),i(v.yaxis,g),i(v.zaxis,g),v._scene=null}}var m=document.createElement(\"div\");e.tileClass&&(m.className=e.tileClass);var y={gd:m,td:m,layout:u,data:c,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(y.config.setBackground=e.setBackground||\"opaque\"),y.gd.defaultLayout=o(e.tileClass),y}},{\"../lib\":694}],827:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/to_image\"),i=t(\"../lib\"),a=t(\"./filesaver\");e.exports=function(t,e){var r;return i.isPlainObject(t)||(r=i.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",new Promise(function(o,s){r&&r._snapshotInProgress&&s(new Error(\"Snapshotting already in progress.\")),i.isIE()&&\"svg\"!==e.format&&s(new Error(\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\")),r&&(r._snapshotInProgress=!0);var l=n(t,e),c=e.filename||t.fn||\"newplot\";c+=\".\"+e.format,l.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,c)}).then(function(t){o(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),s(t)})})}},{\"../lib\":694,\"../plot_api/to_image\":735,\"./filesaver\":828}],828:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=document.createElement(\"a\"),n=\"download\"in r,i=/Version\\/[\\d\\.]+.*Safari/.test(navigator.userAgent);return new Promise(function(a,o){if(\"undefined\"!=typeof navigator&&/MSIE [1-9]\\./.test(navigator.userAgent)&&o(new Error(\"IE < 10 unsupported\")),i&&(document.location.href=\"data:application/octet-stream\"+t.slice(t.search(/[,;]/)),a(e)),e||(e=\"download\"),n&&(r.href=t,r.download=e,document.body.appendChild(r),r.click(),document.body.removeChild(r),a(e)),\"undefined\"!=typeof navigator&&navigator.msSaveBlob){var s=t.split(/^data:image\\/svg\\+xml,/)[1],l=decodeURIComponent(s);navigator.msSaveBlob(new Blob([l]),e),a(e)}o(new Error(\"download error\"))})}},{}],829:[function(t,e,r){\"use strict\";r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){var e=t._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return function(){(t.calcdata||[]).forEach(function(t){t[0]&&t[0].t&&t[0].t.cb&&t[0].t.cb()})}}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":826,\"./download\":827,\"./helpers\":829,\"./svgtoimg\":831,\"./toimage\":832,\"./tosvg\":833}],831:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter;e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,a){var o=window.Image,s=t.svg,l=t.format||\"png\";if(n.isIE()&&\"svg\"!==l){var c=new Error(\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\");return a(c),t.promise?r:e.emit(\"error\",c)}var u=t.canvas,f=t.scale||1,h=t.width||300,p=t.height||150,d=f*h,g=f*p,v=u.getContext(\"2d\"),m=new o,y=\"data:image/svg+xml,\"+encodeURIComponent(s);u.width=d,u.height=g,m.onload=function(){var r;switch(\"svg\"!==l&&v.drawImage(m,0,0,d,g),l){case\"jpeg\":r=u.toDataURL(\"image/jpeg\");break;case\"png\":r=u.toDataURL(\"image/png\");break;case\"webp\":r=u.toDataURL(\"image/webp\");break;case\"svg\":r=y;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(a(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},m.onerror=function(r){if(a(r),!t.promise)return e.emit(\"error\",r)},m.src=y});return t.promise?r:e}},{\"../lib\":694,events:93}],832:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),f=u.gd;f.style.position=\"absolute\",f.style.left=\"-5000px\",document.body.appendChild(f);var h=o.getRedrawFunc(f);return i.call(\"plot\",f,u.data,u.layout,u.config).then(h).then(function(){var t=o.getDelay(f._fullLayout);setTimeout(function(){var t=l(f),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:f._fullLayout.width,height:f._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){f&&document.body.removeChild(f)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":694,\"../registry\":825,\"./cloneplot\":826,\"./helpers\":829,\"./svgtoimg\":831,\"./tosvg\":833,events:93}],833:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,f=t._fullLayout,h=f._paper,p=f._toppaper,d=f.width,g=f.height;h.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,f.paper_bgcolor);var v=f._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&h.node().appendChild(b)}}f._draggers&&f._draggers.remove(),h.node().style.background=\"\",h.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),h.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||h.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),h.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),h.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(h.attr(\"width\",r*d),h.attr(\"height\",r*g),h.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(h.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":571,\"../components/drawing\":592,\"../constants/xmlns_namespaces\":672,\"../lib\":694,d3:149}],834:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").mergeArray;e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n(e.text,t,\"tx\"),n(e.hovertext,t,\"htx\");var i=e.marker;if(i){n(i.opacity,t,\"mo\"),n(i.color,t,\"mc\");var a=i.line;a&&(n(a.color,t,\"mlc\"),n(a.width,t,\"mlw\"))}}},{\"../../lib\":694}],835:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/colorbar/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"./constants.js\"),c=t(\"../../lib/extend\").extendFlat,u=s({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),f=c({},n.marker.line.width,{dflt:0}),h=c({width:f,editType:\"calc\"},a(\"marker.line\")),p=c({line:h,editType:\"calc\"},a(\"marker\"),{colorbar:o,opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:l.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:p,selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plots/font_attributes\":769,\"../scatter/attributes\":1047,\"./constants.js\":837}],836:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var f=Math.min(l.length,r.length),h=new Array(f),p=0;p<f;p++)h[p]={p:l[p],s:r[p]},e.ids&&(h[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(h,e),s(h,e),h}},{\"../../components/colorscale/calc\":579,\"../../components/colorscale/helpers\":582,\"../../plots/cartesian/axes\":742,\"../scatter/calc_selection\":1049,\"./arrays_to_calcdata\":834}],837:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],838:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"./sieve.js\");function c(t,e,r,o){if(o.length){var c,x,b,_,w=t._fullLayout.barmode,k=\"overlay\"===w,M=\"group\"===w;if(function(t,e,r,a){var o,s;for(o=0;o<a.length;o++){var l,c=a[o],u=c[0].trace,f=u.base,h=\"h\"===u.orientation?u.xcalendar:u.ycalendar,p=\"category\"===r.type||\"multicategory\"===r.type?function(){return null}:r.d2c;if(i(f)){for(s=0;s<Math.min(f.length,c.length);s++)l=p(f[s],0,h),n(l)?(c[s].b=+l,c[s].hasB=1):c[s].b=0;for(;s<c.length;s++)c[s].b=0}else{l=p(f,0,h);var d=n(l);for(l=d?l:0,s=0;s<c.length;s++)c[s].b=l,d&&(c[s].hasB=1)}}}(0,0,r,o),k)u(t,e,r,o);else if(M){for(c=[],x=[],b=0;b<o.length;b++)void 0===(_=o[b])[0].trace.offset?x.push(_):c.push(_);x.length&&function(t,e,r,n){var i=t._fullLayout.barnorm,a=new l(n,!1,!i);(function(t,e,r){for(var n=t._fullLayout,i=n.bargap,a=n.bargroupgap||0,o=r.positions,s=r.distinctPositions,l=r.minDiff,c=r.traces,u=o.length!==s.length,f=c.length,g=l*(1-i),v=u?g/f:g,m=v*(1-a),y=0;y<f;y++){var x=c[y],b=x[0].t,_=u?((2*y+1-f)*v-m)/2:-m/2;b.barwidth=m,b.poffset=_,b.bargroupwidth=g,b.bardelta=l}r.binWidth=c[0][0].t.barwidth/100,h(r),p(t,e,r),d(t,e,r,u)})(t,e,a),i?(v(t,r,a),m(t,r,a)):g(t,r,a)}(t,e,r,x),c.length&&u(t,e,r,c)}else{for(c=[],x=[],b=0;b<o.length;b++)void 0===(_=o[b])[0].trace.base?x.push(_):c.push(_);x.length&&function(t,e,r,n){var i=t._fullLayout,o=i.barmode,c=\"stack\"===o,u=\"relative\"===o,h=i.barnorm,p=new l(n,u,!(h||c||u));f(t,e,p),function(t,e,r){for(var n=t._fullLayout.barnorm,i=y(e),o=r.traces,l=0;l<o.length;l++){for(var c=o[l],u=c[0].trace,f=[],h=0;h<c.length;h++){var p=c[h];if(p.s!==a){var d=r.put(p.p,p.b+p.s),g=d+p.b+p.s;p.b=d,p[i]=g,n||(f.push(g),p.hasB&&f.push(d))}}n||(u._extremes[e._id]=s.findExtremes(e,f,{tozero:!0,padded:!0}))}}(t,r,p);for(var d=0;d<n.length;d++)for(var g=n[d],v=0;v<g.length;v++){var x=g[v];if(x.s!==a){var b=x.b+x.s===p.get(x.p,x.s);b&&(x._outmost=!0)}}h&&m(t,r,p)}(t,e,r,x),c.length&&u(t,e,r,c)}!function(t,e){var r,i,a,o=y(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var f=1e4/(c-l),h=s.round=function(t){return String(Math.round(f*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,x=h(g.p);s[x]?s[x]=[Math.min(v,s[x][0]),Math.max(m,s[x][1])]:s[x]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function u(t,e,r,n){for(var i=t._fullLayout.barnorm,a=!i,o=0;o<n.length;o++){var s=n[o],c=new l([s],!1,a);f(t,e,c),i?(v(t,r,c),m(t,r,c)):g(t,r,c)}}function f(t,e,r){for(var n=t._fullLayout,i=n.bargap,a=n.bargroupgap||0,o=r.minDiff,s=r.traces,l=o*(1-i),c=l*(1-a),u=-c/2,f=0;f<s.length;f++){var g=s[f][0].t;g.barwidth=c,g.poffset=u,g.bargroupwidth=l,g.bardelta=o}r.binWidth=s[0][0].t.barwidth/100,h(r),p(t,e,r),d(t,e,r)}function h(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,f=c._offset||c.offset,h=u.poffset;if(i(f)){for(o=Array.prototype.slice.call(f,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=h);for(r=o.length;r<s.length;r++)o.push(h);u.poffset=o}else void 0!==f&&(u.poffset=f);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===f){for(o=[],r=0;r<s.length;r++)o.push(h+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===f&&(u.poffset=h+(d-p)/2))}}function p(t,e,r){for(var n=r.traces,i=y(e),a=0;a<n.length;a++)for(var o=n[a],s=o[0].t,l=s.poffset,c=Array.isArray(l),u=s.barwidth,f=Array.isArray(u),h=0;h<o.length;h++){var p=o[h],d=p.w=f?u[h]:u;p[i]=p.p+(c?l[h]:l)+d/2}}function d(t,e,r,n){var i=r.traces,a=r.minDiff/2;s.minDtick(e,r.minDiff,r.distinctPositions[0],n);for(var o=0;o<i.length;o++){var l,c,u,f,h=i[o],p=h[0],d=p.trace,g=[];for(f=0;f<h.length;f++)c=(l=h[f]).p-a,u=l.p+a,g.push(c,u);if(d.width||d.offset){var v=p.t,m=v.poffset,y=v.barwidth,x=Array.isArray(m),b=Array.isArray(y);for(f=0;f<h.length;f++){l=h[f];var _=x?m[f]:m,w=b?y[f]:y;u=(c=l.p+_)+w,g.push(c,u)}}d._extremes[e._id]=s.findExtremes(e,g,{padded:!1})}}function g(t,e,r){for(var n=r.traces,i=y(e),a=0;a<n.length;a++){for(var o=n[a],l=o[0].trace,c=[],u=!0,f=0;f<o.length;f++){var h=o[f],p=h.b,d=p+h.s;h[i]=d,c.push(d),h.hasB&&c.push(p),h.hasB&&h.b>0&&h.s>0||(u=!1)}l._extremes[e._id]=s.findExtremes(e,c,{tozero:!u,padded:!0})}}function v(t,e,r){for(var n=r.traces,i=0;i<n.length;i++)for(var o=n[i],s=0;s<o.length;s++){var l=o[s];l.s!==a&&r.put(l.p,l.b+l.s)}}function m(t,e,r){var i=t._fullLayout,o=r.traces,l=y(e),c=\"fraction\"===i.barnorm?1:100,u=c/1e9,f=e.l2c(e.c2l(0)),h=\"stack\"===i.barmode?c:f;function p(t){return n(e.c2l(t))&&(t<f-u||t>h+u||!n(f))}for(var d=0;d<o.length;d++){for(var g=o[d],v=g[0].trace,m=[],x=!0,b=!1,_=0;_<g.length;_++){var w=g[_];if(w.s!==a){var k=Math.abs(c/r.get(w.p,w.s));w.b*=k,w.s*=k;var M=w.b,A=M+w.s;w[l]=A,m.push(A),b=b||p(A),w.hasB&&(m.push(M),b=b||p(M)),w.hasB&&w.b>0&&w.s>0||(x=!1)}}v._extremes[e._id]=s.findExtremes(e,m,{tozero:!x,padded:b})}}function y(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullData,a=t.calcdata,s=[],l=[],u=0;u<i.length;u++){var f=i[u];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?s.push(a[u]):l.push(a[u]))}c(t,r,n,l),c(t,n,r,s)},setGroupPositions:c}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"./sieve.js\":847,\"fast-isnumeric\":215}],839:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../bar/style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}var f=n.coerceFont;if(o(t,e,c,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\"),p=Array.isArray(h)||\"auto\"===h,d=p||\"outside\"===h;if(p||\"inside\"===h||d){var g=f(u,\"textfont\",c.font),v=n.extendFlat({},g);!(t.textfont&&t.textfont.color)&&delete v.color,f(u,\"insidetextfont\",v),d&&f(u,\"outsidetextfont\",g),u(\"constraintext\"),u(\"selected.textfont.color\"),u(\"unselected.textfont.color\"),u(\"cliponaxis\")}s(t,e,u,r,c);var m=(e.marker.line||{}).color,y=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");y(t,e,m||i.defaultLine,{axis:\"y\"}),y(t,e,m||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1}},{\"../../components/color\":571,\"../../lib\":694,\"../../registry\":825,\"../bar/style_defaults\":849,\"../scatter/xy_defaults\":1073,\"./attributes\":835}],840:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\");r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if(\"number\"==typeof e&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r}},{\"fast-isnumeric\":215,tinycolor2:515}],841:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../scatter/fill_hover_text\");function s(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=e.mlw||t.marker.line.width;return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,a){var l,c,u,f,h,p,d,g=t.cd,v=g[0].trace,m=g[0].t,y=\"closest\"===a,x=t.maxHoverDistance,b=t.maxSpikeDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var k=y?_:function(t){return Math.min(_(t),t.p-m.bardelta/2)},M=y?w:function(t){return Math.max(w(t),t.p+m.bardelta/2)};function A(t,e){return n.inbox(t-l,e-l,x+Math.min(1,Math.abs(e-t)/d)-1)}function T(t){return A(k(t),M(t))}function S(t){return n.inbox(t.b-c,t[f]-c,x+(t[f]-c)/(t[f]-t.b)-1)}\"h\"===v.orientation?(l=r,c=e,u=\"y\",f=\"x\",h=S,p=T):(l=e,c=r,u=\"x\",f=\"y\",p=S,h=T);var C=t[u+\"a\"],E=t[f+\"a\"];d=Math.abs(C.r2c(C.range[1])-C.r2c(C.range[0]));var L=n.getDistanceFunction(a,h,p,function(t){return(h(t)+p(t))/2});if(n.getClosest(g,L,t),!1!==t.index){y||(k=function(t){return Math.min(_(t),t.p-m.bargroupwidth/2)},M=function(t){return Math.max(w(t),t.p+m.bargroupwidth/2)});var z=g[t.index],O=v.base?z.b+z.s:z.s;t[f+\"0\"]=t[f+\"1\"]=E.c2p(z[f],!0),t[f+\"LabelVal\"]=O;var I=m.extents[m.extents.round(z.p)];return t[u+\"0\"]=C.c2p(y?k(z):I[0],!0),t[u+\"1\"]=C.c2p(y?M(z):I[1],!0),t[u+\"LabelVal\"]=z.p,t.spikeDistance=(S(z)+function(t){return A(_(t),w(t))}(z))/2+b-x,t[u+\"Spike\"]=C.c2p(z.p,!0),t.color=s(v,z),o(z,v,t),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(z,v,t),t.hovertemplate=v.hovertemplate,[t]}},getTraceColor:s}},{\"../../components/color\":571,\"../../components/fx\":610,\"../../registry\":825,\"../scatter/fill_hover_text\":1055}],842:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.layoutAttributes=t(\"./layout_attributes\"),n.supplyDefaults=t(\"./defaults\"),n.supplyLayoutDefaults=t(\"./layout_defaults\"),n.calc=t(\"./calc\"),n.crossTraceCalc=t(\"./cross_trace_calc\").crossTraceCalc,n.colorbar=t(\"../scatter/marker_colorbar\"),n.arraysToCalcdata=t(\"./arrays_to_calcdata\"),n.plot=t(\"./plot\"),n.style=t(\"./style\").style,n.styleOnSelect=t(\"./style\").styleOnSelect,n.hoverPoints=t(\"./hover\").hoverPoints,n.selectPoints=t(\"./select\"),n.moduleType=\"trace\",n.name=\"bar\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"../scatter/marker_colorbar\":1065,\"./arrays_to_calcdata\":834,\"./attributes\":835,\"./calc\":836,\"./cross_trace_calc\":838,\"./defaults\":839,\"./hover\":841,\"./layout_attributes\":843,\"./layout_defaults\":844,\"./plot\":845,\"./select\":846,\"./style\":848}],843:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],844:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,f={},h=0;h<r.length;h++){var p=r[h];if(n.traceIs(p,\"bar\")&&p.visible){if(l=!0,\"overlay\"!==t.barmode&&\"stack\"!==t.barmode){var d=p.xaxis+p.yaxis;f[d]&&(u=!0),f[d]=!0}if(p.visible&&\"histogram\"===p.type)\"category\"!==i.getFromId({_fullLayout:e},p[\"v\"===p.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l&&(\"overlay\"!==s(\"barmode\")&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\"))}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"./layout_attributes\":843}],845:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"./attributes\"),f=u.text,h=u.textposition,p=t(\"./helpers\"),d=t(\"./style\"),g=3;function v(t,e,r,n,i,a){var o;return i<1?o=\"scale(\"+i+\") \":(i=1,o=\"\"),\"translate(\"+(r-i*t)+\" \"+(n-i*e)+\")\"+o+(a?\"rotate(\"+a+\" \"+t+\" \"+e+\") \":\"\")}e.exports=function(t,e,r,u){var m=e.xaxis,y=e.yaxis,x=t._fullLayout,b=a.makeTraceGroups(u,r,\"trace bars\").each(function(r){var c=n.select(this),u=r[0],b=u.trace;e.isRangePlot||(u.node3=c);var _=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);_.enter().append(\"g\").classed(\"point\",!0),_.exit().remove(),_.each(function(c,u){var _,w,k,M,A=n.select(this);if(\"h\"===b.orientation?(k=y.c2p(c.p0,!0),M=y.c2p(c.p1,!0),_=m.c2p(c.s0,!0),w=m.c2p(c.s1,!0),c.ct=[w,(k+M)/2]):(_=m.c2p(c.p0,!0),w=m.c2p(c.p1,!0),k=y.c2p(c.s0,!0),M=y.c2p(c.s1,!0),c.ct=[(_+w)/2,M]),i(_)&&i(w)&&i(k)&&i(M)&&_!==w&&k!==M){var T=(c.mlw+1||b.marker.line.width+1||(c.trace?c.trace.marker.line.width:0)+1)-1,S=n.round(T/2%1,2);if(!t._context.staticPlot){var C=s.opacity(c.mc||b.marker.color)<1||T>.01?E:function(t,e){return Math.abs(t-e)>=2?E(t):t>e?Math.ceil(t):Math.floor(t)};_=C(_,w),w=C(w,_),k=C(k,M),M=C(M,k)}a.ensureSingle(A,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",\"M\"+_+\",\"+k+\"V\"+M+\"H\"+w+\"V\"+k+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,u){var m;function y(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+m,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var x=r[0].trace,b=x.orientation,_=function(t,e){var r=p.getValue(t.text,e);return p.coerceString(f,r)}(x,n);if(m=function(t,e){var r=p.getValue(t.textposition,e);return p.coerceEnumerated(h,r)}(x,n),!_||\"none\"===m)return void e.select(\"text\").remove();var w,k,M,A,T,S,C=t._fullLayout.font,E=d.getBarColor(r[n],x),L=d.getInsideTextFont(x,n,C,E),z=d.getOutsideTextFont(x,n,C),O=t._fullLayout.barmode,I=\"relative\"===O,D=\"stack\"===O||I,P=r[n],R=!D||P._outmost,F=Math.abs(s-i)-2*g,B=Math.abs(u-c)-2*g;\"outside\"===m&&(R||P.hasB||(m=\"inside\"));if(\"auto\"===m)if(R){m=\"inside\",w=y(e,_,L),k=l.bBox(w.node()),M=k.width,A=k.height;var N=M>0&&A>0,j=M<=F&&A<=B,V=M<=B&&A<=F,U=\"h\"===b?F>=M*(B/A):B>=A*(F/M);N&&(j||V||U)?m=\"inside\":(m=\"outside\",w.remove(),w=null)}else m=\"inside\";if(!w&&(w=y(e,_,\"outside\"===m?z:L),k=l.bBox(w.node()),M=k.width,A=k.height,M<=0||A<=0))return void w.remove();\"outside\"===m?(S=\"both\"===x.constraintext||\"outside\"===x.constraintext,T=function(t,e,r,n,i,a,o){var s,l=\"h\"===a?Math.abs(n-r):Math.abs(e-t);l>2*g&&(s=g);var c=1;o&&(c=\"h\"===a?Math.min(1,l/i.height):Math.min(1,l/i.width));var u,f,h,p,d=(i.left+i.right)/2,m=(i.top+i.bottom)/2;u=c*i.width,f=c*i.height,\"h\"===a?e<t?(h=e-s-u/2,p=(r+n)/2):(h=e+s+u/2,p=(r+n)/2):n>r?(h=(t+e)/2,p=n+s+f/2):(h=(t+e)/2,p=n-s-f/2);return v(d,m,h,p,c,!1)}(i,s,c,u,k,b,S)):(S=\"both\"===x.constraintext||\"inside\"===x.constraintext,T=function(t,e,r,n,i,a,o){var s,l,c,u,f,h,p,d=i.width,m=i.height,y=(i.left+i.right)/2,x=(i.top+i.bottom)/2,b=Math.abs(e-t),_=Math.abs(n-r);b>2*g&&_>2*g?(b-=2*(f=g),_-=2*f):f=0;d<=b&&m<=_?(h=!1,p=1):d<=_&&m<=b?(h=!0,p=1):d<m==b<_?(h=!1,p=o?Math.min(b/d,_/m):1):(h=!0,p=o?Math.min(_/d,b/m):1);h&&(h=90);h?(s=p*m,l=p*d):(s=p*d,l=p*m);\"h\"===a?e<t?(c=e+f+s/2,u=(r+n)/2):(c=e-f-s/2,u=(r+n)/2):n>r?(c=(t+e)/2,u=n-f-l/2):(c=(t+e)/2,u=n+f+l/2);return v(y,x,c,u,p,h)}(i,s,c,u,k,b,S));w.attr(\"transform\",T)}(t,A,r,u,_,w,k,M),e.layerClipId&&l.hideOutsideRangePoint(c,A.select(\"text\"),m,y,b.xcalendar,b.ycalendar)}else A.remove();function E(t){return 0===x.bargap&&0===x.bargroupgap?n.round(Math.round(t)-S,2):t}});var w=!1===u.trace.cliponaxis;l.setClipUrl(c,w?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,b,e)}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../registry\":825,\"./attributes\":835,\"./helpers\":840,\"./style\":848,d3:149,\"fast-isnumeric\":215}],846:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[];if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var s=n[r];e.contains(s.ct,!1,r,t)?(o.push({pointNumber:r,x:i.c2d(s.x),y:a.c2d(s.y)}),s.selected=1):s.selected=0}return o}},{}],847:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;function a(t,e,r){this.traces=t,this.separateNegativeValues=e,this.dontMergeOverlappingData=r;for(var a=1/0,o=[],s=0;s<t.length;s++){for(var l=t[s],c=0;c<l.length;c++){var u=l[c];u.p!==i&&o.push(u.p)}l[0]&&l[0].width1&&(a=Math.min(l[0].width1,a))}this.positions=o;var f=n.distinctVals(o);this.distinctPositions=f.vals,1===f.vals.length&&a!==1/0?this.minDiff=a:this.minDiff=Math.min(f.minDiff,a),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.separateNegativeValues?\"v\":\"^\")+(this.dontMergeOverlappingData?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":671,\"../../lib\":694}],848:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,f=l.outsidetextfont,h=t(\"./helpers\");function p(t,e,r){var i=t.selectAll(\"path\"),o=t.selectAll(\"text\");a.pointStyle(i,e,r),o.each(function(t){var i=n.select(this),o=d(i,t,e,r);a.font(i,o)})}function d(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=x(e,r);a=v(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=m(r,e.i,i));return a}function g(t,e,r){return y(c,t.textfont,e,r)}function v(t,e,r,n){var a=g(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),y(u,t.insidetextfont,e,a)}function m(t,e,r){var n=g(t,e,r);return y(f,t.outsidetextfont,e,n)}function y(t,e,r,n){e=e||{};var i=h.getValue(e.family,r),a=h.getValue(e.size,r),o=h.getValue(e.color,r);return{family:h.coerceString(t.family,i,n.family),size:h.coerceNumber(t.size,a,n.size),color:h.coerceColor(t.color,o,n.color)}}function x(t,e){return t.mc||e.marker.color}e.exports={style:function(t,e){var r=e?e[0].node3:n.select(t).selectAll(\"g.trace.bars\"),i=r.size(),a=t._fullLayout;r.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===a.barmode&&i>1||0===a.bargap&&0===a.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),r.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(r)},styleOnSelect:function(t,e){var r=e[0].node3,i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},d(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):p(r,i,t)},getInsideTextFont:v,getOutsideTextFont:m,getBarColor:x}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../../lib\":694,\"../../registry\":825,\"./attributes\":835,\"./helpers\":840,d3:149}],849:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":571,\"../../components/colorscale/defaults\":581,\"../../components/colorscale/helpers\":582}],850:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../bar/attributes\":835,\"../scatterpolar/attributes\":1109}],851:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),f=c.makeCalcdata(e,\"theta\"),h=e._length,p=new Array(h),d=u,g=f,v=0;v<h;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var f=c({},e.radialaxis,{_id:\"x\"}),h=e.angularaxis;o({_fullLayout:e},h,f,i)}}},{\"../../components/colorscale/calc\":579,\"../../components/colorscale/helpers\":582,\"../../lib\":694,\"../../registry\":825,\"../bar/arrays_to_calcdata\":834,\"../bar/cross_trace_calc\":838,\"../scatter/calc_selection\":1049}],852:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":694,\"../bar/style_defaults\":849,\"../scatterpolar/defaults\":1111,\"./attributes\":850}],853:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=t(\"../scatter/fill_hover_text\"),s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.subplot,h=f.radialAxis,p=f.angularAxis,d=f.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(h.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);h.range[0]>h.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,f,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":610,\"../../lib\":694,\"../../plots/polar/helpers\":808,\"../bar/hover\":841,\"../scatter/fill_hover_text\":1055,\"../scatterpolar/hover\":1112}],854:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":809,\"../bar/select\":846,\"../bar/style\":848,\"../scatter/marker_colorbar\":1065,\"./attributes\":850,\"./calc\":851,\"./defaults\":852,\"./hover\":853,\"./layout_attributes\":855,\"./layout_defaults\":856,\"./plot\":857}],855:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":694,\"./layout_attributes\":855}],857:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,f=e.angularAxis,h=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var f=s.findEnclosingVertexAngles(c,t.vangles)[0],h=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[f,(c+u)/2,h];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var s=r[0].node3=n.select(this),p=a.ensureSingle(s,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);p.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),p.exit().remove(),p.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=h(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(s,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":592,\"../../lib\":694,\"../../plots/polar/helpers\":808,d3:149,\"fast-isnumeric\":215}],858:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=n.marker,s=o.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:a({},n.text,{}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:a({},o.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:a({},o.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:a({},o.size,{arrayOk:!1,editType:\"calc\"}),color:a({},o.color,{arrayOk:!1,editType:\"style\"}),line:{color:a({},s.color,{arrayOk:!1,dflt:i.defaultLine,editType:\"style\"}),width:a({},s.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":570,\"../../lib/extend\":684,\"../scatter/attributes\":1047}],859:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,f,h,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,f=\"x\",h=v,p=\"y\"):(u=v,f=\"y\",h=g,p=\"x\");var x,b=u.makeCalcdata(e,f),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,h,b,d[y]),w=i.distinctVals(_),k=w.vals,M=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,M),T=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(T);for(r=0;r<e._length;r++){var C=b[r];if(n(C)){var E=i.findBin(_[r],A);if(E>=0&&E<T){var L={v:C,i:r};s(L,e,r),S[E].push(L)}}}var z=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<T;r++)if(S[r].length>0){var O=S[r].sort(l),I=O.map(c),D=I.length;(x={}).pos=k[r],x.pts=O,x.min=I[0],x.max=I[D-1],x.mean=i.mean(I,D),x.sd=i.stdev(I,D,x.mean),x.q1=i.interp(I,.25),x.med=i.interp(I,.5),x.q3=i.interp(I,.75),x.lf=Math.min(x.q1,I[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,I,!0)+1,D-1)]),x.uf=Math.max(x.q3,I[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,I),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var P=1.57*(x.q3-x.q1)/Math.sqrt(D);x.ln=x.med-P,x.un=x.med+P,x.pts2=O.filter(z),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:M,posLetter:p,valLetter:f,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"fast-isnumeric\":215}],860:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=[\"v\",\"h\"];function o(t,e,r,a){var o,s,l,c=e.calcdata,u=e._fullLayout,f=a._id,h=f.charAt(0),p=\"violin\"===t?\"_numViolins\":\"_numBoxes\",d=[],g=0;for(o=0;o<r.length;o++)for(l=c[r[o]],s=0;s<l.length;s++)d.push(l[s].pos),g+=(l[s].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(a,v.minDiff,v.vals[0],!0);var y=u[p],x=\"group\"===u[t+\"mode\"]&&y>1,b=1-u[t+\"gap\"],_=1-u[t+\"groupgap\"];for(o=0;o<r.length;o++){var w,k,M,A,T,S,C=(l=c[r[o]])[0].trace,E=l[0].t,L=C.width,z=C.side;L?(w=k=A=L/2,M=0):(k=(w=m)*b*_/(x?y:1),M=x?2*w*((E.num+.5)/y-.5)*b:0,A=w*(x?b/y:1)),E.dPos=w,E.bPos=M,E.bdPos=k,E.wHover=A;var O,I,D,P,R,F,B=M+k;\"positive\"===z?(T=w*(L?1:.5),O=B,S=O=M):\"negative\"===z?(T=O=M,S=w*(L?1:.5),I=B):(T=S=w,O=I=B);var N=!1;if((C.boxpoints||C.points)&&g>0){var j=C.pointpos,V=C.jitter,U=C.marker.size/2,q=0;j+V>=0&&((q=B*(j+V))>T?(N=!0,R=U,D=q):q>O&&(R=U,D=T)),q<=T&&(D=T);var H=0;j-V<=0&&((H=-B*(j-V))>S?(N=!0,F=U,P=H):H>I&&(F=U,P=S)),H<=S&&(P=S)}else D=T,P=S;var G=l[0].pos,W=l[l.length-1].pos;C._extremes[f]=n.findExtremes(a,[G,W],{padded:N,vpadminus:P,vpadplus:D,ppadminus:{x:F,y:R}[h],ppadplus:{x:R,y:F}[h]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,s=0;s<a.length;s++){for(var l=a[s],c=\"h\"===l?i:n,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(f)}o(\"box\",t,u,c)}},setPositionOffset:o}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"./attributes\");function s(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function l(t,e,r,i){var a=i.prefix,s=n.coerce2(t,e,o,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",s||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\")):delete e.marker,r(\"hoveron\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,o,r,i)}s(t,e,c,i),!1!==e.visible&&(c(\"line.color\",(t.marker||{}).color||r),c(\"line.width\"),c(\"fillcolor\",a.addOpacity(e.line.color,.5)),c(\"whiskerwidth\"),c(\"boxmean\"),c(\"width\"),c(\"notched\",void 0!==t.notchwidth)&&c(\"notchwidth\"),l(t,e,c,{prefix:\"box\"}))},handleSampleDefaults:s,handlePointsDefaults:l}},{\"../../components/color\":571,\"../../lib\":694,\"../../registry\":825,\"./attributes\":858}],862:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],863:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../scatter/fill_hover_text\");function l(t,e,r,s){var l,c,u,f,h,p,d,g,v,m,y,x,b=t.cd,_=t.xa,w=t.ya,k=b[0].trace,M=b[0].t,A=\"violin\"===k.type,T=[],S=M.bdPos,C=M.wHover,E=function(t){return t.pos+M.bPos-p};A&&\"both\"!==k.side?(\"positive\"===k.side&&(v=function(t){var e=E(t);return a.inbox(e,e+C,m)}),\"negative\"===k.side&&(v=function(t){var e=E(t);return a.inbox(e-C,e,m)})):v=function(t){var e=E(t);return a.inbox(e-C,e+C,m)},x=A?function(t){return a.inbox(t.span[0]-h,t.span[1]-h,m)}:function(t){return a.inbox(t.min-h,t.max-h,m)},\"h\"===k.orientation?(h=e,p=r,d=x,g=v,l=\"y\",u=w,c=\"x\",f=_):(h=r,p=e,d=v,g=x,l=\"x\",u=_,c=\"y\",f=w);var L=Math.min(1,S/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-L,y=t.maxSpikeDistance-L;var O=a.getDistanceFunction(s,d,g,z);if(a.getClosest(b,O,t),!1===t.index)return[];var I=b[t.index],D=k.line.color,P=(k.marker||{}).color;o.opacity(D)&&k.line.width?t.color=D:o.opacity(P)&&k.boxpoints?t.color=P:t.color=k.fillcolor,t[l+\"0\"]=u.c2p(I.pos+M.bPos-S,!0),t[l+\"1\"]=u.c2p(I.pos+M.bPos+S,!0),t[l+\"LabelVal\"]=I.pos;var R=l+\"Spike\";t.spikeDistance=z(I)*y/m,t[R]=u.c2p(I.pos,!0);var F={},B=[\"med\",\"min\",\"q1\",\"q3\",\"max\"];(k.boxmean||(k.meanline||{}).visible)&&B.push(\"mean\"),(k.boxpoints||k.points)&&B.push(\"lf\",\"uf\");for(var N=0;N<B.length;N++){var j=B[N];if(j in I&&!(I[j]in F)){F[I[j]]=!0;var V=I[j],U=f.c2p(V,!0),q=i.extendFlat({},t);q[c+\"0\"]=q[c+\"1\"]=U,q[c+\"LabelVal\"]=V,q[c+\"Label\"]=(M.labels?M.labels[j]+\" \":\"\")+n.hoverLabelText(f,V),q.hoverOnBox=!0,\"mean\"===j&&\"sd\"in I&&\"sd\"===k.boxmean&&(q[c+\"err\"]=I.sd),t.name=\"\",t.spikeDistance=void 0,t[R]=void 0,T.push(q)}}return T}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,f=t.ya,h=c[0].trace,p=u.c2p(e),d=f.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(f.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=f.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(h.marker||{}).color,name:h.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance}),\"h\"===h.orientation?(b=f,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,h,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":571,\"../../components/fx\":610,\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../scatter/fill_hover_text\":1055}],864:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.layoutAttributes=t(\"./layout_attributes\"),n.supplyDefaults=t(\"./defaults\").supplyDefaults,n.supplyLayoutDefaults=t(\"./layout_defaults\").supplyLayoutDefaults,n.calc=t(\"./calc\"),n.crossTraceCalc=t(\"./cross_trace_calc\").crossTraceCalc,n.plot=t(\"./plot\").plot,n.style=t(\"./style\").style,n.styleOnSelect=t(\"./style\").styleOnSelect,n.hoverPoints=t(\"./hover\").hoverPoints,n.eventData=t(\"./event_data\"),n.selectPoints=t(\"./select\"),n.moduleType=\"trace\",n.name=\"box\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"./attributes\":858,\"./calc\":859,\"./cross_trace_calc\":860,\"./defaults\":861,\"./event_data\":862,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":869}],865:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o,s=a+\"Layout\",l=0;l<r.length;l++)if(n.traceIs(r[l],s)){o=!0;break}o&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":694,\"../../registry\":825,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,f=a.wdPos||0,h=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+h,v=l.c2p(e+u-o,!0)+h,m=l.c2p(e+u+s,!0)+h,y=l.c2p(e+u-f,!0)+h,x=l.c2p(e+u+f,!0)+h,b=l.c2p(e+u-o*g,!0)+h,_=l.c2p(e+u+s*g,!0)+h,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),M=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,T=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),C=c.c2p(t.ln,!0),E=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+M+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+C+\"L\"+M+\",\"+_+\"L\"+E+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+E+\"L\"+M+\",\"+b+\"L\"+C+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+T+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+T+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+M+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+C+\"L\"+_+\",\"+M+\"L\"+m+\",\"+E:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+E+\"L\"+b+\",\"+M+\"L\"+v+\",\"+C:\"\")+\"ZM\"+a+\",\"+w+\"V\"+T+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+T+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,f=n.bPos,h=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(h?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==h&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,M=t.pos+f+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=M,_.x=w):(_.x=M,_.y=w),\"suspectedoutliers\"===h&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,f=a.bPosPxOffset||0,h=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+f,i=l.c2p(t.pos+u-o,!0)+f,a=l.c2p(t.pos+u+s,!0)+f,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===h?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===h?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var r,i,a=n.select(this),f=t[0],h=f.t,p=f.trace;e.isRangePlot||(f.node3=a),h.wdPos=h.bdPos*p.whiskerwidth,!0!==p.visible||h.empty?a.remove():(\"h\"===p.orientation?(r=s,i=o):(r=o,i=s),l(a,{pos:r,val:i},p,h),c(a,{x:o,y:s},p,h),u(a,{pos:r,val:i},p,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":592,\"../../lib\":694,d3:149}],868:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],869:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e){var r=e?e[0].node3:n.select(t).selectAll(\"g.trace.boxes\");r.style(\"opacity\",function(t){return t[0].trace.opacity}),r.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":571,\"../../components/drawing\":592,d3:149}],870:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":694,\"../box/attributes\":858,\"../ohlc/attributes\":995}],871:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../ohlc/calc\":996}],872:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":571,\"../../lib\":694,\"../ohlc/ohlc_defaults\":1e3,\"./attributes\":870}],873:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":754,\"../box/cross_trace_calc\":860,\"../box/layout_attributes\":865,\"../box/layout_defaults\":866,\"../box/plot\":867,\"../box/style\":869,\"../ohlc/hover\":998,\"../ohlc/select\":1002,\"./attributes\":870,\"./calc\":871,\"./defaults\":872}],874:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":732,\"./axis_defaults\":879}],875:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":694}],876:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":570,\"../../plots/font_attributes\":769,\"./axis_attributes\":878}],877:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,M=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),T=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(M-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),C=b(_[1]),E=S<C?1:-1,L=1e-8*(C-S),z=E>0?Math.floor:Math.ceil,O=E>0?Math.ceil:Math.floor,I=E>0?Math.min:Math.max,D=E>0?Math.max:Math.min,P=z(S+L),R=O(C-L),F=[[f=T(S)]];for(a=P;a*E<R*E;a+=E)c=[],g=D(S,a),m=(v=I(C,a+E))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),h=T(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([f[0]+p[0]/3*m,f[1]+p[1]/3*m]),c.push([h[0]-d[0]/3*m,h[1]-d[1]/3*m])),c.push(h),F.push(c),f=h;return F}},{\"../../lib\":694}],878:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":570,\"../../plot_api/edit_types\":725,\"../../plots/cartesian/layout_attributes\":755,\"../../plots/font_attributes\":769}],879:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),f=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var h=r.letter,p=r.font||{},d=n[h+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",h+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=h,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:h});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),M=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!M)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),T=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!T)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":571,\"../../lib\":694,\"../../plots/cartesian/axis_autotype\":743,\"../../plots/cartesian/category_order_defaults\":746,\"../../plots/cartesian/set_convert\":761,\"../../plots/cartesian/tick_label_defaults\":762,\"../../plots/cartesian/tick_value_defaults\":764,\"../../registry\":825,\"./attributes\":876}],880:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),f=t(\"./smooth_fill_2d_array\"),h=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&h(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,M=\"index\"===v.cheatertype?_.length:_;m=a(k,M,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),f(m,b,_),f(y,b,_),p(e),e.setScale();var A=o(m),T=o(y),S=.5*(A[1]-A[0]),C=.5*(A[1]+A[0]),E=.5*(T[1]-T[0]),L=.5*(T[1]+T[0]);return A=[C-1.3*S,C+1.3*S],T=[L-1.3*E,L+1.3*E],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,T,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../heatmap/clean_2d_array\":946,\"../heatmap/convert_column_xyz\":948,\"./array_minmax\":875,\"./calc_clippath\":881,\"./calc_gridlines\":882,\"./calc_labels\":883,\"./cheater_basis\":885,\"./set_convert\":898,\"./smooth_fill_2d_array\":899}],881:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,f=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=f;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[f][i],o[u-i]=e[f][i];for(s.push({x:a,y:o,bicubic:l}),i=f,a=[],o=[];i>=0;i--)a[f-i]=t[i][0],o[f-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,f,h,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],M=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var T=t._xctrl,S=t._yctrl,C=T[0].length,E=T.length,L=t._a.length,z=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function I(n){var i,a,o,s,l,c,u,f,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(z-2,a))),s=a-o,x.length=z,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,f=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(f[0]-d[0]/3),y.push(f[1]-d[1]/3)),m.push(f[0]),y.push(f[1]),l=f;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=z,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<z;a++)o=Math.min(z-2,a),s=a-o,f=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(f[0]-v[0]/3),y.push(f[1]-v[1]/3)),m.push(f[0]),y.push(f[1]),l=f;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=h,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function D(n){var i,a,o,s,l,c=[],u=[],f={};if(f.length=x.length,f.crossLength=M.length,\"b\"===e)for(o=Math.max(0,Math.min(z-2,n)),l=Math.min(1,Math.max(0,n-o)),f.xy=function(e){return t.evalxy([],e,n)},f.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<C;i++)c[i]=T[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),f.xy=function(e){return t.evalxy([],n,e)},f.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<E;i++)c[i]=T[i][n*O],u[i]=S[i][n*O];return f.axisLetter=e,f.axis=b,f.crossAxis=A,f.value=x[n],f.constvar=r,f.index=n,f.x=c,f.y=u,f.smoothing=A.smoothing,f}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,f=c[1]+1,h=u;h<f;h++)(o=b.arraytick0+b.arraydtick*h)<0||o>x.length-1||_.push(i(D(o),{color:b.gridcolor,width:b.gridwidth}));for(h=u;h<f;h++)if(s=b.arraytick0+b.arraydtick*h,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(I(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(D(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(D(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],f=c[1],h=u;h<=f;h++)p=b.tick0+b.dtick*h,_.push(i(I(p),{color:b.gridcolor,width:b.gridwidth}));for(h=u-1;h<f+1;h++)for(p=b.tick0+b.dtick*h,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(I(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":684,\"../../plots/cartesian/axes\":742}],883:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":684,\"../../plots/cartesian/axes\":742}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,f=(c*c*a-l*l*s)*n,h=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(h&&u/h),e[1]+(h&&f/h)],[e[0]-(p&&u/p),e[1]-(p&&f/p)]]}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],f=n(t)?t.length:t,h=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(f-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(h-1));var g=1/0,v=-1/0;for(a=0;a<h;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(h-1),i=0;i<f;i++)c=(p?(p[i]-p[0])*o:i/(f-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<h;a++)for(i=0;i<f;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":694}],886:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,f,h,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),f=0;f<w;f++)t[f]=i(t[f],_),e[f]=i(e[f],_);for(u=0,h=0;u<b;u++,h+=l?3:1)for(p=t[h],d=e[h],g=r[u],v=o[u],c=0,f=0;c<x;c++,f+=s?3:1)p[f]=g[c],d[f]=v[c];if(s)for(u=0,h=0;u<b;u++,h+=l?3:1){for(c=1,f=3;c<x-1;c++,f+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[h][f-1]=m[0][0],e[h][f-1]=m[0][1],t[h][f+1]=m[1][0],e[h][f+1]=m[1][1];y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=y[0],e[h][1]=y[1],y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=y[0],e[h][_-2]=y[1]}if(l)for(f=0;f<_;f++){for(h=3;h<w-3;h+=3)m=n([t[h-3][f],e[h-3][f]],[t[h][f],e[h][f]],[t[h+3][f],e[h+3][f]],l),t[h-1][f]=m[0][0],e[h-1][f]=m[0][1],t[h+1][f]=m[1][0],e[h+1][f]=m[1][1];y=a([t[0][f],e[0][f]],[t[2][f],e[2][f]],[t[3][f],e[3][f]]),t[1][f]=y[0],e[1][f]=y[1],y=a([t[w-1][f],e[w-1][f]],[t[w-3][f],e[w-3][f]],[t[w-4][f],e[w-4][f]]),t[w-2][f]=y[0],e[w-2][f]=y[1]}if(s&&l)for(h=1;h<w;h+=(h+1)%3==0?2:1){for(f=3;f<_-3;f+=3)m=n([t[h][f-3],e[h][f-3]],[t[h][f],e[h][f]],[t[h][f+3],e[h][f+3]],s),t[h][f-1]=.5*(t[h][f-1]+m[0][0]),e[h][f-1]=.5*(e[h][f-1]+m[0][1]),t[h][f+1]=.5*(t[h][f+1]+m[1][0]),e[h][f+1]=.5*(e[h][f+1]+m[1][1]);y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=.5*(t[h][1]+y[0]),e[h][1]=.5*(e[h][1]+y[1]),y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=.5*(t[h][_-2]+y[0]),e[h][_-2]=.5*(e[h][_-2]+y[1])}return[t,e]}},{\"../../lib\":694,\"./catmull_rom\":884}],887:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],888:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-h),x=3*h,b=a*a,_=b*a,w=1-a,k=w*w,M=k*w;for(f=0;f<t.length;f++)o=v*(u=t[f])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[f]=M*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,f=1-i,h=f*f,p=f*i*2,d=-3*h,g=3*(h-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),n*=3;var h=a*a,p=h*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n][r+1]-f[n][r],s=f[n+1][r+1]-f[n+1][r],l=f[n+2][r+1]-f[n+2][r],c=f[n+3][r+1]-f[n+3][r],e[u]=v*o+3*(g*a*s+d*h*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],889:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=h*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),M=3*m;for(f=0;f<t.length;f++)o=_*(u=t[f])[n][r]+w*u[n+1][r]+k*u[n+2][r]+M*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+M*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+M*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+M*u[n+3][r+3],e[f]=v*o+3*(g*i*s+d*h*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3;var h=a*a,p=h*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n+1][r]-f[n][r],s=f[n+1][r+1]-f[n][r+1],l=f[n+1][r+2]-f[n][r+2],c=f[n+1][r+3]-f[n][r+3],e[u]=v*o+3*(g*a*s+d*h*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,f=a*a,h=1-a,p=h*h,d=h*a*2,g=-3*p,v=3*(p-d),m=3*(d-f),y=3*f;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,f;e||(e=[]);var h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,M=k*k,A=M*k;for(f=0;f<t.length;f++)i=b*(u=t[f])[p][h]+3*(x*d*u[p][h+1]+y*v*u[p][h+2])+m*u[p][h+3],s=b*u[p+1][h]+3*(x*d*u[p+1][h+1]+y*v*u[p+1][h+2])+m*u[p+1][h+3],l=b*u[p+2][h]+3*(x*d*u[p+2][h+1]+y*v*u[p+2][h+2])+m*u[p+2][h+3],c=b*u[p+3][h]+3*(x*d*u[p+3][h+1]+y*v*u[p+3][h+2])+m*u[p+3][h+3],e[f]=A*i+3*(M*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+g*f[p+1][h],s=_*f[p][h+1]+g*f[p+1][h+1],l=_*f[p][h+2]+g*f[p+1][h+1],c=_*f[p][h+3]+g*f[p+1][h+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+d*f[p][h+1],s=_*f[p+1][h]+d*f[p+1][h+1],l=_*f[p+2][h]+d*f[p+2][h+1],c=_*f[p+3][h]+d*f[p+3][h+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),f=Math.max(0,Math.min(Math.floor(n),o)),h=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-f)),d=1-p,g=1-h;for(l=0;l<t.length;l++)i=g*(c=t[l])[f][u]+h*c[f][u+1],s=g*c[f+1][u]+h*c[f+1][u+1],e[l]=d*i+p*s;return e}}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":570,\"../../lib\":694,\"./ab_defaults\":874,\"./attributes\":876,\"./xy_defaults\":900}],892:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.plot=t(\"./plot\"),n.calc=t(\"./calc\"),n.animatable=!0,n.isContainer=!0,n.moduleType=\"trace\",n.name=\"carpet\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"./attributes\":876,\"./calc\":880,\"./defaults\":891,\"./plot\":897}],893:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],894:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],895:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":694}],896:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=(i[0]*a[0]+i[1]*a[1])/u/f;c=Math.max(0,h)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],897:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function f(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),f=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function h(t,e,r,a,o,c,u,f){var h=c.selectAll(\"text.\"+f).data(u);h.enter().append(\"text\").classed(f,!0);var p=0,d={};return h.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var f=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(f),Math.sin(f)])}c||(d={angle:u.angle,flip:u.flip});var h=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":h>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*h+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),h.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),f(l,u,x,v,\"a\",v._gridlines),f(l,u,x,m,\"b\",m._gridlines),f(l,u,y,v,\"a\",v._minorgridlines),f(l,u,y,m,\"b\",m._minorgridlines),f(l,u,b,v,\"a-boundary\",v._boundarylines),f(l,u,b,m,\"b-boundary\",m._boundarylines);var w=h(t,l,u,d,i,_,v._labels,\"a-label\"),k=h(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,f,h,p;u=.5*(r.a[0]+r.a[r.a.length-1]),f=r.b[0],h=r.ab2xy(u,f,!0),p=r.dxyda_rough(u,f),void 0===o.angle&&c.extendFlat(o,s(r,i,a,h,r.dxydb_rough(u,f)));g(t,e,r,n,h,p,r.aaxis,i,a,o,\"a-title\"),u=r.a[0],f=.5*(r.b[0]+r.b[r.b.length-1]),h=r.ab2xy(u,f,!0),p=r.dxydb_rough(u,f),void 0===l.angle&&c.extendFlat(l,s(r,i,a,h,r.dxyda_rough(u,f)));g(t,e,r,n,h,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,f,h=r.select(\"#\"+t._clipPathId);h.size()||(h=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(h,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(f=0;f<d.length;f++)s=d[f],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";h.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,f,h,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,f,h,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":592,\"../../constants/alignment\":666,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"./makepath\":894,\"./map_1d_array\":895,\"./orient_text\":896,d3:149}],898:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,f=t.aaxis,h=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,f.smoothing,h.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,f.smoothing,h.smoothing),t.dxydi=s([t._xctrl,t._yctrl],f.smoothing,h.smoothing),t.dxydj=l([t._xctrl,t._yctrl],f.smoothing,h.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var f,h,p,d,g=0,v=0,m=[];n<e[0]?(f=0,h=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(f=c-2,h=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):h=o-(f=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,f,p,h,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,f,p,h,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":713,\"./compute_control_points\":886,\"./constants\":887,\"./create_i_derivative_evaluator\":888,\"./create_j_derivative_evaluator\":889,\"./create_spline_evaluator\":890}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function f(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var h,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=f(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var M=0,A=0,T=s.length;do{for(M=0,o=0;o<T;o++){i=s[o],a=l[o];var S,C,E,L,z,O,I=0,D=0;0===i?(E=e[z=Math.min(c-1,2)],L=e[1],S=t[a][z],D+=(C=t[a][1])+(C-S)*(e[0]-L)/(L-E),I++):i===c-1&&(E=e[z=Math.max(0,c-3)],L=e[c-2],S=t[a][z],D+=(C=t[a][c-2])+(C-S)*(e[c-1]-L)/(L-E),I++),(0===i||i===c-1)&&a>0&&a<u-1&&(h=r[a+1]-r[a],D+=((p=r[a]-r[a-1])*t[a+1][i]+h*t[a-1][i])/(p+h),I++),0===a?(E=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],D+=(C=t[1][i])+(C-S)*(r[0]-L)/(L-E),I++):a===u-1&&(E=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],D+=(C=t[u-2][i])+(C-S)*(r[u-1]-L)/(L-E),I++),(0===a||a===u-1)&&i>0&&i<c-1&&(h=e[i+1]-e[i],D+=((p=e[i]-e[i-1])*t[a][i+1]+h*t[a][i-1])/(p+h),I++),I?D/=I:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),D=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),M+=(_=(b=D-t[a][i])/k)*_,w=I?0:.85,t[a][i]+=b*(1+w)}M=Math.sqrt(M)}while(A++<100&&M>1e-5);return n.log(\"Smoother converged to\",M,\"after\",A,\"iterations\"),t}},{\"../../lib\":694}],900:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":694}],901:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/colorbar/attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),marker:{line:{color:c.color,width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},s.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}),{colorbar:o})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../scattergeo/attributes\":1087}],902:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=0;c<r;c++){var u=l[c]={},f=e.locations[c],h=e.z[c];u.loc=\"string\"==typeof f?f:null,u.z=n(h)?h:i}return o(l,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(l,e),l}},{\"../../components/colorscale/calc\":579,\"../../constants/numerical\":671,\"../scatter/arrays_to_calcdata\":1046,\"../scatter/calc_selection\":1049,\"fast-isnumeric\":215}],903:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertemplate\"),s(\"marker.line.color\"),s(\"marker.line.width\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"./attributes\":901}],904:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.location=e.location,t.z=e.z,t}},{}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../scatter/fill_hover_text\");e.exports=function(t,e,r){var o,s,l,c,u=t.cd,f=u[0].trace,h=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.hovertemplate=o.hovertemplate,function(t,e,r,o){if(e.hovertemplate)return;var s=r.hi||e.hoverinfo,l=\"all\"===s?i.hoverinfo.flags:s.split(\"+\"),c=-1!==l.indexOf(\"name\"),u=-1!==l.indexOf(\"location\"),f=-1!==l.indexOf(\"z\"),h=-1!==l.indexOf(\"text\"),p=[];!c&&u?t.nameOverride=r.loc:(c&&(t.nameOverride=e.name),u&&p.push(r.loc));f&&p.push((d=r.z,n.tickText(o,o.c2l(d),\"hover\").text));var d;h&&a(r,e,p);t.extraText=p.join(\"<br>\")}(t,f,o,h.mockAxis),[t]}},{\"../../plots/cartesian/axes\":742,\"../scatter/fill_hover_text\":1055,\"./attributes\":901}],906:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=t(\"../heatmap/colorbar\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.style=t(\"./style\").style,n.styleOnSelect=t(\"./style\").styleOnSelect,n.hoverPoints=t(\"./hover\"),n.eventData=t(\"./event_data\"),n.selectPoints=t(\"./select\"),n.moduleType=\"trace\",n.name=\"choropleth\",n.basePlotModule=t(\"../../plots/geo\"),n.categories=[\"geo\",\"noOpacity\"],n.meta={},e.exports=n},{\"../../plots/geo\":773,\"../heatmap/colorbar\":947,\"./attributes\":901,\"./calc\":902,\"./defaults\":903,\"./event_data\":904,\"./hover\":905,\"./plot\":907,\"./select\":908,\"./style\":909}],907:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l.index=a,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports=function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=(e[0].node3=n.select(this)).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})}},{\"../../lib\":694,\"../../lib/geo_location_utils\":687,\"../../lib/polygon\":706,\"../../lib/topojson_utils\":721,\"./style\":909,d3:149}],908:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],909:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFunc(o.extractScale(r,{cLetter:\"z\"}));s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":571,\"../../components/colorscale\":583,\"../../components/drawing\":592,d3:149}],910:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/colorbar/attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"}};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i});[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../mesh3d/attributes\":990}],911:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],f=i[c],h=a[c],p=Math.sqrt(u*u+f*f+h*h);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":579}],912:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../plots/gl3d/zip3\");function l(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var c=l.prototype;c.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var u={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},h={tip:1,tail:1,cm:.75,center:.5};function p(t,e){var r=t.fullSceneLayout,i=t.dataScale,l={};function c(t,e){var n=r[e],o=i[u[e]];return a(t,function(t){return n.d2l(t)*o})}l.vectors=s(c(e.u,\"xaxis\"),c(e.v,\"yaxis\"),c(e.w,\"zaxis\"),e._len),l.positions=s(c(e.x,\"xaxis\"),c(e.y,\"yaxis\"),c(e.z,\"zaxis\"),e._len),l.colormap=o(e),l.vertexIntensityBounds=[e.cmin/e._normMax,e.cmax/e._normMax],l.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?l.coneSize=e.sizeref||.5:l.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var p=n(l),d=e.lightposition;return p.lightPosition=[d.x,d.y,d.z],p.ambient=e.lighting.ambient,p.diffuse=e.lighting.diffuse,p.specular=e.lighting.specular,p.roughness=e.lighting.roughness,p.fresnel=e.lighting.fresnel,p.opacity=e.opacity,e._pad=h[e.anchor]*p.vectorScale*p.coneScale*e._normMax,p}c.update=function(t){this.data=t;var e=p(this.scene,t);this.mesh.update(e)},c.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=p(t,e),a=i(r,n),o=new l(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../lib\":694,\"../../lib/gl_format_color\":691,\"../../plots/gl3d/zip3\":796,\"gl-cone3d\":232}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"./attributes\":910}],914:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),meta:{}}},{\"../../plots/gl3d\":785,\"./attributes\":910,\"./calc\":911,\"./convert\":912,\"./defaults\":913}],915:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/colorbar/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../plots/font_attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../constants/filter_ops\"),f=u.COMPARISON_OPS2,h=u.INTERVAL_OPS,p=i.line;e.exports=c({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:l({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(f).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:c({},p.color,{editType:\"style+colorbars\"}),width:c({},p.width,{editType:\"style+colorbars\"}),dash:s,smoothing:c({},p.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}),{colorbar:o})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../components/drawing/attributes\":591,\"../../constants/filter_ops\":667,\"../../lib/extend\":684,\"../../plots/font_attributes\":769,\"../heatmap/attributes\":944,\"../scatter/attributes\":1047}],916:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/calc\"),i=t(\"./set_contours\");e.exports=function(t,e){var r=n(t,e);return i(e),r}},{\"../heatmap/calc\":945,\"./set_contours\":934}],917:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,f=n.contours,h=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),h=Math.max(h,u[i][0]),h=Math.max(h,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),h=Math.max(h,u[0][i]),h=Math.max(h,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":f.value>h&&(s.prefixBoundary=!0);break;case\"<\":f.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,f.value),((o=Math.max.apply(null,f.value))<p||a>h)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,f.value),o=Math.max.apply(null,f.value),a<p&&o>h&&(s.prefixBoundary=!0)}}},{}],918:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorbar/draw\"),i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports=function(t,e){var r=e[0].trace,o=\"cb\"+r.uid;if(t._fullLayout._infolayer.selectAll(\".\"+o).remove(),r.showscale){var s=e[0].t.cb=n(t,o),l=r.contours,c=r.line,u=l.size||1,f=l.coloring,h=i(r,{isColorbar:!0});s.fillgradient(\"heatmap\"===f?r.colorscale:\"\").zrange(\"heatmap\"===f?[r.zmin,r.zmax]:\"\").fillcolor(\"fill\"===f?h:\"\").line({color:\"lines\"===f?h:c.color,width:!1!==l.showlines?c.width:0,dash:c.dash}).levels({start:l.start,end:a(l),size:u}).options(r.colorbar)()}}},{\"../../components/colorbar/draw\":576,\"./end_plus\":926,\"./make_color_map\":931}],919:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],920:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,f){var h,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?h=g.showlines=!0:(h=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),h)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,f)}},{\"../../components/color\":571,\"../../constants/filter_ops\":667,\"./label_defaults\":930,\"fast-isnumeric\":215}],921:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":667,\"fast-isnumeric\":215}],922:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],923:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":694}],924:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\");var f=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),f?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":694,\"../heatmap/xyz_defaults\":958,\"./attributes\":915,\"./constraint_defaults\":920,\"./contours_defaults\":922,\"./style_defaults\":936}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,f=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},h=o.start;h<c;h+=s)if(l.push(n.extendFlat({level:h,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},f)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":694,\"./constraint_mapping\":921,\"./end_plus\":926}],926:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),f=u,h=t.crossings[f],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(h,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(h>20?(h=i.CHOOSESADDLE[h][(p[0]||p[1])<0?0:1],t.crossings[f]=i.SADDLEREMAINDER[h]):delete t.crossings[f],!(p=i.NEWDELTA[h])){n.log(\"Found bad marching index:\",h,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),f=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(f===u&&p.join(\",\")===g||r&&y)break;h=t.crossings[f]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,M,A,T,S,C,E,L,z,O,I,D=a(d[0],d[d.length-1],o,l),P=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],z=d[c-1],void 0,void 0,O=L[2]-z[2],I=L[3]-z[3],P+=A=Math.sqrt(O*O+I*I),F.push(A);var N=P/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(D&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,M=Math.floor((c+b+_+2)/2),w=D||c!==d.length-2?D||-1!==b?k%2?j(M):[(j(M)[0]+j(M+1)[0])/2,(j(M)[1]+j(M+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),D&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(D)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var V=!1;for(T=0;T<t.edgepaths.length;T++)if(C=t.edgepaths[T],!V&&a(C[0],d[d.length-1],o,l)){d.pop(),V=!0;var U=!1;for(S=0;S<t.edgepaths.length;S++)if(a((E=t.edgepaths[S])[E.length-1],d[0],o,l)){U=!0,d.shift(),t.edgepaths.splice(T,1),S===T?t.paths.push(d.concat(E)):(S>T&&S--,t.edgepaths[S]=E.concat(d,C));break}U||(t.edgepaths[T]=d.concat(C))}for(T=0;T<t.edgepaths.length&&!V;T++)a((C=t.edgepaths[T])[C.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[T]=C.concat(d),V=!0);V||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":694,\"./constants\":919}],928:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":571,\"../heatmap/hover\":951}],929:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\").plot,n.style=t(\"./style\"),n.colorbar=t(\"./colorbar\"),n.hoverPoints=t(\"./hover\"),n.moduleType=\"trace\",n.name=\"contour\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"./attributes\":915,\"./calc\":916,\"./colorbar\":918,\"./defaults\":924,\"./hover\":928,\"./plot\":933,\"./style\":935}],930:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":694}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1;isFinite(s)||(s=1,l=1);var u,f,h=t.reversescale?i.flipScale(t.colorscale):t.colorscale,p=h.length,d=new Array(p),g=new Array(p);if(\"heatmap\"===e.coloring){for(t.zauto&&!1===t.autocontour&&(t.zmin=r-s/2,t.zmax=t.zmin+l*s),f=0;f<p;f++)u=h[f],d[f]=u[0]*(t.zmax-t.zmin)+t.zmin,g[f]=u[1];var v=n.extent([t.zmin,t.zmax,e.start,e.start+s*(l-1)]),m=v[t.zmin<t.zmax?0:1],y=v[t.zmin<t.zmax?1:0];m!==t.zmin&&(d.splice(0,0,m),g.splice(0,0,Range[0])),y!==t.zmax&&(d.push(y),g.push(g[g.length-1]))}else for(f=0;f<p;f++)u=h[f],d[f]=(u[0]*(l+c-1)-c/2)*s+r,g[f]=u[1];return i.makeColorScaleFunc({domain:d,range:g},{noNumericCheck:!0})}},{\"../../components/colorscale\":583,\"./end_plus\":926,d3:149}],932:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,f,h=t[0].z,p=h.length,d=h[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[h[r][e],h[r][e+1]],[h[r+1][e],h[r+1][e+1]]],f=0;f<t.length;f++)(c=i((u=t[f]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":919}],933:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),f=t(\"./find_all_paths\"),h=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,f=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),h=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[h],t.smoothing),f+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(h),1),r=t.edgepaths[h][t.edgepaths[h].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",h,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;f+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}h=s,(d=-1===p.indexOf(h))&&(h=p[0],f+=\"Z\")}for(h=0;h<t.paths.length;h++)f+=a.smoothclosed(t.paths[h],t.smoothing);return f}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,f=Math.sin(c)*a,h=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(f)+Math.cos(c)*o);if(h<1||p<1)return 1/0;var d=v.EDGECOST*(1/(h-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-f,y=s+u,x=l+f,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,M=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,T=A?v.SAMELEVELDISTANCE:1;if(M<=T)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(M-T)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=h(w,e,y),M=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(x.zauto&&!1===x.autocontour&&(x._input.zmin=x.zmin=w.start-w.size/2,x._input.zmax=x.zmax=x.zmin+k.length*w.size),A=[o]),c(t,e,A,M),u(k),f(k);var T=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),C=v.c2p(_[0],!0),E=v.c2p(_[_.length-1],!0),L=[[T,E],[S,E],[S,C],[T,C]],z=k;\"constraint\"===w.type&&(z=p(k,w._operation),d(z,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,z,L,w),function(t,e,o,s,l,c){var u=i.ensureSingle(t,\"g\",\"contourlines\"),f=!1!==l.showlines,h=l.showlabels,p=f&&h,d=r.createLines(u,f||h,e),v=r.createLineClip(u,p,o,s.trace.uid),m=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(m.exit().remove(),m.enter().append(\"g\").classed(\"contourlabels\",!0),h){var y=[],x=[];i.clearLocationCache();var b=r.labelFormatter(l,s.t.cb,o._fullLayout),_=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),w=e[0].xaxis,k=e[0].yaxis,M=w._length,A=k._length,T=w.range,S=k.range,C=Math.max(c[0][0],0),E=Math.min(c[2][0],M),L=Math.max(c[0][1],0),z=Math.min(c[2][1],A),O={};T[0]<T[1]?(O.left=C,O.right=E):(O.left=E,O.right=C),S[0]<S[1]?(O.top=L,O.bottom=z):(O.top=z,O.bottom=L),O.middle=(O.top+O.bottom)/2,O.center=(O.left+O.right)/2,y.push([[O.left,O.top],[O.right,O.top],[O.right,O.bottom],[O.left,O.bottom]]);var I=Math.sqrt(M*M+A*A),D=g.LABELDISTANCE*I/Math.max(1,e.length/g.LABELINCREASE);d.each(function(t){var e=r.calcTextOpts(t.level,b,_,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,O,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/D),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,x,O);if(!o)break;r.addLabelData(o,e,x,y)}})}),_.remove(),r.drawLabels(m,x,o,v,p?y:null)}h&&!f&&d.remove()}(s,k,t,y,w,L),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var h={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([h]),f([h]);var p=m(h,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,f=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-f)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+f/2,l=e.max-(s+f)/2);for(var h=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,f),m=y(g,r,n,a);m<h&&(h=m,u=g,c=d)}if(h>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(h<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),f=i*u,h=a*c,p=i*c,d=-a*u,g=[[o-f-h,s-p-d],[o+f-h,s+p-d],[o+f+h,s+p+d],[o-f+h,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plots/cartesian/axes\":742,\"../../plots/cartesian/set_convert\":761,\"../heatmap/plot\":955,\"./close_boundaries\":917,\"./constants\":919,\"./convert_to_constraints\":923,\"./empty_pathinfo\":925,\"./find_all_paths\":927,\"./make_crossings\":932,d3:149}],934:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t){var e=t.contours;if(t.autocontour){var r=t.zmin,o=t.zmax;void 0!==r&&void 0!==o||(r=i.aggNums(Math.min,null,t._z),o=i.aggNums(Math.max,null,t._z));var s=a(r,o,t.ncontours);e.size=s.dtick,e.start=n.tickFirst(s),s.range.reverse(),e.end=n.tickFirst(s),e.start===r&&(e.start+=e.size),e.end===o&&(e.end-=e.size),e.start>e.end&&(e.start=e.end=(e.start+e.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:e.start,end:e.end,size:e.size}),t._input.autocontour=!0}else if(\"constraint\"!==e.type){var l,c=e.start,u=e.end,f=t._input.contours;if(c>u&&(e.start=f.start=u,u=e.end=f.end=c,c=e.start),!(e.size>0))l=c===u?1:a(c,u,t.ncontours).dtick,f.size=e.size=l}}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742}],935:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,f=!u&&\"lines\"===a.coloring,h=!u&&\"fill\"===a.coloring,p=f||h?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,f?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(f?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(h){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":592,\"../heatmap/style\":956,\"./make_color_map\":931,d3:149}],936:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":581,\"./label_defaults\":930}],937:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/colorbar/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=o.line;e.exports=c({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:c({},u.color,{}),width:u.width,dash:u.dash,smoothing:c({},u.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}),{colorbar:l})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../contour/attributes\":915,\"../heatmap/attributes\":944,\"../scatter/attributes\":1047}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),f=t(\"../carpet/lookup_carpetid\"),h=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=f(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,f,h,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,h=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],h=h?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,f=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,f,x,m),w=\"scaled\"===e.ytype?\"\":h,k=c(e,w,p,d,g.length,y),M={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[M]}(t,e);return h(e),g}}},{\"../../components/colorscale/calc\":579,\"../../lib\":694,\"../carpet/lookup_carpetid\":893,\"../contour/set_contours\":934,\"../heatmap/clean_2d_array\":946,\"../heatmap/convert_column_xyz\":948,\"../heatmap/find_empties\":950,\"../heatmap/interp2d\":953,\"../heatmap/make_bound_array\":954,\"./defaults\":939}],939:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":694,\"../contour/constraint_defaults\":920,\"../contour/contours_defaults\":922,\"../contour/style_defaults\":936,\"../heatmap/xyz_defaults\":958,\"./attributes\":937}],940:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=t(\"../contour/colorbar\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.style=t(\"../contour/style\"),n.moduleType=\"trace\",n.name=\"contourcarpet\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"../contour/colorbar\":918,\"../contour/style\":935,\"./attributes\":937,\"./calc\":938,\"./defaults\":939,\"./plot\":943}],941:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var f,h,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function M(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function T(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,f=\"\";for(k(t)&&!T(t)||M(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(f+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var h=a[r][n];f+=[c.c2p(h[0]),u.c2p(h[1])]+\" \"}return f}for(f=0,h=null;x.length;){var C=e.edgepaths[f][0];for(h&&(y+=S(h,C)),m=n.smoothopen(e.edgepaths[f].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(f),1),h=e.edgepaths[f][e.edgepaths[f].length-1],g=-1,d=0;d<4;d++){if(!h){a.log(\"Missing end?\",f,e);break}for(k(h)&&!T(h)?p=r[1]:A(h)?p=r[0]:M(h)?p=r[3]:T(h)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var E=e.edgepaths[v][0];Math.abs(h[0]-p[0])<_?Math.abs(h[0]-E[0])<_&&(E[1]-h[1])*(p[1]-E[1])>=0&&(p=E,g=v):Math.abs(h[1]-p[1])<w?Math.abs(h[1]-E[1])<w&&(E[0]-h[0])*(p[0]-E[0])>=0&&(p=E,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",h,p,E)}if(g>=0)break;y+=S(h,p),h=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}f=g,(b=-1===x.indexOf(f))&&(f=x[0],y+=S(h,p)+\"Z\",h=null)}for(f=0;f<e.paths.length;f++)y+=n.smoothclosed(e.paths[f].map(o),e.smoothing);return y}},{\"../../components/drawing\":592,\"../../lib\":694,\"../carpet/axis_aligned_line\":877}],942:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],943:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),f=t(\"../contour/constants\"),h=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),M=r[0],A=M.trace,T=A._carpetTrace=v(t,A),S=t.calcdata[T.index][0];if(T.visible&&\"legendonly\"!==T.visible){var C=M.a,E=M.b,L=A.contours,z=d(L,e,M),O=\"constraint\"===L.type,I=L._operation,D=O?\"=\"===I?\"lines\":\"fill\":L.coloring,P=[[C[0],E[E.length-1]],[C[C.length-1],E[E.length-1]],[C[C.length-1],E[0]],[C[0],E[0]]];l(z);var R=1e-8*(C[C.length-1]-C[0]),F=1e-8*(E[E.length-1]-E[0]);c(z,R,F);var B,N,j,V,U=z;\"constraint\"===L.type&&(U=h(z,I),m(U,I,P,A)),g(z,G);var q=[];for(V=S.clipsegments.length-1;V>=0;V--)B=S.clipsegments[V],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,f,h,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(h=0;h<e.length;h++)c=e[h],u=i([],c.x,r.c2p),f=i([],c.y,n.c2p),d.push(a(u,f,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,D),function(t,e,r,i,a,o,l,c,u,f,h){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===f?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=h+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,U,P,G,T,S,D,H),function(t,e,r,i,a,l,c){var h=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(h,p||d,e),m=u.createLineClip(h,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,M=w._length,A=k._length,T=[[[0,0],[M,0],[M,A],[0,A]]],S=[];s.clearLocationCache();var C=u.labelFormatter(a,i.t.cb,r._fullLayout),E=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:M,center:M/2,top:0,bottom:A,middle:A/2},z=Math.sqrt(M*M+A*A),O=f.LABELDISTANCE*z/Math.max(1,e.length/f.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,C,E,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],f=i.b[i.b.length-1];function h(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-f)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=h(o[0],p),v=n.total-h(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*f.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),f.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,T)}})}),E.remove(),u.drawLabels(_,S,r,m,g?T:null)}d&&!p&&v.remove()}(_,z,t,M,L,e,T),o.setClipUrl(_,T._clipPathId,t)}function G(t){var e=T.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":592,\"../../lib\":694,\"../carpet/lookup_carpetid\":893,\"../carpet/makepath\":894,\"../carpet/map_1d_array\":895,\"../contour/close_boundaries\":917,\"../contour/constants\":919,\"../contour/convert_to_constraints\":923,\"../contour/empty_pathinfo\":925,\"../contour/find_all_paths\":927,\"../contour/make_crossings\":932,\"../contour/plot\":933,\"./join_all_paths\":941,\"./map_pathinfo\":942,d3:149}],944:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/colorbar/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},transforms:void 0},i(\"\",{cLetter:\"z\",autoColorDflt:!1}),{colorbar:a})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../scatter/attributes\":1047}],945:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),f=t(\"./find_empties\"),h=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),M=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),T=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,M)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e.x?_.makeCalcdata(e,\"x\"):[],g=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0||0,d=e.dx||1,v=e.y0||0,m=e.dy||1,y=c(S,e.transpose),(k||e.connectgaps)&&(e._emptypoints=f(y),u(y,e._emptypoints))}function C(t){T=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===T)if(\"log\"===_.type||\"log\"===w.type)C(\"log axis found\");else if(!M){if(r.length){var E=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(E/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-E)>L){C(\"x scale is not linear\");break}}if(g.length&&\"fast\"===T){var z=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(z/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-z)>O){C(\"y scale is not linear\");break}}}var I=i.maxRowLength(y),D=\"scaled\"===e.xtype?\"\":r,P=h(e,D,p,d,I,_),R=\"scaled\"===e.ytype?\"\":g,F=h(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,P),e._extremes[w._id]=a.findExtremes(w,F));var B={x:P,y:F,z:y,text:e._text||e.text};if(D&&D.length===P.length-1&&(B.xCenter=D),R&&R.length===F.length-1&&(B.yCenter=R),M&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k&&\"constraint\"===e.contours.type||s(t,e,{vals:y,containerStr:\"\",cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=h(N,D,p,d,I,_),B.yfill=h(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":579,\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../../registry\":825,\"../histogram2d/calc\":976,\"./clean_2d_array\":946,\"./convert_column_xyz\":948,\"./find_empties\":950,\"./interp2d\":953,\"./make_bound_array\":954}],946:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){var r,i,a,o,s,l;function c(t){if(n(t))return+t}if(e){for(r=0,s=0;s<t.length;s++)r=Math.max(r,t[s].length);if(0===r)return!1;a=function(t){return t.length},o=function(t,e,r){return t[r][e]}}else r=t.length,a=function(t,e){return t[e].length},o=function(t,e,r){return t[e][r]};var u=new Array(r);for(s=0;s<r;s++)for(i=a(t,s),u[s]=new Array(i),l=0;l<i;l++)u[s][l]=c(o(t,s,l));return u}},{\"fast-isnumeric\":215}],947:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],948:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,f=t._length,h=e.makeCalcdata(t,a),p=r.makeCalcdata(t,o),d=t.text,g=void 0!==d&&n.isArray1D(d),v=n.distinctVals(h),m=v.vals,y=n.distinctVals(p),x=y.vals,b=[];for(l=0;l<s.length;l++)b[l]=n.init2dArray(x.length,m.length);for(g&&(u=n.init2dArray(x.length,m.length)),l=0;l<f;l++)if(h[l]!==i&&p[l]!==i){var _=n.findBin(h[l]+v.minDiff/2,m),w=n.findBin(p[l]+y.minDiff/2,x);for(c=0;c<s.length;c++){var k=t[s[c]];b[c][w][_]=k[l]}g&&(u[w][_]=d[l])}for(t[\"_\"+a]=m,t[\"_\"+o]=x,c=0;c<s.length;c++)t[\"_\"+s[c]]=b[c];g&&(t._text=u)}},{\"../../constants/numerical\":671,\"../../lib\":694}],949:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"./attributes\":944,\"./style_defaults\":957,\"./xyz_defaults\":958}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],f={},h=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(f[[r,i]]=[r,i,s]),u.push([r,i,s])):h.push([r,i]));for(;h.length;){for(l={},c=!1,o=h.length-1;o>=0;o--)(s=((f[[(r=(a=h[o])[0])-1,i=a[1]]]||g)[2]+(f[[r+1,i]]||g)[2]+(f[[r,i-1]]||g)[2]+(f[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],h.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)f[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":694}],951:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,o,s,l){var c,u,f,h,p=t.cd[0],d=p.trace,g=t.xa,v=t.ya,m=p.x,y=p.y,x=p.z,b=p.xCenter,_=p.yCenter,w=p.zmask,k=[d.zmin,d.zmax],M=d.zhoverformat,A=m,T=y;if(!1!==t.index){try{f=Math.round(t.index[1]),h=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=x[0].length||h<0||h>x.length)return}else{if(n.inbox(e-m[0],e-m[m.length-1],0)>0||n.inbox(r-y[0],r-y[y.length-1],0)>0)return;if(l){var S;for(A=[2*m[0]-m[1]],S=1;S<m.length;S++)A.push((m[S]+m[S-1])/2);for(A.push([2*m[m.length-1]-m[m.length-2]]),T=[2*y[0]-y[1]],S=1;S<y.length;S++)T.push((y[S]+y[S-1])/2);T.push([2*y[y.length-1]-y[y.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),h=Math.max(0,Math.min(T.length-2,i.findBin(r,T)))}var C=g.c2p(m[f]),E=g.c2p(m[f+1]),L=v.c2p(y[h]),z=v.c2p(y[h+1]);l?(E=C,c=m[f],z=L,u=y[h]):(c=b?b[f]:(m[f]+m[f+1])/2,u=_?_[h]:(y[h]+y[h+1])/2,d.zsmooth&&(C=E=g.c2p(c),L=z=v.c2p(u)));var O,I,D=x[h][f];w&&!w[h][f]&&(D=void 0),Array.isArray(p.text)&&Array.isArray(p.text[h])&&(O=p.text[h][f]);var P={type:\"linear\",range:k,hoverformat:M,_separators:g._separators,_numFormat:g._numFormat};return I=a.tickText(P,D,\"hover\").text,[i.extendFlat(t,{index:[h,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:C,x1:E,y0:L,y1:z,xLabelVal:c,yLabelVal:u,zLabelVal:D,zLabel:I,text:O})]}},{\"../../components/fx\":610,\"../../lib\":694,\"../../plots/cartesian/axes\":742}],952:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.colorbar=t(\"./colorbar\"),n.style=t(\"./style\"),n.hoverPoints=t(\"./hover\"),n.moduleType=\"trace\",n.name=\"heatmap\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"2dMap\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"./attributes\":944,\"./calc\":945,\"./colorbar\":947,\"./defaults\":949,\"./hover\":951,\"./plot\":955,\"./style\":956}],953:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,f,h,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,h=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(f=u[o+c[1]])&&(0===p?g=v=f:(g=Math.min(g,f),v=Math.max(v,f)),h++,p+=f);if(0===h)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/h,void 0===d?h<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":694}],954:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,f=[],h=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return h?e.slice(0,o):e.slice(0,o+1);if(h||d)f=e.slice(0,o);else if(1===o)f=[e[0]-.5,e[0]+.5];else{for(f=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)f.push(.5*(e[u-1]+e[u]));f.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=f[f.length-1],m=v-f[f.length-2];for(u=g;u<o;u++)v+=m,f.push(v)}}else{c=a||1;var y=t[s._id.charAt(0)+\"calendar\"];for(l=p||\"category\"===s.type||\"multicategory\"===s.type?s.r2c(r,0,y)||0:i(e)&&1===e.length?e[0]:void 0===r?0:s.d2c(r,0,y),u=h||d?0:-.5;u<o;u++)f.push(l+c*u)}return f}},{\"../../lib\":694,\"../../registry\":825}],955:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function f(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,h){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(h,r,\"hm\").each(function(e){var r,h,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,M=b.y,A=b.xCenter,T=b.yCenter,S=a.traceIs(_,\"contour\"),C=S?\"best\":_.zsmooth,E=w.length,L=o.maxRowLength(w),z=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===h&&y>0;)h=p.c2p(k[y]),y--;for(h<r&&(g=h,h=r,r=g,z=!0),y=0;void 0===v&&y<M.length-1;)v=d.c2p(M[y]),y++;for(y=M.length-1;void 0===m&&y>0;)m=d.c2p(M[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,T=M,k=b.xfill,M=b.yfill),\"fast\"!==C){var I=\"best\"===C?0:.5;r=Math.max(-I*p._length,r),h=Math.min((1+I)*p._length,h),v=Math.max(-I*d._length,v),m=Math.min((1+I)*d._length,m)}var D=Math.round(h-r),P=Math.round(m-v);if(D<=0||P<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===C?(R=L,F=E):(R=D,F=P);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,V=B.getContext(\"2d\"),U=s.makeColorScaleFunc(s.extractScale(_,{cLetter:\"z\"}),{noNumericCheck:!0,returnArray:!0});\"fast\"===C?(N=z?function(t){return L-1-t}:o.identity,j=O?function(t){return E-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,D)},j=function(t){return o.constrain(Math.round(d.c2p(M[t])-v),0,P)});var q,H,G,W,Y,X=j(0),Z=[X,X],$=z?0:1,J=O?0:1,K=0,Q=0,tt=0,et=0;if(C){var rt,nt=0;try{rt=new Uint8Array(D*P*4)}catch(t){rt=new Array(D*P*4)}if(\"best\"===C){var it,at,ot,st=A||k,lt=T||M,ct=new Array(st.length),ut=new Array(lt.length),ft=new Array(D),ht=A?u:c,pt=T?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<D;y++)ft[y]=ht(y,ct);for(H=0;H<P;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<D;y++,nt+=4)f(rt,nt,Y=Mt(at,ot,ft[y],it))}else for(H=0;H<E;H++)for(W=w[H],Z=j(H),y=0;y<D;y++)Y=kt(W[y],1),f(rt,nt=4*(Z*D+N(y)),Y);var dt=V.createImageData(D,P);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}V.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<E;H++)if(W=w[H],Z.reverse(),Z[J]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[$]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(Y=kt(W[y],(q[1]-q[0])*(Z[1]-Z[0])),V.fillStyle=\"rgba(\"+Y.join(\",\")+\")\",V.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/K),tt=Math.round(tt/K),et=Math.round(et/K);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+K,t._hmlumcount=(t._hmlumcount||0)+K*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:P,width:D,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=U(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),K+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Mt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":583,\"../../constants/xmlns_namespaces\":672,\"../../lib\":694,\"../../registry\":825,d3:149,tinycolor2:515}],956:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:149}],957:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],958:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,f,h=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===h||!h.length)return 0;if(i.isArray1D(t.z)){u=r(l),f=r(c);var p=i.minRowLength(u),d=i.minRowLength(f);if(0===p||0===d)return 0;e._length=Math.min(p,d,h.length)}else{if(u=o(l,r),f=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(h))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":694,\"../../registry\":825,\"fast-isnumeric\":215}],959:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/colorbar/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],c={},u=0;u<l.length;u++){var f=l[u];c[f]=n[f]}o(c,i(\"\",{cLetter:\"z\",autoColorDflt:!1}),{colorbar:a}),e.exports=s(c,\"calc\",\"nested\")},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../heatmap/attributes\":944}],960:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var f=0;f<4;f++)s[4*l+f]=u[f]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":717,\"../../plots/cartesian/axes\":742,\"gl-heatmap2d\":242}],961:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"../heatmap/defaults\"),n.colorbar=t(\"../heatmap/colorbar\"),n.calc=t(\"../heatmap/calc\"),n.plot=t(\"./convert\"),n.moduleType=\"trace\",n.name=\"heatmapgl\",n.basePlotModule=t(\"../../plots/gl2d\"),n.categories=[\"gl\",\"gl2d\",\"2dMap\"],n.meta={},e.exports=n},{\"../../plots/gl2d\":782,\"../heatmap/calc\":945,\"../heatmap/colorbar\":947,\"../heatmap/defaults\":949,\"./attributes\":959,\"./convert\":960}],962:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\");e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:n.text,orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":609,\"../bar/attributes\":835,\"./bin_attributes\":964,\"./constants\":968}],963:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],964:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],965:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":215}],966:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function f(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=h(i,a),s=0;s<10;s++){var l=h(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function h(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,h=-.1*e,p=t-h,d=r[0],g=r[1],v=Math.min(f(d+h,d+p,n,a),f(g+h,g+p,n,a)),m=Math.min(f(d+c,d+h,n,a),f(g+c,g+h,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var f=u(c,x,!1,a);(c+f)/2<e+t&&(c=f)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":671,\"../../plots/cartesian/axes\":742}],967:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../bar/arrays_to_calcdata\"),s=t(\"./bin_functions\"),l=t(\"./norm_functions\"),c=t(\"./average\"),u=t(\"./bin_label_vals\");function f(t,e,r,o,s){var l,c,u,h,p,d,g,v=o+\"bins\",m=t._fullLayout,y=\"overlay\"===m.barmode,x=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,r.calendar):null}:function(t){return n(t)?Number(t):null};function b(t,e,r){e[t+\"Found\"]?(e[t]=x(e[t]),null===e[t]&&(e[t]=r[t])):(d[t]=e[t]=r[t],i.nestedProperty(c[0],v+\".\"+t).set(r[t]))}var _=m._histogramBinOpts[e._groupName];if(e._autoBinFinished)delete e._autoBinFinished;else{c=_.traces;var w=_.sizeFound,k=[];d=c[0]._autoBin={};var M=!0;for(l=0;l<c.length;l++)(u=c[l]).visible&&(p=u._pos0=r.makeCalcdata(u,o),k=i.concat(k,p),delete u._autoBinFinished,!0===e.visible&&(M?M=!1:(delete u._autoBin,u._autoBinFinished=1)));h=c[0][o+\"calendar\"];var A=a.autoBin(k,r,_.nbins,!1,h,w&&_.size);if(y&&0===A._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(s)return[A,p,!0];A=function(t,e,r,n,a){var o,s,l=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),c=!1,u=1/0,h=[e];for(o=0;o<l.length;o++)if((s=l[o])===e)c=!0;else if(c){var p=f(t,s,r,n,!0),d=p[0],g=p[2];s._autoBinFinished=1,s._pos0=p[1],g?h.push(s):u=Math.min(u,d.size)}else u=Math.min(u,s[a].size);var v=new Array(h.length);for(o=0;o<h.length;o++)for(var m=h[o]._pos0,y=0;y<m.length;y++)if(void 0!==m[y]){v[o]=m[y];break}isFinite(u)||(u=i.distinctVals(v).minDiff);for(o=0;o<h.length;o++){var x=(s=h[o])[n+\"calendar\"];s._input[a]=s[a]={start:r.c2r(v[o]-u/2,0,x),end:r.c2r(v[o]+u/2,0,x),size:u}}return e[a]}(t,e,r,o,v)}(g=u.cumulative).enabled&&\"include\"!==g.currentbin&&(\"decreasing\"===g.direction?A.start=r.c2r(a.tickIncrement(r.r2c(A.start,0,h),A.size,!0,h)):A.end=r.c2r(a.tickIncrement(r.r2c(A.end,0,h),A.size,!1,h))),_.size=A.size,w||(d.size=A.size,i.nestedProperty(c[0],v+\".size\").set(A.size)),b(\"start\",_,A),b(\"end\",_,A)}p=e._pos0,delete e._pos0;var T=e._input[v]||{},S=i.extendFlat({},_),C=_.start,E=r.r2l(T.start),L=void 0!==E;if((_.startFound||L)&&E!==r.r2l(C)){var z=L?E:i.aggNums(Math.min,null,p),O={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:_.size,tick0:C,calendar:h,range:[z,a.tickIncrement(z,_.size,!1,h)].map(r.l2r)},I=a.tickFirst(O);I>r.r2l(z)&&(I=a.tickIncrement(I,_.size,!0,h)),S.start=r.l2r(I),L||i.nestedProperty(e,v+\".start\").set(S.start)}var D=_.end,P=r.r2l(T.end),R=void 0!==P;if((_.endFound||R)&&P!==r.r2l(D)){var F=R?P:i.aggNums(Math.max,null,p);S.end=r.l2r(F),R||i.nestedProperty(e,v+\".start\").set(S.end)}var B=\"autobin\"+o;return!1===e._input[B]&&(e._input[v]=i.extendFlat({},e[v]||{}),delete e._input[B],delete e[B]),[S,p]}e.exports=function(t,e){if(!0===e.visible){var r,h,p,d,g=[],v=[],m=a.getFromId(t,\"h\"===e.orientation?e.yaxis||\"y\":e.xaxis||\"x\"),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],M=w[1],A=\"string\"==typeof k.size,T=[],S=A?T:k,C=[],E=[],L=[],z=0,O=e.histnorm,I=e.histfunc,D=-1!==O.indexOf(\"density\");_.enabled&&D&&(O=O.replace(/ ?density$/,\"\"),D=!1);var P,R=\"max\"===I||\"min\"===I?null:0,F=s.count,B=l[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==I&&(P=e[x],N=\"avg\"===I,F=s[I]),r=j(k.start),p=j(k.end)+(r-a.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(h=a.tickIncrement(r,k.size,!1,b),g.push((r+h)/2),v.push(R),L.push([]),T.push(r),D&&C.push(1/(h-r)),N&&E.push(0),!(h<=r));)r=h;T.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var V,U=v.length,q=!0,H=1/0,G=1/0,W={};for(r=0;r<M.length;r++){var Y=M[r];(d=i.findBin(Y,S))>=0&&d<U&&(z+=F(d,r,v,P,E),q&&L[d].length&&Y!==M[L[d][0]]&&(q=!1),L[d].push(r),W[r]=d,H=Math.min(H,Y-T[d]),G=Math.min(G,T[d+1]-Y))}q||(V=u(H,G,T,m,b)),N&&(z=c(v,E)),B&&B(v,z,C),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],$=0,J=X-1;for(r=0;r<X;r++)if(v[r]){$=r;break}for(r=X-1;r>=$;r--)if(v[r]){J=r;break}for(r=$;r<=J;r++)if(n(g[r])&&n(v[r])){var K={p:g[r],s:v[r],b:0};_.enabled||(K.pts=L[r],q?K.ph0=K.ph1=L[r].length?M[L[r][0]]:g[r]:(K.ph0=V(T[r]),K.ph1=V(T[r+1],!0))),Z.push(K)}return 1===Z.length&&(Z[0].width1=a.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),o(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,W),Z}}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../bar/arrays_to_calcdata\":834,\"./average\":963,\"./bin_functions\":965,\"./bin_label_vals\":966,\"./norm_functions\":974,\"fast-isnumeric\":215}],968:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],969:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n.nestedProperty,a=t(\"./attributes\"),o={x:[{aStr:\"xbins.start\",name:\"start\"},{aStr:\"xbins.end\",name:\"end\"},{aStr:\"xbins.size\",name:\"size\"},{aStr:\"nbinsx\",name:\"nbins\"}],y:[{aStr:\"ybins.start\",name:\"start\"},{aStr:\"ybins.end\",name:\"end\"},{aStr:\"ybins.size\",name:\"size\"},{aStr:\"nbinsy\",name:\"nbins\"}]};e.exports=function(t,e){var r,s,l,c,u,f,h,p=e._histogramBinOpts={},d=\"overlay\"===e.barmode;function g(t){return n.coerce(l._input,l,a,t)}for(r=0;r<t.length;r++)\"histogram\"===(l=t[r]).type&&(delete l._autoBinFinished,u=\"v\"===l.orientation?\"x\":\"y\",f=d?l.uid:l.xaxis+l.yaxis+u,l._groupName=f,(h=p[f])?h.traces.push(l):h=p[f]={traces:[l],direction:u});for(f in p){u=(h=p[f]).direction;var v=o[u];for(s=0;s<v.length;s++){var m=v[s],y=m.name;if(\"nbins\"!==y||!h.sizeFound){var x=m.aStr;for(r=0;r<h.traces.length;r++){if(c=(l=h.traces[r])._input,void 0!==i(c,x).get()){h[y]=g(x),h[y+\"Found\"]=!0;break}var b=l._autoBin;b&&b[y]&&i(l,x).set(b[y])}if(\"start\"===y||\"end\"===y)for(;r<h.traces.length;r++)g(x,((l=h.traces[r])._autoBin||{})[y]);\"nbins\"!==y||h.sizeFound||h.nbinsFound||(l=h.traces[0],h[y]=g(x))}}}}},{\"../../lib\":694,\"./attributes\":962}],970:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),f=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\");var h=c(\"orientation\",f&&!u?\"h\":\"v\"),p=\"v\"===h?\"x\":\"y\",d=\"v\"===h?\"y\":\"x\",g=u&&f?Math.min(i.minRowLength(u)&&i.minRowLength(f)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),c(\"hovertemplate\"),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":571,\"../../lib\":694,\"../../registry\":825,\"../bar/style_defaults\":849,\"./attributes\":962}],971:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],972:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":742,\"../bar/hover\":841}],973:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.layoutAttributes=t(\"../bar/layout_attributes\"),n.supplyDefaults=t(\"./defaults\"),n.crossTraceDefaults=t(\"./cross_trace_defaults\"),n.supplyLayoutDefaults=t(\"../bar/layout_defaults\"),n.calc=t(\"./calc\"),n.crossTraceCalc=t(\"../bar/cross_trace_calc\").crossTraceCalc,n.plot=t(\"../bar/plot\"),n.layerName=\"barlayer\",n.style=t(\"../bar/style\").style,n.styleOnSelect=t(\"../bar/style\").styleOnSelect,n.colorbar=t(\"../scatter/marker_colorbar\"),n.hoverPoints=t(\"./hover\"),n.selectPoints=t(\"../bar/select\"),n.eventData=t(\"./event_data\"),n.moduleType=\"trace\",n.name=\"histogram\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"../bar/cross_trace_calc\":838,\"../bar/layout_attributes\":843,\"../bar/layout_defaults\":844,\"../bar/plot\":845,\"../bar/select\":846,\"../bar/style\":848,\"../scatter/marker_colorbar\":1065,\"./attributes\":962,\"./calc\":967,\"./cross_trace_defaults\":969,\"./defaults\":970,\"./event_data\":971,\"./hover\":972}],974:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],975:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/colorbar/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat},o(\"\",{cLetter:\"z\",autoColorDflt:!1}),{colorbar:s})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../heatmap/attributes\":944,\"../histogram/attributes\":962,\"../histogram/bin_attributes\":964}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\");function c(t,e,r,a,o,s,l){var c=e+\"bins\",u=t[c];u||(u=t[c]={});var f=t._input[c]||{},h=t._autoBin={};f.size||delete u.size,void 0===f.start&&delete u.start,void 0===f.end&&delete u.end;var p=!u.size,d=void 0===u.start,g=void 0===u.end;if(p||d||g){var v=i.autoBin(r,a,t[\"nbins\"+e],\"2d\",l,u.size);\"histogram2dcontour\"===t.type&&(d&&(v.start=s(i.tickIncrement(o(v.start),v.size,!0,l))),g&&(v.end=s(i.tickIncrement(o(v.end),v.size,!1,l)))),p&&(u.size=h.size=v.size),d&&(u.start=h.start=v.start),g&&(u.end=h.end=v.end)}var m=\"autobin\"+e;!1===t._input[m]&&(t._input[c]=n.extendFlat({},u),delete t._input[m],delete t[m])}function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function f(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function h(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s);if(e)for(o=0;o<s;o++)c[o]=[e[o],e[o]];else{var u=l(r,n,t,i,a);for(o=0;o<s;o++)c[o]=[u(t[o]),u(t[o+1],!0)]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis||\"x\"),v=e.x?g.makeCalcdata(e,\"x\"):[],m=i.getFromId(t,e.yaxis||\"y\"),y=e.y?m.makeCalcdata(e,\"y\"):[],x=e.xcalendar,b=e.ycalendar,_=function(t){return g.r2c(t,0,x)},w=function(t){return m.r2c(t,0,b)},k=function(t){return g.c2r(t,0,x)},M=function(t){return m.c2r(t,0,b)},A=e._length;v.length>A&&v.splice(A,v.length-A),y.length>A&&y.splice(A,y.length-A),c(e,\"x\",v,g,_,k,x),c(e,\"y\",y,m,w,M,b);var T=[],S=[],C=[],E=\"string\"==typeof e.xbins.size,L=\"string\"==typeof e.ybins.size,z=[],O=[],I=E?z:e.xbins,D=L?O:e.ybins,P=0,R=[],F=[],B=e.histnorm,N=e.histfunc,j=-1!==B.indexOf(\"density\"),V=\"max\"===N||\"min\"===N?null:0,U=a.count,q=o[B],H=!1,G=[],W=[],Y=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Y&&\"count\"!==N&&(H=\"avg\"===N,U=a[N]);var X=e.xbins,Z=_(X.start),$=_(X.end)+(Z-i.tickIncrement(Z,X.size,!1,x))/1e6;for(r=Z;r<$;r=i.tickIncrement(r,X.size,!1,x))S.push(V),z.push(r),H&&C.push(0);z.push(r);var J=S.length,K=_(e.xbins.start),Q=(r-K)/J,tt=k(K+Q/2);for(Z=w((X=e.ybins).start),$=w(X.end)+(Z-i.tickIncrement(Z,X.size,!1,b))/1e6,r=Z;r<$;r=i.tickIncrement(r,X.size,!1,b)){T.push(S.slice()),O.push(r);var et=new Array(J);for(l=0;l<J;l++)et[l]=[];F.push(et),H&&R.push(C.slice())}O.push(r);var rt=T.length,nt=w(e.ybins.start),it=(r-nt)/rt,at=M(nt+it/2);j&&(G=u(S.length,I,Q,E),W=u(T.length,D,it,L)),E||\"date\"!==g.type||(I=f(_,I)),L||\"date\"!==m.type||(D=f(w,D));var ot=!0,st=!0,lt=new Array(J),ct=new Array(rt),ut=1/0,ft=1/0,ht=1/0,pt=1/0;for(r=0;r<A;r++){var dt=v[r],gt=y[r];p=n.findBin(dt,I),d=n.findBin(gt,D),p>=0&&p<J&&d>=0&&d<rt&&(P+=U(p,r,T[d],Y,R[d]),F[d][p].push(r),ot&&(void 0===lt[p]?lt[p]=dt:lt[p]!==dt&&(ot=!1)),st&&(void 0===ct[p]?ct[p]=gt:ct[p]!==gt&&(st=!1)),ut=Math.min(ut,dt-z[p]),ft=Math.min(ft,z[p+1]-dt),ht=Math.min(ht,gt-O[d]),pt=Math.min(pt,O[d+1]-gt))}if(H)for(d=0;d<rt;d++)P+=s(T[d],R[d]);if(q)for(d=0;d<rt;d++)q(T[d],P,G,W[d]);return{x:v,xRanges:h(z,ot&&lt,ut,ft,g,x),x0:tt,dx:Q,y:y,yRanges:h(O,st&&ct,ht,pt,m,b),y0:at,dy:it,z:T,pts:F}}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../histogram/average\":963,\"../histogram/bin_functions\":965,\"../histogram/bin_label_vals\":966,\"../histogram/norm_functions\":974}],977:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"./attributes\"),l=[\"x\",\"y\"];function c(t,e,r,s){var l=r[a.id2name(t[e+\"axis\"])].type,c=e+\"bins\",u=t[c],f=t[e+\"calendar\"];u||(u=t[c]={});var h=\"date\"===l?function(t,e){return t||0===t?o.cleanDate(t,i,f):e}:function(t,e){return n(t)?Number(t):e};u.start=h(u.start,s.start),u.end=h(u.end,s.end);var p=s.size,d=u.size;if(n(d))u.size=d>0?Number(d):p;else if(\"string\"!=typeof d)u.size=p;else{var g=d.charAt(0),v=d.substr(1);((v=n(v)?Number(v):0)<=0||\"date\"!==l||\"M\"!==g||v!==Math.round(v))&&(u.size=p)}}e.exports=function(t,e){var r,n,i,a;function u(t){return o.coerce(i._input,i,s,t)}for(r=0;r<t.length;r++){var f=(i=t[r]).type;if(\"histogram2d\"===f||\"histogram2dcontour\"===f)for(n=0;n<l.length;n++){var h=(a=l[n])+\"bins\",p=(i._autoBin||{})[a]||{};u(h+\".start\",p.start),u(h+\".end\",p.end),u(h+\".size\",p.size),c(i,a,e,p),(i[h]||{}).size||u(\"nbins\"+a)}}}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../plots/cartesian/axis_ids\":745,\"./attributes\":975,\"fast-isnumeric\":215}],978:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}))}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"../heatmap/style_defaults\":957,\"./attributes\":975,\"./sample_defaults\":981}],979:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],f=c[1],h=t.cd[0],p=h.xRanges[f],d=h.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":742,\"../heatmap/hover\":951}],980:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.crossTraceDefaults=t(\"./cross_trace_defaults\"),n.calc=t(\"../heatmap/calc\"),n.plot=t(\"../heatmap/plot\"),n.layerName=\"heatmaplayer\",n.colorbar=t(\"../heatmap/colorbar\"),n.style=t(\"../heatmap/style\"),n.hoverPoints=t(\"./hover\"),n.eventData=t(\"../histogram/event_data\"),n.moduleType=\"trace\",n.name=\"histogram2d\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"../heatmap/calc\":945,\"../heatmap/colorbar\":947,\"../heatmap/plot\":955,\"../heatmap/style\":956,\"../histogram/event_data\":971,\"./attributes\":975,\"./cross_trace_defaults\":977,\"./defaults\":978,\"./hover\":979}],981:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":694,\"../../registry\":825}],982:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/colorbar/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}),{colorbar:o})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../contour/attributes\":915,\"../histogram2d/attributes\":975}],983:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l))}},{\"../../lib\":694,\"../contour/contours_defaults\":922,\"../contour/style_defaults\":936,\"../histogram2d/sample_defaults\":981,\"./attributes\":982}],984:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.crossTraceDefaults=t(\"../histogram2d/cross_trace_defaults\"),n.calc=t(\"../contour/calc\"),n.plot=t(\"../contour/plot\").plot,n.layerName=\"contourlayer\",n.style=t(\"../contour/style\"),n.colorbar=t(\"../contour/colorbar\"),n.hoverPoints=t(\"../contour/hover\"),n.moduleType=\"trace\",n.name=\"histogram2dcontour\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"../contour/calc\":916,\"../contour/colorbar\":918,\"../contour/hover\":928,\"../contour/plot\":933,\"../contour/style\":935,\"../histogram2d/cross_trace_defaults\":977,\"./attributes\":982,\"./defaults\":983}],985:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/colorbar/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../mesh3d/attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll;var u=e.exports=c(l({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0}},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i,flatshading:{valType:\"boolean\",dflt:!1},contour:{show:l({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width},lightposition:{x:l({},a.lightposition.x,{dflt:1e5}),y:l({},a.lightposition.y,{dflt:1e5}),z:l({},a.lightposition.z,{dflt:0})},lighting:o.lighting,hoverinfo:l({},s.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=u.value.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739,\"../mesh3d/attributes\":990,\"../surface/attributes\":1134}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":579}],987:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../plots/gl3d/zip3\"),s=t(\"../../lib\");function l(t){return s.distinctVals(t).vals}function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;function f(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}}u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=f(r,this.data._Xs).id,l=f(n,this.data._Ys).id,c=f(i,this.data._Zs).id,u=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[u],this.data._y[u],this.data._z[u],this.data.value[u]];var h=this.data.text;return Array.isArray(h)&&void 0!==h[u]?t.textLabel=h[u]:h&&(t.textLabel=h),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=function(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,c=!1,u=!1,h=0,p=l(t.x.slice(0,t._len)),d=l(t.y.slice(0,t._len)),g=l(t.z.slice(0,t._len)),v=p.length,m=d.length,y=g.length;function x(t,e,r){return r+y*e+y*m*t}var b,_,w,k,M,A=t._minValues,T=t._maxValues,S=t._vMin,C=t._vMax;function E(t,e,n){for(var i=k.length,a=r;a<i;a++)if(t===b[a]&&e===_[a]&&n===w[a])return a;return-1}function L(){r=e}function z(){b=[],_=[],w=[],k=[],e=0,L()}function O(t,r,n,i){return b.push(t),_.push(r),w.push(n),k.push(i),++e-1}function I(e,r,n){return t._i.push(e),t._j.push(r),t._k.push(n),++h-1}function D(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function P(t){M=t}function R(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function F(t,e){return null===t?e:t}function B(t,e,r){L();var n=[e],i=[r];if(M>=1)n=[e],i=[r];else if(M>0){var a=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-M),s=D(a,r,o),l=D(a,n,o),c=D(a,i,o),u=e[0],f=e[1],h=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,f,-1],[-1,-1,u],[f,h,-1],[-1,-1,f],[h,u,-1],[-1,-1,h]]}}(e,r);n=a.xyzv,i=a.abc}for(var o=0;o<n.length;o++){e=n[o],r=i[o];for(var s=[],l=0;l<3;l++){var c=e[l][0],u=e[l][1],f=e[l][2],h=e[l][3],p=r[l]>-1?r[l]:E(c,u,f);s[l]=p>-1?p:O(c,u,f,F(t,h))}I(s[0],s[1],s[2])}}function N(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function j(t,e,r){return t>=e&&t<=r}function V(t){var e=.01*(C-S);return t>=S-e&&t<=C+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}function q(t,e,r,n,i,a){r=[-1,-1,-1];var o=function(t,e,r){V(e[0][3])&&V(e[1][3])&&V(e[2][3])?B(t,e,r):a||q(t,e,r,S,C,!0)},s=[j(e[0][3],n,i),j(e[1][3],n,i),j(e[2][3],n,i)],l=!1;return s[0]||s[1]||s[2]?s[0]&&s[1]&&s[2]?(u||o(t,e,r),l):([[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var c=e[a[0]],u=e[a[1]],f=e[a[2]],h=N(f,c,n,i),p=N(f,u,n,i);o(t,[p,h,c],[-1,-1,r[a[0]]]),o(t,[c,u,p],[r[a[0]],r[a[1]],-1]),l=!0}}),l||([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var c=e[a[0]],u=e[a[1]],f=e[a[2]],h=N(u,c,n,i),p=N(f,c,n,i);o(t,[p,h,c],[-1,-1,r[a[0]]]),l=!0}}),l)):l}function H(t,e,r,n){var i=U(e),a=[j(i[0][3],r,n),j(i[1][3],r,n),j(i[2][3],r,n),j(i[3][3],r,n)],o=!1;return a[0]||a[1]||a[2]||a[3]?a[0]&&a[1]&&a[2]&&a[3]?(c&&function(t,e,r){var n=function(n,i,a){B(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,i,e),o):([[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(s){if(a[s[0]]&&a[s[1]]&&a[s[2]]&&!a[s[3]]){var l=i[s[0]],u=i[s[1]],f=i[s[2]],h=i[s[3]];if(c)B(t,[l,u,f],[e[s[0]],e[s[1]],e[s[2]]]);else{var p=N(h,l,r,n),d=N(h,u,r,n),g=N(h,f,r,n);B(null,[p,d,g],[-1,-1,-1])}o=!0}}),o||([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(s){if(a[s[0]]&&a[s[1]]&&!a[s[2]]&&!a[s[3]]){var l=i[s[0]],u=i[s[1]],f=i[s[2]],h=i[s[3]],p=N(f,l,r,n),d=N(f,u,r,n),g=N(h,u,r,n),v=N(h,l,r,n);c?(B(t,[l,v,p],[e[s[0]],-1,-1]),B(t,[u,d,g],[e[s[1]],-1,-1])):function(t,e,r){var n=function(n,i,a){B(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[p,d,g,v],[-1,-1,-1,-1]),o=!0}}),o||([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(s){if(a[s[0]]&&!a[s[1]]&&!a[s[2]]&&!a[s[3]]){var l=i[s[0]],u=i[s[1]],f=i[s[2]],h=i[s[3]],p=N(u,l,r,n),d=N(f,l,r,n),g=N(h,l,r,n);c?(B(t,[l,p,d],[e[s[0]],-1,-1]),B(t,[l,d,g],[e[s[0]],-1,-1]),B(t,[l,g,p],[e[s[0]],-1,-1])):B(null,[p,d,g],[-1,-1,-1]),o=!0}}),o))):o}function G(t,e,r,n,i,a,o,l,u,f,h){s&&(R(t,\"A\")&&H(null,[e,r,n,a],f,h),R(t,\"B\")&&H(null,[r,n,i,u],f,h),R(t,\"C\")&&H(null,[r,a,o,u],f,h),R(t,\"D\")&&H(null,[n,a,l,u],f,h),R(t,\"E\")&&H(null,[r,n,a,u],f,h)),c&&H(t,[r,n,a,u],f,h)}function W(t,e,r,n,i,a,o){q(t,U([e,r,n]),[e,r,n],a,o),q(t,U([n,i,e]),[n,i,e],a,o)}function Y(t,e,r,n,i,a,o,s){s?W(t,e,r,i,n,a,o):W(t,r,i,n,e,a,o)}function X(t,e,r,n,i,a,o){var s,l,c,u,f=function(){q(t,[s,l,c],[-1,-1,-1],i,a),q(t,[c,u,s],[-1,-1,-1],i,a)},h=o[0],p=o[1],d=o[2];h&&(s=D(U([x(e,r-0,n-0)])[0],U([x(e-1,r-0,n-0)])[0],h),l=D(U([x(e,r-0,n-1)])[0],U([x(e-1,r-0,n-1)])[0],h),c=D(U([x(e,r-1,n-1)])[0],U([x(e-1,r-1,n-1)])[0],h),u=D(U([x(e,r-1,n-0)])[0],U([x(e-1,r-1,n-0)])[0],h),f()),p&&(s=D(U([x(e-0,r,n-0)])[0],U([x(e-0,r-1,n-0)])[0],p),l=D(U([x(e-0,r,n-1)])[0],U([x(e-0,r-1,n-1)])[0],p),c=D(U([x(e-1,r,n-1)])[0],U([x(e-1,r-1,n-1)])[0],p),u=D(U([x(e-1,r,n-0)])[0],U([x(e-1,r-1,n-0)])[0],p),f()),d&&(s=D(U([x(e-0,r-0,n)])[0],U([x(e-0,r-0,n-1)])[0],d),l=D(U([x(e-0,r-1,n)])[0],U([x(e-0,r-1,n-1)])[0],d),c=D(U([x(e-1,r-1,n)])[0],U([x(e-1,r-1,n-1)])[0],d),u=D(U([x(e-1,r-0,n)])[0],U([x(e-1,r-0,n-1)])[0],d),f())}function Z(t,e,r,n,i,a,o,l,c,u,f,h){var p=t;h?(s&&\"even\"===t&&(p=null),G(p,e,r,n,i,a,o,l,c,u,f)):(s&&\"odd\"===t&&(p=null),G(p,c,l,o,a,i,n,r,e,u,f))}function $(t,e,r,n){for(var i=0;i<e.length;i++)for(var a=e[i],o=1;o<y;o++)for(var s=1;s<m;s++)Y(t,x(a,s-1,o-1),x(a,s-1,o),x(a,s,o-1),x(a,s,o),r,n,(a+s+o)%2)}function J(t,e,r,n){for(var i=0;i<e.length;i++)for(var a=e[i],o=1;o<v;o++)for(var s=1;s<y;s++)Y(t,x(o-1,a,s-1),x(o,a,s-1),x(o-1,a,s),x(o,a,s),r,n,(o+a+s)%2)}function K(t,e,r,n){for(var i=0;i<e.length;i++)for(var a=e[i],o=1;o<m;o++)for(var s=1;s<v;s++)Y(t,x(s-1,o-1,a),x(s-1,o,a),x(s,o-1,a),x(s,o,a),r,n,(s+o+a)%2)}function Q(t,e,r){for(var n=1;n<y;n++)for(var i=1;i<m;i++)for(var a=1;a<v;a++)Z(t,x(a-1,i-1,n-1),x(a-1,i-1,n),x(a-1,i,n-1),x(a-1,i,n),x(a,i-1,n-1),x(a,i-1,n),x(a,i,n-1),x(a,i,n),e,r,(a+i+n)%2)}function tt(t,e,r){s=!0,Q(t,e,r),s=!1}function et(t,e,r,n,i){for(var a=0;a<e.length;a++)for(var o=e[a],s=1;s<y;s++)for(var l=1;l<m;l++)X(t,o,l,s,r,n,i[a])}function rt(t,e,r,n,i){for(var a=0;a<e.length;a++)for(var o=e[a],s=1;s<v;s++)for(var l=1;l<y;l++)X(t,s,o,l,r,n,i[a])}function nt(t,e,r,n,i){for(var a=0;a<e.length;a++)for(var o=e[a],s=1;s<m;s++)for(var l=1;l<v;l++)X(t,l,s,o,r,n,i[a])}function it(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(z(),function(){for(var e=0;e<v;e++)for(var r=0;r<m;r++)for(var n=0;n<y;n++){var i=x(e,r,n);O(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(P(o),c=!0,Q(null,S,C),c=!1),n&&a){P(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var l=1===r?.5:s/(r-1),M=(1-l)*S+l*C,E=Math.abs(M-A),L=Math.abs(M-T),I=E>L?[A,M]:[M,T];tt(e,I[0],I[1])}}var D=[[Math.min(S,T),Math.max(S,T)],[Math.min(A,C),Math.max(A,C)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=0;r<D.length;r++){u=0!==r;var n=D[r][0],i=D[r][1],a=t.slices[e];if(a.show&&a.fill){P(a.fill);var o=[],s=[],l=[];if(a.locations.length)for(var c=0;c<a.locations.length;c++){var h=f(a.locations[c],\"x\"===e?p:\"y\"===e?d:g);0===h.distRatio?o.push(h.id):h.id>0&&(s.push(h.id),\"x\"===e?l.push([h.distRatio,0,0]):\"y\"===e?l.push([0,h.distRatio,0]):l.push([0,0,h.distRatio]))}else o=it(1,\"x\"===e?v-1:\"y\"===e?m-1:y-1);s.length>0&&(\"x\"===e?et(null,s,n,i,l):\"y\"===e?rt(null,s,n,i,l):nt(null,s,n,i,l)),o.length>0&&(\"x\"===e?$(null,o,n,i):\"y\"===e?J(null,o,n,i):K(null,o,n,i))}var x=t.caps[e];x.show&&x.fill&&(P(x.fill),\"x\"===e?$(null,[0,v-1],n,i):\"y\"===e?J(null,[0,m-1],n,i):K(null,[0,y-1],n,i))}}),0===h&&z(),t._x=b,t._y=_,t._z=w,t._intensity=k,t._Xs=p,t._Ys=d,t._Zs=g}(),t}(t);var s={positions:o(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:o(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:1,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};s.vertexIntensity=t._intensity,s.vertexIntensityBounds=[t.cmin,t.cmax],s.colormap=i(t),this.mesh.update(s)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new c(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../lib\":694,\"../../lib/gl_format_color\":691,\"../../lib/str2rgbarray\":717,\"../../plots/gl3d/zip3\":796,\"gl-mesh3d\":270}],988:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}var c=l(\"isomin\"),u=l(\"isomax\");null!=u&&null!=c&&c>u&&(e.isomin=null,e.isomax=null);var f=l(\"x\"),h=l(\"y\"),p=l(\"z\"),d=l(\"value\");f&&f.length&&h&&h.length&&p&&p.length&&d&&d.length?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;l(e+\".show\")&&l(e+\".fill\");var r=\"slices.\"+t;l(r+\".show\")&&(l(r+\".fill\"),l(r+\".locations\"))}),l(\"spaceframe.show\")&&l(\"spaceframe.fill\"),l(\"surface.show\")&&(l(\"surface.count\"),l(\"surface.fill\"),l(\"surface.pattern\")),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),[\"text\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\"].forEach(function(t){l(t)}),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"../../registry\":825,\"./attributes\":985}],989:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.colorbar={min:\"cmin\",max:\"cmax\"},n.plot=t(\"./convert\"),n.moduleType=\"trace\",n.name=\"isosurface\",n.basePlotModule=t(\"../../plots/gl3d\"),n.categories=[\"gl3d\"],n.meta={},e.exports=n},{\"../../plots/gl3d\":785,\"./attributes\":985,\"./calc\":986,\"./convert\":987,\"./defaults\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/colorbar/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i,opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../surface/attributes\":1134}],991:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":579}],992:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../plots/gl3d/zip3\");function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=u.prototype;function h(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function p(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function d(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function g(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,u=t.x.length,f=c(p(r.xaxis,t.x,e.dataScale[0],t.xcalendar),p(r.yaxis,t.y,e.dataScale[1],t.ycalendar),p(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!g(t.i,u)||!g(t.j,u)||!g(t.k,u))return;n=c(d(t.i),d(t.j),d(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var v={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};t.intensity?(this.color=\"#fff\",v.vertexIntensity=t.intensity,v.vertexIntensityBounds=[t.cmin,t.cmax],v.colormap=s(t)):t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=h(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=h(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color)),this.mesh.update(v)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../lib/gl_format_color\":691,\"../../lib/str2rgbarray\":717,\"../../plots/gl3d/zip3\":796,\"alpha-shape\":53,\"convex-hull\":119,\"delaunay-triangulate\":151,\"gl-mesh3d\":270}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"../../registry\":825,\"./attributes\":990}],994:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.colorbar={min:\"cmin\",max:\"cmax\"},n.plot=t(\"./convert\"),n.moduleType=\"trace\",n.name=\"mesh3d\",n.basePlotModule=t(\"../../plots/gl3d\"),n.categories=[\"gl3d\"],n.meta={},e.exports=n},{\"../../plots/gl3d\":785,\"./attributes\":990,\"./calc\":991,\"./convert\":992,\"./defaults\":993}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=i.line;function l(t){return{line:{color:n({},s.color,{dflt:t}),width:s.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},s.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:l(\"#3D9970\"),decreasing:l(\"#FF4136\"),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":591,\"../../components/fx/attributes\":601,\"../../lib\":694,\"../scatter/attributes\":1047}],996:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),f=s.makeCalcdata(e,\"low\"),h=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=!0,g=null,v=[],m=0;m<r.length;m++){var y=r[m],x=c[m],b=u[m],_=f[m],w=h[m];if(y!==o&&x!==o&&b!==o&&_!==o&&w!==o){w===x?null!==g&&w!==g&&(d=w>g):d=w>x,g=w;var k=l(x,b,_,w);k.pos=y,k.yc=(x+w)/2,k.i=m,k.dir=d?\"increasing\":\"decreasing\",p&&(k.tx=e.text[m]),v.push(k)}else v.push({empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(f,u),{padded:!0}),v.length&&(v[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),v}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var f=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),f.length?(n.extendFlat(f[0].t,{wHover:c/2,tickLen:o}),f):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../plots/cartesian/axes\":742}],997:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":694,\"./attributes\":995,\"./ohlc_defaults\":1e3}],998:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../scatter/fill_hover_text\"),l={increasing:\"\\u25b2\",decreasing:\"\\u25bc\"};function c(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,f=l[0].t,h=u.type,p=\"ohlc\"===h?\"l\":\"min\",d=\"ohlc\"===h?\"h\":\"max\",g=f.bPos||0,v=function(t){return t.pos+g-e},m=f.bdPos||f.tickLen,y=f.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var M=l[t.index],A=u[M.dir],T=A.line.color;return o.opacity(T)&&A.line.width?t.color=T:t.color=A.fillcolor,t.x0=c.c2p(M.pos+g-m,!0),t.x1=c.c2p(M.pos+g+m,!0),t.xLabelVal=M.pos,t.spikeDistance=w(M)*s/i,t.xSpike=c.c2p(M.pos,!0),t}function u(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,u=o[0].t,f=[],h=c(t,e,r,a);if(!h)return[];var p=o[h.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][h.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+u.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},h)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=u.labels[x]+n.hoverLabelText(s,b),y.name=\"\",f.push(y),v[b]=y)}return f}function f(t,e,r,i){var a=t.cd,o=t.ya,u=a[0].trace,f=a[0].t,h=c(t,e,r,i);if(!h)return[];var p=a[h.index],d=h.index=p.i,g=p.dir;function v(t){return f.labels[t]+n.hoverLabelText(o,u[t][d])}var m=p.hi||u.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+l[g]]:[];return _&&s(p,u,w),h.extraText=w.join(\"<br>\"),h.y0=h.y1=o.c2p(p.yc,!0),[h]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?u(t,e,r,n):f(t,e,r,n)},hoverSplit:u,hoverOnPoints:f}},{\"../../components/color\":571,\"../../components/fx\":610,\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../scatter/fill_hover_text\":1055}],999:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":754,\"./attributes\":995,\"./calc\":996,\"./defaults\":997,\"./hover\":998,\"./plot\":1001,\"./select\":1002,\"./style\":1003}],1000:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var f=Math.min(s.length,l.length,c.length,u.length);return o&&(f=Math.min(f,i.minRowLength(o))),e._length=f,f}}},{\"../../lib\":694,\"../../registry\":825}],1001:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var r=n.select(this),a=t[0],l=a.t,c=a.trace;if(e.isRangePlot||(a.node3=r),!0!==c.visible||l.empty)r.remove();else{var u=l.tickLen,f=r.selectAll(\"path\").data(i.identity);f.enter().append(\"path\"),f.exit().remove(),f.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-u,!0),n=o.c2p(t.pos+u,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":694,d3:149}],1002:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1003:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e){var r=e?e[0].node3:n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");r.style(\"opacity\",function(t){return t[0].trace.opacity}),r.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":571,\"../../components/drawing\":592,d3:149}],1004:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../scatter/attributes\").line,c=t(\"../../components/colorbar/attributes\"),u=n({editType:\"calc\"},o(\"line\",{editType:\"calc\"}),{showscale:l.showscale,colorbar:c,shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"}});e.exports={domain:s({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:u,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../../plots/domain\":768,\"../../plots/font_attributes\":769,\"../scatter/attributes\":1047}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":779,\"./plot\":1010}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var f,h,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});f=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var M=[];for(y=0;y<k.length;y++)M.push(k[y][m]);h=f[m%f.length],p+=h;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),T=M+\"-\"+A.rawColor;void 0===w[T]&&(w[T]={categoryInds:M,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[T],m,h)}var S,C=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(h=f[m%f.length],y=0;y<C.length;y++){var E=C[y].containerInd,L=d[y].inds[m],z=C[y].categories;if(void 0===z[L]){var O=e.dimensions[E]._categoryarray[L],I=e.dimensions[E]._ticktext[L];z[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:I,valueInds:[],count:0,dragY:null}}c(z[L],m,h)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(C,w,p))}},{\"../../components/colorscale/calc\":579,\"../../components/colorscale/helpers\":582,\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/filter_unique.js\":685,\"../../lib/gup\":692}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,f,h);o(e,f,h),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),h(\"hoveron\"),h(\"arrangement\"),h(\"bundlecolors\"),h(\"sortpaths\"),h(\"counts\");var g={family:f.font.family,size:Math.round(f.font.size),color:f.font.color};n.coerceFont(h,\"labelfont\",g);var v={family:f.font.family,size:Math.round(f.font.size/1.2),color:f.font.color};n.coerceFont(h,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":581,\"../../components/colorscale/helpers\":582,\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../../plots/domain\":768,\"../parcoords/merge_length\":1019,\"./attributes\":1004}],1008:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.colorbar={container:\"line\",min:\"cmin\",max:\"cmax\"},n.moduleType=\"trace\",n.name=\"parcats\",n.basePlotModule=t(\"./base_plot\"),n.categories=[\"noOpacity\"],n.meta={},e.exports=n},{\"./attributes\":1004,\"./base_plot\":1005,\"./calc\":1006,\"./defaults\":1007,\"./plot\":1010}],1009:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),f=Math.floor(c*(s.y[1]-s.y[0])),h=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:o.hoverinfo.split(\"+\");var g={key:o.uid,model:i,x:h,y:p,width:u,height:f,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),P(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,f),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},f);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},f);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var M=k.selectAll(\"g.category\").data(function(t){return t.categories},f),A=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var z=M.selectAll(\"rect.bandrect\").data(function(t){return t.bands},f);z.each(function(){o.raiseToTop(this)}),z.attr(\"fill\",function(t){return t.color});var O=z.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);z.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),z.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var I=e._fullLayout.paper_bgcolor;M.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return h(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",I+\" -1px  1px 2px, \"+I+\" 1px  1px 2px, \"+I+\"  1px -1px 2px, \"+I+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return h(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),M.selectAll(\"rect.bandrect\").on(\"mouseover\",T).on(\"mouseout\",S),M.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",C).on(\"drag\",E).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function f(t){return t.key}function h(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,f=u._fullLayout,h=f._paperdiv.node().getBoundingClientRect(),p=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var d=t.parcatsViewModel.dimensions[s],g=t.parcatsViewModel.dimensions[s+1];r=(d.x+d.width+g.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var m=t.parcatsViewModel.x+r,y=t.parcatsViewModel.y+i,b=l.mostReadable(t.model.color,[\"black\",\"white\"]),_=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&_.push([\"Count:\",t.model.count].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&_.push([\"P:\",(t.model.count/t.parcatsViewModel.model.count).toFixed(3)].join(\" \"));var w=_.join(\"<br>\"),k=n.mouse(u)[0];a.loneHover({x:m-h.left+p.left,y:y-h.top+p.top,text:w,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:b,idealAlign:k<m?\"right\":\"left\"},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=z(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function M(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&f.push([\"Count:\",s.model.count].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&f.push([\"P(\"+s.model.categoryLabel+\"):\",(s.model.count/s.parcatsViewModel.model.count).toFixed(3)].join(\" \"));var h=f.join(\"<br>\");return{x:r-t.left,y:u-t.top,text:h,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i}}function T(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),M(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var h=s.model.categoryLabel,p=o.parcatsViewModel.model.count,d=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(d+=t.count)});var g=s.model.count,v=0;c.pathSelection.each(function(t){t.model.color===o.color&&(v+=t.model.count)});var m=[];if(-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&m.push([\"Count:\",d].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")){var y=\"P(color \\u2229 \"+h+\"): \"+(d/p).toFixed(3);m.push(y);var x=\"P(\"+h+\" | color): \"+(d/v).toFixed(3);m.push(x);var b=\"P(color | \"+h+\"): \"+(d/g).toFixed(3);m.push(b)}var _=m.join(\"<br>\"),w=l.mostReadable(o.color,[\"black\",\"white\"]);return{x:r-t.left,y:f-t.top,text:_,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:w,fontSize:10,idealAlign:i}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.multiHovers(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?M(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function C(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function E(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],f=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==f&&s+o.height>f.y+f.height/2&&(o.model.displayInd=f.model.displayInd,f.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var h=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==h&&a.model.dragX<h.x+h.width&&(a.model.displayInd=h.model.displayInd,h.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),P(t.parcatsViewModel),I(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=z(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),f=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[f],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),P(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){I(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function z(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},f),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function I(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},f);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},f);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return h(t)?\"start\":\"end\"}).attr(\"x\",function(t){return h(t)?t.width+5:-5}).each(function(t){var e,r;h(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},f),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function D(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function P(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function f(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=f(e),i=f(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var h=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var M=t.dimensions[k].categories[w],A=M.bands.length,T=M.bands[A-1];if(void 0===T||m.rawColor!==T.rawColor){var S=void 0===T?0:T.y+T.height;M.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:M.width,count:m.count,y:S,categoryViewModel:M,parcatsViewModel:t})}else{var C=M.bands[A-1];C.height+=v,C.count+=m.count}}y=\"hspline\"===t.pathShape?D(s,x,l,v,.5):D(s,x,l,v,0),h[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=h}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],f=t.model.maxCats,h=e.categories.length,p=e.count,d=t.height-8*(f-1),g=8*(f-h)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<h;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":592,\"../../components/fx\":610,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"../../plot_api/plot_api\":729,d3:149,tinycolor2:515}],1010:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1009}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/colorbar/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:s({name:\"parcoords\",trace:!0,editType:\"calc\"}),hoverlabel:void 0,labelfont:o({editType:\"calc\"}),tickfont:o({editType:\"calc\"}),rangefont:o({editType:\"calc\"}),dimensions:c(\"dimension\",{label:{valType:\"string\",editType:\"calc\"},tickvals:l({},a.tickvals,{editType:\"calc\"}),ticktext:l({},a.ticktext,{editType:\"calc\"}),tickformat:{valType:\"string\",dflt:\"3s\",editType:\"calc\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:l(n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}),{colorbar:i,editType:\"calc\"})}},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/layout_attributes\":755,\"../../plots/domain\":768,\"../../plots/font_attributes\":769}],1012:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function f(t,e){return t*(1-u)+e*u}function h(t,e,r){if(d(e,r))return e;for(var n=t[0],i=n,a=1;a<t.length;a++){var o=t[a];if(e<f(n,o))return c(n,i);if(e<o||a===t.length-1)return c(o,n);i=n,n=o}}function p(t,e,r){if(d(e,r))return e;for(var n=t[t.length-1],i=n,a=t.length-2;a>=0;a--){var o=t[a];if(e>f(n,o))return c(n,i);if(e>o||a===t.length-1)return c(o,n);i=n,n=o}}function d(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}function g(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function v(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function m(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=y(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function y(t,e){return t.map(function(t){return t.map(function(t){return t*e}).sort(s)})}function x(){i.select(document.body).style(\"cursor\",null)}function b(t){t.attr(\"stroke-dasharray\",m)}function _(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");b(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function w(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=y(l,s),u=NaN,f=NaN,h=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(f=r?r-1:NaN,p&&p[0]>e){h=r;break}}if(a=u,isNaN(a)&&(a=isNaN(f)||isNaN(h)?isNaN(f)?h:f:e-c[f][1]<c[h][0]-e?f:h),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var v=t.unitTickvals,m=t.unitToPaddedPx.invert(e);for(r=0;r<v.length;r++){var x=[.25*v[Math.max(r-1,0)]+.75*v[r],.25*v[Math.min(r+1,v.length-1)]+.75*v[r]];if(m>=x[0]&&m<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function k(t){t.on(\"mousemove\",function(t){if(i.event.preventDefault(),!t.parent.inBrushDrag){var e=w(t,t.height-i.mouse(this)[1]-2*n.verticalPadding),r=\"crosshair\";e.clickableOrdinalRange?r=\"pointer\":e.region&&(r=e.region+\"-resize\"),i.select(document.body).style(\"cursor\",r)}}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||x()}).call(i.behavior.drag().on(\"dragstart\",function(t){i.event.sourceEvent.stopPropagation();var e=t.height-i.mouse(this)[1]-2*n.verticalPadding,r=t.unitToPaddedPx.invert(e),a=t.brush,o=w(t,e),s=o.interval,l=a.svgBrush;if(l.wasDragged=!1,l.grabbingBar=\"ns\"===o.region,l.grabbingBar){var c=s.map(t.unitToPaddedPx);l.grabPoint=e-c[0]-n.verticalPadding,l.barLength=c[1]-c[0]}l.clickableOrdinalRange=o.clickableOrdinalRange,l.stayingIntervals=t.multiselect&&a.filterSpecified?a.filter.getConsolidated():[],s&&(l.stayingIntervals=l.stayingIntervals.filter(function(t){return t[0]!==s[0]&&t[1]!==s[1]})),l.startExtent=o.region?s[\"s\"===o.region?1:0]:r,t.parent.inBrushDrag=!0,l.brushStartCallback()}).on(\"drag\",function(t){i.event.sourceEvent.stopPropagation();var e=t.height-i.mouse(this)[1]-2*n.verticalPadding,r=t.brush.svgBrush;r.wasDragged=!0,r.grabbingBar?r.newExtent=[e-r.grabPoint,e+r.barLength-r.grabPoint].map(t.unitToPaddedPx.invert):r.newExtent=[r.startExtent,t.unitToPaddedPx.invert(e)].sort(s);var a=Math.max(0,-r.newExtent[0]),o=Math.max(0,r.newExtent[1]-1);r.newExtent[0]+=a,r.newExtent[1]-=o,r.grabbingBar&&(r.newExtent[1]+=a,r.newExtent[0]-=o),t.brush.filterSpecified=!0,r.extent=r.stayingIntervals.concat([r.newExtent]),r.brushCallback(t),_(this.parentNode)}).on(\"dragend\",function(t){i.event.sourceEvent.stopPropagation();var e=t.brush,r=e.filter,n=e.svgBrush,a=n.grabbingBar;if(n.grabbingBar=!1,n.grabLocation=void 0,t.parent.inBrushDrag=!1,x(),!n.wasDragged)return n.wasDragged=void 0,n.clickableOrdinalRange?e.filterSpecified&&t.multiselect?n.extent.push(n.clickableOrdinalRange):(n.extent=[n.clickableOrdinalRange],e.filterSpecified=!0):a?(n.extent=n.stayingIntervals,0===n.extent.length&&A(e)):A(e),n.brushCallback(t),_(this.parentNode),void n.brushEndCallback(e.filterSpecified?r.getConsolidated():[]);var o=function(){r.set(r.getConsolidated())};if(t.ordinal){var s=t.unitTickvals;s[s.length-1]<s[0]&&s.reverse(),n.newExtent=[h(s,n.newExtent[0],n.stayingIntervals),p(s,n.newExtent[1],n.stayingIntervals)];var l=n.newExtent[1]>n.newExtent[0];n.extent=n.stayingIntervals.concat(l?[n.newExtent]:[]),n.extent.length||A(e),n.brushCallback(t),l?_(this.parentNode,o):(o(),_(this.parentNode))}else o();n.brushEndCallback(e.filterSpecified?r.getConsolidated():[])}))}function M(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[0,1]]}function T(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){r=n.map(function(t){return t.slice().sort(s)}).sort(M),t=T(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(g).call(v).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(b);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(b)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?T(t.sort(M)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[h(r,t[0],[]),p(r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":694,\"../../lib/gup\":692,\"./constants\":1015,d3:149}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":672,\"../../plots/get_data\":779,\"./plot\":1021,d3:149}],1014:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../../lib\"),o=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r=!!e.line.colorscale&&a.isArrayOrTypedArray(e.line.color),s=r?e.line.color:function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),l=r?e.line.colorscale:[[0,e.line.color],[1,e.line.color]];return n(e,\"line\")&&i(t,e,{vals:s,containerStr:\"line\",cLetter:\"c\"}),o({lineColor:s,cscale:l})}},{\"../../components/colorscale/calc\":579,\"../../components/colorscale/helpers\":582,\"../../lib\":694,\"../../lib/gup\":692}],1015:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1016:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"./axisbrush\"),u=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function h(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"tickvals\"),r(\"ticktext\"),r(\"tickformat\"),r(\"range\"),r(\"multiselect\");var o=r(\"constraintrange\");o&&(e.constraintrange=c.cleanRanges(o,e))}}e.exports=function(t,e,r,c){function p(r,i){return n.coerce(t,e,l,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>u&&(n.log(\"parcoords traces support up to \"+u+\" dimensions at the moment\"),d.splice(u));var g=s(t,e,{name:\"dimensions\",handleItemDefaults:h}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,c,p);o(e,c,p),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:c.font.family,size:Math.round(c.font.size/1.2),color:c.font.color};n.coerceFont(p,\"labelfont\",m),n.coerceFont(p,\"tickfont\",m),n.coerceFont(p,\"rangefont\",m)}},{\"../../components/colorscale/defaults\":581,\"../../components/colorscale/helpers\":582,\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../../plots/domain\":768,\"./attributes\":1011,\"./axisbrush\":1012,\"./constants\":1015,\"./merge_length\":1019}],1017:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.colorbar={container:\"line\",min:\"cmin\",max:\"cmax\"},n.moduleType=\"trace\",n.name=\"parcoords\",n.basePlotModule=t(\"./base_plot\"),n.categories=[\"gl\",\"regl\",\"noOpacity\"],n.meta={},e.exports=n},{\"./attributes\":1011,\"./base_plot\":1013,\"./calc\":1014,\"./defaults\":1016,\"./plot\":1021}],1018:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 p0, p1, p2, p3,\\n               p4, p5, p6, p7,\\n               p8, p9, pa, pb,\\n               pc, pd, pe;\\n\\nattribute vec4 pf;\\n\\nuniform mat4 dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution,\\n             viewBoxPosition,\\n             viewBoxSize;\\n\\nuniform sampler2D palette;\\nuniform sampler2D mask;\\nuniform float maskHeight;\\n\\nuniform vec2 colorClamp;\\n\\nvarying vec4 fragColor;\\n\\nvec4 unit_1 = vec4(1, 1, 1, 1);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * unit_1, unit_1);\\n}\\n\\nfloat axisY(\\n        float x,\\n        mat4 d[4],\\n        mat4 dim1A, mat4 dim2A, mat4 dim1B, mat4 dim2B, mat4 dim1C, mat4 dim2C, mat4 dim1D, mat4 dim2D\\n    ) {\\n\\n    float y1 = val(d[0], dim1A) + val(d[1], dim1B) + val(d[2], dim1C) + val(d[3], dim1D);\\n    float y2 = val(d[0], dim2A) + val(d[1], dim2B) + val(d[2], dim2C) + val(d[3], dim2D);\\n    return y1 * (1.0 - x) + y2 * x;\\n}\\n\\nconst int bitsPerByte = 8;\\n\\nint mod2(int a) {\\n    return a - 2 * (a / 2);\\n}\\n\\nint mod8(int a) {\\n    return a - 8 * (a / 8);\\n}\\n\\nvec4 zero = vec4(0, 0, 0, 0);\\nvec4 unit_0 = vec4(1, 1, 1, 1);\\nvec2 xyProjection = vec2(1, 1);\\n\\nmat4 mclamp(mat4 m, mat4 lo, mat4 hi) {\\n    return mat4(clamp(m[0], lo[0], hi[0]),\\n                clamp(m[1], lo[1], hi[1]),\\n                clamp(m[2], lo[2], hi[2]),\\n                clamp(m[3], lo[3], hi[3]));\\n}\\n\\nbool mshow(mat4 p, mat4 lo, mat4 hi) {\\n    return mclamp(p, lo, hi) == p;\\n}\\n\\nbool withinBoundingBox(\\n        mat4 d[4],\\n        mat4 loA, mat4 hiA, mat4 loB, mat4 hiB, mat4 loC, mat4 hiC, mat4 loD, mat4 hiD\\n    ) {\\n\\n    return mshow(d[0], loA, hiA) &&\\n           mshow(d[1], loB, hiB) &&\\n           mshow(d[2], loC, hiC) &&\\n           mshow(d[3], loD, hiD);\\n}\\n\\nbool withinRasterMask(mat4 d[4], sampler2D mask, float height) {\\n    bool result = true;\\n    int bitInByteStepper;\\n    float valY, valueY, scaleX;\\n    int hit, bitmask, valX;\\n    for(int i = 0; i < 4; i++) {\\n        for(int j = 0; j < 4; j++) {\\n            for(int k = 0; k < 4; k++) {\\n                bitInByteStepper = mod8(j * 4 + k);\\n                valX = i * 2 + j / 2;\\n                valY = d[i][j][k];\\n                valueY = valY * (height - 1.0) + 0.5;\\n                scaleX = (float(valX) + 0.5) / 8.0;\\n                hit = int(texture2D(mask, vec2(scaleX, (valueY + 0.5) / height))[3] * 255.0) / int(pow(2.0, float(bitInByteStepper)));\\n                result = result && mod2(hit) == 1;\\n            }\\n        }\\n    }\\n    return result;\\n}\\n\\nvec4 position(\\n        float depth,\\n        vec2 resolution, vec2 viewBoxPosition, vec2 viewBoxSize,\\n        mat4 dims[4],\\n        float signum,\\n        mat4 dim1A, mat4 dim2A, mat4 dim1B, mat4 dim2B, mat4 dim1C, mat4 dim2C, mat4 dim1D, mat4 dim2D,\\n        mat4 loA, mat4 hiA, mat4 loB, mat4 hiB, mat4 loC, mat4 hiC, mat4 loD, mat4 hiD,\\n        sampler2D mask, float maskHeight\\n    ) {\\n\\n    float x = 0.5 * signum + 0.5;\\n    float y = axisY(x, dims, dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D);\\n\\n    float show = float(\\n                            withinBoundingBox(dims, loA, hiA, loB, hiB, loC, hiC, loD, hiD)\\n                         && withinRasterMask(dims, mask, maskHeight)\\n                      );\\n\\n    vec2 viewBoxXY = viewBoxPosition + viewBoxSize * vec2(x, y);\\n    float depthOrHide = depth + 2.0 * (1.0 - show);\\n\\n    return vec4(\\n        xyProjection * (2.0 * viewBoxXY / resolution - 1.0),\\n        depthOrHide,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n\\n    float prominence = abs(pf[3]);\\n\\n    mat4 p[4];\\n    p[0] = mat4(p0, p1, p2, p3);\\n    p[1] = mat4(p4, p5, p6, p7);\\n    p[2] = mat4(p8, p9, pa, pb);\\n    p[3] = mat4(pc, pd, pe, abs(pf));\\n\\n    gl_Position = position(\\n        1.0 - prominence,\\n        resolution, viewBoxPosition, viewBoxSize,\\n        p,\\n        sign(pf[3]),\\n        dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D,\\n        loA, hiA, loB, hiB, loC, hiC, loD, hiD,\\n        mask, maskHeight\\n    );\\n\\n    float clampedColorIndex = clamp((prominence - colorClamp[0]) / (colorClamp[1] - colorClamp[0]), 0.0, 1.0);\\n    fragColor = texture2D(palette, vec2((clampedColorIndex * 255.0 + 0.5) / 256.0, 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 p0, p1, p2, p3,\\n               p4, p5, p6, p7,\\n               p8, p9, pa, pb,\\n               pc, pd, pe;\\n\\nattribute vec4 pf;\\n\\nuniform mat4 dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D;\\n\\nuniform vec2 resolution,\\n             viewBoxPosition,\\n             viewBoxSize;\\n\\nuniform sampler2D palette;\\n\\nuniform vec2 colorClamp;\\n\\nvarying vec4 fragColor;\\n\\nvec2 xyProjection = vec2(1, 1);\\n\\nvec4 unit = vec4(1, 1, 1, 1);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * unit, unit);\\n}\\n\\nfloat axisY(\\n        float x,\\n        mat4 d[4],\\n        mat4 dim1A, mat4 dim2A, mat4 dim1B, mat4 dim2B, mat4 dim1C, mat4 dim2C, mat4 dim1D, mat4 dim2D\\n    ) {\\n\\n    float y1 = val(d[0], dim1A) + val(d[1], dim1B) + val(d[2], dim1C) + val(d[3], dim1D);\\n    float y2 = val(d[0], dim2A) + val(d[1], dim2B) + val(d[2], dim2C) + val(d[3], dim2D);\\n    return y1 * (1.0 - x) + y2 * x;\\n}\\n\\nvec4 position(\\n        float depth,\\n        vec2 resolution, vec2 viewBoxPosition, vec2 viewBoxSize,\\n        mat4 dims[4],\\n        float signum,\\n        mat4 dim1A, mat4 dim2A, mat4 dim1B, mat4 dim2B, mat4 dim1C, mat4 dim2C, mat4 dim1D, mat4 dim2D\\n    ) {\\n\\n    float x = 0.5 * signum + 0.5;\\n    float y = axisY(x, dims, dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D);\\n\\n    vec2 viewBoxXY = viewBoxPosition + viewBoxSize * vec2(x, y);\\n\\n    return vec4(\\n        xyProjection * (2.0 * viewBoxXY / resolution - 1.0),\\n        depth,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n\\n    float prominence = abs(pf[3]);\\n\\n    mat4 p[4];\\n    p[0] = mat4(p0, p1, p2, p3);\\n    p[1] = mat4(p4, p5, p6, p7);\\n    p[2] = mat4(p8, p9, pa, pb);\\n    p[3] = mat4(pc, pd, pe, abs(pf));\\n\\n    gl_Position = position(\\n        1.0 - prominence,\\n        resolution, viewBoxPosition, viewBoxSize,\\n        p,\\n        sign(pf[3]),\\n        dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D\\n    );\\n\\n    float clampedColorIndex = clamp((prominence - colorClamp[0]) / (colorClamp[1] - colorClamp[0]), 0.0, 1.0);\\n    fragColor = texture2D(palette, vec2((clampedColorIndex * 255.0 + 0.5) / 256.0, 0.5));\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 p0, p1, p2, p3,\\n               p4, p5, p6, p7,\\n               p8, p9, pa, pb,\\n               pc, pd, pe;\\n\\nattribute vec4 pf;\\n\\nuniform mat4 dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution,\\n             viewBoxPosition,\\n             viewBoxSize;\\n\\nuniform sampler2D mask;\\nuniform float maskHeight;\\n\\nuniform vec2 colorClamp;\\n\\nvarying vec4 fragColor;\\n\\nvec4 unit_1 = vec4(1, 1, 1, 1);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * unit_1, unit_1);\\n}\\n\\nfloat axisY(\\n        float x,\\n        mat4 d[4],\\n        mat4 dim1A, mat4 dim2A, mat4 dim1B, mat4 dim2B, mat4 dim1C, mat4 dim2C, mat4 dim1D, mat4 dim2D\\n    ) {\\n\\n    float y1 = val(d[0], dim1A) + val(d[1], dim1B) + val(d[2], dim1C) + val(d[3], dim1D);\\n    float y2 = val(d[0], dim2A) + val(d[1], dim2B) + val(d[2], dim2C) + val(d[3], dim2D);\\n    return y1 * (1.0 - x) + y2 * x;\\n}\\n\\nconst int bitsPerByte = 8;\\n\\nint mod2(int a) {\\n    return a - 2 * (a / 2);\\n}\\n\\nint mod8(int a) {\\n    return a - 8 * (a / 8);\\n}\\n\\nvec4 zero = vec4(0, 0, 0, 0);\\nvec4 unit_0 = vec4(1, 1, 1, 1);\\nvec2 xyProjection = vec2(1, 1);\\n\\nmat4 mclamp(mat4 m, mat4 lo, mat4 hi) {\\n    return mat4(clamp(m[0], lo[0], hi[0]),\\n                clamp(m[1], lo[1], hi[1]),\\n                clamp(m[2], lo[2], hi[2]),\\n                clamp(m[3], lo[3], hi[3]));\\n}\\n\\nbool mshow(mat4 p, mat4 lo, mat4 hi) {\\n    return mclamp(p, lo, hi) == p;\\n}\\n\\nbool withinBoundingBox(\\n        mat4 d[4],\\n        mat4 loA, mat4 hiA, mat4 loB, mat4 hiB, mat4 loC, mat4 hiC, mat4 loD, mat4 hiD\\n    ) {\\n\\n    return mshow(d[0], loA, hiA) &&\\n           mshow(d[1], loB, hiB) &&\\n           mshow(d[2], loC, hiC) &&\\n           mshow(d[3], loD, hiD);\\n}\\n\\nbool withinRasterMask(mat4 d[4], sampler2D mask, float height) {\\n    bool result = true;\\n    int bitInByteStepper;\\n    float valY, valueY, scaleX;\\n    int hit, bitmask, valX;\\n    for(int i = 0; i < 4; i++) {\\n        for(int j = 0; j < 4; j++) {\\n            for(int k = 0; k < 4; k++) {\\n                bitInByteStepper = mod8(j * 4 + k);\\n                valX = i * 2 + j / 2;\\n                valY = d[i][j][k];\\n                valueY = valY * (height - 1.0) + 0.5;\\n                scaleX = (float(valX) + 0.5) / 8.0;\\n                hit = int(texture2D(mask, vec2(scaleX, (valueY + 0.5) / height))[3] * 255.0) / int(pow(2.0, float(bitInByteStepper)));\\n                result = result && mod2(hit) == 1;\\n            }\\n        }\\n    }\\n    return result;\\n}\\n\\nvec4 position(\\n        float depth,\\n        vec2 resolution, vec2 viewBoxPosition, vec2 viewBoxSize,\\n        mat4 dims[4],\\n        float signum,\\n        mat4 dim1A, mat4 dim2A, mat4 dim1B, mat4 dim2B, mat4 dim1C, mat4 dim2C, mat4 dim1D, mat4 dim2D,\\n        mat4 loA, mat4 hiA, mat4 loB, mat4 hiB, mat4 loC, mat4 hiC, mat4 loD, mat4 hiD,\\n        sampler2D mask, float maskHeight\\n    ) {\\n\\n    float x = 0.5 * signum + 0.5;\\n    float y = axisY(x, dims, dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D);\\n\\n    float show = float(\\n                            withinBoundingBox(dims, loA, hiA, loB, hiB, loC, hiC, loD, hiD)\\n                         && withinRasterMask(dims, mask, maskHeight)\\n                      );\\n\\n    vec2 viewBoxXY = viewBoxPosition + viewBoxSize * vec2(x, y);\\n    float depthOrHide = depth + 2.0 * (1.0 - show);\\n\\n    return vec4(\\n        xyProjection * (2.0 * viewBoxXY / resolution - 1.0),\\n        depthOrHide,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n\\n    float prominence = abs(pf[3]);\\n\\n    mat4 p[4];\\n    p[0] = mat4(p0, p1, p2, p3);\\n    p[1] = mat4(p4, p5, p6, p7);\\n    p[2] = mat4(p8, p9, pa, pb);\\n    p[3] = mat4(pc, pd, pe, abs(pf));\\n\\n    gl_Position = position(\\n        1.0 - prominence,\\n        resolution, viewBoxPosition, viewBoxSize,\\n        p,\\n        sign(pf[3]),\\n        dim1A, dim2A, dim1B, dim2B, dim1C, dim2C, dim1D, dim2D,\\n        loA, hiA, loB, hiB, loC, hiC, loD, hiD,\\n        mask, maskHeight\\n    );\\n\\n    fragColor = vec4(pf.rgb, 1.0);\\n}\\n\"]),s=n([\"precision lowp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),l=t(\"../../lib\"),c=1e-6,u=1e-7,f=2048,h=64,p=2,d=4,g=8,v=h/g,m=[119,119,119],y=new Uint8Array(4),x=new Uint8Array(4),b={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function _(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function w(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:y})}(t),r.drawCompleted=!0),function s(l){var c;c=Math.min(n,i-l*n),a.offset=p*l*n,a.count=p*c,0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],_(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function k(t,e){return(t>>>8*e)%256/255}function M(t,e,r){var n,i,a,o=[];for(i=0;i<t;i++)for(a=0;a<p;a++)for(n=0;n<d;n++)o.push(e[i*h+r*d+n]),r*d+n===h-1&&a%2==0&&(o[o.length-1]*=-1);return o}e.exports=function(t,e){var r,n,p,d,y,A=e.context,T=e.pick,S=e.regl,C={currentRafs:{},drawCompleted:!0,clearOnly:!1},E=function(t){for(var e={},r=0;r<16;r++)e[\"p\"+r.toString(16)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(S),L=S.texture(b);O(e);var z=S({profile:!1,blend:{enable:A,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!A,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:S.prop(\"scissorX\"),y:S.prop(\"scissorY\"),width:S.prop(\"scissorWidth\"),height:S.prop(\"scissorHeight\")}},viewport:{x:S.prop(\"viewportX\"),y:S.prop(\"viewportY\"),width:S.prop(\"viewportWidth\"),height:S.prop(\"viewportHeight\")},dither:!1,vert:T?o:A?a:i,frag:s,primitive:\"lines\",lineWidth:1,attributes:E,uniforms:{resolution:S.prop(\"resolution\"),viewBoxPosition:S.prop(\"viewBoxPosition\"),viewBoxSize:S.prop(\"viewBoxSize\"),dim1A:S.prop(\"dim1A\"),dim2A:S.prop(\"dim2A\"),dim1B:S.prop(\"dim1B\"),dim2B:S.prop(\"dim2B\"),dim1C:S.prop(\"dim1C\"),dim2C:S.prop(\"dim2C\"),dim1D:S.prop(\"dim1D\"),dim2D:S.prop(\"dim2D\"),loA:S.prop(\"loA\"),hiA:S.prop(\"hiA\"),loB:S.prop(\"loB\"),hiB:S.prop(\"hiB\"),loC:S.prop(\"loC\"),hiC:S.prop(\"hiC\"),loD:S.prop(\"loD\"),hiD:S.prop(\"hiD\"),palette:L,mask:S.prop(\"maskTexture\"),maskHeight:S.prop(\"maskHeight\"),colorClamp:S.prop(\"colorClamp\")},offset:S.prop(\"offset\"),count:S.prop(\"count\")});function O(t){r=t.model,n=t.viewModel,p=n.dimensions.slice(),d=p[0]?p[0].values.length:0;var e=r.lines,i=T?e.color.map(function(t,r){return r/e.color.length}):e.color,a=Math.max(1/255,Math.pow(1/i.length,1/3)),o=function(t,e,r){for(var n,i=e.length,a=[],o=0;o<t;o++)for(var s=0;s<h;s++)a.push(s<i?e[s].paddedUnitValues[o]:s===h-1?(n=r[o],Math.max(c,Math.min(1-c,n))):s>=h-4?k(o,h-2-s):.5);return a}(d,p,i);!function(t,e,r){for(var n=0;n<16;n++)t[\"p\"+n.toString(16)](M(e,r,n))}(E,d,o),L=S.texture(l.extendFlat({data:function(t,e,r){for(var n=[],i=0;i<256;i++){var a=t(i/255);n.push((e?m:a).concat(r))}return n}(r.unitToColor,A,Math.round(255*(A?a:1)))},b))}var I=[0,1];var D=[];function P(t,e,n,i,a,o,s,c,u,f,h){var p,d,g,v,m=[t,e],y=[0,1].map(function(){return[0,1,2,3].map(function(){return new Float32Array(16)})});for(p=0;p<2;p++)for(v=m[p],d=0;d<4;d++)for(g=0;g<16;g++)y[p][d][g]=g+16*d===v?1:0;var x=r.lines.canvasOverdrag,b=r.domain,_=r.canvasWidth,w=r.canvasHeight;return l.extendFlat({key:s,resolution:[_,w],viewBoxPosition:[n+x,i],viewBoxSize:[a,o],i:t,ii:e,dim1A:y[0][0],dim1B:y[0][1],dim1C:y[0][2],dim1D:y[0][3],dim2A:y[1][0],dim2B:y[1][1],dim2C:y[1][2],dim2D:y[1][3],colorClamp:I,scissorX:(c===u?0:n+x)+(r.pad.l-x)+r.layoutWidth*b.x[0],scissorWidth:(c===f?_-n+x:a+.5)+(c===u?n+x:0),scissorY:i+r.pad.b+r.layoutHeight*b.y[0],scissorHeight:o,viewportX:r.pad.l-x+r.layoutWidth*b.x[0],viewportY:r.pad.b+r.layoutHeight*b.y[0],viewportWidth:_,viewportHeight:w},h)}return{setColorDomain:function(t){I[0]=t[0],I[1]=t[1]},render:function(t,e,n){var i,a,o,s=t.length,l=1/0,c=-1/0;for(i=0;i<s;i++)t[i].dim2.canvasX>c&&(c=t[i].dim2.canvasX,o=i),t[i].dim1.canvasX<l&&(l=t[i].dim1.canvasX,a=i);0===s&&_(S,0,0,r.canvasWidth,r.canvasHeight);var h=A?{}:function(){var t,e,r,n=[0,1].map(function(){return[0,1,2,3].map(function(){return new Float32Array(16)})});for(t=0;t<2;t++)for(e=0;e<4;e++)for(r=0;r<16;r++){var i,a=r+16*e;i=a<p.length?p[a].brush.filter.getBounds()[t]:t,n[t][e][r]=i+(2*t-1)*u}function o(t,e){var r=f-1;return[Math.max(0,Math.floor(e[0]*r)),Math.min(r,Math.ceil(e[1]*r))]}for(var s=Array.apply(null,new Array(f*v)).map(function(){return 255}),l=0;l<p.length;l++){var c=l%g,h=(l-c)/g,d=Math.pow(2,c),m=p[l],x=m.brush.filter.get();if(!(x.length<2))for(var b=o(0,x[0])[1],_=1;_<x.length;_++){for(var w=o(0,x[_]),k=b+1;k<w[0];k++)s[k*v+h]&=~d;b=Math.max(b,w[1])}}var M={shape:[v,f],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return y?y(M):y=S.texture(M),{maskTexture:y,maskHeight:f,loA:n[0][0],loB:n[0][1],loC:n[0][2],loD:n[0][3],hiA:n[1][0],hiB:n[1][1],hiC:n[1][2],hiD:n[1][3]}}();for(i=0;i<s;i++){var m=t[i],x=m.dim1,b=x.crossfilterDimensionIndex,k=m.canvasX,M=m.canvasY,T=m.dim2.crossfilterDimensionIndex,E=m.panelSizeX,L=m.panelSizeY,O=k+E;if(e||!D[b]||D[b][0]!==k||D[b][1]!==O){D[b]=[k,O];var I=P(b,T,k,M,E,L,x.crossfilterDimensionIndex,i,a,o,h);C.clearOnly=n,w(S,z,C,e?r.lines.blockLineCount:d,d,I)}}},readPixel:function(t,e){return S.read({x:t,y:e,width:1,height:1,data:x}),x},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return S.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",L.destroy(),y&&y.destroy(),E)E[e].destroy()},update:O}}},{\"../../lib\":694,glslify:395}],1019:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1020:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/gup\"),l=s.keyFun,c=s.repeat,u=s.unwrap,f=t(\"./constants\"),h=t(\"./axisbrush\"),p=t(\"./lines\");function d(t){return!(\"visible\"in t)||t.visible}function g(t){var e=t.range?t.range[0]:i.aggNums(Math.min,null,t.values,t._length),r=t.range?t.range[1]:i.aggNums(Math.max,null,t.values,t._length);return!isNaN(e)&&isFinite(e)||(e=0),!isNaN(r)&&isFinite(r)||(r=0),e===r&&(0===e?(e-=1,r+=1):(e*=.9,r*=1.1)),[e,r]}function v(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function m(t,e,r){var a=u(e),s=a.trace,l=a.lineColor,c=s.line,h=c.reversescale?o.flipScale(a.cscale):a.cscale,p=s.domain,v=s.dimensions,m=t.width,y=s.labelfont,x=s.tickfont,b=s.rangefont,_=i.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(g({values:l,range:[c.cmin,c.cmax],_length:s._length}))),blockLineCount:f.blockLineCount,canvasOverdrag:f.overdrag*f.canvasPixelRatio}),w=Math.floor(m*(p.x[1]-p.x[0])),k=Math.floor(t.height*(p.y[1]-p.y[0])),M=t.margin||{l:80,r:80,t:100,b:80},A=w,T=k;return{key:r,colCount:v.filter(d).length,dimensions:v,tickDistance:f.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){return n.rgb(t[1])}),i=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return i.map(function(e){return e(t)})}}(h),lines:_,labelFont:y,tickFont:x,rangeFont:b,layoutWidth:m,layoutHeight:t.height,domain:p,translateX:p.x[0]*m,translateY:t.height-p.y[1]*t.height,pad:M,canvasWidth:A*f.canvasPixelRatio+2*_.canvasOverdrag,canvasHeight:T*f.canvasPixelRatio,width:A,height:T,canvasPixelRatio:f.canvasPixelRatio}}function y(t,e,r){var a=r.width,o=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return a*t/Math.max(1,r.colCount-1)},u=f.verticalPadding/o,p=function(t,e){return n.scale.linear().range([e,t-e])}(o,f.verticalPadding),m={key:r.key,xScale:c,model:r,inBrushDrag:!1},y={};return m.dimensions=s.filter(d).map(function(a,s){var d=function(t,e){return n.scale.linear().domain(g(t)).range([e,1-e])}(a,u),x=y[a.label];y[a.label]=(x||0)+1;var b=a.label+(x?\"__\"+x:\"\"),_=a.constraintrange,w=_&&_.length;w&&!Array.isArray(_[0])&&(_=[_]);var k=w?_.map(function(t){return t.map(d)}):[[0,1]],M=a.values;M.length>a._length&&(M=M.slice(0,a._length));var A,T=a.tickvals;function S(t,e){return{val:t,text:A[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(T)&&T.length){A=a.ticktext,Array.isArray(A)&&A.length?A.length>T.length?A=A.slice(0,T.length):T.length>A.length&&(T=T.slice(0,A.length)):A=T.map(n.format(a.tickformat));for(var E=1;E<T.length;E++)if(T[E]<T[E-1]){for(var L=T.map(S).sort(C),z=0;z<T.length;z++)T[z]=L[z].val,A[z]=L[z].text;break}}else T=void 0;return{key:b,label:a.label,tickFormat:a.tickformat,tickvals:T,ticktext:A,ordinal:!!T,multiselect:a.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:a._index,height:o,values:M,paddedUnitValues:M.map(d),unitTickvals:T&&T.map(d),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:p,domainScale:function(t,e,r,i,a){var o,s,l=g(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(o,f.verticalPadding,a,T,A),ordinalScale:function(t){if(t.tickvals){var e=g(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(a),parent:m,model:r,brush:h.makeBrush(t,w,k,function(){t.linePickActive(!1)},function(){var e=m;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=v(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){var n=m;if(n.focusLayer.render(n.panels,!0),n.pickLayer&&n.pickLayer.render(n.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var o=d.invert,s=r.map(function(t){return t.map(o).sort(i.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(n.key,a._index,s)}})}}),m}function x(t){t.classed(f.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}e.exports=function(t,e,r,o,s,d){var g,b,_=(g=!0,b=!1,{linePickActive:function(t){return arguments.length?g=!!t:g},contextShown:function(t){return arguments.length?b=!!t:b}}),w=o.filter(function(t){return u(t).trace.visible}).map(m.bind(0,s)).map(y.bind(0,_,d));r.each(function(t,e){return i.extendFlat(t,w[e])});var k=r.selectAll(\".gl-canvas\").each(function(t){t.viewModel=w[0],t.model=t.viewModel?t.viewModel.model:null}),M=null;k.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(_.linePickActive()&&t.lineLayer&&d&&d.hover){var e=n.event,r=this.width,i=this.height,a=n.mouse(this),o=a[0],s=a[1];if(o<0||s<0||o>=r||s>=i)return;var l=t.lineLayer.readPixel(o,i-1-s),c=0!==l[3],u=c?l[2]+256*(l[1]+256*l[0]):null,f={x:o,y:s,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:u};u!==M&&(c?d.hover(f):d.unhover&&d.unhover(f),M=u)}}),k.style(\"opacity\",function(t){return t.pick?.01:1}),e.style(\"background\",\"rgba(255, 255, 255, 0)\");var A=e.selectAll(\".\"+f.cn.parcoords).data(w,l);A.exit().remove(),A.enter().append(\"g\").classed(f.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),A.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var T=A.selectAll(\".\"+f.cn.parcoordsControlView).data(c,l);T.enter().append(\"g\").classed(f.cn.parcoordsControlView,!0),T.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var S=T.selectAll(\".\"+f.cn.yAxis).data(function(t){return t.dimensions},l);function C(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=n.length-1,a=0;a<i;a++){var o=r[a]||(r[a]={}),s=n[a],l=n[a+1];o.dim1=s,o.dim2=l,o.canvasX=s.canvasX,o.panelSizeX=l.canvasX-s.canvasX,o.panelSizeY=e.model.canvasHeight,o.y=0,o.canvasY=0}}S.enter().append(\"g\").classed(f.cn.yAxis,!0),T.each(function(t){C(S,t)}),k.each(function(t){if(t.viewModel){!t.lineLayer||d?t.lineLayer=p(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||d;t.lineLayer.render(t.viewModel.panels,e)}}),S.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),S.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;_.linePickActive(!1),t.x=Math.max(-f.overdrag,Math.min(t.model.width+f.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,S.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),C(S,e),S.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),S.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!v(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,C(S,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!v(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),_.linePickActive(!0),d&&d.axesMoved&&d.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),S.exit().remove();var E=S.selectAll(\".\"+f.cn.axisOverlays).data(c,l);E.enter().append(\"g\").classed(f.cn.axisOverlays,!0),E.selectAll(\".\"+f.cn.axis).remove();var L=E.selectAll(\".\"+f.cn.axis).data(c,l);L.enter().append(\"g\").classed(f.cn.axis,!0),L.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(t.ordinal?function(t){return t}:null).scale(r)),a.font(L.selectAll(\"text\"),t.model.tickFont)}),L.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),L.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var z=E.selectAll(\".\"+f.cn.axisHeading).data(c,l);z.enter().append(\"g\").classed(f.cn.axisHeading,!0);var O=z.selectAll(\".\"+f.cn.axisTitle).data(c,l);O.enter().append(\"text\").classed(f.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),O.attr(\"transform\",\"translate(0,\"+-f.axisTitleOffset+\")\").text(function(t){return t.label}).each(function(t){a.font(n.select(this),t.model.labelFont)});var I=E.selectAll(\".\"+f.cn.axisExtent).data(c,l);I.enter().append(\"g\").classed(f.cn.axisExtent,!0);var D=I.selectAll(\".\"+f.cn.axisExtentTop).data(c,l);D.enter().append(\"g\").classed(f.cn.axisExtentTop,!0),D.attr(\"transform\",\"translate(0,\"+-f.axisExtentOffset+\")\");var P=D.selectAll(\".\"+f.cn.axisExtentTopText).data(c,l);function R(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain();return n.format(t.tickFormat)(r[e?r.length-1:0])}P.enter().append(\"text\").classed(f.cn.axisExtentTopText,!0).call(x),P.text(function(t){return R(t,!0)}).each(function(t){a.font(n.select(this),t.model.rangeFont)});var F=I.selectAll(\".\"+f.cn.axisExtentBottom).data(c,l);F.enter().append(\"g\").classed(f.cn.axisExtentBottom,!0),F.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+f.axisExtentOffset)+\")\"});var B=F.selectAll(\".\"+f.cn.axisExtentBottomText).data(c,l);B.enter().append(\"text\").classed(f.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(x),B.text(function(t){return R(t)}).each(function(t){a.font(n.select(this),t.model.rangeFont)}),h.ensureAxisBrush(E)}},{\"../../components/colorscale\":583,\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/gup\":692,\"./axisbrush\":1012,\"./constants\":1015,\"./lines\":1018,d3:149}],1021:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\");e.exports=function(t,e){var r=t._fullLayout,a=r._toppaper,o=r._paperdiv,s=r._glcontainer;if(i(t)){var l={},c={},u={},f={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;u[r]=n.index;var i=f[r]=n._fullInput.index;l[r]=t.data[i].dimensions,c[r]=t.data[i].dimensions.slice()});n(o,a,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=c[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",l=r._tracePreGUI[t._fullData[u[e]]._fullInput.uid];if(void 0===l[s]){var h=a.constraintrange;l[s]=h||null}var p=t._fullData[u[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[f[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){function n(t){return!(\"visible\"in t)||t.visible}function i(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}var a=function(t){return function(e,n){return i(r,t,e)-i(r,t,n)}}(c[e].filter(n));l[e].sort(a),c[e].filter(function(t){return!n(t)}).sort(function(t){return c[e].indexOf(t)}).forEach(function(t){l[e].splice(l[e].indexOf(t),1),l[e].splice(c[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[l[e]]},[f[e]]])}})}}},{\"../../lib/prepare_regl\":707,\"./parcoords\":1020}],1022:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../lib/extend\").extendFlat,c=i({editType:\"calc\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:n.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},a.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"calc\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"},editType:\"calc\"},domain:s({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":570,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../../plots/domain\":768,\"../../plots/font_attributes\":769}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];r.length&&e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":779,\"../../registry\":825}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\");r.calc=function(t,e){var r,l,c,u,f,h=e.values,p=i(h)&&h.length,d=e.labels,g=e.marker.colors||[],v=[],m=t._fullLayout,y=m._piecolormap,x={},b=0,_=m.hiddenlabels||[];if(e.dlabel)for(d=new Array(h.length),r=0;r<h.length;r++)d[r]=String(e.label0+r*e.dlabel);function w(t,e){return!!t&&(!!(t=a(t)).isValid()&&(t=o.addOpacity(t,t.getAlpha()),y[e]||(y[e]=t),t))}var k=(p?h:d).length;for(r=0;r<k;r++){if(p){if(l=h[r],!n(l))continue;if((l=+l)<0)continue}else l=1;void 0!==(c=d[r])&&\"\"!==c||(c=r);var M=x[c=String(c)];void 0===M?(x[c]=v.length,(u=-1!==_.indexOf(c))||(b+=l),v.push({v:l,label:c,color:w(g[r],c),i:r,pts:[r],hidden:u})):((f=v[M]).v+=l,f.pts.push(r),f.hidden||(b+=l),!1===f.color&&g[r]&&(f.color=w(g[r],c)))}if(e.sort&&v.sort(function(t,e){return e.v-t.v}),v[0]&&(v[0].vTotal=b),e.textinfo&&\"none\"!==e.textinfo){var A,T=-1!==e.textinfo.indexOf(\"label\"),S=-1!==e.textinfo.indexOf(\"text\"),C=-1!==e.textinfo.indexOf(\"value\"),E=-1!==e.textinfo.indexOf(\"percent\"),L=m.separators;for(r=0;r<v.length;r++){if(f=v[r],A=T?[f.label]:[],S){var z=s.getFirstFilled(e.text,f.pts);z&&A.push(z)}C&&A.push(s.formatPieValue(f.v,L)),E&&A.push(s.formatPiePercent(f.v/b,L)),f.text=A.join(\"<br>\")}}return v},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.piecolorway,i=e._piecolormap;e.extendpiecolors&&(n=function(t){var e,r=JSON.stringify(t),n=l[r];if(!n){for(n=t.slice(),e=0;e<t.length;e++)n.push(a(t[e]).lighten(20).toHexString());for(e=0;e<t.length;e++)n.push(a(t[e]).darken(20).toHexString());l[r]=n}return n}(n));var o,s,c,u,f=0;for(o=0;o<r.length;o++)if(\"pie\"===(c=r[o])[0].trace.type)for(s=0;s<c.length;s++)!1===(u=c[s]).color&&(i[u.label]?u.color=i[u.label]:(i[u.label]=u.color=n[f%n.length],f++))};var l={}},{\"../../components/color\":571,\"../../lib\":694,\"./helpers\":1027,\"fast-isnumeric\":215,tinycolor2:515}],1025:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l,c=n.coerceFont,u=s(\"values\"),f=n.isArrayOrTypedArray(u),h=s(\"labels\");if(Array.isArray(h)?(l=h.length,f&&(l=Math.min(l,u.length))):f&&(l=u.length,s(\"label0\"),s(\"dlabel\")),l){e._length=l,s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.colors\"),s(\"scalegroup\");var p=s(\"text\"),d=s(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(s(\"hovertext\"),s(\"hovertemplate\"),d&&\"none\"!==d){var g=s(\"textposition\"),v=Array.isArray(g)||\"auto\"===g,m=v||\"inside\"===g,y=v||\"outside\"===g;if(m||y){var x=c(s,\"textfont\",o.font);if(m){var b=n.extendFlat({},x);!(t.textfont&&t.textfont.color)&&delete b.color,c(s,\"insidetextfont\",b)}y&&c(s,\"outsidetextfont\",x)}}a(e,o,s);var _=s(\"hole\");if(s(\"title.text\")){var w=s(\"title.position\",_?\"middle center\":\"top center\");_||\"middle center\"!==w||(e.title.position=\"top center\"),c(s,\"title.font\",o.font)}s(\"sort\"),s(\"direction\"),s(\"rotation\"),s(\"pull\")}else e.visible=!1}},{\"../../lib\":694,\"../../plots/domain\":768,\"./attributes\":1022}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),r}},{\"../../components/fx/helpers\":606}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":694}],1028:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.supplyLayoutDefaults=t(\"./layout_defaults\"),n.layoutAttributes=t(\"./layout_attributes\");var i=t(\"./calc\");n.calc=i.calc,n.crossTraceCalc=i.crossTraceCalc,n.plot=t(\"./plot\"),n.style=t(\"./style\"),n.styleOne=t(\"./style_one\"),n.moduleType=\"trace\",n.name=\"pie\",n.basePlotModule=t(\"./base_plot\"),n.categories=[\"pie\",\"showLegend\"],n.meta={},e.exports=n},{\"./attributes\":1022,\"./base_plot\":1023,\"./calc\":1024,\"./defaults\":1025,\"./layout_attributes\":1029,\"./layout_defaults\":1030,\"./plot\":1031,\"./style\":1032,\"./style_one\":1033}],1029:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1030:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":694,\"./layout_attributes\":1029}],1031:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function f(t,e){if(t.v===e.vTotal&&!e.trace.hole)return 1;var r=Math.PI*Math.min(t.v/e.vTotal,.5);return Math.min(1/(1+1/Math.sin(r)),(1-e.trace.hole)/2)}function h(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function p(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function d(t){var e,r=t.pull;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}e.exports=function(t,e){var r=t._fullLayout;!function(t,e){for(var r,n,i=e._fullLayout,a=0;a<t.length;a++)if(r=t[a][0],(n=r.trace).title.text){var c=i.meta?s.templateString(n.title.text,{meta:i.meta}):n.title.text,u=o.tester.append(\"text\").attr(\"data-notex\",1).text(c).call(o.font,n.title.font).call(l.convertToTspans,e),f=o.bBox(u.node(),!0);r.titleBox={width:f.width,height:f.height},u.remove()}}(e,t),function(t,e){var r,n,i,a,o,s,l,c,u,f=[];for(i=0;i<t.length;i++)o=t[i][0],s=o.trace,r=e.w*(s.domain.x[1]-s.domain.x[0]),n=e.h*(s.domain.y[1]-s.domain.y[0]),s.title.text&&\"middle center\"!==s.title.position&&(n-=p(o,e)),l=d(s),o.r=Math.min(r,n)/(2+2*l),o.cx=e.l+e.w*(s.domain.x[1]+s.domain.x[0])/2,o.cy=e.t+e.h*(1-s.domain.y[0])-n/2,s.title.text&&-1!==s.title.position.indexOf(\"bottom\")&&(o.cy-=p(o,e)),s.scalegroup&&-1===f.indexOf(s.scalegroup)&&f.push(s.scalegroup);for(a=0;a<f.length;a++){for(u=1/0,c=f[a],i=0;i<t.length;i++)(o=t[i][0]).trace.scalegroup===c&&(u=Math.min(u,o.r*o.r/o.vTotal));for(i=0;i<t.length;i++)(o=t[i][0]).trace.scalegroup===c&&(o.r=Math.sqrt(u*o.vTotal))}}(e,r._size);var g=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var g=n.select(this),v=e[0],m=v.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0)}(e),g.attr(\"stroke-linejoin\",\"round\"),g.each(function(){var g=n.select(this).selectAll(\"g.slice\").data(e);g.enter().append(\"g\").classed(\"slice\",!0),g.exit().remove();var y=[[[],[]],[[],[]]],x=!1;g.each(function(e){if(e.hidden)n.select(this).selectAll(\"path,g\").remove();else{e.pointNumber=e.i,e.curveNumber=m.index,y[e.pxmid[1]<0?0:1][e.pxmid[0]<0?0:1].push(e);var p=v.cx,d=v.cy,g=n.select(this),b=g.selectAll(\"path.surface\").data([e]),_=!1,w=!1;if(b.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),g.select(\"path.textline\").remove(),g.on(\"mouseover\",function(){var a=t._fullLayout,o=t._fullData[m.index];if(!t._dragging&&!1!==a.hovermode){var s=o.hoverinfo;if(Array.isArray(s)&&(s=i.castHoverinfo({hoverinfo:[c.castOption(s,e.pts)],_module:m._module},a,0)),\"all\"===s&&(s=\"label+text+value+percent+name\"),o.hovertemplate||\"none\"!==s&&\"skip\"!==s&&s){var l=f(e,v),h=p+e.pxmid[0]*(1-l),g=d+e.pxmid[1]*(1-l),y=r.separators,x=[];if(s&&-1!==s.indexOf(\"label\")&&x.push(e.label),e.text=c.castOption(o.hovertext||o.text,e.pts),s&&-1!==s.indexOf(\"text\")){var b=e.text;b&&x.push(b)}e.value=e.v,e.valueLabel=c.formatPieValue(e.v,y),s&&-1!==s.indexOf(\"value\")&&x.push(e.valueLabel),e.percent=e.v/v.vTotal,e.percentLabel=c.formatPiePercent(e.percent,y),s&&-1!==s.indexOf(\"percent\")&&x.push(e.percentLabel);var k=m.hoverlabel,M=k.font;i.loneHover({x0:h-l*v.r,x1:h+l*v.r,y:g,text:x.join(\"<br>\"),name:o.hovertemplate||-1!==s.indexOf(\"name\")?o.name:void 0,idealAlign:e.pxmid[0]<0?\"left\":\"right\",color:c.castOption(k.bgcolor,e.pts)||e.color,borderColor:c.castOption(k.bordercolor,e.pts),fontFamily:c.castOption(M.family,e.pts),fontSize:c.castOption(M.size,e.pts),fontColor:c.castOption(M.color,e.pts),trace:o,hovertemplate:c.castOption(o.hovertemplate,e.pts),hovertemplateLabels:e,eventData:[u(e,o)]},{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:t}),_=!0}t.emit(\"plotly_hover\",{points:[u(e,o)],event:n.event}),w=!0}}).on(\"mouseout\",function(r){var a=t._fullLayout,o=t._fullData[m.index];w&&(r.originalEvent=n.event,t.emit(\"plotly_unhover\",{points:[u(e,o)],event:n.event}),w=!1),_&&(i.loneUnhover(a._hoverlayer.node()),_=!1)}).on(\"click\",function(){var r=t._fullLayout,a=t._fullData[m.index];t._dragging||!1===r.hovermode||(t._hoverdata=[u(e,a)],i.click(t,n.event))}),m.pull){var k=+c.castOption(m.pull,e.pts)||0;k>0&&(p+=k*e.pxmid[0],d+=k*e.pxmid[1])}e.cxFinal=p,e.cyFinal=d;var M=m.hole;if(e.v===v.vTotal){var A=\"M\"+(p+e.px0[0])+\",\"+(d+e.px0[1])+L(e.px0,e.pxmid,!0,1)+L(e.pxmid,e.px0,!0,1)+\"Z\";M?b.attr(\"d\",\"M\"+(p+M*e.px0[0])+\",\"+(d+M*e.px0[1])+L(e.px0,e.pxmid,!1,M)+L(e.pxmid,e.px0,!1,M)+\"Z\"+A):b.attr(\"d\",A)}else{var T=L(e.px0,e.px1,!0,1);if(M){var S=1-M;b.attr(\"d\",\"M\"+(p+M*e.px1[0])+\",\"+(d+M*e.px1[1])+L(e.px1,e.px0,!1,M)+\"l\"+S*e.px0[0]+\",\"+S*e.px0[1]+T+\"Z\")}else b.attr(\"d\",\"M\"+p+\",\"+d+\"l\"+e.px0[0]+\",\"+e.px0[1]+T+\"Z\")}var C=c.castOption(m.textposition,e.pts),E=g.selectAll(\"g.slicetext\").data(e.text&&\"none\"!==C?[0]:[]);E.enter().append(\"g\").classed(\"slicetext\",!0),E.exit().remove(),E.each(function(){var r=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});r.text(e.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===C?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(m,e,t._fullLayout.font):function(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}(m,e,t._fullLayout.font)).call(l.convertToTspans,t);var i,u=o.bBox(r.node());\"outside\"===C?i=h(u,e):(i=function(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=Math.PI*Math.min(e.v/r.vTotal,.5),o=1-r.trace.hole,s=f(e,r),l={scale:s*r.r*2/n,rCenter:1-s,rotate:0};if(l.scale>=1)return l;var c=i+1/(2*Math.tan(a)),u=r.r*Math.min(1/(Math.sqrt(c*c+.5)+c),o/(Math.sqrt(i*i+o/2)+i)),h={scale:2*u/t.height,rCenter:Math.cos(u/r.r)-u*i/r.r,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=r.r*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/r.r)-g/i/r.r,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>h.scale?v:h;return l.scale<1&&m.scale>l.scale?m:l}(u,e,v),\"auto\"===C&&i.scale<1&&(r.call(o.font,m.outsidetextfont),m.outsidetextfont.family===m.insidetextfont.family&&m.outsidetextfont.size===m.insidetextfont.size||(u=o.bBox(r.node())),i=h(u,e)));var g=p+e.pxmid[0]*i.rCenter+(i.x||0),y=d+e.pxmid[1]*i.rCenter+(i.y||0);i.outside&&(e.yLabelMin=y-u.height/2,e.yLabelMid=y,e.yLabelMax=y+u.height/2,e.labelExtraX=0,e.labelExtraY=0,x=!0),r.attr(\"transform\",\"translate(\"+g+\",\"+y+\")\"+(i.scale<1?\"scale(\"+i.scale+\")\":\"\")+(i.rotate?\"rotate(\"+i.rotate+\")\":\"\")+\"translate(\"+-(u.left+u.right)/2+\",\"+-(u.top+u.bottom)/2+\")\")})}function L(t,r,n,i){return\"a\"+i*v.r+\",\"+i*v.r+\" 0 \"+e.largeArc+(n?\" 1 \":\" 0 \")+i*(r[0]-t[0])+\",\"+i*(r[1]-t[1])}});var b=n.select(this).selectAll(\"g.titletext\").data(m.title.text?[0]:[]);b.enter().append(\"g\").classed(\"titletext\",!0),b.exit().remove(),b.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=r.meta?s.templateString(m.title.text,{meta:r.meta}):m.title.text;i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,m.title.font).call(l.convertToTspans,t),e=\"middle center\"===m.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(v):function(t,e){var r,n,i=1,a=1,o=t.trace,s={x:t.cx,y:t.cy},l={tx:0,ty:0};l.ty+=o.title.font.size,n=d(o),-1!==o.title.position.indexOf(\"top\")?(s.y-=(1+n)*t.r,l.ty-=t.titleBox.height):-1!==o.title.position.indexOf(\"bottom\")&&(s.y+=(1+n)*t.r);-1!==o.title.position.indexOf(\"left\")?(r=e.w*(o.domain.x[1]-o.domain.x[0])/2+t.r,s.x-=(1+n)*t.r,l.tx+=t.titleBox.width/2):-1!==o.title.position.indexOf(\"center\")?r=e.w*(o.domain.x[1]-o.domain.x[0]):-1!==o.title.position.indexOf(\"right\")&&(r=e.w*(o.domain.x[1]-o.domain.x[0])/2+t.r,s.x+=(1+n)*t.r,l.tx-=t.titleBox.width/2);return i=r/t.titleBox.width,a=p(t,e)/t.titleBox.height,{x:s.x,y:s.y,scale:Math.min(i,a),tx:l.tx,ty:l.ty}}(v,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),x&&function(t,e){var r,n,i,a,o,s,l,u,f,h,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,f,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<h.length;u++)(f=h[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,f.pts)||0)||((t.pxmid[1]-f.pxmid[1])*l>0?(p=f.cyFinal+o(f.px0[1],f.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-h.indexOf(t)),d=f.cxFinal+a(f.px0[0],f.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),f=t[1-n][r],h=f.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<f.length;p++)if(void 0!==f[p].yLabelMid){g=f[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(y,m),g.each(function(t){if(t.labelExtraX||t.labelExtraY){var e=n.select(this),r=e.select(\"g.slicetext text\");r.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+r.attr(\"transform\"));var i=t.cxFinal+t.pxmid[0],o=\"M\"+i+\",\"+(t.cyFinal+t.pxmid[1]),s=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var l=t.labelExtraX*t.pxmid[1]/t.pxmid[0],c=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(l)>Math.abs(c)?o+=\"l\"+c*t.pxmid[0]/t.pxmid[1]+\",\"+c+\"H\"+(i+t.labelExtraX+s):o+=\"l\"+t.labelExtraX+\",\"+l+\"v\"+(c-l)+\"h\"+s}else o+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+s;e.append(\"path\").classed(\"textline\",!0).call(a.stroke,m.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,m.outsidetextfont.size/8),d:o,fill:\"none\"})}})})});setTimeout(function(){g.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../../components/fx\":610,\"../../lib\":694,\"../../lib/svg_text_utils\":718,\"./event_data\":1026,\"./helpers\":1027,d3:149}],1032:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1033,d3:149}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style({\"stroke-width\":s}).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":571,\"./helpers\":1027}],1034:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1047}],1035:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,f=this.pickXYData=t.xy,h=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(f){if(n=f,e=f.length>>>1,h)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":717,\"../../plots/cartesian/autorange\":741,\"../scatter/get_trace_color\":1057,\"gl-pointcloud2d\":281}],1036:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":694,\"./attributes\":1034}],1037:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"../scatter3d/calc\"),n.plot=t(\"./convert\"),n.moduleType=\"trace\",n.name=\"pointcloud\",n.basePlotModule=t(\"../../plots/gl2d\"),n.categories=[\"gl\",\"gl2d\",\"showLegend\"],n.meta={},e.exports=n},{\"../../plots/gl2d\":782,\"../scatter3d/calc\":1075,\"./attributes\":1034,\"./convert\":1035,\"./defaults\":1036}],1038:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll;(e.exports=u({hoverinfo:c({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":570,\"../../components/fx/attributes\":601,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739,\"../../plots/domain\":768,\"../../plots/font_attributes\":769}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\");r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&n._paperdiv.selectAll(\".sankey\").remove()}},{\"../../components/fx/layout_attributes\":611,\"../../plot_api/edit_types\":725,\"../../plots/get_data\":779,\"./plot\":1044}],1040:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){return function(t,e,r){for(var a=t.length,o=i.init2dArray(a,0),s=0;s<Math.min(e.length,r.length);s++)if(i.isIndex(e[s],a)&&i.isIndex(r[s],a)){if(e[s]===r[s])return!0;o[e[s]].push(r[s])}return n(o).components.some(function(t){return t.length>1})}(e.node.label,e.link.source,e.link.target)&&(i.error(\"Circularity is present in the Sankey data. Removing all nodes and links.\"),e.link.label=[],e.link.source=[],e.link.target=[],e.link.value=[],e.link.color=[],e.node.label=[],e.node.color=[]),a({link:e.link,node:e.node})}},{\"../../lib\":694,\"../../lib/gup\":692,\"strongly-connected-components\":508}],1041:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"cubic-in-out\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,u){function f(r,a){return n.coerce(t,e,i,r,a)}var h=n.extendDeep(u.hoverlabel,t.hoverlabel),p=t.node,d=c.newContainer(e,\"node\");function g(t,e){return n.coerce(p,d,i.node,t,e)}g(\"label\"),g(\"pad\"),g(\"thickness\"),g(\"line.color\"),g(\"line.width\"),g(\"hoverinfo\",t.hoverinfo),l(p,d,g,h),g(\"hovertemplate\");var v=u.colorway;g(\"color\",d.label.map(function(t,e){return a.addOpacity(function(t){return v[t%v.length]}(e),.8)}));var m=t.link,y=c.newContainer(e,\"link\");function x(t,e){return n.coerce(m,y,i.link,t,e)}x(\"label\"),x(\"source\"),x(\"target\"),x(\"value\"),x(\"line.color\"),x(\"line.width\"),x(\"hoverinfo\",t.hoverinfo),l(m,y,x,h),x(\"hovertemplate\");var b=o(u.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";x(\"color\",n.repeat(b,y.value.length)),s(e,u,f),f(\"orientation\"),f(\"valueformat\"),f(\"valuesuffix\"),f(\"arrangement\"),n.coerceFont(f,\"textfont\",n.extendFlat({},u.font)),e._length=null}},{\"../../components/color\":571,\"../../components/fx/hoverlabel_defaults\":608,\"../../lib\":694,\"../../plot_api/plot_template\":732,\"../../plots/domain\":768,\"./attributes\":1038,tinycolor2:515}],1043:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.moduleType=\"trace\",n.name=\"sankey\",n.basePlotModule=t(\"./base_plot\"),n.categories=[\"noOpacity\"],n.meta={},e.exports=n},{\"./attributes\":1038,\"./base_plot\":1039,\"./calc\":1040,\"./defaults\":1042,\"./plot\":1044}],1044:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function f(t,e){return t.filter(function(t){return t.key===e.traceId})}function h(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",.4),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",.4),r&&f(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&f(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){var r=t._fullLayout,s=r._paper,f=r._size,d=c(t,\"source:\")+\" \",g=c(t,\"target:\")+\" \",_=c(t,\"incoming flow count:\")+\" \",w=c(t,\"outgoing flow count:\")+\" \";i(s,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){var l=t._fullLayout._paperdiv.node().getBoundingClientRect(),c=e.getBoundingClientRect(),f=c.left+c.width/2,v=c.top+c.height/2,m={valueLabel:n.format(i.valueFormat)(i.link.value)+i.valueSuffix};i.link.fullData=i.link.trace;var y=a.loneHover({x:f-l.left,y:v-l.top,name:m.valueLabel,text:[i.link.label||\"\",d+i.link.source.label,g+i.link.target.label].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(i.tinyColorHue,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),idealAlign:n.event.x<f?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:m,eventData:[i.link]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(y,.65),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=s.node().getBoundingClientRect(),d=f.left-2-c.left,g=f.right+2-c.left,v=f.top+f.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,_+i.node.targetLinks.length,w+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":571,\"../../components/fx\":610,\"../../lib\":694,\"./constants\":1041,\"./render\":1045,d3:149}],1045:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\").sankey,c=t(\"d3-force\"),u=t(\"../../lib\"),f=u.isArrayOrTypedArray,h=u.isIndex,p=t(\"../../lib/gup\"),d=p.keyFun,g=p.repeat,v=p.unwrap;function m(t){t.lastDraggedX=t.x,t.lastDraggedY=t.y}function y(t){return function(e){return e.node.originalX===t.node.originalX}}function x(t){for(var e=0;e<t.length;e++)t[e].y=t[e].y+t[e].dy/2}function b(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x.toFixed(3)+\", \"+(t.node.y-t.node.dy/2).toFixed(3)+\")\"})}function _(t){var e=t.sankey.nodes();!function(t){for(var e=0;e<t.length;e++)t[e].y=t[e].y-t[e].dy/2}(e);var r=t.sankey.link()(t.link);return x(e),r}function w(t){t.call(b)}function k(t,e){t.call(w),e.attr(\"d\",_)}function M(t){t.attr(\"width\",function(t){return t.visibleWidth}).attr(\"height\",function(t){return t.visibleHeight})}function A(t){return t.link.dy>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function S(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function C(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function E(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function L(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function z(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function O(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function I(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||r.select(this,t,e)})}function D(t,e,r){var a=i.behavior.drag().origin(function(t){return t.node}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(u.raiseToTop(this),i.interactionState.dragInProgress=i.node,m(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var a=i.traceId+\"|\"+Math.floor(i.node.originalX);i.forceLayouts[a]?i.forceLayouts[a].alpha(1):function(t,e,r){var i=r.sankey.nodes().filter(function(t){return t.originalX===r.node.originalX});r.forceLayouts[e]=c.forceSimulation(i).alphaDecay(0).force(\"collide\",c.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,i,r)).stop()}(0,a,i),function(t,e,r,i){window.requestAnimationFrame(function a(){for(var o=0;o<n.forceTicksPerFrame;o++)r.forceLayouts[i].tick();r.sankey.relayout(),k(t.filter(y(r)),e),r.forceLayouts[i].alpha()>0&&window.requestAnimationFrame(a)})}(t,e,i,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x=n,r.node.y=a):(\"freeform\"===r.arrangement&&(r.node.x=n),r.node.y=Math.max(r.node.dy/2,Math.min(r.size-r.node.dy/2,a))),m(r.node),\"snap\"!==r.arrangement&&(r.sankey.relayout(),k(t.filter(y(r)),e))}}).on(\"dragend\",function(t){t.interactionState.dragInProgress=!1});t.on(\".drag\",null).call(a)}e.exports=function(t,e,r,i){var c=t.selectAll(\".\"+n.cn.sankey).data(e.filter(function(t){return v(t).trace.visible}).map(function(t,e,r){var i,a=v(e).trace,o=a.domain,s=a.node,c=a.link,p=a.arrangement,d=\"h\"===a.orientation,g=a.node.pad,m=a.node.thickness,y=a.node.line.color,b=a.node.line.width,_=a.link.line.color,w=a.link.line.width,k=a.valueformat,M=a.valuesuffix,A=a.textfont,T=t.width*(o.x[1]-o.x[0]),S=t.height*(o.y[1]-o.y[0]),C=[],E=f(c.color),L={},z=s.label.length;for(i=0;i<c.value.length;i++){var O=c.value[i],I=c.source[i],D=c.target[i];O>0&&h(I,z)&&h(D,z)&&(D=+D,L[I=+I]=L[D]=!0,C.push({pointNumber:i,label:c.label[i],color:E?c.color[i]:c.color,source:I,target:D,value:+O}))}var P=f(s.color),R=[],F=!1,B={};for(i=0;i<z;i++)if(L[i]){var N=s.label[i];B[i]=R.length,R.push({pointNumber:i,label:N,color:P?s.color[i]:s.color})}else F=!0;if(F)for(i=0;i<C.length;i++)C[i].source=B[C[i].source],C[i].target=B[C[i].target];var j,V=l().size(d?[T,S]:[S,T]).nodeWidth(m).nodePadding(g).nodes(R).links(C).layout(n.sankeyIterations);V.nodePadding()<g&&u.warn(\"node.pad was reduced to \",V.nodePadding(),\" to fit within the figure.\");for(var U=V.nodes(),q=0;q<U.length;q++)(j=U[q]).width=T,j.height=S;return x(R),{key:r,trace:a,guid:Math.floor(1e12*(1+Math.random())),horizontal:d,width:T,height:S,nodePad:g,nodeLineColor:y,nodeLineWidth:b,linkLineColor:_,linkLineWidth:w,valueFormat:k,valueSuffix:M,textFont:A,translateX:o.x[0]*t.width+t.margin.l,translateY:t.height-o.y[1]*t.height+t.margin.t,dragParallel:d?S:T,dragPerpendicular:d?T:S,nodes:R,links:C,arrangement:p,sankey:V,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,r)),d);c.exit().remove(),c.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),c.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var p=c.selectAll(\".\"+n.cn.sankeyLinks).data(g,d);p.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var m=p.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.sankey.links().filter(function(t){return t.value}).map(function(t,e,r){var n=a(r.color),i=r.source.label+\"|\"+r.target.label,s=t[i];t[i]=(s||0)+1;var l=i+\"__\"+t[i];return r.trace=e.trace,r.curveNumber=e.trace.index,{key:l,traceId:e.key,link:r,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkLineColor:e.linkLineColor,linkLineWidth:e.linkLineWidth,valueFormat:e.valueFormat,valueSuffix:e.valueSuffix,sankey:e.sankey,interactionState:e.interactionState}}.bind(null,{},t))},d);m.enter().append(\"path\").classed(n.cn.sankeyLink,!0).attr(\"d\",_).call(I,c,i.linkEvents),m.style(\"stroke\",function(t){return A(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return A(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"stroke-width\",function(t){return A(t)?t.linkLineWidth:1}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),m.transition().ease(n.ease).duration(n.duration).attr(\"d\",_),m.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var y=c.selectAll(\".\"+n.cn.sankeyNodeSet).data(g,d);y.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),y.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var w=y.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.sankey.nodes();return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=t[e].x,t[e].originalY=t[e].y,-1===r.indexOf(t[e].x)&&r.push(t[e].x);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.filter(function(t){return t.value}).map(function(t,e,r){var i=a(r.color),s=n.nodePadAcross,l=e.nodePad/2,c=r.dx,u=Math.max(.5,r.dy),f=r.label,h=t[f];t[f]=(h||0)+1;var p=f+\"__\"+t[f];return r.trace=e.trace,r.curveNumber=e.trace.index,{key:p,traceId:e.key,node:r,nodePad:e.nodePad,nodeLineColor:e.nodeLineColor,nodeLineWidth:e.nodeLineWidth,textFont:e.textFont,size:e.horizontal?e.height:e.width,visibleWidth:Math.ceil(c),visibleHeight:u,zoneX:-s,zoneY:-l,zoneWidth:c+2*s,zoneHeight:u+2*l,labelY:e.horizontal?r.dy/2+1:r.dx/2+1,left:1===r.originalLayer,sizeAcross:e.width,forceLayouts:e.forceLayouts,horizontal:e.horizontal,darkBackground:i.getBrightness()<=128,tinyColorHue:o.tinyRGB(i),tinyColorAlpha:i.getAlpha(),valueFormat:e.valueFormat,valueSuffix:e.valueSuffix,sankey:e.sankey,arrangement:e.arrangement,uniqueNodeLabelPathId:[e.guid,e.key,p].join(\" \"),interactionState:e.interactionState}}.bind(null,{},t))},d);w.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(b).call(I,c,i.nodeEvents),w.call(D,m,i),w.transition().ease(n.ease).duration(n.duration).call(b),w.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var k=w.selectAll(\".\"+n.cn.nodeRect).data(g);k.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(M),k.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),k.transition().ease(n.ease).duration(n.duration).call(M);var P=w.selectAll(\".\"+n.cn.nodeCapture).data(g);P.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),P.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var R=w.selectAll(\".\"+n.cn.nodeCentered).data(g);R.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",S),R.transition().ease(n.ease).duration(n.duration).attr(\"transform\",S);var F=R.selectAll(\".\"+n.cn.nodeLabelGuide).data(g);F.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",C).attr(\"transform\",E),F.transition().ease(n.ease).duration(n.duration).attr(\"d\",C).attr(\"transform\",E);var B=R.selectAll(\".\"+n.cn.nodeLabel).data(g);B.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",L).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),B.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(B,t.textFont)}),B.transition().ease(n.ease).duration(n.duration).attr(\"transform\",L);var N=B.selectAll(\".\"+n.cn.nodeLabelTextPath).data(g);N.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",O).style(\"fill\",z),N.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),N.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",O).style(\"fill\",z)}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/gup\":692,\"./constants\":1041,\"@plotly/d3-sankey\":47,d3:149,\"d3-force\":145,tinycolor2:515}],1046:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArray(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArray(i.size,t,\"ms\"),n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArray(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":694}],1047:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/colorbar/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../components/drawing\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:c.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:u({},s,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:u({symbol:{valType:\"enumerated\",values:l.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},colorbar:a,line:u({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:o({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../components/drawing\":592,\"../../components/drawing/attributes\":591,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plots/font_attributes\":769,\"./constants\":1051}],1048:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function f(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,f=r._id,h=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),f&&(e._extremes[f]=a.findExtremes(r,i,y)),h&&(e._extremes[h]=a.findExtremes(n,o,x))}function h(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),f=0;f<e;f++)u[f]=r(c[f]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),M=e._length,A=new Array(M),T=e.ids,S=g(e,x,b,_),C=!1;p(x,e);var E,L=\"x\",z=\"y\";for(S?(S.traceIndices.push(e.index),(r=\"v\"===S.orientation)?(z=\"s\",E=\"x\"):(L=\"s\",E=\"y\"),m=\"interpolate\"===S.stackgaps):f(t,e,b,_,w,k,h(e,M)),s=0;s<M;s++){var O=A[s]={},I=n(w[s]),D=n(k[s]);I&&D?(O[L]=w[s],O[z]=k[s]):S&&(r?I:D)?(O[E]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,C=!0):O.s=0):O[L]=O[z]=o,T&&(O.id=String(T[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][E]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[E]-e[E]||t.i-e.i}),C){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var P=A[s-1][E],R=A[s-1].s,F=(A[d].s-R)/(A[d][E]-P);s<d;)A[s].s=R+(A[s][E]-P)*F,s++}}}return A},calcMarkerSize:h,calcAxisExpansion:f,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"./arrays_to_calcdata\":1046,\"./calc_selection\":1049,\"./colorscale_calc\":1050,\"./subtypes\":1071,\"fast-isnumeric\":215}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":694}],1050:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":579,\"../../components/colorscale/helpers\":582,\"./subtypes\":1071}],1051:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1052:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,f,h,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var M in s){var A=(m=s[M]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var T=new Array(p.length);for(l=0;l<p.length;l++)T[l]=p[l][b];for(l=1;l<A.length;l++){for(h=k[A[l]],c=u=0;c<h.length;c++){for(d=h[c][b];d>T[u]&&u<T.length;u++)i(h,c,T[u],l,w,y,b),c++;if(d!==T[u]){for(f=0;f<l;f++)i(k[A[f]],u,d,f,w,y,b);T.splice(u,0,d)}u++}for(;u<T.length;u++)i(h,c,T[u],l,w,y,b),c++}var S=T.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(h=k[A[l]])[0].trace._rawLength=h[0].trace._length,h[0].trace._length=S,g+=h[c].s,h[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var C=k[A[l]][c];C[_]/=v,C.sNorm=C.s/v}}for(l=0;l<A.length;l++){var E=(h=k[A[l]])[0].trace,L=n.calcMarkerSize(E,E._rawLength),z=Array.isArray(L);if(L&&w[l]||z){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=h[c].gap?0:z?O[h[c].i]:O}var I=new Array(S),D=new Array(S);for(c=0;c<S;c++)I[c]=h[c].x,D[c]=h[c].y;n.calcAxisExpansion(t,E,r,a,I,D,L),h[0].t.orientation=m.orientation}}}}}},{\"./calc\":1048}],1053:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),f=t(\"./line_defaults\"),h=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(f(t,e,r,g,v),h(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||h(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":694,\"../../registry\":825,\"./attributes\":1047,\"./constants\":1051,\"./fillcolor_defaults\":1056,\"./line_defaults\":1060,\"./line_shape_defaults\":1062,\"./marker_defaults\":1066,\"./stack_defaults\":1069,\"./subtypes\":1071,\"./text_defaults\":1072,\"./xy_defaults\":1073}],1055:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return t||0===t}e.exports=function(t,e,r){var a=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},o=n.extractOption(t,e,\"htx\",\"hovertext\");if(i(o))return a(o);var s=n.extractOption(t,e,\"tx\",\"text\");return i(s)?a(s):void 0}},{\"../../lib\":694}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":571,\"../../lib\":694}],1057:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":571,\"./subtypes\":1071}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=t(\"./fill_hover_text\");e.exports=function(t,e,r,c){var u=t.cd,f=u[0].trace,h=t.xa,p=t.ya,d=h.c2p(e),g=p.c2p(r),v=[d,g],m=f.hoveron||\"\",y=-1!==f.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=h.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(h.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=h.c2p(_.x,!0),k=p.c2p(_.y,!0),M=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,T=A&&(_.sNorm||_.s),S=\"h\"===A?T:_.x,C=\"v\"===A?T:_.y;return n.extendFlat(t,{color:o(f,_),x0:w-M,x1:w+M,xLabelVal:S,y0:k-M,y1:k+M,yLabelVal:C,spikeDistance:x(_),hovertemplate:f.hovertemplate}),l(_,f,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,f,t),[t]}}if(-1!==m.indexOf(\"fills\")&&f._polygons){var E,L,z,O,I,D,P,R,F,B=f._polygons,N=[],j=!1,V=1/0,U=-1/0,q=1/0,H=-1/0;for(E=0;E<B.length;E++)(z=B[E]).contains(v)&&(j=!j,N.push(z),q=Math.min(q,z.ymin),H=Math.max(H,z.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(E=0;E<N.length;E++)for(O=N[E].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(D=O[L-1][0],P=O[L][0],F-R&&(I=D+(P-D)*(G-R)/(F-R),V=Math.min(V,I),U=Math.max(U,I)));V=Math.max(V,0),U=Math.min(U,h._length);var W=s.defaultLine;return s.opacity(f.fillcolor)?W=f.fillcolor:s.opacity((f.line||{}).color)&&(W=f.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:V,x1:U,y0:G,y1:G,color:W,hovertemplate:\"%{name}\"}),delete t.index,f.text&&!Array.isArray(f.text)?t.text=String(f.text):t.text=f.name,[t]}}}},{\"../../components/color\":571,\"../../components/fx\":610,\"../../lib\":694,\"../../registry\":825,\"./fill_hover_text\":1055,\"./get_trace_color\":1057}],1059:[function(t,e,r){\"use strict\";var n={},i=t(\"./subtypes\");n.hasLines=i.hasLines,n.hasMarkers=i.hasMarkers,n.hasText=i.hasText,n.isBubble=i.isBubble,n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.crossTraceDefaults=t(\"./cross_trace_defaults\"),n.calc=t(\"./calc\").calc,n.crossTraceCalc=t(\"./cross_trace_calc\"),n.arraysToCalcdata=t(\"./arrays_to_calcdata\"),n.plot=t(\"./plot\"),n.colorbar=t(\"./marker_colorbar\"),n.style=t(\"./style\").style,n.styleOnSelect=t(\"./style\").styleOnSelect,n.hoverPoints=t(\"./hover\"),n.selectPoints=t(\"./select\"),n.animatable=!0,n.moduleType=\"trace\",n.name=\"scatter\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"./arrays_to_calcdata\":1046,\"./attributes\":1047,\"./calc\":1048,\"./cross_trace_calc\":1052,\"./cross_trace_defaults\":1053,\"./defaults\":1054,\"./hover\":1058,\"./marker_colorbar\":1065,\"./plot\":1067,\"./select\":1068,\"./style\":1070,\"./subtypes\":1071}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":581,\"../../components/colorscale/helpers\":582,\"../../lib\":694}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,f=t(\"./constants\");e.exports=function(t,e){var r,n,a,h,p,d,g,v,m,y,x,b,_,w,k,M,A,T,S=e.xaxis,C=e.yaxis,E=\"log\"===S.type,L=\"log\"===C.type,z=S._length,O=C._length,I=e.connectGaps,D=e.baseTolerance,P=e.shape,R=\"linear\"===P,F=[],B=f.minTolerance,N=new Array(t.length),j=0;function V(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=C.c2p(r.y);if(n===i){if(E&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(C._m*z*(C._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=C.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function U(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function q(t,e){var r=t[0]/z,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&U(r,n,A,T)&&(i=0),i&&e&&U(r,n,e[0]/z,e[1]/O)&&(i=0),(1+f.toleranceGrowth*i)*D}function H(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var G,W,Y,X,Z,$,J,K=f.maxScreensAway,Q=-z*K,tt=z*(1+K),et=-O*K,rt=O*(1+K),nt=[[Q,et,tt,et],[tt,et,tt,rt],[tt,rt,Q,rt],[Q,rt,Q,et]];function it(t){if(t[0]<Q||t[0]>tt||t[1]<et||t[1]>rt)return[u(t[0],Q,tt),u(t[1],et,rt)]}function at(t,e){return t[0]===e[0]&&(t[0]===Q||t[0]===tt)||(t[1]===e[1]&&(t[1]===et||t[1]===rt)||void 0)}function ot(t,e,r){return function(n,i){var a=it(n),o=it(i),s=[];if(a&&o&&at(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function st(t){var e=t[0],r=t[1],n=e===N[j-1][0],i=r===N[j-1][1];if(!n||!i)if(j>1){var a=e===N[j-2][0],o=r===N[j-2][1];n&&(e===Q||e===tt)&&a?o?j--:N[j-1]=t:i&&(r===et||r===rt)&&o?a?j--:N[j-1]=t:N[j++]=t}else N[j++]=t}function lt(t){N[j-1][0]!==t[0]&&N[j-1][1]!==t[1]&&st([Y,X]),st(t),Z=null,Y=X=0}function ct(t){if(A=t[0]/z,T=t[1]/O,G=t[0]<Q?Q:t[0]>tt?tt:0,W=t[1]<et?et:t[1]>rt?rt:0,G||W){if(j)if(Z){var e=J(Z,t);e.length>1&&(lt(e[0]),N[j++]=e[1])}else $=J(N[j-1],t)[0],N[j++]=$;else N[j++]=[G||t[0],W||t[1]];var r=N[j-1];G&&W&&(r[0]!==G||r[1]!==W)?(Z&&(Y!==G&&X!==W?st(Y&&X?(n=Z,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?Q:tt,rt]:[o>0?tt:Q,et]):[Y||G,X||W]):Y&&X&&st([Y,X])),st([G,W])):Y-G&&X-W&&st([G||Y,W||X]),Z=t,Y=G,X=W}else Z&&lt(J(Z,t)[0]),N[j++]=t;var n,i,a,o}for(\"linear\"===P||\"spline\"===P?J=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=nt[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&H(o,t)<H(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===P||\"vh\"===P?J=function(t,e){var r=[],n=it(t),i=it(e);return n&&i&&at(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===P?J=ot(0,Q,tt):\"vhv\"===P&&(J=ot(1,et,rt)),r=0;r<t.length;r++)if(n=V(r)){for(j=0,Z=null,ct(n),r++;r<t.length;r++){if(!(h=V(r))){if(I)continue;break}if(R&&e.simplify){var ut=V(r+1);if(!((y=H(h,n))<q(h,ut)*B)){for(v=[(h[0]-n[0])/y,(h[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=h,r++;r<t.length;r++){if(d=ut,ut=V(r+1),!d){if(I)continue;break}if(M=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,M),(k=Math.max(k,M))-w>q(d,ut))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,h=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ct(h),a!==p&&ct(p)):(p!==n&&ct(p),a!==h&&ct(h)),ct(a),r>=t.length||!d)break;ct(d),n=d}}else ct(h)}Z&&st([Y||Z[0],X||Z[1]]),F.push(N.slice(0,j))}return F}},{\"../../constants/numerical\":671,\"../../lib\":694,\"./constants\":1051}],1062:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1063:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,f=-1,h=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=h,h++):i.fill in n&&p>=0?l=p:(l=p=h,h++),l<f&&(u=!0),i._groupIndex=f=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1064:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":215}],1065:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),f=(t.line||{}).color;(c=c||{},f&&(r=f),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",f&&!Array.isArray(f)&&e.marker.color!==f?f:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":571,\"../../components/colorscale/defaults\":581,\"../../components/colorscale/helpers\":582,\"./subtypes\":1071}],1067:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),f=t(\"./link_traces\"),h=t(\"../../lib/polygon\").tester;function p(t,e,r,f,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),f=n.extent(a.simpleMap(l.range,l.r2c)),h=i[0].trace;if(!c.hasMarkers(h))return;var p=h.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=f[0]&&t.y<=f[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,f,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=f[0].trace,w=_.line,k=n.select(d),M=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),T=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,M,r,g),!0===_.visible){var C,E;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),r.isRangePlot||(f[0].node3=k);var z,O,I=\"\",D=[],P=_._prevtrace;P&&(I=P._prevRevpath||\"\",E=P._nextFill,D=P._polygons);var R,F,B,N,j,V,U,q=\"\",H=\"\",G=[],W=a.noop;if(C=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(E&&E.datum(f),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(f,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify}),U=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=h(G[v]);G.length&&(N=G[0][0],V=(j=G[G.length-1])[j.length-1]),W=function(t){return function(e){if(z=R(e),O=B(e),q?L?(q+=\"L\"+z.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+z,H=O+\"Z\"+H):(q=z,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(f),t)y(r.style(\"opacity\",0).attr(\"d\",z).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",z),l.singleLineStyle(f,i)}}}}}var Y=A.selectAll(\".js-line\").data(G);y(Y.exit()).style(\"opacity\",0).remove(),Y.each(W(!1)),Y.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(W(!0)),l.setClipUrl(Y,r.layerClipId,t),G.length?(C?(C.datum(f),N&&V&&(L?(\"y\"===L?N[1]=V[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=V[0]=x.c2p(0,!0)),y(C).attr(\"d\",\"M\"+V+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(C).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):E&&(\"tonext\"===_.fill.substr(0,6)&&q&&I?(\"tonext\"===_.fill?y(E).attr(\"d\",q+\"Z\"+I+\"Z\").call(l.singleFillStyle):y(E).attr(\"d\",q+\"L\"+I.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(D)):(Z(E),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=U):(C?Z(C):E&&Z(E),_._polygons=_._prevRevpath=_._prevPolygons=null),T.datum(f),S.datum(f),function(e,i,a){var o,u=a[0].trace,f=c.hasMarkers(u),h=c.hasText(u),p=tt(u),d=et,g=et;if(f||h){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?J:$:_&&!w&&(v=K),f&&(d=v),h&&(g=v)}var k,M=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&M.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),f&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(T,S,f);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(T,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function $(t){return t.filter(function(t){return!t.gap&&t.vis})}function J(t){return t.filter(function(t){return t.vis})}function K(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,h,d=!a,g=!!a&&a.duration>0,v=f(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(h=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){h&&h()}).each(\"interrupt\",function(){h&&h()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/polygon\":706,\"../../registry\":825,\"./line_points\":1061,\"./link_traces\":1063,\"./subtypes\":1071,d3:149}],1068:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],f=s[0].trace;if(!n.hasMarkers(f)&&!n.hasText(f))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1071}],1069:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var f={orientation:e.x&&!e.y?\"h\":\"v\"},h=0;h<n.length;h++){var p=n[h],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,f[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1070:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t,e){var r=e?e[0].node3:n.select(t).selectAll(\"g.trace.scatter\");r.style(\"opacity\",function(t){return t[0].trace.opacity}),r.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),r.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),r.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),r.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(r)},stylePoints:o,styleText:s,styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":592,\"../../registry\":825,d3:149}],1071:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":694}],1072:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":694}],1073:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":694,\"../../registry\":825}],1074:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../constants/gl3d_dashes\"),s=t(\"../../constants/gl3d_markers\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=n.line,f=n.marker,h=f.line,p=l({width:u.width,dash:{valType:\"enumerated\",values:Object.keys(o),dflt:\"solid\"}},i(\"line\"));var d=e.exports=c({x:n.x,y:n.y,z:{valType:\"data_array\"},text:l({},n.text,{}),hovertext:l({},n.hovertext,{}),mode:l({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:p,marker:l({symbol:{valType:\"enumerated\",values:Object.keys(s),dflt:\"circle\",arrayOk:!0},size:l({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:l({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:l({width:l({},h.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:l({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:l({},n.textfont.family,{arrayOk:!1})},hoverinfo:l({},a.hoverinfo)},\"calc\",\"nested\");d.x.editType=d.y.editType=d.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":578,\"../../constants/gl3d_dashes\":668,\"../../constants/gl3d_markers\":669,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739,\"../scatter/attributes\":1047}],1075:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1046,\"../scatter/colorscale_calc\":1050}],1076:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],f=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(f,!0)-c)*r],u>0){var h=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=h),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,h)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":825}],1077:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/make_bubble_size_func\"),h=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,h=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,M=e.marker,A=e.line,T=e.x||[],S=e.y||[],C=e.z||[],E=T.length,L=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<E;o++)r=v.d2l(T[o],0,L)*g[0],n=w.d2l(S[o],0,z)*g[1],i=k.d2l(C[o],0,O)*g[2],h[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(E),o=0;o<E;o++)s[o]=e.text;if(a={position:h,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,E),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var I=f(e);a.scatterColor=u(M,1,E),a.scatterSize=_(M.size,E,x,20,I),a.scatterMarker=_(M.symbol,E,b,\"\\u25cf\"),a.scatterLineWidth=M.line.width,a.scatterLineColor=u(M.line,1,E),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,E),a.textSize=_(e.textfont.size,E,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var D=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var P=e.projection[D[o]];(a.project[o]=P.show)&&(a.projectOpacity[o]=P.opacity,a.projectScale[o]=P.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,f=h.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in h&&(f=h[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:u,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:f[0],dashScale:f[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:u,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:u,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:u,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var f=u[n],h=0;h<f.length;++h)f[h]=l[f[h]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":668,\"../../constants/gl3d_markers\":669,\"../../lib\":694,\"../../lib/gl_format_color\":691,\"../../lib/str2rgbarray\":717,\"../scatter/make_bubble_size_func\":1064,\"./calc_errors\":1076,\"delaunay-triangulate\":151,\"gl-error3d\":238,\"gl-line3d\":246,\"gl-mesh3d\":270,\"gl-scatter3d\":286}],1078:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,f,u)){f(\"text\"),f(\"hovertext\"),f(\"mode\"),a.hasLines(e)&&(f(\"connectgaps\"),s(t,e,r,u,f)),a.hasMarkers(e)&&o(t,e,r,u,f,{noSelect:!0}),a.hasText(e)&&l(t,e,u,f,{noSelect:!0});var h=(e.line||{}).color,p=(e.marker||{}).color;f(\"surfaceaxis\")>=0&&f(\"surfacecolor\",h||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];f(v+\".show\")&&(f(v+\".opacity\"),f(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,h||p||r,{axis:\"z\"}),m(t,e,h||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,h||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":694,\"../../registry\":825,\"../scatter/line_defaults\":1060,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"./attributes\":1074}],1079:[function(t,e,r){\"use strict\";var n={};n.plot=t(\"./convert\"),n.attributes=t(\"./attributes\"),n.markerSymbols=t(\"../../constants/gl3d_markers\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],n.calc=t(\"./calc\"),n.moduleType=\"trace\",n.name=\"scatter3d\",n.basePlotModule=t(\"../../plots/gl3d\"),n.categories=[\"gl3d\",\"symbols\",\"showLegend\"],n.meta={},e.exports=n},{\"../../constants/gl3d_markers\":669,\"../../plots/gl3d\":785,\"./attributes\":1074,\"./calc\":1075,\"./convert\":1077,\"./defaults\":1078}],1080:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/colorbar/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},a(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},a(\"marker\"),{colorbar:o}),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron}},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../scatter/attributes\":1047}],1081:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,f,h=e._length,p=new Array(h),d=!1;for(c=0;c<h;c++)if(u=e.a[c],f=e.b[c],n(u)&&n(f)){var g=r.ab2xy(+u,+f,!0),v=r.isVisible(+u,+f);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:f,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,h),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":893,\"../scatter/arrays_to_calcdata\":1046,\"../scatter/calc\":1048,\"../scatter/calc_selection\":1049,\"../scatter/colorscale_calc\":1050,\"fast-isnumeric\":215}],1082:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),p(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":694,\"../scatter/constants\":1051,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/line_shape_defaults\":1062,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"./attributes\":1080}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var f=o.cd[o.index];o.a=f.a,o.b=f.b,o.xLabelVal=void 0,o.yLabelVal=void 0;var h=o.trace,p=h._carpet,d=(f.hi||h.hoverinfo).split(\"+\"),g=[];-1!==d.indexOf(\"all\")&&(d=[\"a\",\"b\"]),-1!==d.indexOf(\"a\")&&w(p.aaxis,f.a),-1!==d.indexOf(\"b\")&&w(p.baxis,f.b);var v=p.ab2ij([f.a,f.b]),m=Math.floor(v[0]),y=v[0]-m,x=Math.floor(v[1]),b=v[1]-x,_=p.evalxy([],m,x,y,b);return g.push(\"y: \"+_[1].toFixed(3)),o.extraText=g.join(\"<br>\"),a}function w(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,g.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../scatter/hover\":1058}],1085:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=t(\"../scatter/marker_colorbar\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.style=t(\"../scatter/style\").style,n.styleOnSelect=t(\"../scatter/style\").styleOnSelect,n.hoverPoints=t(\"./hover\"),n.selectPoints=t(\"../scatter/select\"),n.eventData=t(\"./event_data\"),n.moduleType=\"trace\",n.name=\"scattercarpet\",n.basePlotModule=t(\"../../plots/cartesian\"),n.categories=[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],n.meta={},e.exports=n},{\"../../plots/cartesian\":754,\"../scatter/marker_colorbar\":1065,\"../scatter/select\":1068,\"../scatter/style\":1070,\"./attributes\":1080,\"./calc\":1081,\"./defaults\":1082,\"./event_data\":1083,\"./hover\":1084,\"./plot\":1086}],1086:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,f={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,f,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,u._clipPathId,t)}},{\"../../components/drawing\":592,\"../../plots/cartesian/axes\":742,\"../scatter/plot\":1067}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,f=i.line,h=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:f.color,width:f.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:h.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":578,\"../../components/drawing/attributes\":591,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739,\"../scatter/attributes\":1047}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),f=0;f<c;f++){var h=u[f]={};if(r){var p=e.locations[f];h.loc=\"string\"==typeof p?p:null}else{var d=e.lon[f],g=e.lat[f];n(d)&&n(g)?h.lonlat=[+d,+g]:h.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../scatter/arrays_to_calcdata\":1046,\"../scatter/calc_selection\":1049,\"../scatter/colorscale_calc\":1050,\"fast-isnumeric\":215}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,f)?e.visible=!1:(f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f),f(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,f,{gradient:!0}),i.hasText(e)&&s(t,e,u,f),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f))}},{\"../../lib\":694,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"./attributes\":1087}],1090:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../scatter/fill_hover_text\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.xa,h=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[f.c2p(m),h.c2p(m)],x=v.mrc||1;return t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1],t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var a=e.hi||t.hoverinfo,o=\"all\"===a?l.hoverinfo.flags:a.split(\"+\"),c=-1!==o.indexOf(\"location\")&&Array.isArray(t.locations),u=-1!==o.indexOf(\"lon\"),f=-1!==o.indexOf(\"lat\"),h=-1!==o.indexOf(\"text\"),p=[];function d(t){return i.tickText(r,r.c2l(t),\"hover\").text+\"\\xb0\"}c?p.push(e.loc):u&&f?p.push(\"(\"+d(e.lonlat[0])+\", \"+d(e.lonlat[1])+\")\"):u?p.push(n.lon+d(e.lonlat[0])):f&&p.push(n.lat+d(e.lonlat[1]));h&&s(e,t,p);return p.join(\"<br>\")}(u,v,p.mockAxis,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":610,\"../../constants/numerical\":671,\"../../plots/cartesian/axes\":742,\"../scatter/fill_hover_text\":1055,\"../scatter/get_trace_color\":1057,\"./attributes\":1087}],1092:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=t(\"../scatter/marker_colorbar\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.style=t(\"./style\"),n.styleOnSelect=t(\"../scatter/style\").styleOnSelect,n.hoverPoints=t(\"./hover\"),n.eventData=t(\"./event_data\"),n.selectPoints=t(\"./select\"),n.moduleType=\"trace\",n.name=\"scattergeo\",n.basePlotModule=t(\"../../plots/geo\"),n.categories=[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],n.meta={},e.exports=n},{\"../../plots/geo\":773,\"../scatter/marker_colorbar\":1065,\"../scatter/style\":1070,\"./attributes\":1087,\"./calc\":1088,\"./defaults\":1089,\"./event_data\":1090,\"./hover\":1091,\"./plot\":1093,\"./select\":1094,\"./style\":1095}],1093:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function f(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)f(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var h=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(h,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=e[0].node3=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),f=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:f,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../lib/geo_location_utils\":687,\"../../lib/geojson_utils\":688,\"../../lib/topojson_utils\":721,\"../scatter/subtypes\":1071,\"./style\":1095,d3:149}],1094:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,f=t.yaxis,h=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=f.c2p(a),e.contains([o,s],null,l,t)?(h.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return h}},{\"../../constants/numerical\":671,\"../scatter/subtypes\":1071}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../scatter/style\":1070,d3:149}],1096:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,f=u.line,h=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:f.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");h.x.editType=h.y.editType=h.x0.editType=h.y0.editType=\"calc+clearAxisTypes\",h.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739,\"../scatter/attributes\":1047,\"./constants\":1097}],1097:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1098:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/subtypes\"),h=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var f=o[e].split(/\\s+/);switch(f[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(f[1])}switch(f[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(f[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var h=u.font[e]={};h.size=Array.isArray(l)?n(l[e])?l[e]:0:l,h.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),f=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||f||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=T(i.symbol[e]);else o.marker=T(i.symbol);var w,k=h(t);if(g||v){var M,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),C=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),C+=A[e];M=C/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=M}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,M={},A=l.symbolFuncs[0](.05*w);function T(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return M[t]?M[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),M[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),f.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=d):(h=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),f=r.length/2,h={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*f),d=1/0,g=-1/0,v=0,m=0;v<f;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,M=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(M)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}h[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),h},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,h=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/h,x/h]}}return o}}},{\"../../components/drawing\":592,\"../../constants/interactions\":670,\"../../lib\":694,\"../../lib/gl_format_color\":691,\"../../plots/cartesian/axis_ids\":745,\"../../registry\":825,\"../scatter/make_bubble_size_func\":1064,\"../scatter/subtypes\":1071,\"./constants\":1097,\"color-normalize\":109,\"fast-isnumeric\":215,\"svg-path-sdf\":513}],1099:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),f=t(\"../scatter/fillcolor_defaults\"),h=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&h(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&f(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":694,\"../../registry\":825,\"../scatter/constants\":1051,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"../scatter/xy_defaults\":1073,\"./attributes\":1096}],1100:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"point-cluster\"),s=t(\"array-range\"),l=t(\"gl-text\"),c=t(\"../../registry\"),u=t(\"../../lib\"),f=t(\"../../lib/prepare_regl\"),h=t(\"../../plots/cartesian/axis_ids\"),p=t(\"../../plots/cartesian/autorange\").findExtremes,d=t(\"../../components/color\"),g=t(\"../scatter/subtypes\"),v=t(\"../scatter/calc\"),m=v.calcMarkerSize,y=v.calcAxisExpansion,x=v.setFirstScatter,b=t(\"../scatter/colorscale_calc\"),_=t(\"../scatter/link_traces\"),w=t(\"../scatter/get_trace_color\"),k=t(\"../scatter/fill_hover_text\"),M=t(\"./convert\"),A=t(\"../../constants/numerical\").BADNUM,T=t(\"./constants\").TOO_MANY_POINTS,S=t(\"../../constants/interactions\").DESELECTDIM;function C(t,e,r){var n=t._extremes[e._id],i=p(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}function E(t,e){var r=e._scene,n={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[]},i={selectBatch:null,unselectBatch:null,fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:null};return e._scene||((r=e._scene={}).init=function(){u.extendFlat(r,i,n)},r.init(),r.update=function(t){var e=u.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var n=0;n<r.count;n++)r.glText[n].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,n=r.error2d,i=r.line2d,a=r.scatter2d,o=r.glText,s=r.select2d,l=r.selectBatch,c=r.unselectBatch,u=0;u<t;u++)e&&r.fillOrder[u]&&e.draw(r.fillOrder[u]),i&&r.lineOptions[u]&&i.draw(u),n&&(r.errorXOptions[u]&&n.draw(u),r.errorYOptions[u]&&n.draw(u+t)),!a||!r.markerOptions[u]||l&&l[u]||a.draw(u),o[u]&&r.textOptions[u]&&o[u].render();a&&s&&l&&(s.draw(l),a.draw(c)),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||u.extendFlat(r,n),r}function L(t,e,r,n){var i=t.xa,a=t.ya,o=t.distance,s=t.dxy,l=t.index,f={pointNumber:l,x:e[l],y:r[l]};f.tx=Array.isArray(n.text)?n.text[l]:n.text,f.htx=Array.isArray(n.hovertext)?n.hovertext[l]:n.hovertext,f.data=Array.isArray(n.customdata)?n.customdata[l]:n.customdata,f.tp=Array.isArray(n.textposition)?n.textposition[l]:n.textposition;var h=n.textfont;h&&(f.ts=Array.isArray(h.size)?h.size[l]:h.size,f.tc=Array.isArray(h.color)?h.color[l]:h.color,f.tf=Array.isArray(h.family)?h.family[l]:h.family);var p=n.marker;p&&(f.ms=u.isArrayOrTypedArray(p.size)?p.size[l]:p.size,f.mo=u.isArrayOrTypedArray(p.opacity)?p.opacity[l]:p.opacity,f.mx=Array.isArray(p.symbol)?p.symbol[l]:p.symbol,f.mc=u.isArrayOrTypedArray(p.color)?p.color[l]:p.color);var d=p&&p.line;d&&(f.mlc=Array.isArray(d.color)?d.color[l]:d.color,f.mlw=u.isArrayOrTypedArray(d.width)?d.width[l]:d.width);var g=p&&p.gradient;g&&\"none\"!==g.type&&(f.mgt=Array.isArray(g.type)?g.type[l]:g.type,f.mgc=Array.isArray(g.color)?g.color[l]:g.color);var v=i.c2p(f.x,!0),m=a.c2p(f.y,!0),y=f.mrc||1,x=n.hoverlabel;x&&(f.hbg=Array.isArray(x.bgcolor)?x.bgcolor[l]:x.bgcolor,f.hbc=Array.isArray(x.bordercolor)?x.bordercolor[l]:x.bordercolor,f.hts=Array.isArray(x.font.size)?x.font.size[l]:x.font.size,f.htc=Array.isArray(x.font.color)?x.font.color[l]:x.font.color,f.htf=Array.isArray(x.font.family)?x.font.family[l]:x.font.family,f.hnl=Array.isArray(x.namelength)?x.namelength[l]:x.namelength);var b=n.hoverinfo;b&&(f.hi=Array.isArray(b)?b[l]:b);var _=n.hovertemplate;_&&(f.ht=Array.isArray(_)?_[l]:_);var M={};return M[t.index]=f,u.extendFlat(t,{color:w(n,f),x0:v-y,x1:v+y,xLabelVal:f.x,y0:m-y,y1:m+y,yLabelVal:f.y,cd:M,distance:o,spikeDistance:s,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:n.text&&(t.text=n.text),k(f,n,t),c.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,n,t),t}function z(t){var e,r,n=t[0],i=n.trace,a=n.t,o=a._scene,s=a.index,l=o.selectBatch[s],c=o.unselectBatch[s],f=o.textOptions[s],h=o.textSelectedOptions[s]||{},p=o.textUnselectedOptions[s]||{},g=u.extendFlat({},f);if(l&&c){var v=h.color,m=p.color,y=f.color,x=Array.isArray(y);for(g.color=new Array(i._length),e=0;e<l.length;e++)r=l[e],g.color[r]=v||(x?y[r]:y);for(e=0;e<c.length;e++){r=c[e];var b=x?y[r]:y;g.color[r]=m||(v?b:d.addOpacity(b,S))}}o.glText[s].update(g)}e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:function(t,e){var r,n,i,a=t._fullLayout,s=h.getFromId(t,e.xaxis),l=h.getFromId(t,e.yaxis),c=a._plots[e.xaxis+e.yaxis],f=e._length,p=2*f,d={},g=s.makeCalcdata(e,\"x\"),v=l.makeCalcdata(e,\"y\"),_=new Array(p);for(r=0;r<f;r++)n=g[r],i=v[r],_[2*r]=n===A?NaN:n,_[2*r+1]=i===A?NaN:i;if(\"log\"===s.type)for(r=0;r<p;r+=2)_[r]=s.c2l(_[r]);if(\"log\"===l.type)for(r=1;r<p;r+=2)_[r]=l.c2l(_[r]);if(\"log\"!==s.type&&\"log\"!==l.type)d.tree=o(_);else{var w=d.ids=new Array(f);for(r=0;r<f;r++)w[r]=r}b(t,e);var k,S=function(t,e,r,n,i,a){var o=M.style(t,r);if(o.marker&&(o.marker.positions=n),o.line&&n.length>1&&u.extendFlat(o.line,M.linePositions(t,r,n)),o.errorX||o.errorY){var s=M.errorBarPositions(t,r,n,i,a);o.errorX&&u.extendFlat(o.errorX,s.x),o.errorY&&u.extendFlat(o.errorY,s.y)}return o.text&&(u.extendFlat(o.text,{positions:n},M.textPosition(t,r,o.text,o.marker)),u.extendFlat(o.textSel,{positions:n},M.textPosition(t,r,o.text,o.markerSel)),u.extendFlat(o.textUnsel,{positions:n},M.textPosition(t,r,o.text,o.markerUnsel))),o}(t,0,e,_,g,v),L=E(0,c);return x(a,e),f<T?k=m(e,f):S.marker&&(k=2*(S.marker.sizeAvg||Math.max(S.marker.size,3))),y(t,e,s,l,g,v,k),S.errorX&&C(e,s,S.errorX),S.errorY&&C(e,l,S.errorY),S.fill&&!L.fill2d&&(L.fill2d=!0),S.marker&&!L.scatter2d&&(L.scatter2d=!0),S.line&&!L.line2d&&(L.line2d=!0),!S.errorX&&!S.errorY||L.error2d||(L.error2d=!0),S.text&&!L.glText&&(L.glText=!0),S.marker&&f>=T&&(S.marker.cluster=d.tree),L.lineOptions.push(S.line),L.errorXOptions.push(S.errorX),L.errorYOptions.push(S.errorY),L.fillOptions.push(S.fill),L.markerOptions.push(S.marker),L.markerSelectedOptions.push(S.markerSel),L.markerUnselectedOptions.push(S.markerUnsel),L.textOptions.push(S.text),L.textSelectedOptions.push(S.textSel),L.textUnselectedOptions.push(S.textUnsel),d._scene=L,d.index=L.count,d.x=g,d.y=v,d.positions=_,L.count++,[{x:!1,y:!1,t:d,trace:e}]},plot:function(t,e,r){if(r.length){var o,s,c=t._fullLayout,h=e._scene,p=e.xaxis,d=e.yaxis;if(h)if(f(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var g=c._glcanvas.data()[0].regl;if(_(t,e,r),h.dirty){if(!0===h.error2d&&(h.error2d=a(g)),!0===h.line2d&&(h.line2d=i(g)),!0===h.scatter2d&&(h.scatter2d=n(g)),!0===h.fill2d&&(h.fill2d=i(g)),!0===h.glText)for(h.glText=new Array(h.count),o=0;o<h.count;o++)h.glText[o]=new l(g);if(h.glText)for(o=0;o<h.count;o++)h.glText[o].update(h.textOptions[o]);if(h.line2d&&(h.line2d.update(h.lineOptions),h.lineOptions=h.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),h.line2d.update(h.lineOptions)),h.error2d){var v=(h.errorXOptions||[]).concat(h.errorYOptions||[]);h.error2d.update(v)}h.scatter2d&&h.scatter2d.update(h.markerOptions),h.fillOrder=u.repeat(null,h.count),h.fill2d&&(h.fillOptions=h.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=h.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(h.fillOrder[e]=u);var f,p,d=[],g=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(f=0;f<g.length&&isNaN(g[f+1]);)f+=2;for(p=g.length-2;p>f&&isNaN(g[p+1]);)p-=2;0!==g[f+1]&&(d=[g[f],0]),d=d.concat(g.slice(f,p+2)),0!==g[p+1]&&(d=d.concat([g[p],0]))}else if(\"tozerox\"===s.fill){for(f=0;f<g.length&&isNaN(g[f]);)f+=2;for(p=g.length-2;p>f&&isNaN(g[p]);)p-=2;0!==g[f]&&(d=[0,g[f+1]]),d=d.concat(g.slice(f,p+2)),0!==g[p]&&(d=d.concat([0,g[p+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(d=[],i=0,a=0;a<g.length;a+=2)(isNaN(g[a])||isNaN(g[a+1]))&&((d=d.concat(g.slice(i,a))).push(g[i],g[i+1]),i=a+2);d=d.concat(g.slice(i)),i&&d.push(g[i],g[i+1])}else{var v=s._nexttrace;if(v){var m=h.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(d=g.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||d.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=h.lineOptions[e-1].positions,w=d.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);d=d.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=d,t}}),h.fill2d.update(h.fillOptions))}h.selectBatch=null,h.unselectBatch=null;var m=c.dragmode,y=\"lasso\"===m||\"select\"===m,x=c.clickmode.indexOf(\"select\")>-1;for(o=0;o<r.length;o++){var b=r[o][0],w=b.trace,k=b.t,M=k.index,A=w._length,T=k.x,S=k.y;if(w.selectedpoints||y||x){if(y||(y=!0),h.selectBatch||(h.selectBatch=[],h.unselectBatch=[]),w.selectedpoints){var C=h.selectBatch[M]=u.selIndices2selPoints(w),E={};for(s=0;s<C.length;s++)E[C[s]]=1;var L=[];for(s=0;s<A;s++)E[s]||L.push(s);h.unselectBatch[M]=L}var O=k.xpx=new Array(A),I=k.ypx=new Array(A);for(s=0;s<A;s++)O[s]=p.c2p(T[s]),I[s]=d.c2p(S[s])}else k.xpx=k.ypx=null}y?(h.select2d||(h.select2d=n(c._glcanvas.data()[1].regl)),h.scatter2d&&h.selectBatch&&h.selectBatch.length&&h.scatter2d.update(h.markerUnselectedOptions.map(function(t,e){return h.selectBatch[e]?t:null})),h.select2d&&(h.select2d.update(h.markerOptions),h.select2d.update(h.markerSelectedOptions)),h.glText&&r.forEach(function(t){t&&t[0]&&t[0].trace&&z(t)})):h.scatter2d&&h.scatter2d.update(h.markerOptions);var D={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(c,p,d),range:[(p._rl||p.range)[0],(d._rl||d.range)[0],(p._rl||p.range)[1],(d._rl||d.range)[1]]},P=u.repeat(D,h.count);h.fill2d&&h.fill2d.update(P),h.line2d&&h.line2d.update(P),h.error2d&&h.error2d.update(P.concat(P)),h.scatter2d&&h.scatter2d.update(P),h.select2d&&h.select2d.update(P),h.glText&&h.glText.forEach(function(t){t.update(D)})}else h.init()}},hoverPoints:function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p=t.cd,d=p[0].t,g=p[0].trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=v.c2p(e),_=m.c2p(r),w=t.distance;if(d.tree){var k=v.p2c(b-w),M=v.p2c(b+w),A=m.p2c(_-w),T=m.p2c(_+w);i=\"x\"===n?d.tree.range(Math.min(k,M),Math.min(m._rl[0],m._rl[1]),Math.max(k,M),Math.max(m._rl[0],m._rl[1])):d.tree.range(Math.min(k,M),Math.min(A,T),Math.max(k,M),Math.max(A,T))}else{if(!d.ids)return[t];i=d.ids}var S=w;if(\"x\"===n)for(l=0;l<i.length;l++)o=y[i[l]],(c=Math.abs(v.c2p(o)-b))<S&&(S=c,u=m.c2p(x[i[l]])-_,h=Math.sqrt(c*c+u*u),a=i[l]);else for(l=0;l<i.length;l++)o=y[i[l]],s=x[i[l]],c=v.c2p(o)-b,u=m.c2p(s)-_,(f=Math.sqrt(c*c+u*u))<S&&(S=h=f,a=i[l]);return t.index=a,t.distance=S,t.dxy=h,void 0===a?[t]:(L(t,y,x,g),[t])},selectPoints:function(t,e){var r=t.cd,n=[],i=r[0].trace,a=r[0].t,o=i._length,l=a.x,c=a.y,u=a._scene;if(!u)return n;var f=g.hasText(i),h=g.hasMarkers(i),p=!h&&!f;if(!0!==i.visible||p)return n;var d,v=null,m=null;if(!1===e||e.degenerate)m=s(o);else for(v=[],m=[],d=0;d<o;d++)e.contains([a.xpx[d],a.ypx[d]],!1,d,t)?(v.push(d),n.push({pointNumber:d,x:l[d],y:c[d]})):m.push(d);if(u.selectBatch||(u.selectBatch=[],u.unselectBatch=[]),!u.selectBatch[a.index]){for(d=0;d<u.count;d++)u.selectBatch[d]=[],u.unselectBatch[d]=[];h&&u.scatter2d.update(u.markerUnselectedOptions)}return u.selectBatch[a.index]=v,u.unselectBatch[a.index]=m,f&&z(r),n},sceneUpdate:E,calcHover:L,meta:{}}},{\"../../components/color\":571,\"../../constants/interactions\":670,\"../../constants/numerical\":671,\"../../lib\":694,\"../../lib/prepare_regl\":707,\"../../plots/cartesian\":754,\"../../plots/cartesian/autorange\":741,\"../../plots/cartesian/axis_ids\":745,\"../../registry\":825,\"../scatter/calc\":1048,\"../scatter/colorscale_calc\":1050,\"../scatter/cross_trace_defaults\":1053,\"../scatter/fill_hover_text\":1055,\"../scatter/get_trace_color\":1057,\"../scatter/link_traces\":1063,\"../scatter/marker_colorbar\":1065,\"../scatter/subtypes\":1071,\"./attributes\":1096,\"./constants\":1097,\"./convert\":1098,\"./defaults\":1099,\"array-range\":56,\"gl-text\":307,\"point-cluster\":455,\"regl-error2d\":476,\"regl-line2d\":477,\"regl-scatter2d\":478}],1101:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorbar/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,f=i.line,h=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:f.color,width:f.width},connectgaps:a.connectgaps,marker:{symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:h.opacity,size:h.size,sizeref:h.sizeref,sizemin:h.sizemin,sizemode:h.sizemode,color:h.color,colorscale:h.colorscale,cauto:h.cauto,cmax:h.cmax,cmin:h.cmin,autocolorscale:h.autocolorscale,reversescale:h.reversescale,showscale:h.showscale,colorbar:l},fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorbar/attributes\":572,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739,\"../../plots/mapbox/layout_attributes\":802,\"../scatter/attributes\":1047,\"../scattergeo/attributes\":1087}],1102:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),f=t(\"../../plots/mapbox/convert_text_opts\");function h(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=h(),k=h(),M=h(),A=h(),T={fill:w,line:k,circle:M,symbol:A};if(!a)return T;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,f=u.marker,h=u.selectedpoints,p=i.isArrayOrTypedArray(f.color),d=i.isArrayOrTypedArray(f.size),v=i.isArrayOrTypedArray(f.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFunc(s.extractScale(f,{cLetter:\"c\"})):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),h&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(h)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:f.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(M=f.size,M/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(f.opacity)};var M}(t);M.geojson=S.geojson,M.layout.visibility=\"visible\",i.extendFlat(M.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var C=(r.marker||{}).size,E=f(r.textposition,C);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":E.anchor,\"text-offset\":E.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return T}},{\"../../components/colorscale\":583,\"../../components/drawing\":592,\"../../constants/numerical\":671,\"../../lib\":694,\"../../lib/geojson_utils\":688,\"../../plots/mapbox/convert_text_opts\":799,\"../scatter/make_bubble_size_func\":1064,\"../scatter/subtypes\":1071,\"fast-isnumeric\":215}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f)){if(f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f,{noDash:!0}),f(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,f,{noLine:!0});var h=e.marker;\"circle\"!==h.symbol&&(n.isArrayOrTypedArray(h.size)&&(h.size=h.size[0]),n.isArrayOrTypedArray(h.color)&&(h.color=h.color[0]))}i.hasText(e)&&s(t,e,u,f,{noSelect:!0}),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":694,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"./attributes\":1101}],1104:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1105:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=t(\"../scatter/fill_hover_text\"),s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=h.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-f.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=f.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":610,\"../../constants/numerical\":671,\"../../lib\":694,\"../scatter/fill_hover_text\":1055,\"../scatter/get_trace_color\":1057}],1106:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=t(\"../scatter/marker_colorbar\"),n.calc=t(\"../scattergeo/calc\"),n.plot=t(\"./plot\"),n.hoverPoints=t(\"./hover\"),n.eventData=t(\"./event_data\"),n.selectPoints=t(\"./select\"),n.style=function(t,e){e&&e[0].trace._glTrace.update(e)},n.moduleType=\"trace\",n.name=\"scattermapbox\",n.basePlotModule=t(\"../../plots/mapbox\"),n.categories=[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],n.meta={},e.exports=n},{\"../../plots/mapbox\":800,\"../scatter/marker_colorbar\":1065,\"../scattergeo/calc\":1088,\"./attributes\":1101,\"./defaults\":1103,\"./event_data\":1104,\"./hover\":1105,\"./plot\":1107,\"./select\":1108}],1107:[function(t,e,r){\"use strict\";var n=t(\"./convert\");function i(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:e+\"-source-fill\",line:e+\"-source-line\",circle:e+\"-source-circle\",symbol:e+\"-source-symbol\"},this.layerIds={fill:e+\"-layer-fill\",line:e+\"-layer-line\",circle:e+\"-layer-circle\",symbol:e+\"-layer-symbol\"},this.order=[\"fill\",\"line\",\"circle\",\"symbol\"]}var a=i.prototype;a.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},a.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},a.addLayer=function(t,e){this.subplot.map.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint})},a.update=function(t){for(var e=this.subplot,r=n(t),i=0;i<this.order.length;i++){var a=this.order[i],o=r[a];e.setOptions(this.layerIds[a],\"setLayoutProperty\",o.layout),\"visible\"===o.layout.visibility&&(this.setSourceData(a,o),e.setOptions(this.layerIds[a],\"setPaintProperty\",o.paint))}t[0].trace._glTrace=this},a.dispose=function(){for(var t=this.subplot.map,e=0;e<this.order.length;e++){var r=this.order[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=new i(t,e[0].trace.uid),a=n(e),o=0;o<r.order.length;o++){var s=r.order[o],l=a[s];r.addSource(s,l),r.addLayer(s,l)}return e[0].trace._glTrace=r,r}},{\"./convert\":1102}],1108:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var f=o[r],h=f.lonlat;if(h[0]!==a){var p=[n.modHalf(h[0],360),h[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:h[0],lat:h[1]}),f.selected=1):f.selected=0}}return c}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../scatter/subtypes\":1071}],1109:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../scatter/attributes\":1047}],1110:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,f=r[u].radialaxis,h=r[u].angularaxis,p=f.makeCalcdata(e,\"r\"),d=h.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(f,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":671,\"../../plots/cartesian/axes\":742,\"../scatter/arrays_to_calcdata\":1046,\"../scatter/calc\":1048,\"../scatter/calc_selection\":1049,\"../scatter/colorscale_calc\":1050,\"fast-isnumeric\":215}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");function h(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:h,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,f,r,i)}var g=h(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":694,\"../scatter/constants\":1051,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/line_shape_defaults\":1062,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"./attributes\":1109}],1112:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+i.tickText(t,e,\"hover\").text)}if(!e.hovertemplate){var f=l.split(\"+\");if(-1!==f.indexOf(\"all\")&&(f=[\"r\",\"theta\",\"text\"]),-1!==f.indexOf(\"r\")&&u(o,o.c2l(t.r)),-1!==f.indexOf(\"theta\")){var h=t.theta;u(s,\"degrees\"===s.thetaunit?a.rad2deg(h):h)}-1!==f.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../scatter/hover\":1058}],1113:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":809,\"../scatter/marker_colorbar\":1065,\"../scatter/select\":1068,\"../scatter/style\":1070,\"./attributes\":1109,\"./calc\":1110,\"./defaults\":1111,\"./hover\":1112,\"./plot\":1114}],1114:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],f=0;f<u.length;f++){var h=u[f],p=h.r;if(p===i)h.x=h.y=i;else{var d=s.c2g(p),g=l.c2g(h.theta);h.x=d*Math.cos(g),h.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":671,\"../scatter/plot\":1067}],1115:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1096,\"../scatterpolar/attributes\":1109}],1116:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d=a(t,e,h,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,h,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,h,p),i.hasText(e)&&l(t,e,h,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":694,\"../scatter/constants\":1051,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"../scatterpolar/defaults\":1111,\"./attributes\":1115}],1117:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../scattergl/convert\"),c=t(\"../../lib\"),u=t(\"../../plots/cartesian/axes\"),f=t(\"../scatterpolar/hover\").makeHoverPointText,h=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:function(t,e){var r=t._fullLayout,n=e.subplot,i=r[n].radialaxis,a=r[n].angularaxis,c=i.makeCalcdata(e,\"r\"),f=a.makeCalcdata(e,\"theta\"),p=e._length,d={};p<c.length&&(c=c.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=c,d.theta=f,o(t,e);var g,v=d.opts=l.style(t,e);return p<h?g=s(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=u.findExtremes(i,c,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]},plot:function(t,e,r){if(r.length){var o=e.radialAxis,s=e.angularAxis,u=a.sceneUpdate(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,f=r[0],p=f.trace,d=f.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var M,A,T=x[a];if(i(T)){var S=o.c2g(T),C=s.c2g(b[a],p.thetaunit);M=S*Math.cos(C),A=S*Math.sin(C)}else M=A=NaN;w[a]=_[2*a]=M,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=h&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&c.extendFlat(y.line,l.linePositions(t,p,_)),y.text&&(c.extendFlat(y.text,{positions:_},l.textPosition(t,p,y.text,y.marker)),c.extendFlat(y.textSel,{positions:_},l.textPosition(t,p,y.text,y.markerSel)),c.extendFlat(y.textUnsel,{positions:_},l.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!u.fill2d&&(u.fill2d=!0),y.marker&&!u.scatter2d&&(u.scatter2d=!0),y.line&&!u.line2d&&(u.line2d=!0),y.text&&!u.glText&&(u.glText=!0),u.lineOptions.push(y.line),u.fillOptions.push(y.fill),u.markerOptions.push(y.marker),u.markerSelectedOptions.push(y.markerSel),u.markerUnselectedOptions.push(y.markerUnsel),u.textOptions.push(y.text),u.textSelectedOptions.push(y.textSel),u.textUnselectedOptions.push(y.textUnsel),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=u,d.index=u.count,u.count++}}),a.plot(t,e,r)}},hoverPoints:function(t,e,r,n){var i=t.cd[0].t,o=i.r,s=i.theta,l=a.hoverPoints(t,e,r,n);if(l&&!1!==l[0].index){var c=l[0];if(void 0===c.index)return l;var u=t.subplot,h=c.cd[c.index],p=c.trace;if(h.r=o[c.index],h.theta=s[c.index],u.isPtInside(h))return c.xLabelVal=void 0,c.yLabelVal=void 0,f(h,p,u,c),l}},selectPoints:a.selectPoints,meta:{}}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../../plots/polar\":809,\"../scatter/calc\":1048,\"../scatter/colorscale_calc\":1050,\"../scatter/marker_colorbar\":1065,\"../scattergl\":1100,\"../scattergl/constants\":1097,\"../scattergl/convert\":1098,\"../scatterpolar/hover\":1112,\"./attributes\":1115,\"./defaults\":1116,\"fast-isnumeric\":215,\"point-cluster\":455}],1118:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/colorbar/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=i.marker,f=i.line,h=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},i.mode,{dflt:\"markers\"}),text:c({},i.text,{}),hovertext:c({},i.hovertext,{}),line:{color:f.color,width:f.width,dash:l,shape:c({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:c({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},o(\"marker\"),{colorbar:s}),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:c({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../components/drawing/attributes\":591,\"../../components/fx/hovertemplate_attributes\":609,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../scatter/attributes\":1047}],1119:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,f,h,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[f=l[r]]){for(p=m[c[f][0]],d=m[c[f][1]],h=new Array(p.length),u=0;u<p.length;u++)h[u]=v-p[u]-d[u];m[f]=h}var y,x,b,_,w,k,M=e._length,A=new Array(M);for(r=0;r<M;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,M),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1046,\"../scatter/calc\":1048,\"../scatter/calc_selection\":1049,\"../scatter/colorscale_calc\":1050,\"fast-isnumeric\":215}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":694,\"../scatter/constants\":1051,\"../scatter/fillcolor_defaults\":1056,\"../scatter/line_defaults\":1060,\"../scatter/line_shape_defaults\":1062,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"../scatter/text_defaults\":1072,\"./attributes\":1118}],1121:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1122:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,f=c-u;return s.x0=Math.max(Math.min(s.x0,f),u),s.x1=Math.max(Math.min(s.x1,f),u),o}var h=s.cd[s.index];s.a=h.a,s.b=h.b,s.c=h.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=s.subplot,g=h.hi||p.hoverinfo,v=[];if(!p.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(d.aaxis,h.a),-1!==m.indexOf(\"b\")&&y(d.baxis,h.b),-1!==m.indexOf(\"c\")&&y(d.caxis,h.c)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=p.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+i.tickText(t,e,\"hover\").text)}}},{\"../../plots/cartesian/axes\":742,\"../scatter/hover\":1058}],1123:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar=t(\"../scatter/marker_colorbar\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.style=t(\"../scatter/style\").style,n.styleOnSelect=t(\"../scatter/style\").styleOnSelect,n.hoverPoints=t(\"./hover\"),n.selectPoints=t(\"../scatter/select\"),n.eventData=t(\"./event_data\"),n.moduleType=\"trace\",n.name=\"scatterternary\",n.basePlotModule=t(\"../../plots/ternary\"),n.categories=[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],n.meta={},e.exports=n},{\"../../plots/ternary\":821,\"../scatter/marker_colorbar\":1065,\"../scatter/select\":1068,\"../scatter/style\":1070,\"./attributes\":1118,\"./calc\":1119,\"./defaults\":1120,\"./event_data\":1121,\"./hover\":1122,\"./plot\":1124}],1124:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1067}],1125:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../scattergl/attributes\"),o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\").templatedArray,l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=c.line,f=l(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:l({},u.width,{editType:\"calc\"}),editType:\"calc\"}),h=l(i(\"marker\"),{symbol:c.symbol,size:l({},c.size,{editType:\"markerSize\"}),sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,opacity:c.opacity,colorbar:c.colorbar,line:f,editType:\"calc\"});function p(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:o[t],editType:\"plot\"}}}h.color.editType=h.cmin.editType=h.cmax.editType=\"style\",e.exports={dimensions:s(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:l({},a.text,{}),marker:h,xaxes:p(\"x\"),yaxes:p(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:a.selected.marker,editType:\"calc\"},unselected:{marker:a.unselected.marker,editType:\"calc\"},opacity:a.opacity}},{\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plot_api/plot_template\":732,\"../../plots/cartesian/constants\":748,\"../scatter/attributes\":1047,\"../scattergl/attributes\":1096}],1126:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function f(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var f=l(t,e._diag[s][1]);f&&(c[1]=f.r2l(f.range[0]),c[3]=f.r2l(f.range[1]))}r.selectBatch?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function h(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],f=u.xaxis,h=u.yaxis,p=f._vals,d=h._vals,g=n.b+h.domain[0]*n.h,v=-h._m,m=-v*h.r2l(h.range[0],h.calendar);if(f.showgrid)for(e=0;e<p.length;e++)s=f._offset+f.l2p(p[e].x),o(\"grid\",f,s,g,s,g+h._length);if(h.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",h,f._offset,l,f._offset+f._length,l);c(t,f,h)&&(s=f._offset+f.l2p(0),o(\"zeroline\",f,s,g,s,g+h._length)),c(t,h,f)&&(l=g+m+0,o(\"zeroline\",h,f._offset,l,f._offset+f._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&h(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&h(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&f(t,i,a)}},updateGrid:h,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:function(t){s.updateFx(t);var e=t._fullLayout,r=e.dragmode;if(\"zoom\"===r||\"pan\"===r)for(var n=t.calcdata,i=0;i<n.length;i++){var a=n[i][0].trace;if(\"splom\"===a.type){var o=e._splomScenes[a.uid];null===o.selectBatch&&o.matrix.update(o.matrixOptions,null)}}},toSVG:s.toSVG}},{\"../../lib/prepare_regl\":707,\"../../plots/cartesian\":754,\"../../plots/cartesian/axes\":742,\"../../plots/cartesian/axis_ids\":745,\"../../plots/get_data\":779,\"../../registry\":825,\"regl-line2d\":477}],1127:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\")}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=h(\"diagonal.visible\"),g=h(\"showupperhalf\"),v=h(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){h(\"text\"),s(t,e,r,f,h);var m=c.test(e.marker.symbol),y=o.isBubble(e);h(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,f=new Array(s),h=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";f[i]=\"x\"+p,h[i]=\"y\"+p}var d=n(\"xaxes\",f),g=n(\"yaxes\",h),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i){if(t){var a=t.charAt(0),o=r._splomAxes[a];if(e[\"_\"+a+\"axes\"][t]=1,i.push(t),!(t in o)){var s=o[t]={};n&&(s.label=n.label||\"\",n.visible&&n.axis&&(s.type=n.axis.type))}}}var b=!u&&!c,_=!u&&!l;for(i=0;i<s;i++){var w=o[i],k=0===i,M=i===s-1,A=k&&b||M&&_?void 0:d[i],T=k&&_||M&&b?void 0:g[i];x(A,w,m),x(T,w,y),v[i]=[A,T]}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,f,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":694,\"../../plots/array_container_defaults\":738,\"../parcoords/merge_length\":1019,\"../scatter/marker_defaults\":1066,\"../scatter/subtypes\":1071,\"./attributes\":1125}],1128:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"array-range\"),a=t(\"../../registry\"),o=t(\"../../components/grid\"),s=t(\"../../lib\"),l=t(\"../../plots/cartesian/axis_ids\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/calc\").calcMarkerSize,f=t(\"../scatter/calc\").calcAxisExpansion,h=t(\"../scatter/colorscale_calc\"),p=t(\"../scattergl/convert\").markerSelection,d=t(\"../scattergl/convert\").markerStyle,g=t(\"../scattergl\").calcHover,v=t(\"../../constants/numerical\").BADNUM,m=t(\"../scattergl/constants\").TOO_MANY_POINTS;function y(t,e){var r,i,a,o,c,u=t._fullLayout,f=u._size,h=e.trace,p=e.t,d=u._splomScenes[h.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=h.showupperhalf,g.upper=h.showlowerhalf,g.diagonal=h.diagonal.visible;var x=h._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){a=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=l.getFromId(t,h._diag[a][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(i=l.getFromId(t,h._diag[a][1]))&&(w[1]=i._rl[0],w[3]=i._rl[1],k[1]=i.domain[0],k[3]=i.domain[1])}_.viewport=[f.l,f.b,f.w+f.l,f.h+f.b],!0===d.matrix&&(d.matrix=n(m));var M=u.clickmode.indexOf(\"select\")>-1,A=\"lasso\"===y||\"select\"===y||!!h.selectedpoints||M;if(d.selectBatch=null,d.unselectBatch=null,A){var T=h._length;if(d.selectBatch||(d.selectBatch=[],d.unselectBatch=[]),h.selectedpoints){d.selectBatch=h.selectedpoints;var S=h.selectedpoints,C={};for(a=0;a<S.length;a++)C[S[a]]=!0;var E=[];for(a=0;a<T;a++)C[a]||E.push(a);d.unselectBatch=E}var L=p.xpx=new Array(b),z=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(a=x[c],r=l.getFromId(t,h._diag[a][0]))for(L[c]=new Array(T),o=0;o<T;o++)L[c][o]=r.c2p(v[c][o]);if(i=l.getFromId(t,h._diag[a][1]))for(z[c]=new Array(T),o=0;o<T;o++)z[c][o]=i.c2p(v[c][o])}d.selectBatch?(d.matrix.update(g,g),d.matrix.update(d.unselectedOptions,d.selectedOptions),d.matrix.update(_,_)):d.matrix.update(_,null)}else{var O=s.extendFlat({},g,_);d.matrix.update(O,null),p.xpx=p.ypx=null}}}function x(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:function(t,e){var r,n,i,a,o,c,g=e.dimensions,y=e._length,x={},b=x.cdata=[],_=x.data=[],w=e._visibleDims=[];function k(t,r){for(var n=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),i=0;i<n.length;i++)n[i]=n[i]===v?NaN:n[i];b.push(n),_.push(\"log\"===t.type?s.simpleMap(n,t.c2l):n)}for(r=0;r<g.length;r++)if((i=g[r]).visible){if(a=l.getFromId(t,e._diag[r][0]),o=l.getFromId(t,e._diag[r][1]),a&&o&&a.type!==o.type){s.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}a?(k(a,i),o&&\"category\"===o.type&&(o._categories=a._categories.slice())):k(o,i),w.push(r)}for(h(t,e),s.extendFlat(x,d(e)),c=b.length*y>m?2*(x.sizeAvg||Math.max(x.size,3)):u(e,y),n=0;n<w.length;n++)i=g[r=w[n]],a=l.getFromId(t,e._diag[r][0])||{},o=l.getFromId(t,e._diag[r][1])||{},f(t,e,a,o,b[n],b[n],c);var M=function(t,e){var r=t._fullLayout,n=e.uid,i=r._splomScenes;i||(i=r._splomScenes={});var a={dirty:!0},o=i[e.uid];return o||((o=i[n]=s.extendFlat({},a,{selectBatch:null,unselectBatch:null,matrix:!1,select:null})).draw=function(){o.matrix&&o.matrix.draw&&(o.selectBatch?o.matrix.draw(o.unselectBatch,o.selectBatch):o.matrix.draw()),o.dirty=!1},o.destroy=function(){o.matrix&&o.matrix.destroy&&o.matrix.destroy(),o.matrixOptions=null,o.selectBatch=null,o.unselectBatch=null,o=null}),o.dirty||s.extendFlat(o,a),o}(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=x,M.selectedOptions=p(e,e.selected),M.unselectedOptions=p(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]},plot:function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)y(t,r[n][0])},hoverPoints:function(t,e,r){var n=t.cd[0].trace,i=t.scene.matrixOptions.cdata,a=t.xa,o=t.ya,s=a.c2p(e),l=o.c2p(r),c=t.distance,u=x(n,a),f=x(n,o);if(!1===u||!1===f)return[t];for(var h,p,d=i[u],v=i[f],m=c,y=0;y<d.length;y++){var b=d[y],_=v[y],w=a.c2p(b)-s,k=o.c2p(_)-l,M=Math.sqrt(w*w+k*k);M<m&&(m=p=M,h=y)}return t.index=h,t.distance=m,t.dxy=p,void 0===h?[t]:(g(t,d,v,n),[t])},selectPoints:function(t,e){var r,n=t.cd,a=n[0].trace,o=n[0].t,s=t.scene,l=s.matrixOptions.cdata,u=t.xaxis,f=t.yaxis,h=[];if(!s)return h;var p=!c.hasMarkers(a)&&!c.hasText(a);if(!0!==a.visible||p)return h;var d=x(a,u),g=x(a,f);if(!1===d||!1===g)return h;var v=o.xpx[d],m=o.ypx[g],y=l[d],b=l[g],_=null,w=null;if(!1===e||e.degenerate)w=i(o.count);else for(_=[],w=[],r=0;r<y.length;r++)e.contains([v[r],m[r]],null,r,t)?(_.push(r),h.push({pointNumber:r,x:y[r],y:b[r]})):w.push(r);if(s.selectBatch||(s.selectBatch=[],s.unselectBatch=[]),!s.selectBatch){for(r=0;r<s.count;r++)s.selectBatch=[],s.unselectBatch=[];s.matrix.update(s.unselectedOptions,s.selectedOptions)}return s.selectBatch=_,s.unselectBatch=w,h},editStyle:function(t,e){var r=e.trace,n=t._fullLayout._splomScenes[r.uid];if(n){h(t,r),s.extendFlat(n.matrixOptions,d(r));var i=s.extendFlat({},n.matrixOptions,n.viewOpts);n.matrix.update(i,null)}},meta:{}},a.register(o)},{\"../../components/grid\":614,\"../../constants/numerical\":671,\"../../lib\":694,\"../../plots/cartesian/axis_ids\":745,\"../../registry\":825,\"../scatter/calc\":1048,\"../scatter/colorscale_calc\":1050,\"../scatter/marker_colorbar\":1065,\"../scatter/subtypes\":1071,\"../scattergl\":1100,\"../scattergl/constants\":1097,\"../scattergl/convert\":1098,\"./attributes\":1125,\"./base_plot\":1126,\"./defaults\":1127,\"array-range\":56,\"regl-splom\":479}],1129:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/colorbar/attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"}};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i});[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plots/attributes\":739,\"../mesh3d/attributes\":990}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,f=e.y,h=e.z,p=Math.min(u.length,f.length,h.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,M=1/0,A=-1/0,T=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var C=f[r];k=Math.max(k,C),M=Math.min(M,C);var E=h[r];A=Math.max(A,E),T=Math.min(T,E)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var z=a[r];k=Math.max(k,z),M=Math.min(M,z);var O=o[r];A=Math.max(A,O),T=Math.min(T,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[M,k],e._zbnds=[T,A]}},{\"../../components/colorscale/calc\":579}],1131:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../plots/gl3d/zip3\"),l={xaxis:0,yaxis:1,zaxis:2};function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;function f(t){return a.distinctVals(t).vals}function h(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c=e._len,u={};function d(t,e){var n=r[e],o=i[l[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}u.vectors=s(d(e.u,\"xaxis\"),d(e.v,\"yaxis\"),d(e.w,\"zaxis\"),c);var g=f(e.x.slice(0,c)),v=f(e.y.slice(0,c)),m=f(e.z.slice(0,c));if(g.length*v.length*m.length>c)return{positions:[],cells:[]};var y=d(g,\"xaxis\"),x=d(v,\"yaxis\"),b=d(m,\"zaxis\");if(u.meshgrid=[y,x,b],e.starts){var _=e._slen;u.startingPositions=s(d(e.starts.x.slice(0,_),\"xaxis\"),d(e.starts.y.slice(0,_),\"yaxis\"),d(e.starts.z.slice(0,_),\"zaxis\"))}else{for(var w=x[0],k=h(y),M=h(b),A=new Array(k.length*M.length),T=0,S=0;S<k.length;S++)for(var C=0;C<M.length;C++)A[T++]=[k[S],w,M[C]];u.startingPositions=A}u.colormap=o(e),u.tubeSize=e.sizeref,u.maxLength=e.maxdisplayed;var E=d(e._xbnds,\"xaxis\"),L=d(e._ybnds,\"yaxis\"),z=d(e._zbnds,\"zaxis\"),O=p(y),I=p(x),D=p(b),P=[[E[0]-O[0],L[0]-I[0],z[0]-D[0]],[E[1]+O[1],L[1]+I[1],z[1]+D[1]]],R=n(u,P);R.vertexIntensityBounds=[e.cmin/e._normMax,e.cmax/e._normMax];var F=e.lightposition;return R.lightPosition=[F.x,F.y,F.z],R.ambient=e.lighting.ambient,R.diffuse=e.lighting.diffuse,R.specular=e.lighting.specular,R.roughness=e.lighting.roughness,R.fresnel=e.lighting.fresnel,R.opacity=e.opacity,e._pad=R.tubeScale*e.sizeref*2,R}u.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[l[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.text,!0}},u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../lib\":694,\"../../lib/gl_format_color\":691,\"../../plots/gl3d/zip3\":796,\"gl-streamtube3d\":303}],1132:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"./attributes\":1129}],1133:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":785,\"./attributes\":1129,\"./calc\":1130,\"./convert\":1131,\"./defaults\":1132}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/colorbar/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{colorbar:a,contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":571,\"../../components/colorbar/attributes\":572,\"../../components/colorscale/attributes\":578,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/attributes\":739}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":579}],1136:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\");function u(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0}var f=u.prototype;f.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},f.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},f.getZat=function(t,e,r,n){var i=this.data.z[e][t];return void 0===r?i:n.d2l(i,0,r)},f.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var h=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function p(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function d(t){for(var e=[],r=0;r<h.length;r++){var n=h[r];e.push(p(t,n))}return e}function g(t){for(var e=d(t),r=t,n=0;n<h.length;n++)if(e[n]>0){r=h[n];break}return r}function v(t,e){if(!(t<1||e<1)){for(var r=d(t),n=d(e),i=1,a=0;a<h.length;a++)i*=Math.pow(h[a],Math.max(r[a],n[a]));return i}}f.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},f.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var m=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],y=m[9],x=m[13];f.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=v(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<y;)r*=2;for(;r>x;)r--,r/=g(r),++r<y&&(r=x);var n=Math.round(r/t);return n>1?n:1},f.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,f=i(new Float32Array(c*u),[c,u]),h=0;h<t.length;++h){this.surface.padField(f,t[h]);var p=i(new Float32Array(s*l),[s,l]);a(p,f,[e,0,0,0,r,0,0,0,1]),t[h]=p}},f.setContourLevels=function(){for(var t=[[],[],[]],e=!1,r=0;r<3;++r)this.showContour[r]&&(e=!0,t[r]=this.scene.contourLevels[r]);e&&this.surface.update({levels:t})},f.update=function(t){var e,r,n,a,s=this.scene,u=s.fullSceneLayout,f=this.surface,h=t.opacity,p=l(t,h),d=s.dataScale,g=t.z[0].length,v=t._ylength,m=s.contourLevels;this.data=t;var y=[];for(e=0;e<3;e++)for(y[e]=[],r=0;r<g;r++)y[e][r]=[];for(r=0;r<g;r++)for(n=0;n<v;n++)y[0][r][n]=this.getXat(r,n,t.xcalendar,u.xaxis),y[1][r][n]=this.getYat(r,n,t.ycalendar,u.yaxis),y[2][r][n]=this.getZat(r,n,t.zcalendar,u.zaxis);for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)null==(a=y[e][r][n])?y[e][r][n]=NaN:a=y[e][r][n]*=d[e];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)null!=(a=y[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)t._objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)null!=(a=y[e][r][n])&&(y[e][r][n]-=t._objectOffset[e]);var b=[i(new Float32Array(g*v),[g,v]),i(new Float32Array(g*v),[g,v]),i(new Float32Array(g*v),[g,v])];o(b[0],function(t,e){return y[0][t][e]}),o(b[1],function(t,e){return y[1][t][e]}),o(b[2],function(t,e){return y[2][t][e]}),y=[];var _={colormap:p,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity};if(_.intensityBounds=[t.cmin,t.cmax],t.surfacecolor){var w=i(new Float32Array(g*v),[g,v]);o(w,function(e,r){return t.surfacecolor[r][e]}),b.push(w)}else _.intensityBounds[0]*=d[2],_.intensityBounds[1]*=d[2];(x<b[0].shape[0]||x<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(_.intensity=b.pop());var k=[!0,!0,!0],M=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var A=t.contours[M[e]];k[e]=A.highlight,_.showContour[e]=A.show||A.highlight,_.showContour[e]&&(_.contourProject[e]=[A.project.x,A.project.y,A.project.z],A.show?(this.showContour[e]=!0,_.levels[e]=m[e],f.highlightColor[e]=_.contourColor[e]=c(A.color),A.usecolormap?f.highlightTint[e]=_.contourTint[e]=0:f.highlightTint[e]=_.contourTint[e]=1,_.contourWidth[e]=A.width):this.showContour[e]=!1,A.highlight&&(_.dynamicColor[e]=c(A.highlightcolor),_.dynamicWidth[e]=A.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(p)&&(_.vertexColor=!0),_.objectOffset=[t._objectOffset[0],t._objectOffset[1],t._objectOffset[2]],_.coords=b,f.update(_),f.visible=t.visible,f.enableDynamic=k,f.enableHighlight=k,f.snapToData=!0,\"lighting\"in t&&(f.ambientLight=t.lighting.ambient,f.diffuseLight=t.lighting.diffuse,f.specularLight=t.lighting.specular,f.roughness=t.lighting.roughness,f.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(f.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),h&&h<1&&(f.supportsTransparency=!0)},f.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../lib\":694,\"../../lib/gl_format_color\":691,\"../../lib/str2rgbarray\":717,\"gl-surface3d\":306,ndarray:436,\"ndarray-fill\":426,\"ndarray-homography\":428}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function f(r,n){return i.coerce(t,e,o,r,n)}var h=f(\"x\"),p=f(\"y\"),d=f(\"z\");if(!d||!d.length||h&&h.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(h)&&i.isArrayOrTypedArray(h[0])?d.length:d[0].length,e._ylength=d.length,e._objectOffset=[0,0,0],n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),f(\"text\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"opacity\"].forEach(function(t){f(t)});var g=f(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=f(m+\".show\"),x=f(m+\".highlight\");if(y||x)for(u=0;u<3;++u)f(m+\".project.\"+v[u]);y&&(f(m+\".color\"),f(m+\".width\"),f(m+\".usecolormap\")),x&&(f(m+\".highlightcolor\"),f(m+\".highlightwidth\"))}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,f,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":581,\"../../lib\":694,\"../../registry\":825,\"./attributes\":1134}],1138:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.colorbar={min:\"cmin\",max:\"cmax\"},n.calc=t(\"./calc\"),n.plot=t(\"./convert\"),n.moduleType=\"trace\",n.name=\"surface\",n.basePlotModule=t(\"../../plots/gl3d\"),n.categories=[\"gl3d\",\"2dMap\",\"noOpacity\"],n.meta={},e.exports=n},{\"../../plots/gl3d\":785,\"./attributes\":1134,\"./calc\":1135,\"./convert\":1136,\"./defaults\":1137}],1139:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":554,\"../../lib/extend\":684,\"../../plot_api/edit_types\":725,\"../../plots/domain\":768,\"../../plots/font_attributes\":769}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":779,\"./plot\":1147}],1141:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":692}],1142:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1143:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function f(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function h(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=h(b,y-_+n.uplift),k=f(h(x,_),[]),M=f(w,k),A={},T=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),C=S.reduce(s,0);S=S.map(function(t){return t/C*m});var E=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:E,height:y,columnOrder:T,groupHeight:y,rowBlocks:M,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:T[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":684,\"./constants\":1142,\"fast-isnumeric\":215}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":684}],1145:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":694,\"../../plots/domain\":768,\"./attributes\":1139}],1146:[function(t,e,r){\"use strict\";var n={};n.attributes=t(\"./attributes\"),n.supplyDefaults=t(\"./defaults\"),n.calc=t(\"./calc\"),n.plot=t(\"./plot\"),n.moduleType=\"trace\",n.name=\"table\",n.basePlotModule=t(\"./base_plot\"),n.categories=[\"noOpacity\"],n.meta={},e.exports=n},{\"./attributes\":1139,\"./base_plot\":1140,\"./calc\":1141,\"./defaults\":1145,\"./plot\":1147}],1147:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),f=t(\"./data_split_helpers\"),h=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return I(e,e.length-1)+(e.length?D(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(f.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);h.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),h.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var f,h,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(f=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===f?b(v):f),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),h=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,h=v;return h}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?E:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+z(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function M(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+D(e,1/0)},0)}function T(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=I(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(I(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(C(t,r,e,c,n.prevPages,n,0),C(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var f=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return T(t,f,l),s.scrollY===u}}function C(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function E(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,f=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,h=Math.max(f,u);h-l.rows[c].rowHeight&&(l.rows[c].rowHeight=h,t.selectAll(\".\"+n.cn.columnCell).call(O),T(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+z(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function z(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+D(e,1/0)},0);return\"translate(0 \"+(D(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function I(t,e){for(var r=0,n=e-1;n>=0;n--)r+=P(t[n]);return r}function D(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function P(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var h=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=h.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){h.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,h,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),h.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=h.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),h.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=h.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(h.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(f.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var C=A.filter(M),E=A.filter(k);r&&E.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,h,-1)).on(\"dragend\",function(){})),y(t,h,C,A),y(t,h,E,A);var L=h.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var z=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var I=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);I.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),I.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),T(null,E,h)}},{\"../../components/color\":571,\"../../components/drawing\":592,\"../../lib\":694,\"../../lib/gup\":692,\"../../lib/svg_text_utils\":718,\"./constants\":1142,\"./data_preparation_helper\":1143,\"./data_split_helpers\":1144,d3:149}],1148:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:n.name,orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":684,\"../box/attributes\":858}],1149:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return 1;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function f(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var h={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[f(0),f(1)]};return i.setConvert(h),h.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),f=1/0,h=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y),b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var M=0,A=x[0];A<x[1]+w/2;M++,A+=w){var T=k(A);v.density[M]={v:T,t:A},p=Math.max(p,T)}d=Math.max(d,m.length),f=Math.min(f,x[0]),h=Math.max(h,x[1])}var S=i.findExtremes(u,[f,h],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var C=s._violinScaleGroupStats,E=e.scalegroup,L=C[E];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):C[E]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":671,\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../box/calc\":859,\"./helpers\":1152}],1150:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(f)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":860}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,f=l(\"span\");Array.isArray(f)&&(u=\"manual\"),l(\"spanmode\",u);var h=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",h),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",h),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":571,\"../../lib\":694,\"../box/defaults\":861,\"./attributes\":1148}],1152:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":694}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,f=t.cd,h=f[0].trace,p=h.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(d&&(v=v.concat(m)),g&&m.length>0){var y,x,b,_,w,k=t.xa,M=t.ya;\"h\"===h.orientation?(w=e,y=\"y\",b=M,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=M);var A=f[t.index];if(w>=A.span[0]&&w<=A.span[1]){var T=n.extendFlat({},t),S=_.c2p(w,!0),C=o.getKdeValue(A,h,w),E=o.getPositionOnKdePath(A,h,S),L=b._offset,z=b._length;T[y+\"0\"]=E[0],T[y+\"1\"]=E[1],T[x+\"0\"]=T[x+\"1\"]=S,T[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+f[0].t.labels.kde+\" \"+C.toFixed(3),T.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";T[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,v.push(T),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+E[0],L,L+z),u[y+\"2\"]=n.constrain(L+E[1],L,L+z),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var I=l.selectAll(\".violinline-\"+h.uid).data(u?[0]:[]);return I.enter().append(\"line\").classed(\"violinline-\"+h.uid,!0).attr(\"stroke-width\",1.5),I.exit().remove(),I.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":694,\"../../plots/cartesian/axes\":742,\"../box/hover\":863,\"./helpers\":1152}],1154:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":754,\"../box/select\":868,\"../scatter/style\":1070,\"./attributes\":1148,\"./calc\":1149,\"./cross_trace_calc\":1150,\"./defaults\":1151,\"./hover\":1153,\"./layout_attributes\":1155,\"./layout_defaults\":1156,\"./plot\":1157,\"./style\":1158}],1155:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":694,\"../box/layout_attributes\":865}],1156:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":694,\"../box/layout_defaults\":866,\"./layout_attributes\":1155}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,f=e.xaxis,h=e.yaxis;function p(t){var e=s(t,{xaxis:f,yaxis:h,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(e.isRangePlot||(a.node3=r),!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,f,h,_=n.select(this),w=t.density,k=w.length,M=t.pos+d,A=m.c2p(M);if(c.width)e=s.maxKDE/g;else{var T=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?T.maxKDE/g*(T.maxCount/t.pts.length):T.maxKDE/g}if(x){for(f=new Array(k),o=0;o<k;o++)(h=f[o]={})[s.posLetter]=M+w[o].v/e,h[s.valLetter]=w[o].t;r=p(f)}if(b){for(f=new Array(k),l=0,o=k-1;l<k;l++,o--)(h=f[l]={})[s.posLetter]=M-w[o].v/e,h[s.valLetter]=w[o].t;i=p(f)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],C=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),C.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+C:\"M\"+C+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,M,A=c.box,T=A.width,S=(A.line||{}).width;y?(w=g*T,k=0):x?(w=[0,g*T/2],k=-S):(w=[g*T/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(M=i.identity);var C=r.selectAll(\"path.meanline\").data(M||[]);C.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),C.exit().remove(),C.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:f,y:h},c,s)}})}},{\"../../components/drawing\":592,\"../../lib\":694,\"../box/plot\":867,\"../scatter/line_points\":1061,\"./helpers\":1152,d3:149}],1158:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t,e){var r=e?e[0].node3:n.select(t).selectAll(\"g.trace.violins\");r.style(\"opacity\",function(t){return t[0].trace.opacity}),r.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var f={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(f).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(f).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":571,\"../scatter/style\":1070,d3:149}],1159:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return f;case\"first\":return h;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var f=u-c;a+=f,o+=f*f,l++}}var h=\"sample\"===t.funcmode?l-1:l;return h?Math.sqrt((o-a*a/l)/h):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function f(t,e){return e.length}function h(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var f=o(\"groups\");if(!Array.isArray(f)){if(!u[f])return n.enabled=!1,n;u[f]=0}var h,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],h,c,t,e)}for(r=0;r<p.length;r++){h={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=h):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,f,h={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=h[l=a[s]])?(h[l]=d.length,f=[s],d.push(f),p[h[l]]=g(s)):(d[c].push(s),p[h[l]]=(p[h[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":671,\"../lib\":694,\"../plot_api/plot_schema\":731,\"../plots/cartesian/axes\":742,\"./helpers\":1162}],1160:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){a(\"preservegaps\"),a(\"operation\"),a(\"value\"),a(\"target\");var o=i.getComponentMethod(\"calendars\",\"handleDefaults\");o(t,e,\"valuecalendar\",null),o(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,f=i.length;e._length&&(f=Math.min(f,e._length));var h=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(h=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,f=function(r){return e(r,0,t.valuecalendar)},h=function(t){return e(t,0,r)};o(l)?s=f(a?i[0]:i):o(c)?s=a?[f(i[0]),f(i[1])]:[f(i),f(i)]:o(u)&&(s=a?i.map(f):[f(i)]);switch(n){case\"=\":return function(t){return h(t)===s};case\"!=\":return function(t){return h(t)!==s};case\"<\":return function(t){return h(t)<s};case\"<=\":return function(t){return h(t)<=s};case\">\":return function(t){return h(t)>s};case\">=\":return function(t){return h(t)>=s};case\"[]\":return function(t){var e=h(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=h(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=h(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=h(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=h(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=h(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=h(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=h(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(h(t))};case\"}{\":return function(t){return-1===s.indexOf(h(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),h),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(f))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),M(v);for(var w=o(e.transforms,r),k=0;k<f;k++){y(i[k])?(M(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function M(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":667,\"../lib\":694,\"../plots/cartesian/axes\":742,\"../registry\":825,\"./helpers\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,f,h,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),M=v.styles||[],A={};for(r=0;r<M.length;r++)A[M[r].target]=M[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var T={},S={};for(r=0;r<b.length;r++){T[f=b[r]]=r,S[f]=0,(h=_[r]=n.extendDeepNoArrays({},t))._group=f,h.transforms[m]._indexToPoints={};var C=null;for(g&&(C=g.get(f)),h.name=C||\"\"===C?C:n.templateString(v.nameformat,{trace:t.name,group:f}),p=h.transforms,h.transforms=[],s=0;s<p.length;s++)h.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(h,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[T[y[s]]].push(u[s])}for(s=0;s<w;s++){(h=_[T[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)f=b[r],h=_[r],a.clearExpandedTraceDefaultColors(h),h=n.extendDeepNoArrays(h,A[f]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var f=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(f)?u.value=n.extendDeep({},f):f&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":694,\"../plot_api/plot_schema\":731,\"../plots/plots\":806,\"./helpers\":1162}],1162:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,f=e._arrayAttrs,h=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<f.length;c++){var g=n.nestedProperty(e,f[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[h[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(h[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":694,\"../plots/cartesian/axes\":742,\"./helpers\":1162}]},{},[22])(22)});</script><div id=\"05b6fce5-c266-47bc-bb1e-ffb7e9f7ec8f\" style=\"height: 540px; width: 540px;\" class=\"plotly-graph-div\"></div><script type=\"text/javascript\">window.PLOTLYENV=window.PLOTLYENV || {};window.PLOTLYENV.BASE_URL=\"https://plot.ly\";Plotly.newPlot(\"05b6fce5-c266-47bc-bb1e-ffb7e9f7ec8f\", [{\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 2.0539078156312622, 4.057815631262525, 6.0617234468937875, 8.06563126252505, 10.069539078156312, 12.073446893787576, 14.077354709418838, 16.0812625250501, 18.085170340681362, 20.089078156312624, 22.092985971943886, 24.09689378757515, 26.100801603206413, 28.104709418837675, 30.108617234468937, 32.112525050100196, 34.11643286573146, 36.12034068136272, 38.124248496993985, 40.128156312625244, 42.13206412825651, 44.13597194388777, 46.13987975951903, 48.1437875751503, 50.14769539078156, 52.15160320641282, 54.15551102204408, 56.15941883767535, 58.163326653306605, 60.16723446893787, 62.17114228456913, 64.1750501002004, 66.17895791583166, 68.18286573146293, 70.18677354709418, 72.19068136272544, 74.19458917835671, 76.19849699398797, 78.20240480961922, 80.20631262525049, 82.21022044088176, 84.21412825651302, 86.21803607214429, 88.22194388777554, 90.2258517034068, 92.22975951903807, 94.23366733466933, 96.2375751503006, 98.24148296593185, 100.24539078156312, 102.24929859719438, 104.25320641282565, 106.2571142284569, 108.26102204408816, 110.26492985971943, 112.2688376753507, 114.27274549098196, 116.27665330661321, 118.28056112224448, 120.28446893787574, 122.28837675350701, 124.29228456913826, 126.29619238476953, 128.3001002004008, 130.30400801603207, 132.30791583166334, 134.3118236472946, 136.31573146292587, 138.3196392785571, 140.32354709418837, 142.32745490981964, 144.3313627254509, 146.33527054108217, 148.33917835671343, 150.3430861723447, 152.34699398797596, 154.35090180360723, 156.35480961923847, 158.35871743486973, 160.362625250501, 162.36653306613226, 164.37044088176353, 166.3743486973948, 168.37825651302606, 170.38216432865732, 172.3860721442886, 174.38997995991983, 176.3938877755511, 178.39779559118236, 180.40170340681362, 182.4056112224449, 184.40951903807616, 186.41342685370742, 188.4173346693387, 190.42124248496995, 192.42515030060122, 194.42905811623245, 196.43296593186372, 198.43687374749499, 200.44078156312625, 202.44468937875752, 204.44859719438878, 206.45250501002005, 208.4564128256513, 210.46032064128258, 212.46422845691382, 214.46813627254508, 216.47204408817635, 218.4759519038076, 220.47985971943888, 222.48376753507014, 224.4876753507014, 226.49158316633267, 228.49549098196394, 230.49939879759518, 232.50330661322644, 234.5072144288577, 236.51112224448897, 238.51503006012024, 240.5189378757515, 242.52284569138277, 244.52675350701404, 246.5306613226453, 248.53456913827654, 250.5384769539078, 252.54238476953907, 254.54629258517033, 256.5502004008016, 258.55410821643284, 260.55801603206413, 262.56192384769537, 264.56583166332666, 266.5697394789579, 268.5736472945892, 270.57755511022043, 272.5814629258517, 274.58537074148296, 276.5892785571142, 278.5931863727455, 280.59709418837673, 282.601002004008, 284.60490981963926, 286.60881763527055, 288.6127254509018, 290.6166332665331, 292.6205410821643, 294.62444889779556, 296.62835671342685, 298.6322645290581, 300.6361723446894, 302.6400801603206, 304.6439879759519, 306.64789579158315, 308.65180360721445, 310.6557114228457, 312.6596192384769, 314.6635270541082, 316.66743486973945, 318.67134268537075, 320.675250501002, 322.6791583166333, 324.6830661322645, 326.6869739478958, 328.69088176352705, 330.6947895791583, 332.6986973947896, 334.7026052104208, 336.7065130260521, 338.71042084168334, 340.71432865731464, 342.7182364729459, 344.72214428857717, 346.7260521042084, 348.72995991983964, 350.73386773547094, 352.7377755511022, 354.74168336673347, 356.7455911823647, 358.749498997996, 360.75340681362724, 362.75731462925853, 364.76122244488977, 366.765130260521, 368.7690380761523, 370.77294589178354, 372.77685370741483, 374.78076152304607, 376.78466933867736, 378.7885771543086, 380.7924849699399, 382.79639278557113, 384.8003006012024, 386.80420841683366, 388.8081162324649, 390.8120240480962, 392.8159318637274, 394.8198396793587, 396.82374749498996, 398.82765531062125, 400.8315631262525, 402.8354709418838, 404.839378757515, 406.84328657314626, 408.84719438877755, 410.8511022044088, 412.8550100200401, 414.8589178356713, 416.8628256513026, 418.86673346693385, 420.87064128256515, 422.8745490981964, 424.8784569138276, 426.8823647294589, 428.88627254509015, 430.89018036072144, 432.8940881763527, 434.897995991984, 436.9019038076152, 438.9058116232465, 440.90971943887774, 442.913627254509, 444.9175350701403, 446.9214428857715, 448.9253507014028, 450.92925851703404, 452.93316633266534, 454.9370741482966, 456.94098196392787, 458.9448897795591, 460.94879759519034, 462.95270541082164, 464.9566132264529, 466.96052104208417, 468.9644288577154, 470.9683366733467, 472.97224448897794, 474.97615230460923, 476.98006012024047, 478.9839679358717, 480.987875751503, 482.99178356713423, 484.99569138276553, 486.99959919839677, 489.00350701402806, 491.0074148296593, 493.0113226452906, 495.0152304609218, 497.01913827655306, 499.02304609218436, 501.0269539078156, 503.0308617234469, 505.0347695390781, 507.0386773547094, 509.04258517034066, 511.04649298597195, 513.0504008016031, 515.0543086172344, 517.0582164328656, 519.062124248497, 521.0660320641282, 523.0699398797594, 525.0738476953907, 527.077755511022, 529.0816633266533, 531.0855711422845, 533.0894789579157, 535.093386773547, 537.0972945891783, 539.1012024048096, 541.1051102204408, 543.109018036072, 545.1129258517034, 547.1168336673346, 549.1207414829659, 551.1246492985971, 553.1285571142283, 555.1324649298597, 557.1363727454909, 559.1402805611222, 561.1441883767534, 563.1480961923847, 565.152004008016, 567.1559118236472, 569.1598196392785, 571.1637274549097, 573.167635270541, 575.1715430861723, 577.1754509018035, 579.1793587174348, 581.1832665330661, 583.1871743486973, 585.1910821643286, 587.1949899799598, 589.198897795591, 591.2028056112224, 593.2067134268536, 595.2106212424849, 597.2145290581161, 599.2184368737475, 601.2223446893787, 603.2262525050099, 605.2301603206412, 607.2340681362724, 609.2379759519038, 611.241883767535, 613.2457915831662, 615.2496993987975, 617.2536072144288, 619.2575150300601, 621.2614228456913, 623.2653306613225, 625.2692384769538, 627.2731462925851, 629.2770541082164, 631.2809619238476, 633.2848697394788, 635.2887775551102, 637.2926853707414, 639.2965931863727, 641.3005010020039, 643.3044088176351, 645.3083166332665, 647.3122244488977, 649.316132264529, 651.3200400801602, 653.3239478957915, 655.3278557114228, 657.331763527054, 659.3356713426853, 661.3395791583165, 663.3434869739478, 665.3473947895791, 667.3513026052103, 669.3552104208416, 671.3591182364729, 673.3630260521041, 675.3669338677354, 677.3708416833666, 679.3747494989979, 681.3786573146292, 683.3825651302604, 685.3864729458917, 687.3903807615229, 689.3942885771543, 691.3981963927855, 693.4021042084167, 695.406012024048, 697.4099198396792, 699.4138276553106, 701.4177354709418, 703.421643286573, 705.4255511022043, 707.4294589178356, 709.4333667334669, 711.4372745490981, 713.4411823647293, 715.4450901803606, 717.4489979959919, 719.4529058116232, 721.4568136272544, 723.4607214428856, 725.464629258517, 727.4685370741482, 729.4724448897795, 731.4763527054107, 733.4802605210419, 735.4841683366733, 737.4880761523045, 739.4919839679358, 741.495891783567, 743.4997995991984, 745.5037074148296, 747.5076152304608, 749.5115230460921, 751.5154308617233, 753.5193386773547, 755.5232464929859, 757.5271543086171, 759.5310621242484, 761.5349699398797, 763.538877755511, 765.5427855711422, 767.5466933867734, 769.5506012024048, 771.554509018036, 773.5584168336673, 775.5623246492985, 777.5662324649297, 779.5701402805611, 781.5740480961923, 783.5779559118236, 785.5818637274548, 787.5857715430861, 789.5896793587174, 791.5935871743486, 793.5974949899799, 795.6014028056111, 797.6053106212424, 799.6092184368737, 801.6131262525049, 803.6170340681361, 805.6209418837675, 807.6248496993987, 809.62875751503, 811.6326653306612, 813.6365731462924, 815.6404809619238, 817.644388777555, 819.6482965931863, 821.6522044088175, 823.6561122244489, 825.6600200400801, 827.6639278557113, 829.6678356713426, 831.6717434869738, 833.6756513026052, 835.6795591182364, 837.6834669338676, 839.6873747494989, 841.6912825651302, 843.6951903807615, 845.6990981963927, 847.7030060120239, 849.7069138276552, 851.7108216432865, 853.7147294589178, 855.718637274549, 857.7225450901802, 859.7264529058116, 861.7303607214428, 863.7342685370741, 865.7381763527053, 867.7420841683365, 869.7459919839679, 871.7498997995991, 873.7538076152304, 875.7577154308616, 877.761623246493, 879.7655310621242, 881.7694388777554, 883.7733466933867, 885.7772545090179, 887.7811623246492, 889.7850701402805, 891.7889779559117, 893.792885771543, 895.7967935871743, 897.8007014028055, 899.8046092184368, 901.808517034068, 903.8124248496993, 905.8163326653306, 907.8202404809618, 909.8241482965931, 911.8280561122243, 913.8319639278557, 915.8358717434869, 917.8397795591181, 919.8436873747494, 921.8475951903806, 923.851503006012, 925.8554108216432, 927.8593186372744, 929.8632264529057, 931.867134268537, 933.8710420841683, 935.8749498997995, 937.8788577154307, 939.882765531062, 941.8866733466933, 943.8905811623246, 945.8944889779558, 947.898396793587, 949.9023046092184, 951.9062124248496, 953.9101202404809, 955.9140280561121, 957.9179358717433, 959.9218436873747, 961.9257515030059, 963.9296593186372, 965.9335671342684, 967.9374749498998, 969.941382765531, 971.9452905811622, 973.9491983967935, 975.9531062124247, 977.957014028056, 979.9609218436873, 981.9648296593185, 983.9687374749498, 985.9726452905811, 987.9765531062124, 989.9804609218436, 991.9843687374748, 993.9882765531061, 995.9921843687374, 997.9960921843686, 1000.0], \"y\": [0.6706959041673459, 0.6662479767130076, 0.6618099418375614, 0.657381777539048, 0.6529634618644433, 0.6485549729095477, 0.6441562888188788, 0.6397673877855632, 0.635388248051227, 0.6310188479058894, 0.6266591656878544, 0.6223091797836033, 0.6179688686276883, 0.6136382107026241, 0.6093171845387833, 0.6050057687142878, 0.6007039418549043, 0.5964116826339372, 0.5921289697721237, 0.5878557820375279, 0.5835920982454352, 0.5793378972582481, 0.5750931579853811, 0.570857859383155, 0.5666319804546949, 0.5624155002498239, 0.5582083978649601, 0.554010652443014, 0.5498222431732827, 0.5456431492913487, 0.5414733500789772, 0.5373128248640111, 0.5331615530202711, 0.5290195139674516, 0.52488668717102, 0.520763052142114, 0.5166485884374401, 0.5125432756591728, 0.5084470934548531, 0.5043600215172876, 0.5002820395844478, 0.49621312743936974, 0.49215326491005396, 0.48810243186936497, 0.4840606082349319, 0.48002777396904883, 0.4760039090785757, 0.4719889936148385, 0.4679830076735312, 0.4639859313946164, 0.45999774496222723, 0.456018428604569, 0.45204796259382163, 0.4480863272460407, 0.44413350292106135, 0.4401894700223994, 0.4362542089971557, 0.43232770033591805, 0.4284099245726649, 0.4245008622846691, 0.42060049409240086, 0.4167088006594324, 0.41282576269234195, 0.4089513609406181, 0.40508557619656393, 0.401228389295202, 0.39737978111418015, 0.39353973257367536, 0.38970822463629995, 0.38588523830700705, 0.38207075463299667, 0.3782647547036213, 0.3744672196502923, 0.3706781306463862, 0.36689746890715247, 0.36312521568961853, 0.3593613522924983, 0.35560586005609873, 0.3518587203622279, 0.3481199146341023, 0.3443894243362542, 0.3406672309744414, 0.33695331609555357, 0.33324766128752215, 0.32955024817922896, 0.325861058440414, 0.32218007378158586, 0.3185072759539307, 0.31484264674922113, 0.311186167999727, 0.30753782157812415, 0.30389758939740585, 0.3002654534107918, 0.29664139561164027, 0.29302539803335637, 0.28941744274930614, 0.28581751187272486, 0.28222558755662996, 0.27864165199373203, 0.2750656874163466, 0.2714976760963066, 0.267937600344873, 0.2643854425126486, 0.26084118498949027, 0.25730481020442086, 0.2537763006255431, 0.2502556387599515, 0.24674280715364705, 0.24323778839144938, 0.23974056509691133, 0.23625111993223258, 0.2327694355981733, 0.22929549483396872, 0.2258292804172437, 0.222370775163927, 0.21891996192816654, 0.21547682360224352, 0.2120413431164887, 0.20861350343919716, 0.2051932875765441, 0.20178067857250004, 0.19837565950874758, 0.1949782135045972, 0.19158832371690315, 0.18820597333998057, 0.18483114560552183, 0.18146382378251347, 0.17810399117715336, 0.17475163113276748, 0.17140672702972837, 0.16806926228537145, 0.16473922035391375, 0.16141658472637133, 0.15810133893047795, 0.154793466530603, 0.15149295112767036, 0.14819977635907655, 0.14491392589860985, 0.14163538345636995, 0.1383641327786862, 0.13510015764803818, 0.1318434418829737, 0.12859396933803047, 0.1253517239036548, 0.12211668950612165, 0.11888885010745565, 0.11566818970535175, 0.11245469233309469, 0.10924834205948075, 0.10604912298873881, 0.10285701926045143, 0.09967201504947587, 0.09649409456586566, 0.09332324205479314, 0.0901594417964704, 0.08700267810607176, 0.08385293533365612, 0.0807101978640885, 0.07757445011696484, 0.07444567654653156, 0.07132386164161142, 0.06820898992552449, 0.06510104595601329, 0.06200001432516422, 0.05890587965933336, 0.05581862661906811, 0.05273823989903259, 0.04966470422793123, 0.04659800436843353, 0.043538125117097426, 0.04048505130429536, 0.037438767794137906, 0.03439925948439915, 0.0313665113064423, 0.028340508225144, 0.02532123523882035, 0.022308677379153208, 0.01930281971111447, 0.016303647332893023, 0.01331114537582101, 0.01032529900429946, 0.00734609341572523, 0.004373513840417509, 0.0014075455415443194, 0.0015518261849505333, 0.00450461601041896, 0.007450838573584306, 0.010390508480610183, 0.013323640305176632, 0.016250248588549177, 0.01917034783965299, 0.02208395253514417, 0.024991077119480787, 0.02789173600499617, 0.03078594357196862, 0.0336737141686938, 0.036555062111555126, 0.039430001685095695, 0.042298547142087806, 0.04516071270360533, 0.04801651255909234, 0.05086596086643458, 0.05370907175202966, 0.05654585931085676, 0.05937633760654637, 0.062200520671450654, 0.06501842250671208, 0.06783005708233358, 0.07063543833724806, 0.07343458017938631, 0.07622749648574678, 0.0790142011024646, 0.08179470784487974, 0.08456903049760589, 0.08733718281459768, 0.09009917851922089, 0.09285503130431838, 0.09560475483227959, 0.09834836273510739, 0.10108586861448599, 0.10381728604184803, 0.10654262855844188, 0.10926190967539995, 0.11197514287380361, 0.11468234160475177, 0.11738351928942681, 0.12007868931916144, 0.12276786505550397, 0.1254510598302867, 0.12812828694568967, 0.13079955967430879, 0.1334648912592198, 0.13612429491404443, 0.1387777838230173, 0.1414253711410487, 0.14406706999379293, 0.14670289347770993, 0.14933285466013313, 0.15195696657933278, 0.15457524224458075, 0.15718769463621518, 0.1597943367057051, 0.16239518137571385, 0.16499024154016406, 0.16757953006430104, 0.17016305978475632, 0.17274084350961227, 0.17531289401846428, 0.17787922406248557, 0.18043984636448918, 0.1829947736189912, 0.18554401849227453, 0.1880875936224511, 0.19062551161952435, 0.19315778506545223, 0.19568442651420903, 0.19820544849184785, 0.20072086349656337, 0.20323068399875255, 0.20573492244107738, 0.20823359123852603, 0.21072670277847516, 0.21321426942075017, 0.21569630349768776, 0.21817281731419613, 0.22064382314781605, 0.22310933324878213, 0.22556935984008408, 0.22802391511752562, 0.23047301124978636, 0.2329166603784818, 0.2353548746182228, 0.23778766605667778, 0.24021504675462912, 0.24263702874603643, 0.24505362403809428, 0.24746484461129192, 0.24987070241947396, 0.2522712093898969, 0.25466637742329157, 0.2570562183939198, 0.25944074414963425, 0.2618199665119365, 0.2641938972760367, 0.2665625482109111, 0.2689259310593606, 0.2712840575380693, 0.27363693933766253, 0.27598458812276383, 0.27832701553205474, 0.28066423317833067, 0.2829962526485592, 0.2853230855039375, 0.2876447432799498, 0.28996123748642444, 0.2922725796075909, 0.2945787811021361, 0.29687985340326284, 0.29917580791874454, 0.30146665603098355, 0.303752409097066, 0.30603307844881966, 0.30830867539286877, 0.31057921121069065, 0.312844697158672, 0.31510514446816407, 0.3173605643455386, 0.3196109679722434, 0.32185636650485816, 0.32409677107514834, 0.3263321927901226, 0.3285626427320858, 0.33078813195869505, 0.3330086715030147, 0.33522427237356967, 0.3374349455544018, 0.339640702005123, 0.3418415526609704, 0.34403750843285963, 0.3462285802074401, 0.3484147788471481, 0.3505961151902609, 0.3527726000509508, 0.35494424421933757, 0.3571110584615438, 0.3592730535197469, 0.3614302401122328, 0.3635826289334486, 0.36573023065405685, 0.3678730559209866, 0.3700111153574883, 0.37214441956318445, 0.3742729791141235, 0.37639680456283175, 0.37851590643836575, 0.3806302952463648, 0.38273998146910204, 0.38484497556553776, 0.3869452879713704, 0.3890409290990885, 0.39113190933802255, 0.39321823905439557, 0.39529992859137586, 0.3973769882691275, 0.3994494283848614, 0.40151725921288683, 0.40358049100466187, 0.40563913398884444, 0.40769319837134343, 0.4097426943353686, 0.41178763204148117, 0.41382802162764465, 0.41586387320927487, 0.4178951968792901, 0.4199220027081608, 0.42194430074396017, 0.42396210101241316, 0.42597541351694723, 0.42798424823874115, 0.4299886151367742, 0.4319885241478766, 0.43398398518677794, 0.43597500814615675, 0.4379616028966892, 0.43994377928709816, 0.4419215471442022, 0.4438949162729644, 0.44586389645654045, 0.44782849745632747, 0.4497887290120123, 0.45174460084162016, 0.45369612264156267, 0.45564330408668496, 0.4575861548303153, 0.4595246845043116, 0.46145890271911016, 0.4633888190637726, 0.4653144431060331, 0.46723578439234736, 0.46915285244793814, 0.47106565677684376, 0.47297420686196445, 0.47487851216510946, 0.4767785821270448, 0.47867442616753875, 0.4805660536854095, 0.48245347405857153, 0.48433669664408163, 0.48621573077818614, 0.48809058577636655, 0.4899612709333858, 0.4918277955233349, 0.49369016879967775, 0.49554839999529854, 0.497402498322546, 0.49925247297328035, 0.501098333118918, 0.5029400879104774, 0.5047777464786246, 0.5066113179337175, 0.5084408113658526, 0.510266235844909, 0.5120876004205934, 0.5139049141224852, 0.5157181859600812, 0.5175274249228405, 0.5193326399802289, 0.521133840081763, 0.522931034157055, 0.5247242311158571, 0.5265134398481051, 0.5282986692239631, 0.5300799280938668, 0.5318572252885684, 0.533630569619179, 0.5353999698772135, 0.5371654348346336, 0.5389269732438913, 0.5406845938379724, 0.5424383053304399, 0.5441881164154769, 0.5459340357679301, 0.5476760720433522, 0.5494142338780458, 0.551148529889105, 0.5528789686744591, 0.5546055588129147, 0.5563283088641984, 0.5580472273689993, 0.5597623228490113, 0.561473603806975, 0.5631810787267205, 0.564884756073209, 0.5665846442925748, 0.5682807518121678, 0.5699730870405936, 0.5716616583677575, 0.5733464741649041, 0.5750275427846604, 0.5767048725610757, 0.5783784718096638, 0.5800483488274444, 0.5817145118929837, 0.5833769692664358, 0.585035729189583, 0.5866907998858777, 0.5883421895604823, 0.5899899064003108, 0.5916339585740676, 0.5932743542322905, 0.5949111015073889, 0.5965442085136854, 0.5981736833474556, 0.5997995340869682, 0.601421768792525, 0.6030403955065015, 0.6046554222533854, 0.6062668570398182, 0.6078747078546333, 0.6094789826688962, 0.6110796894359445, 0.6126768360914266, 0.6142704305533414, 0.6158604807220772, 0.6174469944804516, 0.6190299796937501, 0.6206094442097645, 0.6221853958588331, 0.6237578424538788, 0.6253267917904473, 0.6268922516467469, 0.6284542297836863, 0.6300127339449131, 0.6315677718568526, 0.633119351228746, 0.6346674797526879, 0.6362121651036655, 0.6377534149395959, 0.6392912369013648, 0.640825638612863, 0.642356627681026, 0.6438842116958704, 0.6454083982305318, 0.646929194841303, 0.6484466090676702, 0.6499606484323518, 0.6514713204413346, 0.6529786325839119, 0.6544825923327197, 0.6559832071437742, 0.657480484456509, 0.6589744316938119, 0.660465056262061, 0.6619523655511625, 0.6634363669345865, 0.6649170677694038, 0.666394475396323, 0.6678685971397257, 0.6693394403077034, 0.6708070121920945], \"type\": \"scatter\", \"uid\": \"9cf1b3c4-1bd9-4998-b91e-65618cb7444b\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 2.254308617234469, 4.458617234468938, 6.662925851703407, 8.867234468937877, 11.071543086172346, 13.275851703406815, 15.480160320641284, 17.684468937875753, 19.88877755511022, 22.09308617234469, 24.29739478957916, 26.50170340681363, 28.706012024048096, 30.910320641282567, 33.114629258517034, 35.3189378757515, 37.52324649298597, 39.727555110220436, 41.93186372745491, 44.13617234468938, 46.340480961923845, 48.54478957915832, 50.74909819639279, 52.953406813627254, 55.15771543086172, 57.36202404809619, 59.56633266533066, 61.77064128256513, 63.9749498997996, 66.17925851703407, 68.38356713426853, 70.587875751503, 72.79218436873748, 74.99649298597194, 77.20080160320641, 79.40511022044087, 81.60941883767535, 83.81372745490982, 86.01803607214428, 88.22234468937876, 90.42665330661323, 92.63096192384769, 94.83527054108217, 97.03957915831664, 99.2438877755511, 101.44819639278558, 103.65250501002004, 105.85681362725451, 108.06112224448898, 110.26543086172344, 112.46973947895792, 114.67404809619238, 116.87835671342685, 119.08266533066133, 121.28697394789579, 123.49128256513026, 125.69559118236474, 127.8998997995992, 130.10420841683367, 132.30851703406816, 134.51282565130262, 136.71713426853708, 138.92144288577157, 141.12575150300603, 143.3300601202405, 145.53436873747498, 147.73867735470944, 149.9429859719439, 152.1472945891784, 154.35160320641285, 156.5559118236473, 158.76022044088177, 160.96452905811626, 163.16883767535072, 165.37314629258518, 167.57745490981966, 169.78176352705412, 171.98607214428858, 174.19038076152307, 176.39468937875753, 178.598997995992, 180.80330661322648, 183.00761523046094, 185.2119238476954, 187.4162324649299, 189.62054108216435, 191.8248496993988, 194.0291583166333, 196.23346693386776, 198.43777555110222, 200.64208416833668, 202.84639278557117, 205.05070140280563, 207.2550100200401, 209.45931863727458, 211.66362725450904, 213.8679358717435, 216.072244488978, 218.27655310621245, 220.4808617234469, 222.6851703406814, 224.88947895791586, 227.09378757515032, 229.29809619238478, 231.50240480961926, 233.70671342685372, 235.91102204408818, 238.11533066132267, 240.31963927855713, 242.5239478957916, 244.72825651302608, 246.93256513026054, 249.136873747495, 251.3411823647295, 253.54549098196395, 255.7497995991984, 257.95410821643287, 260.15841683366733, 262.36272545090185, 264.5670340681363, 266.77134268537077, 268.97565130260523, 271.1799599198397, 273.38426853707415, 275.58857715430867, 277.7928857715431, 279.9971943887776, 282.20150300601205, 284.4058116232465, 286.61012024048097, 288.8144288577154, 291.01873747494994, 293.2230460921844, 295.42735470941886, 297.6316633266533, 299.8359719438878, 302.04028056112224, 304.24458917835676, 306.4488977955912, 308.6532064128257, 310.85751503006014, 313.0618236472946, 315.26613226452906, 317.4704408817635, 319.67474949899804, 321.8790581162325, 324.08336673346696, 326.2876753507014, 328.4919839679359, 330.69629258517034, 332.90060120240486, 335.1049098196393, 337.3092184368738, 339.51352705410824, 341.7178356713427, 343.92214428857716, 346.1264529058117, 348.33076152304614, 350.5350701402806, 352.73937875751506, 354.9436873747495, 357.147995991984, 359.35230460921844, 361.55661322645295, 363.7609218436874, 365.9652304609219, 368.16953907815633, 370.3738476953908, 372.57815631262525, 374.78246492985977, 376.98677354709423, 379.1910821643287, 381.39539078156315, 383.5996993987976, 385.80400801603207, 388.0083166332666, 390.21262525050105, 392.4169338677355, 394.62124248496997, 396.82555110220443, 399.0298597194389, 401.23416833667335, 403.43847695390787, 405.6427855711423, 407.8470941883768, 410.05140280561125, 412.2557114228457, 414.46002004008017, 416.6643286573147, 418.86863727454914, 421.0729458917836, 423.27725450901806, 425.4815631262525, 427.685871743487, 429.89018036072144, 432.09448897795596, 434.2987975951904, 436.5031062124249, 438.70741482965934, 440.9117234468938, 443.11603206412826, 445.3203406813628, 447.52464929859724, 449.7289579158317, 451.93326653306616, 454.1375751503006, 456.3418837675351, 458.54619238476954, 460.75050100200406, 462.9548096192385, 465.159118236473, 467.36342685370744, 469.5677354709419, 471.77204408817636, 473.9763527054109, 476.18066132264534, 478.3849699398798, 480.58927855711426, 482.7935871743487, 484.9978957915832, 487.2022044088177, 489.40651302605215, 491.6108216432866, 493.8151302605211, 496.01943887775553, 498.22374749499, 500.42805611222445, 502.63236472945897, 504.83667334669343, 507.0409819639279, 509.24529058116235, 511.4495991983968, 513.6539078156312, 515.8582164328657, 518.0625250501001, 520.2668336673346, 522.4711422845692, 524.6754509018036, 526.8797595190381, 529.0840681362725, 531.288376753507, 533.4926853707415, 535.6969939879759, 537.9013026052104, 540.1056112224448, 542.3099198396793, 544.5142284569138, 546.7185370741482, 548.9228456913827, 551.1271543086173, 553.3314629258517, 555.5357715430862, 557.7400801603206, 559.9443887775551, 562.1486973947896, 564.353006012024, 566.5573146292585, 568.761623246493, 570.9659318637274, 573.1702404809619, 575.3745490981963, 577.5788577154308, 579.7831663326654, 581.9874749498998, 584.1917835671343, 586.3960921843687, 588.6004008016032, 590.8047094188377, 593.0090180360721, 595.2133266533066, 597.417635270541, 599.6219438877755, 601.82625250501, 604.0305611222444, 606.2348697394789, 608.4391783567135, 610.6434869739479, 612.8477955911824, 615.0521042084168, 617.2564128256513, 619.4607214428858, 621.6650300601202, 623.8693386773547, 626.0736472945891, 628.2779559118236, 630.482264529058, 632.6865731462925, 634.890881763527, 637.0951903807616, 639.299498997996, 641.5038076152305, 643.7081162324649, 645.9124248496994, 648.1167334669339, 650.3210420841683, 652.5253507014028, 654.7296593186372, 656.9339679358717, 659.1382765531062, 661.3425851703406, 663.5468937875752, 665.7512024048096, 667.9555110220441, 670.1598196392786, 672.364128256513, 674.5684368737475, 676.772745490982, 678.9770541082164, 681.1813627254509, 683.3856713426853, 685.5899799599198, 687.7942885771542, 689.9985971943887, 692.2029058116233, 694.4072144288577, 696.6115230460922, 698.8158316633267, 701.0201402805611, 703.2244488977956, 705.42875751503, 707.6330661322645, 709.837374749499, 712.0416833667334, 714.2459919839679, 716.4503006012023, 718.6546092184368, 720.8589178356714, 723.0632264529058, 725.2675350701403, 727.4718436873748, 729.6761523046092, 731.8804609218437, 734.0847695390781, 736.2890781563126, 738.4933867735471, 740.6976953907815, 742.902004008016, 745.1063126252504, 747.3106212424849, 749.5149298597195, 751.7192384769539, 753.9235470941884, 756.1278557114229, 758.3321643286573, 760.5364729458918, 762.7407815631262, 764.9450901803607, 767.1493987975952, 769.3537074148296, 771.5580160320641, 773.7623246492985, 775.9666332665331, 778.1709418837676, 780.375250501002, 782.5795591182365, 784.783867735471, 786.9881763527054, 789.1924849699399, 791.3967935871743, 793.6011022044088, 795.8054108216432, 798.0097194388777, 800.2140280561122, 802.4183366733466, 804.6226452905812, 806.8269539078157, 809.0312625250501, 811.2355711422846, 813.439879759519, 815.6441883767535, 817.848496993988, 820.0528056112224, 822.2571142284569, 824.4614228456913, 826.6657314629258, 828.8700400801603, 831.0743486973947, 833.2786573146293, 835.4829659318638, 837.6872745490982, 839.8915831663327, 842.0958917835671, 844.3002004008016, 846.5045090180361, 848.7088176352705, 850.913126252505, 853.1174348697394, 855.3217434869739, 857.5260521042084, 859.7303607214428, 861.9346693386774, 864.1389779559119, 866.3432865731463, 868.5475951903808, 870.7519038076152, 872.9562124248497, 875.1605210420842, 877.3648296593186, 879.5691382765531, 881.7734468937875, 883.977755511022, 886.1820641282565, 888.3863727454909, 890.5906813627255, 892.79498997996, 894.9992985971944, 897.2036072144289, 899.4079158316633, 901.6122244488978, 903.8165330661323, 906.0208416833667, 908.2251503006012, 910.4294589178356, 912.6337675350701, 914.8380761523046, 917.042384769539, 919.2466933867736, 921.451002004008, 923.6553106212425, 925.859619238477, 928.0639278557114, 930.2682364729459, 932.4725450901803, 934.6768537074148, 936.8811623246493, 939.0854709418837, 941.2897795591182, 943.4940881763526, 945.6983967935872, 947.9027054108217, 950.1070140280561, 952.3113226452906, 954.5156312625251, 956.7199398797595, 958.924248496994, 961.1285571142284, 963.3328657314629, 965.5371743486974, 967.7414829659318, 969.9457915831663, 972.1501002004007, 974.3544088176353, 976.5587174348698, 978.7630260521042, 980.9673346693387, 983.1716432865732, 985.3759519038076, 987.5802605210421, 989.7845691382765, 991.988877755511, 994.1931863727455, 996.3974949899799, 998.6018036072144, 1000.8061122244488, 1003.0104208416834, 1005.2147294589179, 1007.4190380761523, 1009.6233466933868, 1011.8276553106213, 1014.0319639278557, 1016.2362725450902, 1018.4405811623246, 1020.6448897795591, 1022.8491983967936, 1025.0535070140281, 1027.2578156312625, 1029.462124248497, 1031.6664328657314, 1033.870741482966, 1036.0750501002003, 1038.279358717435, 1040.4836673346692, 1042.6879759519038, 1044.8922845691384, 1047.0965931863727, 1049.3009018036073, 1051.5052104208416, 1053.7095190380762, 1055.9138276553106, 1058.1181362725451, 1060.3224448897795, 1062.526753507014, 1064.7310621242484, 1066.935370741483, 1069.1396793587173, 1071.343987975952, 1073.5482965931865, 1075.7526052104208, 1077.9569138276554, 1080.1612224448897, 1082.3655310621243, 1084.5698396793587, 1086.7741482965932, 1088.9784569138276, 1091.1827655310622, 1093.3870741482965, 1095.591382765531, 1097.7956913827654, 1100.0], \"y\": [0.7053140636651443, 0.7004218657095753, 0.6955416352192654, 0.6906733429189835, 0.6858169596051129, 0.6809724561454757, 0.6761398034791581, 0.6713189726163362, 0.6665099346381018, 0.6617126606962898, 0.6569271220133035, 0.6521532898819438, 0.6473911356652358, 0.6426406307962571, 0.6379017467779675, 0.6331744551830365, 0.6284587276536737, 0.6237545359014587, 0.6190618517071711, 0.6143806469206214, 0.609710893460482, 0.6050525633141188, 0.6004056285374235, 0.595770061254645, 0.5911458336582236, 0.5865329180086227, 0.5819312866341639, 0.5773409119308595, 0.5727617663622477, 0.5681938224592282, 0.5636370528198955, 0.5590914301093761, 0.5545569270596642, 0.5500335164694576, 0.5455211712039949, 0.5410198641948929, 0.536529568439984, 0.532050257003154, 0.5275819030141811, 0.5231244796685741, 0.5186779602274119, 0.5142423180171833, 0.5098175264296265, 0.50540355892157, 0.5010003890147732, 0.49660799029576674, 0.492226336415696, 0.487855401090161, 0.48349515809905985, 0.47914558128643114, 0.4748066445602972, 0.47047832189250705, 0.46616058731858145, 0.4618534149375555, 0.45755677891182467, 0.45327065346698925, 0.44899501289169974, 0.44472983153750256, 0.44047508381868616, 0.43623074421212804, 0.43199678725714064, 0.4277731875553199, 0.42355991977039187, 0.41935695862806077, 0.4151642789158585, 0.4109818554829918, 0.40680966324019274, 0.40264767715956706, 0.39849587227444494, 0.394354223679231, 0.3902227065292545, 0.38610129604062093, 0.38198996749006286, 0.3778886962147914, 0.3737974576123495, 0.3697162271404624, 0.36564498031689263, 0.36158369271929125, 0.3575323399850523, 0.3534908978111666, 0.3494593419540759, 0.34543764822952694, 0.34142579251242755, 0.3374237507367004, 0.33343149889514034, 0.32944901303926843, 0.32547626927919016, 0.3215132437834509, 0.3175599127788937, 0.31361625255051595, 0.3096822394413279, 0.30575784985221, 0.30184306024177143, 0.2979378471262102, 0.2940421870791703, 0.29015605673160216, 0.2862794327716227, 0.2824122919443752, 0.2785546110518895, 0.27470636695294326, 0.27086753656292295, 0.2670380968536856, 0.2632180248534204, 0.2594072976465107, 0.2556058923733975, 0.2518137862304408, 0.24803095646978424, 0.24425738039921807, 0.24049303538204292, 0.23673789883693352, 0.2329919482378051, 0.2292551611136755, 0.2255275150485332, 0.2218089876812006, 0.21809955670520087, 0.21439919986862477, 0.21070789497399578, 0.20702561987813772, 0.20335235249204198, 0.1996880707807347, 0.19603275276314513, 0.19238637651197266, 0.18874892015355682, 0.1851203618677446, 0.18150067988776053, 0.1778898525000756, 0.1742878580442775, 0.17069467491294033, 0.16711028155149465, 0.16353465645809862, 0.1599677781835096, 0.15640962533095415, 0.15286017655600026, 0.1493194105664304, 0.14578730612211155, 0.14226384203487008, 0.13874899716836286, 0.13524275043795164, 0.131745080810576, 0.12825596730462752, 0.12477538898982332, 0.12130332498708118, 0.11783975446839423, 0.1143846566567055, 0.11093801082578336, 0.10749979630009765, 0.10406999245469595, 0.10064857871507837, 0.0972355345570759, 0.09383083950672577, 0.09043447314014963, 0.08704641508343092, 0.08366664501249255, 0.0802951426529741, 0.07693188778011195, 0.07357686021861665, 0.07023003984255194, 0.06689140657521464, 0.06356094038901383, 0.06023862130535096, 0.05692442939449949, 0.053618344775486104, 0.050320347615970595, 0.04703041813212727, 0.04374853658852684, 0.040474683298016956, 0.03720883862160518, 0.033950982968340204, 0.03070109679519506, 0.02745916060694964, 0.024225154956073247, 0.020999060442609352, 0.01778085771405724, 0.014570527465257443, 0.011368050438275823, 0.008173407422286783, 0.0049865792534598, 0.0018075468148430751, 0.0013637089637505984, 0.004527207105858189, 0.007682966588480333, 0.010831006342196137, 0.013971345251275524, 0.017104002153793374, 0.020228995841741648, 0.023346345061143525, 0.02645606851216442, 0.02955818484922479, 0.03265271268111225, 0.03573967057109262, 0.038819077037022254, 0.04189095055145731, 0.044955309541766963, 0.04801217239024225, 0.051061557434206595, 0.054103482966126215, 0.057137967233719555, 0.06016502844006699, 0.06318468474371985, 0.06619695425880923, 0.06920185505515519, 0.07219940515837431, 0.07518962254998862, 0.07817252516753292, 0.08114813090466244, 0.08411645761126074, 0.08707752309354633, 0.0900313451141792, 0.09297794139236748, 0.09591732960397525, 0.09884952738162545, 0.10177455231480903, 0.10469242194998785, 0.10760315379070184, 0.11050676529767234, 0.11340327388890836, 0.11629269693980993, 0.11917505178327326, 0.12205035570979339, 0.12491862596756964, 0.12777987976260774, 0.13063413425882353, 0.13348140657814556, 0.13632171380061897, 0.13915507296450635, 0.14198150106639096, 0.14480101506127818, 0.14761363186269816, 0.15041936834280567, 0.15321824133248296, 0.1560102676214392, 0.15879546395831334, 0.1615738470507715, 0.16434543356561027, 0.16711024012885467, 0.1698682833258589, 0.17261957970140518, 0.17536414575980364, 0.1781019979649907, 0.18083315274062817, 0.1835576264702019, 0.18627543549711967, 0.1889865961248096, 0.1916911246168178, 0.19438903719690614, 0.19708035004914848, 0.19976507931802967, 0.20244324110854084, 0.20511485148627662, 0.20777992647753152, 0.21043848206939586, 0.2130905342098517, 0.21573609880786848, 0.21837519173349929, 0.22100782881797443, 0.2236340258537981, 0.22625379859484118, 0.22886716275643826, 0.23147413401547978, 0.23407472801050666, 0.23666896034180485, 0.23925684657149793, 0.24183840222364084, 0.24441364278431355, 0.24698258370171255, 0.24954524038624526, 0.252101628210621, 0.2546517625099445, 0.2571956585818065, 0.259733331686377, 0.2622647970464951, 0.2647900698477619, 0.26730916523863124, 0.2698220983304995, 0.27232888419779755, 0.2748295378780805, 0.27732407437211815, 0.27981250864398444, 0.28229485562114864, 0.284771130194563, 0.2872413472187536, 0.2897055215119084, 0.2921636678559667, 0.29461580099670825, 0.2970619356438402, 0.2995020864710872, 0.30193626811627805, 0.30436449518143394, 0.3067867822328565, 0.3092031438012143, 0.3116135943816306, 0.3140181484337703, 0.31641682038192653, 0.3188096246151073, 0.32119657548712155, 0.3235776873166655, 0.32595297438740845, 0.32832245094807866, 0.3306861312125483, 0.3330440293599194, 0.33539615953460855, 0.33774253584643166, 0.34008317237068864, 0.34241808314824806, 0.3447472821856312, 0.347070783455096, 0.3493886008947211, 0.3517007484084895, 0.35400723986637117, 0.3563080891044077, 0.3586033099247937, 0.36089291609596097, 0.36317692135266, 0.36545533939604335, 0.3677281838937472, 0.3699954684799728, 0.37225720675557006, 0.3745134122881173, 0.37676409861200344, 0.37900927922850924, 0.3812489676058882, 0.38348317717944724, 0.38571192135162713, 0.3879352134920836, 0.3901530669377665, 0.3923654949930009, 0.39457251092956613, 0.3967741279867756, 0.3989703593715562, 0.4011612182585277, 0.4033467177900816, 0.40552687107646, 0.40770169119583444, 0.40987119119438387, 0.4120353840863734, 0.41419428285423243, 0.4163479004486318, 0.41849624978856237, 0.4206393437614119, 0.42277719522304247, 0.42490981699786823, 0.427037221878931, 0.42915942262797857, 0.43127643197554, 0.4333882626210027, 0.43549492723268846, 0.43759643844792917, 0.4396928088731429, 0.4417840510839095, 0.4438701776250462, 0.4459512010106823, 0.4480271337243349, 0.45009798821898317, 0.4521637769171436, 0.4542245122109442, 0.456280206462199, 0.45833087200248224, 0.4603765211332018, 0.46241716612567396, 0.46445281922119597, 0.46648349263112054, 0.46850919853692796, 0.4705299490903002, 0.4725457564131932, 0.4745566325979098, 0.47656258970717225, 0.47856363977419414, 0.4805597948027537, 0.48255106676726456, 0.4845374676128482, 0.48651900925540603, 0.4884957035816895, 0.49046756244937295, 0.49243459768712383, 0.494396821094674, 0.4963542444428901, 0.4983068794738449, 0.5002547379008869, 0.5021978314087114, 0.5041361716534298, 0.50606977026264, 0.5079986388354963, 0.5099227889427786, 0.5118422321269619, 0.5137569799022856, 0.5156670437548228, 0.5175724351425486, 0.5194731654954092, 0.521369246215391, 0.523260688676588, 0.5251475042252706, 0.5270297041799537, 0.5289072998314639, 0.5307803024430084, 0.5326487232502419, 0.5345125734613339, 0.5363718642570359, 0.5382266067907489, 0.5400768121885899, 0.5419224915494593, 0.5437636559451061, 0.545600316420196, 0.5474324839923764, 0.5492601696523434, 0.5510833843639066, 0.5529021390640559, 0.554716444663027, 0.5565263120443663, 0.5583317520649965, 0.5601327755552818, 0.5619293933190928, 0.5637216161338711, 0.5655094547506945, 0.5672929198943409, 0.5690720222633529, 0.5708467725301017, 0.5726171813408522, 0.574383259315825, 0.5761450170492618, 0.5779024651094881, 0.5796556140389769, 0.5814044743544116, 0.5831490565467494, 0.5848893710812844, 0.5866254283977099, 0.5883572389101814, 0.5900848130073787, 0.5918081610525686, 0.593527293383667, 0.5952422203133009, 0.5969529521288697, 0.5986594990926078, 0.6003618714416458, 0.6020600793880717, 0.6037541331189924, 0.6054440427965948, 0.6071298185582068, 0.6088114705163576, 0.6104890087588392, 0.6121624433487662, 0.6138317843246368, 0.6154970417003925, 0.617158225465478, 0.6188153455849023, 0.6204684119992965, 0.6221174346249756, 0.6237624233539966, 0.625403388054218, 0.6270403385693598, 0.628673284719061, 0.6303022362989404, 0.6319272030806538, 0.6335481948119535, 0.6351652212167466, 0.6367782919951529, 0.6383874168235638, 0.6399926053546995, 0.6415938672176679, 0.6431912120180215, 0.6447846493378158, 0.6463741887356657, 0.6479598397468038, 0.6495416118831374, 0.6511195146333053, 0.6526935574627349, 0.654263749813699, 0.6558301011053721, 0.6573926207338877, 0.6589513180723934, 0.6605062024711088, 0.6620572832573799, 0.6636045697357363, 0.6651480711879462, 0.6666877968730727, 0.6682237560275289, 0.6697559578651332, 0.6712844115771656, 0.6728091263324212, 0.6743301112772668, 0.6758473755356942, 0.677360928209377, 0.6788707783777226, 0.680376935097929, 0.6818794074050377, 0.6833782043119888, 0.6848733348096739, 0.6863648078669918, 0.6878526324309002, 0.6893368174264711, 0.6908173717569434, 0.6922943043037768, 0.6937676239267048, 0.6952373394637876, 0.696703459731466, 0.6981659935246132, 0.6996249496165885, 0.7010803367592888, 0.7025321636832029, 0.7039804390974619, 0.7054251716898926], \"type\": \"scatter\", \"uid\": \"a4acf9a5-15f3-4ccb-828b-81dc8017b6da\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 2.4547094188376755, 4.859418837675351, 7.264128256513026, 9.668837675350703, 12.07354709418838, 14.478256513026054, 16.88296593186373, 19.287675350701406, 21.692384769539082, 24.097094188376758, 26.501803607214434, 28.906513026052107, 31.311222444889783, 33.715931863727455, 36.12064128256513, 38.52535070140281, 40.93006012024048, 43.33476953907816, 45.739478957915836, 48.14418837675351, 50.54889779559119, 52.953607214428864, 55.35831663326654, 57.76302605210421, 60.167735470941885, 62.57244488977956, 64.97715430861724, 67.38186372745491, 69.7865731462926, 72.19128256513027, 74.59599198396795, 77.00070140280562, 79.40541082164329, 81.81012024048097, 84.21482965931864, 86.61953907815632, 89.02424849699399, 91.42895791583167, 93.83366733466934, 96.23837675350703, 98.6430861723447, 101.04779559118238, 103.45250501002005, 105.85721442885773, 108.2619238476954, 110.66663326653308, 113.07134268537075, 115.47605210420842, 117.8807615230461, 120.28547094188377, 122.69018036072146, 125.09488977955913, 127.49959919839681, 129.9043086172345, 132.30901803607216, 134.71372745490984, 137.11843687374753, 139.5231462925852, 141.92785571142286, 144.33256513026055, 146.73727454909823, 149.14198396793591, 151.54669338677357, 153.95140280561125, 156.35611222444894, 158.7608216432866, 161.16553106212427, 163.57024048096196, 165.97494989979964, 168.3796593186373, 170.78436873747498, 173.18907815631266, 175.59378757515034, 177.998496993988, 180.40320641282568, 182.80791583166337, 185.21262525050105, 187.6173346693387, 190.0220440881764, 192.42675350701407, 194.83146292585172, 197.2361723446894, 199.6408817635271, 202.04559118236477, 204.45030060120243, 206.8550100200401, 209.2597194388778, 211.66442885771548, 214.06913827655313, 216.47384769539082, 218.8785571142285, 221.28326653306618, 223.68797595190384, 226.09268537074152, 228.4973947895792, 230.90210420841686, 233.30681362725454, 235.71152304609222, 238.1162324649299, 240.52094188376756, 242.92565130260525, 245.33036072144293, 247.7350701402806, 250.13977955911827, 252.54448897795595, 254.94919839679363, 257.3539078156313, 259.758617234469, 262.1633266533067, 264.5680360721443, 266.972745490982, 269.3774549098197, 271.78216432865736, 274.18687374749504, 276.5915831663327, 278.9962925851704, 281.40100200400803, 283.8057114228457, 286.2104208416834, 288.6151302605211, 291.01983967935877, 293.42454909819645, 295.82925851703413, 298.2339679358718, 300.63867735470944, 303.0433867735471, 305.4480961923848, 307.8528056112225, 310.2575150300602, 312.66222444889786, 315.06693386773554, 317.47164328657317, 319.87635270541085, 322.28106212424854, 324.6857715430862, 327.0904809619239, 329.4951903807616, 331.89989979959927, 334.30460921843695, 336.7093186372746, 339.11402805611226, 341.51873747494994, 343.9234468937876, 346.3281563126253, 348.732865731463, 351.1375751503007, 353.5422845691383, 355.946993987976, 358.35170340681367, 360.75641282565135, 363.16112224448904, 365.5658316633267, 367.9705410821644, 370.3752505010021, 372.7799599198397, 375.1846693386774, 377.5893787575151, 379.99408817635276, 382.39879759519044, 384.8035070140281, 387.2082164328658, 389.61292585170344, 392.0176352705411, 394.4223446893788, 396.8270541082165, 399.23176352705417, 401.63647294589185, 404.04118236472954, 406.4458917835672, 408.85060120240485, 411.25531062124253, 413.6600200400802, 416.0647294589179, 418.4694388777556, 420.87414829659326, 423.27885771543095, 425.68356713426857, 428.08827655310625, 430.49298597194394, 432.8976953907816, 435.3024048096193, 437.707114228457, 440.11182364729467, 442.51653306613235, 444.92124248497, 447.32595190380766, 449.73066132264535, 452.13537074148303, 454.5400801603207, 456.9447895791584, 459.3494989979961, 461.7542084168337, 464.1589178356714, 466.5636272545091, 468.96833667334676, 471.37304609218444, 473.7777555110221, 476.1824649298598, 478.5871743486975, 480.9918837675351, 483.3965931863728, 485.8013026052105, 488.20601202404816, 490.61072144288585, 493.01543086172353, 495.4201402805612, 497.8248496993989, 500.2295591182365, 502.6342685370742, 505.0389779559119, 507.4436873747496, 509.84839679358726, 512.2531062124249, 514.6578156312626, 517.0625250501002, 519.4672344689379, 521.8719438877756, 524.2766533066133, 526.6813627254509, 529.0860721442886, 531.4907815631262, 533.8954909819639, 536.3002004008016, 538.7049098196393, 541.109619238477, 543.5143286573146, 545.9190380761523, 548.32374749499, 550.7284569138277, 553.1331663326654, 555.5378757515031, 557.9425851703407, 560.3472945891784, 562.752004008016, 565.1567134268537, 567.5614228456914, 569.966132264529, 572.3708416833667, 574.7755511022044, 577.1802605210421, 579.5849699398798, 581.9896793587175, 584.3943887775552, 586.7990981963928, 589.2038076152305, 591.6085170340682, 594.0132264529059, 596.4179358717436, 598.8226452905811, 601.2273547094188, 603.6320641282565, 606.0367735470942, 608.4414829659319, 610.8461923847696, 613.2509018036072, 615.6556112224449, 618.0603206412826, 620.4650300601203, 622.869739478958, 625.2744488977957, 627.6791583166333, 630.083867735471, 632.4885771543087, 634.8932865731463, 637.297995991984, 639.7027054108216, 642.1074148296593, 644.512124248497, 646.9168336673347, 649.3215430861724, 651.72625250501, 654.1309619238477, 656.5356713426854, 658.9403807615231, 661.3450901803608, 663.7497995991985, 666.1545090180362, 668.5592184368738, 670.9639278557114, 673.3686372745491, 675.7733466933868, 678.1780561122245, 680.5827655310621, 682.9874749498998, 685.3921843687375, 687.7968937875752, 690.2016032064129, 692.6063126252506, 695.0110220440882, 697.4157314629259, 699.8204408817636, 702.2251503006013, 704.629859719439, 707.0345691382765, 709.4392785571142, 711.8439879759519, 714.2486973947896, 716.6534068136273, 719.058116232465, 721.4628256513026, 723.8675350701403, 726.272244488978, 728.6769539078157, 731.0816633266534, 733.486372745491, 735.8910821643287, 738.2957915831664, 740.7005010020041, 743.1052104208417, 745.5099198396794, 747.914629258517, 750.3193386773547, 752.7240480961924, 755.1287575150301, 757.5334669338678, 759.9381763527055, 762.3428857715431, 764.7475951903808, 767.1523046092185, 769.5570140280562, 771.9617234468939, 774.3664328657316, 776.7711422845692, 779.1758517034068, 781.5805611222445, 783.9852705410822, 786.3899799599199, 788.7946893787575, 791.1993987975952, 793.6041082164329, 796.0088176352706, 798.4135270541083, 800.818236472946, 803.2229458917836, 805.6276553106213, 808.032364729459, 810.4370741482967, 812.8417835671344, 815.2464929859719, 817.6512024048096, 820.0559118236473, 822.460621242485, 824.8653306613227, 827.2700400801604, 829.674749498998, 832.0794589178357, 834.4841683366734, 836.8888777555111, 839.2935871743488, 841.6982965931865, 844.1030060120241, 846.5077154308618, 848.9124248496995, 851.3171342685371, 853.7218436873748, 856.1265531062124, 858.5312625250501, 860.9359719438878, 863.3406813627255, 865.7453907815632, 868.1501002004009, 870.5548096192385, 872.9595190380762, 875.3642284569139, 877.7689378757516, 880.1736472945893, 882.578356713427, 884.9830661322646, 887.3877755511022, 889.7924849699399, 892.1971943887776, 894.6019038076153, 897.0066132264529, 899.4113226452906, 901.8160320641283, 904.220741482966, 906.6254509018037, 909.0301603206414, 911.434869739479, 913.8395791583167, 916.2442885771544, 918.6489979959921, 921.0537074148298, 923.4584168336673, 925.863126252505, 928.2678356713427, 930.6725450901804, 933.0772545090181, 935.4819639278558, 937.8866733466934, 940.2913827655311, 942.6960921843688, 945.1008016032065, 947.5055110220442, 949.9102204408819, 952.3149298597195, 954.7196392785572, 957.1243486973949, 959.5290581162326, 961.9337675350702, 964.3384769539078, 966.7431863727455, 969.1478957915832, 971.5526052104209, 973.9573146292586, 976.3620240480963, 978.7667334669339, 981.1714428857716, 983.5761523046093, 985.980861723447, 988.3855711422847, 990.7902805611224, 993.19498997996, 995.5996993987977, 998.0044088176353, 1000.409118236473, 1002.8138276553107, 1005.2185370741483, 1007.623246492986, 1010.0279559118237, 1012.4326653306614, 1014.8373747494991, 1017.2420841683368, 1019.6467935871744, 1022.0515030060121, 1024.4562124248498, 1026.8609218436875, 1029.2656312625252, 1031.6703406813629, 1034.0750501002005, 1036.4797595190382, 1038.884468937876, 1041.2891783567136, 1043.6938877755513, 1046.098597194389, 1048.5033066132266, 1050.908016032064, 1053.3127254509018, 1055.7174348697395, 1058.1221442885771, 1060.5268537074148, 1062.9315631262525, 1065.3362725450902, 1067.7409819639279, 1070.1456913827656, 1072.5504008016032, 1074.955110220441, 1077.3598196392786, 1079.7645290581163, 1082.169238476954, 1084.5739478957917, 1086.9786573146293, 1089.383366733467, 1091.7880761523047, 1094.1927855711424, 1096.59749498998, 1099.0022044088178, 1101.4069138276554, 1103.8116232464931, 1106.2163326653308, 1108.6210420841685, 1111.0257515030062, 1113.4304609218439, 1115.8351703406815, 1118.2398797595192, 1120.644589178357, 1123.0492985971944, 1125.454008016032, 1127.8587174348697, 1130.2634268537074, 1132.668136272545, 1135.0728456913828, 1137.4775551102205, 1139.8822645290581, 1142.2869739478958, 1144.6916833667335, 1147.0963927855712, 1149.5011022044089, 1151.9058116232466, 1154.3105210420842, 1156.715230460922, 1159.1199398797596, 1161.5246492985973, 1163.929358717435, 1166.3340681362727, 1168.7387775551103, 1171.143486973948, 1173.5481963927857, 1175.9529058116234, 1178.357615230461, 1180.7623246492988, 1183.1670340681364, 1185.5717434869741, 1187.9764529058118, 1190.3811623246495, 1192.7858717434872, 1195.1905811623246, 1197.5952905811623, 1200.0], \"y\": [0.7362917538595248, 0.7309553843163399, 0.7256332539841508, 0.7203253248680013, 0.7150315590743173, 0.7097519188106385, 0.7044863663853465, 0.6992348642073973, 0.6939973747860522, 0.6887738607306102, 0.6835642847501411, 0.6783686096532195, 0.6731867983476587, 0.668018813840247, 0.662864619236482, 0.6577241777403091, 0.6525974526538572, 0.6474844073771773, 0.6423850054079814, 0.6372992103413821, 0.6322269858696321, 0.627168295781865, 0.6221231039638373, 0.6170913743976703, 0.6120730711615932, 0.6070681584296858, 0.602076600471624, 0.5970983616524244, 0.5921334064321886, 0.5871816993658512, 0.5822432051029258, 0.577317888387253, 0.5724057140567482, 0.5675066470431518, 0.5626206523717772, 0.5577476951612619, 0.552887740623319, 0.5480407540624881, 0.5432067008758878, 0.5383855465529686, 0.5335772566752668, 0.5287817969161588, 0.5239991330406153, 0.5192292309049582, 0.5144720564566154, 0.5097275757338791, 0.5049957548656618, 0.5002765600712562, 0.4955699576600927, 0.4908759140314991, 0.4861943956744619, 0.48152536916738486, 0.47686880117785324, 0.4722246584623928, 0.46759290786623464, 0.46297351632307815, 0.45836645085485417, 0.4537716785714896, 0.4491891666706742, 0.44461888243762426, 0.4400607932448499, 0.43551486655192306, 0.4309810699052439, 0.4264593709378095, 0.4219497373689829, 0.417452137004263, 0.412966537735054, 0.4084929075384365, 0.4040312144769391, 0.3995814266983102, 0.39514351243529044, 0.39071744000538633, 0.3863031778106434, 0.3819006943374217, 0.3775099581561696, 0.3731309379212002, 0.36876360237046746, 0.3644079203253425, 0.36006386069039187, 0.35573139245315466, 0.35141048468392166, 0.34710110653551496, 0.34280322724306633, 0.338516816123799, 0.3342418425768079, 0.3299782760828416, 0.3257260862040836, 0.3214852425839363, 0.31725571494680316, 0.31303747309787333, 0.3088304869229055, 0.30463472638801337, 0.30045016153945103, 0.29627676250339907, 0.2921144994857512, 0.2879633427719024, 0.28382326272653513, 0.27969422979340974, 0.27557621449515146, 0.27146918743304194, 0.26737311928680785, 0.2632879808144122, 0.2592137428518453, 0.25515037631291726, 0.25109785218904945, 0.24705614154906796, 0.2430252155389967, 0.23900504538185152, 0.23499560237743533, 0.23099685790213242, 0.22700878340870445, 0.22303135042608613, 0.2190645305591834, 0.21510829548866894, 0.21116261697078142, 0.2072274668371228, 0.20330281699445818, 0.19938863942451435, 0.19548490618378045, 0.19159158940330778, 0.18770866128851194, 0.18383609411897317, 0.17997386024823947, 0.17612193210362825, 0.17228028218603053, 0.16844888306971417, 0.16462770740212718, 0.16081672790370427, 0.1570159173676704, 0.15322524865984777, 0.14944469471846134, 0.14567422855394607, 0.141913823248754, 0.13816345195716173, 0.13442308790508006, 0.13069270438986091, 0.12697227478010897, 0.1232617725154892, 0.11956117110653919, 0.11587044413447867, 0.1121895652510223, 0.10851850817818964, 0.10485724670811947, 0.10120575470288129, 0.09756400609429017, 0.09393197488371863, 0.09030963514191326, 0.08669696100880797, 0.0830939266933397, 0.07950050647326501, 0.07591667469497598, 0.07234240577331685, 0.06877767419140146, 0.0652224545004314, 0.06167672131951418, 0.058140449335482014, 0.05461361330271064, 0.051096188042939916, 0.04758814844509396, 0.04408946946510084, 0.040600126125715175, 0.03712009351633894, 0.03364934679284404, 0.03018786117739425, 0.02673561195826979, 0.023292574489689022, 0.01985872419163437, 0.016434036549675124, 0.013018487114793587, 0.009612051503210317, 0.00621470539620983, 0.002826424539966954, 0.0005528152546263598, 0.003923038112132904, 0.007284268092743851, 0.010636529192449506, 0.013979845343210728, 0.0173142404131299, 0.020639738206621683, 0.023956362464582437, 0.027264136864559863, 0.030563085020922198, 0.03385323048502653, 0.03713459674538733, 0.04040720722784363, 0.043671085295726275, 0.046926254250025945, 0.050172737329557515, 0.05341055771112746, 0.056639738509698834, 0.059860302778555585, 0.06307227350946909, 0.06627567363285958, 0.06947052601796244, 0.07265685347298989, 0.07583467874529437, 0.07900402452153021, 0.08216491342781707, 0.08531736802989975, 0.08846141083331127, 0.09159706428353087, 0.09472435076614727, 0.09784329260701585, 0.10095391207241988, 0.10405623136922859, 0.10715027264505528, 0.11023605798841718, 0.11331360942889113, 0.11638294893727208, 0.11944409842572923, 0.12249707974796364, 0.12554191469936238, 0.1285786250171559, 0.13160723238057193, 0.13462775841099117, 0.1376402246721018, 0.14064465267005133, 0.14364106385360342, 0.1466294796142884, 0.14960992128655648, 0.15258241014793184, 0.15554696741916185, 0.15850361426437032, 0.1614523717912082, 0.16439326105100394, 0.16732630303891427, 0.17025151869407407, 0.1731689288997449, 0.17607855448346554, 0.17898041621719973, 0.1818745348174844, 0.18476093094557844, 0.1876396252076089, 0.1905106381547199, 0.19337399028321678, 0.19622970203471524, 0.19907779379628532, 0.20191828590059768, 0.2047511986260684, 0.20757655219700455, 0.21039436678374734, 0.21320466250281767, 0.2160074594170578, 0.21880277753577637, 0.22159063681489033, 0.22437105715706762, 0.22714405841186935, 0.229909660375891, 0.23266788279290473, 0.23541874535399887, 0.23816226769772042, 0.24089846941021342, 0.24362737002535995, 0.24634898902491909, 0.24906334583866574, 0.2517704598445305, 0.2544703503687362, 0.2571630366859379, 0.2598485380193585, 0.26252687354092763, 0.2651980623714174, 0.2678621235805798, 0.2705190761872819, 0.27316893915964235, 0.27581173141516635, 0.27844747182088125, 0.2810761791934704, 0.28369787229940857, 0.2863125698550947, 0.28892029052698653, 0.29152105293173336, 0.2941148756363091, 0.29670177715814494, 0.29928177596526107, 0.301854890476399, 0.304421139061153, 0.3069805400401012, 0.3095331116849359, 0.312078872218595, 0.31461783981539093, 0.31715003260114183, 0.3196754686532993, 0.32219416600107886, 0.3247061426255875, 0.3272114164599531, 0.32971000538945205, 0.33220192725163644, 0.3346871998364621, 0.3371658408864153, 0.33963786809663954, 0.34210329911506143, 0.34456215154251757, 0.3470144429328791, 0.34946019079317814, 0.3518994125837316, 0.3543321257182671, 0.35675834756404645, 0.3591780954419893, 0.361591386626798, 0.3639982383470798, 0.3663986677854707, 0.3687926920787571, 0.3711803283179994, 0.3735615935486529, 0.3759365047706903, 0.37830507893872234, 0.3806673329621194, 0.38302328370513217, 0.3853729479870116, 0.3877163425821294, 0.3900534842200979, 0.39238438958588906, 0.3947090753199536, 0.39702755801834033, 0.39933985423281404, 0.4016459804709739, 0.4039459531963714, 0.40623978882862777, 0.4085275037435512, 0.41080911427325384, 0.41308463670626816, 0.41535408728766365, 0.4176174822191623, 0.4198748376592546, 0.42212616972331474, 0.424371494483716, 0.4266108279699452, 0.42884418616871656, 0.43107158502408705, 0.4332930404375692, 0.4355085682682456, 0.43771818433288057, 0.43992190440603496, 0.4421197442201772, 0.44431171946579684, 0.4464978457915152, 0.4486781388041987, 0.45085261406906896, 0.45302128710981426, 0.4551841734087011, 0.45734128840668353, 0.4594926475035145, 0.46163826605785485, 0.46377815938738376, 0.46591234276890725, 0.46804083143846853, 0.470163640591455, 0.4722807853827087, 0.47439228092663255, 0.47649814229730003, 0.4785983845285613, 0.4806930226141518, 0.4827820715077983, 0.4848655461233261, 0.4869434613347655, 0.48901583197645804, 0.4910826728431622, 0.493143998690159, 0.4951998242333576, 0.49725016414940015, 0.49929503307576684, 0.5013344456108797, 0.5033684163142079, 0.5053969597063706, 0.5074200902692414, 0.5094378224460516, 0.5114501706414926, 0.5134571492218197, 0.5154587725149541, 0.5174550548105855, 0.5194460103602738, 0.5214316533775512, 0.5234119980380229, 0.5253870584794694, 0.5273568488019469, 0.5293213830678877, 0.5312806753022009, 0.5332347394923728, 0.5351835895885657, 0.5371272395037189, 0.5390657031136471, 0.5409989942571399, 0.54292712673606, 0.5448501143154424, 0.5467679707235923, 0.5486807096521834, 0.5505883447563553, 0.5524908896548113, 0.5543883579299149, 0.5562807631277882, 0.558168118758407, 0.5600504382956984, 0.5619277351776367, 0.5638000228063387, 0.56566731454816, 0.5675296237337908, 0.5693869636583502, 0.5712393475814812, 0.5730867887274463, 0.574929300285221, 0.5767668954085882, 0.5785995872162318, 0.5804273887918313, 0.5822503131841543, 0.5840683734071498, 0.5858815824400413, 0.5876899532274196, 0.589493498679335, 0.5912922316713891, 0.5930861650448276, 0.5948753116066312, 0.5966596841296077, 0.598439295352482, 0.6002141579799884, 0.6019842846829611, 0.6037496880984233, 0.6055103808296795, 0.6072663754464034, 0.6090176844847295, 0.6107643204473409, 0.61250629580356, 0.6142436229894366, 0.6159763144078372, 0.617704382428533, 0.6194278393882886, 0.6211466975909504, 0.6228609693075339, 0.6245706667763107, 0.6262758022028976, 0.6279763877603423, 0.6296724355892107, 0.6313639577976741, 0.6330509664615943, 0.6347334736246115, 0.6364114912982292, 0.6380850314619001, 0.6397541060631116, 0.6414187270174714, 0.6430789062087927, 0.6447346554891783, 0.6463859866791057, 0.6480329115675116, 0.6496754419118758, 0.6513135894383051, 0.6529473658416174, 0.6545767827854246, 0.6562018519022166, 0.6578225847934436, 0.6594389930295996, 0.6610510881503042, 0.6626588816643859, 0.6642623850499636, 0.665861609754529, 0.6674565671950276, 0.6690472687579408, 0.6706337257993676, 0.6722159496451048, 0.6737939515907281, 0.6753677429016728, 0.6769373348133144, 0.6785027385310488, 0.6800639652303722, 0.6816210260569604, 0.6831739321267492, 0.6847226945260133, 0.6862673243114458, 0.6878078325102361, 0.6893442301201502, 0.6908765281096082, 0.6924047374177624, 0.6939288689545765, 0.6954489336009019, 0.6969649422085569, 0.6984769056004033, 0.6999848345704243, 0.7014887398838004, 0.7029886322769876, 0.7044845224577934, 0.7059764211054531, 0.7074643388707064, 0.708948286375873, 0.7104282742149293, 0.7119043129535829, 0.7133764131293489, 0.7148445852516243, 0.7163088398017642, 0.7177691872331555, 0.7192256379712924, 0.7206782024138496, 0.7221268909307583, 0.7235717138642789, 0.7250126815290749, 0.7264498042122871, 0.7278830921736069, 0.7293125556453492, 0.730738204832526, 0.7321600499129185, 0.7335781010371503, 0.73499236832876, 0.7364028618842732], \"type\": \"scatter\", \"uid\": \"1663776f-a88f-4114-8c43-2bd33401c6f3\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 2.6551102204408816, 5.260220440881763, 7.865330661322646, 10.470440881763528, 13.07555110220441, 15.680661322645292, 18.285771543086174, 20.890881763527055, 23.495991983967937, 26.101102204408818, 28.7062124248497, 31.311322645290584, 33.91643286573146, 36.52154308617234, 39.12665330661322, 41.731763527054106, 44.33687374749499, 46.94198396793587, 49.547094188376754, 52.15220440881763, 54.75731462925852, 57.362424849699394, 59.96753507014028, 62.572645290581164, 65.17775551102204, 67.78286573146292, 70.38797595190381, 72.99308617234469, 75.59819639278557, 78.20330661322645, 80.80841683366734, 83.41352705410821, 86.01863727454909, 88.62374749498998, 91.22885771543086, 93.83396793587174, 96.43907815631262, 99.04418837675351, 101.64929859719439, 104.25440881763527, 106.85951903807616, 109.46462925851704, 112.06973947895791, 114.67484969939879, 117.27995991983968, 119.88507014028056, 122.49018036072144, 125.09529058116233, 127.70040080160321, 130.3055110220441, 132.91062124248498, 135.51573146292586, 138.12084168336673, 140.72595190380764, 143.33106212424852, 145.9361723446894, 148.54128256513027, 151.14639278557115, 153.75150300601203, 156.3566132264529, 158.9617234468938, 161.5668336673347, 164.17194388777557, 166.77705410821645, 169.38216432865732, 171.9872745490982, 174.59238476953908, 177.19749498998, 179.80260521042086, 182.40771543086174, 185.01282565130262, 187.6179358717435, 190.22304609218438, 192.82815631262525, 195.43326653306616, 198.03837675350704, 200.64348697394792, 203.2485971943888, 205.85370741482967, 208.45881763527055, 211.06392785571143, 213.66903807615233, 216.2741482965932, 218.8792585170341, 221.48436873747497, 224.08947895791584, 226.69458917835672, 229.2996993987976, 231.9048096192385, 234.50991983967938, 237.11503006012026, 239.72014028056114, 242.32525050100202, 244.9303607214429, 247.53547094188377, 250.14058116232468, 252.74569138276556, 255.35080160320643, 257.9559118236473, 260.5610220440882, 263.1661322645291, 265.77124248496995, 268.37635270541085, 270.9814629258517, 273.5865731462926, 276.19168336673346, 278.79679358717436, 281.40190380761527, 284.0070140280561, 286.612124248497, 289.2172344689379, 291.8223446893788, 294.42745490981963, 297.03256513026054, 299.63767535070144, 302.2427855711423, 304.8478957915832, 307.45300601202405, 310.05811623246495, 312.6632264529058, 315.2683366733467, 317.8734468937876, 320.47855711422847, 323.08366733466937, 325.6887775551102, 328.2938877755511, 330.898997995992, 333.5041082164329, 336.1092184368738, 338.71432865731464, 341.31943887775554, 343.9245490981964, 346.5296593186373, 349.13476953907815, 351.73987975951906, 354.34498997995996, 356.9501002004008, 359.5552104208417, 362.16032064128257, 364.7654308617235, 367.3705410821643, 369.97565130260523, 372.58076152304614, 375.185871743487, 377.7909819639279, 380.39609218436874, 383.00120240480965, 385.6063126252505, 388.2114228456914, 390.8165330661323, 393.42164328657316, 396.02675350701406, 398.6318637274549, 401.2369739478958, 403.84208416833667, 406.4471943887776, 409.0523046092185, 411.65741482965933, 414.26252505010024, 416.8676352705411, 419.472745490982, 422.07785571142284, 424.68296593186375, 427.28807615230465, 429.8931863727455, 432.4982965931864, 435.10340681362726, 437.70851703406817, 440.313627254509, 442.9187374749499, 445.5238476953908, 448.1289579158317, 450.7340681362726, 453.33917835671343, 455.94428857715434, 458.5493987975952, 461.1545090180361, 463.759619238477, 466.36472945891785, 468.96983967935876, 471.5749498997996, 474.1800601202405, 476.78517034068136, 479.39028056112227, 481.9953907815632, 484.600501002004, 487.20561122244493, 489.8107214428858, 492.4158316633267, 495.02094188376753, 497.62605210420844, 500.23116232464935, 502.8362725450902, 505.4413827655311, 508.04649298597195, 510.65160320641286, 513.2567134268537, 515.8618236472945, 518.4669338677354, 521.0720440881763, 523.6771543086172, 526.2822645290581, 528.8873747494989, 531.4924849699398, 534.0975951903807, 536.7027054108216, 539.3078156312625, 541.9129258517033, 544.5180360721442, 547.1231462925851, 549.728256513026, 552.3333667334668, 554.9384769539078, 557.5435871743487, 560.1486973947896, 562.7538076152305, 565.3589178356713, 567.9640280561122, 570.5691382765531, 573.174248496994, 575.7793587174349, 578.3844689378757, 580.9895791583166, 583.5946893787575, 586.1997995991984, 588.8049098196392, 591.4100200400801, 594.015130260521, 596.6202404809619, 599.2253507014028, 601.8304609218436, 604.4355711422845, 607.0406813627254, 609.6457915831663, 612.2509018036072, 614.856012024048, 617.4611222444889, 620.0662324649298, 622.6713426853707, 625.2764529058115, 627.8815631262524, 630.4866733466934, 633.0917835671343, 635.6968937875752, 638.302004008016, 640.9071142284569, 643.5122244488978, 646.1173346693387, 648.7224448897796, 651.3275551102204, 653.9326653306613, 656.5377755511022, 659.1428857715431, 661.7479959919839, 664.3531062124248, 666.9582164328657, 669.5633266533066, 672.1684368737475, 674.7735470941883, 677.3786573146292, 679.9837675350701, 682.588877755511, 685.1939879759518, 687.7990981963927, 690.4042084168336, 693.0093186372745, 695.6144288577154, 698.2195390781562, 700.8246492985971, 703.429759519038, 706.034869739479, 708.6399799599199, 711.2450901803606, 713.8502004008016, 716.4553106212425, 719.0604208416834, 721.6655310621242, 724.2706412825651, 726.875751503006, 729.4808617234469, 732.0859719438878, 734.6910821643286, 737.2961923847695, 739.9013026052104, 742.5064128256513, 745.1115230460922, 747.716633266533, 750.3217434869739, 752.9268537074148, 755.5319639278557, 758.1370741482965, 760.7421843687374, 763.3472945891783, 765.9524048096192, 768.5575150300601, 771.1626252505009, 773.7677354709418, 776.3728456913827, 778.9779559118236, 781.5830661322645, 784.1881763527053, 786.7932865731462, 789.3983967935872, 792.0035070140281, 794.6086172344689, 797.2137274549098, 799.8188376753507, 802.4239478957916, 805.0290581162325, 807.6341683366733, 810.2392785571142, 812.8443887775551, 815.449498997996, 818.0546092184369, 820.6597194388777, 823.2648296593186, 825.8699398797595, 828.4750501002004, 831.0801603206412, 833.6852705410821, 836.290380761523, 838.8954909819639, 841.5006012024048, 844.1057114228456, 846.7108216432865, 849.3159318637274, 851.9210420841683, 854.5261523046092, 857.13126252505, 859.7363727454909, 862.3414829659318, 864.9465931863728, 867.5517034068135, 870.1568136272545, 872.7619238476954, 875.3670340681363, 877.9721442885772, 880.577254509018, 883.1823647294589, 885.7874749498998, 888.3925851703407, 890.9976953907816, 893.6028056112224, 896.2079158316633, 898.8130260521042, 901.4181362725451, 904.0232464929859, 906.6283567134268, 909.2334669338677, 911.8385771543086, 914.4436873747495, 917.0487975951903, 919.6539078156312, 922.2590180360721, 924.864128256513, 927.4692384769539, 930.0743486973947, 932.6794589178356, 935.2845691382765, 937.8896793587174, 940.4947895791582, 943.0998997995991, 945.70501002004, 948.310120240481, 950.9152304609219, 953.5203406813627, 956.1254509018036, 958.7305611222445, 961.3356713426854, 963.9407815631263, 966.5458917835671, 969.151002004008, 971.7561122244489, 974.3612224448898, 976.9663326653306, 979.5714428857715, 982.1765531062124, 984.7816633266533, 987.3867735470942, 989.991883767535, 992.5969939879759, 995.2021042084168, 997.8072144288577, 1000.4123246492986, 1003.0174348697394, 1005.6225450901803, 1008.2276553106212, 1010.8327655310621, 1013.4378757515029, 1016.0429859719438, 1018.6480961923847, 1021.2532064128256, 1023.8583166332666, 1026.4634268537075, 1029.0685370741483, 1031.673647294589, 1034.27875751503, 1036.8838677354709, 1039.4889779559119, 1042.0940881763527, 1044.6991983967935, 1047.3043086172345, 1049.9094188376753, 1052.5145290581163, 1055.119639278557, 1057.7247494989979, 1060.329859719439, 1062.9349699398797, 1065.5400801603207, 1068.1451903807615, 1070.7503006012023, 1073.3554108216433, 1075.960521042084, 1078.5656312625251, 1081.170741482966, 1083.7758517034067, 1086.3809619238477, 1088.9860721442885, 1091.5911823647293, 1094.1962925851703, 1096.8014028056111, 1099.4065130260522, 1102.011623246493, 1104.6167334669337, 1107.2218436873748, 1109.8269539078156, 1112.4320641282566, 1115.0371743486974, 1117.6422845691382, 1120.2473947895792, 1122.85250501002, 1125.457615230461, 1128.0627254509018, 1130.6678356713426, 1133.2729458917836, 1135.8780561122244, 1138.4831663326654, 1141.0882765531062, 1143.693386773547, 1146.298496993988, 1148.9036072144288, 1151.5087174348698, 1154.1138276553106, 1156.7189378757514, 1159.3240480961924, 1161.9291583166332, 1164.534268537074, 1167.139378757515, 1169.7444889779558, 1172.3495991983968, 1174.9547094188376, 1177.5598196392784, 1180.1649298597195, 1182.7700400801602, 1185.3751503006013, 1187.980260521042, 1190.5853707414828, 1193.1904809619239, 1195.7955911823647, 1198.4007014028057, 1201.0058116232465, 1203.6109218436873, 1206.2160320641283, 1208.821142284569, 1211.42625250501, 1214.031362725451, 1216.6364729458917, 1219.2415831663327, 1221.8466933867735, 1224.4518036072145, 1227.0569138276553, 1229.662024048096, 1232.2671342685371, 1234.872244488978, 1237.4773547094187, 1240.0824649298597, 1242.6875751503005, 1245.2926853707415, 1247.8977955911823, 1250.5029058116231, 1253.1080160320641, 1255.713126252505, 1258.318236472946, 1260.9233466933867, 1263.5284569138275, 1266.1335671342686, 1268.7386773547094, 1271.3437875751504, 1273.9488977955912, 1276.554008016032, 1279.159118236473, 1281.7642284569138, 1284.3693386773548, 1286.9744488977956, 1289.5795591182364, 1292.1846693386774, 1294.7897795591182, 1297.3948897795592, 1300.0], \"y\": [0.7640118089895516, 0.7582313667503424, 0.7524676321955528, 0.7467205570335973, 0.7409900931124718, 0.73527619241935, 0.7295788070801812, 0.7238978893592882, 0.7182333916589692, 0.7125852665190968, 0.7069534666167223, 0.7013379447656782, 0.6957386539161827, 0.6901555471544463, 0.684588577702278, 0.6790376989166937, 0.6735028642895251, 0.6679840274470306, 0.6624811421495063, 0.6569941622908986, 0.6515230418984181, 0.6460677351321542, 0.6406281962846914, 0.6352043797807254, 0.629796240176683, 0.6244037321603393, 0.6190268105504395, 0.6136654302963196, 0.6083195464775297, 0.6029891143034567, 0.5976740891129495, 0.592374426373945, 0.5870900816830946, 0.5818210107653923, 0.5765671694738039, 0.5713285137888968, 0.5661049998184717, 0.560896583797194, 0.5557032220862281, 0.550524871172871, 0.5453614876701882, 0.5402130283166497, 0.5350794499757683, 0.5299607096357373, 0.5248567644090707, 0.5197675715322436, 0.5146930883653345, 0.5096332723916668, 0.5045880812174539, 0.4995574725714429, 0.4945414043045617, 0.4895398343895643, 0.48455272092068014, 0.4795800221132618, 0.47462169630343554, 0.4696777019477527, 0.4647479976228406, 0.4598325420250555, 0.45493129397013776, 0.4500442123928652, 0.44517125634671073, 0.44031238500349734, 0.43546755765305756, 0.43063673370289224, 0.42581987267782906, 0.4210169342196852, 0.4162278780869282, 0.4114526641543388, 0.4066912524126751, 0.4019436029683372, 0.3972096760430326, 0.39248943197344377, 0.3877828312108951, 0.3830898343210216, 0.37841040198343867, 0.3737444949914128, 0.3690920742515329, 0.36445310078338244, 0.3598275357192138, 0.3552153403036211, 0.3506164758932173, 0.34603090395630876, 0.3414585860725736, 0.33689948393273905, 0.33235355933826116, 0.327820774201004, 0.3233010905429208, 0.31879447049573617, 0.3143008763006281, 0.3098202703079125, 0.30535261497672717, 0.3008978728747165, 0.29645600667771976, 0.29202697916945675, 0.28761075324121643, 0.2832072918915465, 0.27881655822594276, 0.27443851545653986, 0.2700731269018042, 0.26572035598622534, 0.2613801662400097, 0.257052521298776, 0.2527373849032495, 0.24843472089895857, 0.24414449323593224, 0.239866665968397, 0.2356012032544772, 0.23134806935589314, 0.22710722863766275, 0.22287864556780268, 0.2186622847170303, 0.21445811075846777, 0.2102660884673444, 0.20608618272070345, 0.20191835849710627, 0.19776258087634013, 0.19361881503912493, 0.1894870262668209, 0.18536717994113938, 0.18125924154385076, 0.1771631766564974, 0.17307895096010317, 0.16900653023488732, 0.16494588035997748, 0.1608969673131233, 0.156859757170412, 0.15283421610598347, 0.1488203103917476, 0.14481800639710096, 0.14082727058864597, 0.13684806952990924, 0.13288036988106078, 0.1289241383986366, 0.12497934193525784, 0.12104594743935548, 0.11712392195489074, 0.11321323262108174, 0.10931384667212596, 0.10542573143692646, 0.101548854338819, 0.09768318289529754, 0.09382868471774342, 0.08998532751115307, 0.08615307907386827, 0.08233190729730544, 0.078521780165687, 0.0747226657557738, 0.0709345322365964, 0.06715734786918937, 0.06339108100632496, 0.05963570009224761, 0.055891173662410365, 0.05215747034321083, 0.048434558851728315, 0.04472240799546112, 0.04102098667206677, 0.03733026386909932, 0.033650208663751346, 0.029980790222594367, 0.026321977801319507, 0.022673740744481474, 0.019036048485239876, 0.015408870545105424, 0.011792176533682364, 0.008185936148415118, 0.004590119174334051, 0.0010046954838023314, 0.0025703649637365267, 0.006135092122010466, 0.00968951585816935, 0.0132336659530361, 0.016767572101355155, 0.02029126391204228, 0.023804770908431916, 0.02730812252852477, 0.030801348125234496, 0.03428447696663395, 0.03775753823619965, 0.041220561033056935, 0.04467357437222352, 0.04811660718485267, 0.051549688318475395, 0.05497284653724299, 0.05838611052216636, 0.061789508871358256, 0.06518307010027136, 0.06856682264193781, 0.07194079484720795, 0.07530501498498698, 0.07865951124247261, 0.08200431172538969, 0.08533944445822783, 0.08866493738447523, 0.09198081836685179, 0.09528711518754429, 0.09858385554843818, 0.1018710670713503, 0.10514877729825911, 0.10841701369153633, 0.11167580363417806, 0.1149251744300317, 0.11816515330402666, 0.12139576740240221, 0.12461704379293415, 0.12782900946516218, 0.13103169133061643, 0.13422511622304167, 0.1374093108986234, 0.1405843020362112, 0.1437501162375432, 0.1469067800274675, 0.15005431985416617, 0.15319276208937493, 0.15632213302860598, 0.1594424588913672, 0.16255376582138203, 0.1656560798868083, 0.16874942708045726, 0.1718338333200109, 0.1749093244482396, 0.17797592623321745, 0.18103366436853996, 0.1840825644735371, 0.18712265209349055, 0.19015395269984525, 0.19317649169042506, 0.19619029438964297, 0.19919538604871656, 0.202191791845876, 0.20517953688657786, 0.20815864620371394, 0.2111291447578214, 0.2140910574372925, 0.2170444090585819, 0.21998922436641521, 0.2229255280339968, 0.2258533446632156, 0.22877269878485218, 0.2316836148587833, 0.23458611727418788, 0.23748023034974997, 0.2403659783338642, 0.24324338540483792, 0.2461124756710935, 0.24897327317137086, 0.2518258018749292, 0.2546700856817473, 0.25750614842272357, 0.2603340138598762, 0.26315370568654217, 0.26596524752757533, 0.26876866293954527, 0.2715639754109337, 0.2743512083623316, 0.2771303851466357, 0.2799015290492438, 0.28266466328825035, 0.2854198110146402, 0.28816699531248313, 0.29090623919912717, 0.2936375656253918, 0.29636099747575917, 0.2990765575685672, 0.30178426865619956, 0.30448415342527746, 0.3071762344968485, 0.3098605344265771, 0.3125370757049333, 0.3152058807573809, 0.3178669719445655, 0.32052037156250235, 0.3231661018427622, 0.3258041849526583, 0.32843464299543157, 0.33105749801043693, 0.33367277197332623, 0.3362804867962341, 0.3388806643279598, 0.3414733263541524, 0.34405849459749105, 0.3466361907178688, 0.34920643631257287, 0.3517692529164662, 0.35432466200216794, 0.35687268498023317, 0.35941334319933194, 0.3619466579464289, 0.36447265044696087, 0.3669913418650156, 0.3695027533035079, 0.3720069058043577, 0.37450382034866514, 0.3769935178568875, 0.37947601918901375, 0.3819513451447396, 0.38441951646364136, 0.38688055382535047, 0.3893344778497263, 0.3917813090970287, 0.39422106806809076, 0.3966537752044902, 0.39907945088872065, 0.4014981154443631, 0.40390978913625497, 0.40631449217066107, 0.4087122446954419, 0.41110306680022346, 0.4134869785165648, 0.41586399981812605, 0.418234150620836, 0.42059745078305877, 0.42295392010576005, 0.42530357833267374, 0.4276464451504659, 0.4299825401889015, 0.4323118830210072, 0.434634493163237, 0.4369503900756342, 0.4392595931619956, 0.44156212177003307, 0.4438579951915369, 0.4461472326625363, 0.4484298533634612, 0.4507058764193024, 0.45297532089977266, 0.45523820581946584, 0.4574945501380163, 0.4597443727602577, 0.46198769253638183, 0.4642245282620958, 0.46645489867878054, 0.46867882247364656, 0.47089631827989187, 0.47310740467685675, 0.4753121001901809, 0.4775104232919569, 0.47970239240088675, 0.48188802588243485, 0.4840673420489825, 0.48624035915998176, 0.48840709542210714, 0.49056756898940923, 0.4927217979634667, 0.4948698003935371, 0.4970115942767096, 0.4991471975580545, 0.5012766281307737, 0.5033999038363511, 0.5055170424647026, 0.5076280617543233, 0.509732979392438, 0.5118318130151488, 0.5139245802075817, 0.5160112985040364, 0.5180919853881311, 0.5201666582929492, 0.5222353346011864, 0.524298031645296, 0.5263547667076331, 0.5284055570206012, 0.5304504197667947, 0.532489372079144, 0.5345224310410592, 0.5365496136865723, 0.5385709370004806, 0.5405864179184889, 0.5425960733273515, 0.5445999200650132, 0.5465979749207512, 0.5485902546353146, 0.5505767759010658, 0.5525575553621199, 0.5545326096144841, 0.5565019552061968, 0.5584656086374663, 0.5604235863608085, 0.5623759047811863, 0.5643225802561449, 0.5662636290959506, 0.5681990675637267, 0.5701289118755897, 0.5720531782007854, 0.5739718826618246, 0.5758850413346173, 0.5777926702486085, 0.5796947853869117, 0.5815914026864432, 0.5834825380380556, 0.5853682072866709, 0.5872484262314128, 0.5891232106257404, 0.590992576177578, 0.5928565385494493, 0.5947151133586065, 0.5965683161771623, 0.5984161625322199, 0.6002586679060034, 0.6020958477359873, 0.6039277174150259, 0.6057542922914823, 0.6075755876693567, 0.6093916188084154, 0.6112024009243181, 0.6130079491887446, 0.614808278729524, 0.6166034046307592, 0.6183933419329549, 0.6201781056331426, 0.6219577106850069, 0.6237321719990107, 0.6255015044425193, 0.6272657228399261, 0.6290248419727769, 0.630778876579892, 0.6325278413574918, 0.6342717509593185, 0.6360106199967599, 0.6377444630389709, 0.639473294612996, 0.6411971292038909, 0.6429159812548447, 0.6446298651672994, 0.6463387953010714, 0.6480427859744717, 0.6497418514644268, 0.6514360060065963, 0.6531252637954938, 0.6548096389846054, 0.6564891456865081, 0.6581637979729881, 0.6598336098751592, 0.6614985953835789, 0.6631587684483682, 0.6648141429793254, 0.666464732846045, 0.6681105518780333, 0.6697516138648232, 0.6713879325560913, 0.6730195216617719, 0.6746463948521726, 0.676268565758089, 0.6778860479709177, 0.6794988550427715, 0.681107000486592, 0.6827104977762639, 0.6843093603467268, 0.685903601594088, 0.6874932348757355, 0.6890782735104489, 0.6906587307785116, 0.6922346199218218, 0.6938059541440035, 0.6953727466105177, 0.6969350104487718, 0.6984927587482296, 0.7000460045605224, 0.7015947608995561, 0.7031390407416223, 0.7046788570255057, 0.7062142226525934, 0.7077451504869822, 0.7092716533555867, 0.7107937440482471, 0.7123114353178363, 0.7138247398803658, 0.7153336704150935, 0.7168382395646291, 0.7183384599350408, 0.7198343440959601, 0.7213259045806875, 0.7228131538862973, 0.7242961044737429, 0.7257747687679607, 0.727249159157974, 0.728719287996997, 0.7301851676025392, 0.731646810256507, 0.7331042282053076, 0.7345574336599515, 0.7360064387961548, 0.7374512557544409, 0.7388918966402427, 0.7403283735240034, 0.7417606984412786, 0.743188883392836, 0.7446129403447568, 0.7460328812285354, 0.74744871794118, 0.7488604623453118, 0.7502681262692641, 0.7516717215071822, 0.7530712598191218, 0.7544667529311475, 0.7558582125354312, 0.7572456502903493, 0.7586290778205822, 0.7600085067172095, 0.7613839485378088, 0.7627554148065515, 0.7641229170143], \"type\": \"scatter\", \"uid\": \"ebaab503-1c48-40fd-90e3-c67c675674c4\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 2.8555110220440882, 5.661022044088177, 8.466533066132266, 11.272044088176354, 14.077555110220443, 16.88306613226453, 19.68857715430862, 22.494088176352708, 25.299599198396795, 28.105110220440885, 30.910621242484975, 33.71613226452906, 36.521643286573145, 39.32715430861724, 42.132665330661325, 44.93817635270541, 47.7436873747495, 50.549198396793585, 53.35470941883768, 56.160220440881766, 58.96573146292585, 61.771242484969946, 64.57675350701403, 67.38226452905812, 70.1877755511022, 72.99328657314629, 75.79879759519038, 78.60430861723448, 81.40981963927857, 84.21533066132265, 87.02084168336674, 89.82635270541083, 92.63186372745491, 95.437374749499, 98.24288577154309, 101.04839679358717, 103.85390781563127, 106.65941883767536, 109.46492985971945, 112.27044088176353, 115.07595190380762, 117.88146292585171, 120.6869739478958, 123.4924849699399, 126.29799599198398, 129.10350701402808, 131.90901803607215, 134.71452905811626, 137.52004008016036, 140.32555110220443, 143.13106212424853, 145.9365731462926, 148.7420841683367, 151.54759519038078, 154.35310621242488, 157.15861723446898, 159.96412825651305, 162.76963927855715, 165.57515030060122, 168.38066132264532, 171.1861723446894, 173.9916833667335, 176.79719438877757, 179.60270541082167, 182.40821643286577, 185.21372745490984, 188.01923847695394, 190.82474949899802, 193.63026052104212, 196.4357715430862, 199.2412825651303, 202.04679358717436, 204.85230460921846, 207.65781563126257, 210.46332665330664, 213.26883767535074, 216.0743486973948, 218.8798597194389, 221.68537074148298, 224.49088176352709, 227.2963927855712, 230.10190380761526, 232.90741482965936, 235.71292585170343, 238.51843687374753, 241.3239478957916, 244.1294589178357, 246.9349699398798, 249.74048096192388, 252.54599198396798, 255.35150300601205, 258.15701402805615, 260.9625250501002, 263.7680360721443, 266.5735470941884, 269.3790581162325, 272.1845691382766, 274.9900801603207, 277.7955911823648, 280.60110220440885, 283.4066132264529, 286.21212424849705, 289.0176352705411, 291.8231462925852, 294.6286573146293, 297.4341683366734, 300.23967935871747, 303.04519038076154, 305.85070140280567, 308.65621242484974, 311.4617234468938, 314.26723446893794, 317.072745490982, 319.8782565130261, 322.68376753507016, 325.4892785571143, 328.29478957915836, 331.10030060120243, 333.9058116232465, 336.71132264529064, 339.5168336673347, 342.3223446893788, 345.1278557114229, 347.933366733467, 350.73887775551106, 353.5443887775551, 356.34989979959926, 359.15541082164333, 361.9609218436874, 364.76643286573153, 367.5719438877756, 370.3774549098197, 373.18296593186375, 375.9884769539079, 378.79398797595195, 381.599498997996, 384.40501002004015, 387.2105210420842, 390.0160320641283, 392.82154308617237, 395.6270541082165, 398.43256513026057, 401.23807615230464, 404.0435871743487, 406.84909819639284, 409.6546092184369, 412.460120240481, 415.2656312625251, 418.0711422845692, 420.87665330661326, 423.68216432865734, 426.48767535070147, 429.29318637274554, 432.0986973947896, 434.90420841683374, 437.7097194388778, 440.5152304609219, 443.32074148296596, 446.1262525050101, 448.93176352705416, 451.73727454909823, 454.54278557114236, 457.34829659318643, 460.1538076152305, 462.9593186372746, 465.7648296593187, 468.5703406813628, 471.37585170340685, 474.181362725451, 476.98687374749505, 479.7923847695391, 482.5978957915832, 485.4034068136273, 488.2089178356714, 491.0144288577155, 493.8199398797596, 496.6254509018037, 499.43096192384775, 502.2364729458918, 505.04198396793595, 507.84749498998, 510.6530060120241, 513.4585170340681, 516.2640280561122, 519.0695390781564, 521.8750501002004, 524.6805611222445, 527.4860721442885, 530.2915831663327, 533.0970941883768, 535.9026052104208, 538.7081162324649, 541.5136272545091, 544.3191382765531, 547.1246492985972, 549.9301603206413, 552.7356713426854, 555.5411823647295, 558.3466933867735, 561.1522044088176, 563.9577154308618, 566.7632264529058, 569.5687374749499, 572.374248496994, 575.179759519038, 577.9852705410822, 580.7907815631263, 583.5962925851703, 586.4018036072144, 589.2073146292586, 592.0128256513026, 594.8183366733467, 597.6238476953907, 600.4293587174349, 603.234869739479, 606.040380761523, 608.8458917835671, 611.6514028056113, 614.4569138276553, 617.2624248496994, 620.0679358717435, 622.8734468937876, 625.6789579158317, 628.4844689378758, 631.2899799599198, 634.095490981964, 636.901002004008, 639.7065130260521, 642.5120240480962, 645.3175350701403, 648.1230460921844, 650.9285571142285, 653.7340681362725, 656.5395791583167, 659.3450901803608, 662.1506012024048, 664.9561122244489, 667.761623246493, 670.5671342685371, 673.3726452905812, 676.1781563126252, 678.9836673346693, 681.7891783567135, 684.5946893787575, 687.4002004008016, 690.2057114228458, 693.0112224448898, 695.8167334669339, 698.622244488978, 701.427755511022, 704.2332665330662, 707.0387775551102, 709.8442885771543, 712.6497995991984, 715.4553106212425, 718.2608216432866, 721.0663326653307, 723.8718436873747, 726.6773547094189, 729.482865731463, 732.288376753507, 735.0938877755511, 737.8993987975952, 740.7049098196393, 743.5104208416834, 746.3159318637274, 749.1214428857716, 751.9269539078157, 754.7324649298597, 757.5379759519038, 760.343486973948, 763.148997995992, 765.9545090180361, 768.7600200400802, 771.5655310621243, 774.3710420841684, 777.1765531062124, 779.9820641282565, 782.7875751503007, 785.5930861723447, 788.3985971943888, 791.2041082164329, 794.009619238477, 796.8151302605211, 799.6206412825652, 802.4261523046092, 805.2316633266533, 808.0371743486974, 810.8426853707415, 813.6481963927856, 816.4537074148296, 819.2592184368738, 822.0647294589179, 824.8702404809619, 827.675751503006, 830.4812625250502, 833.2867735470942, 836.0922845691383, 838.8977955911824, 841.7033066132265, 844.5088176352706, 847.3143286573146, 850.1198396793587, 852.9253507014029, 855.7308617234469, 858.536372745491, 861.3418837675351, 864.1473947895792, 866.9529058116233, 869.7584168336674, 872.5639278557114, 875.3694388777556, 878.1749498997997, 880.9804609218437, 883.7859719438878, 886.5914829659318, 889.396993987976, 892.2025050100201, 895.0080160320641, 897.8135270541082, 900.6190380761524, 903.4245490981964, 906.2300601202405, 909.0355711422847, 911.8410821643287, 914.6465931863728, 917.4521042084168, 920.2576152304609, 923.0631262525051, 925.8686372745491, 928.6741482965932, 931.4796593186373, 934.2851703406814, 937.0906813627255, 939.8961923847696, 942.7017034068136, 945.5072144288578, 948.3127254509019, 951.1182364729459, 953.92374749499, 956.729258517034, 959.5347695390782, 962.3402805611223, 965.1457915831663, 967.9513026052105, 970.7568136272546, 973.5623246492986, 976.3678356713427, 979.1733466933869, 981.9788577154309, 984.784368737475, 987.5898797595191, 990.3953907815632, 993.2009018036073, 996.0064128256513, 998.8119238476954, 1001.6174348697396, 1004.4229458917836, 1007.2284569138277, 1010.0339679358718, 1012.8394789579158, 1015.64498997996, 1018.4505010020041, 1021.2560120240481, 1024.0615230460921, 1026.8670340681363, 1029.6725450901804, 1032.4780561122245, 1035.2835671342687, 1038.0890781563128, 1040.8945891783567, 1043.7001002004008, 1046.505611222445, 1049.311122244489, 1052.1166332665332, 1054.922144288577, 1057.7276553106212, 1060.5331663326654, 1063.3386773547095, 1066.1441883767536, 1068.9496993987977, 1071.7552104208416, 1074.5607214428858, 1077.36623246493, 1080.171743486974, 1082.9772545090182, 1085.782765531062, 1088.5882765531062, 1091.3937875751503, 1094.1992985971945, 1097.0048096192386, 1099.8103206412827, 1102.6158316633266, 1105.4213426853707, 1108.2268537074149, 1111.032364729459, 1113.8378757515031, 1116.643386773547, 1119.4488977955912, 1122.2544088176353, 1125.0599198396794, 1127.8654308617236, 1130.6709418837677, 1133.4764529058116, 1136.2819639278557, 1139.0874749498998, 1141.892985971944, 1144.698496993988, 1147.5040080160322, 1150.3095190380761, 1153.1150300601203, 1155.9205410821644, 1158.7260521042085, 1161.5315631262526, 1164.3370741482966, 1167.1425851703407, 1169.9480961923848, 1172.753607214429, 1175.559118236473, 1178.3646292585172, 1181.170140280561, 1183.9756513026052, 1186.7811623246494, 1189.5866733466935, 1192.3921843687376, 1195.1976953907815, 1198.0032064128256, 1200.8087174348698, 1203.614228456914, 1206.419739478958, 1209.2252505010022, 1212.030761523046, 1214.8362725450902, 1217.6417835671343, 1220.4472945891785, 1223.2528056112226, 1226.0583166332665, 1228.8638276553106, 1231.6693386773547, 1234.4748496993989, 1237.280360721443, 1240.0858717434871, 1242.891382765531, 1245.6968937875752, 1248.5024048096193, 1251.3079158316634, 1254.1134268537076, 1256.9189378757517, 1259.7244488977956, 1262.5299599198397, 1265.3354709418838, 1268.140981963928, 1270.946492985972, 1273.752004008016, 1276.5575150300601, 1279.3630260521043, 1282.1685370741484, 1284.9740480961925, 1287.7795591182366, 1290.5850701402805, 1293.3905811623247, 1296.1960921843688, 1299.001603206413, 1301.807114228457, 1304.612625250501, 1307.418136272545, 1310.2236472945892, 1313.0291583166334, 1315.8346693386775, 1318.6401803607216, 1321.4456913827655, 1324.2512024048096, 1327.0567134268538, 1329.862224448898, 1332.667735470942, 1335.473246492986, 1338.27875751503, 1341.0842685370742, 1343.8897795591183, 1346.6952905811625, 1349.5008016032066, 1352.3063126252505, 1355.1118236472946, 1357.9173346693387, 1360.7228456913829, 1363.528356713427, 1366.333867735471, 1369.139378757515, 1371.9448897795592, 1374.7504008016033, 1377.5559118236474, 1380.3614228456915, 1383.1669338677355, 1385.9724448897796, 1388.7779559118237, 1391.5834669338678, 1394.388977955912, 1397.194488977956, 1400.0], \"y\": [0.7888168041841614, 0.7825923881185028, 0.7763873448067578, 0.7702016139535361, 0.7640351354511101, 0.7578878493788301, 0.7517596960025423, 0.7456506157740086, 0.7395605493303274, 0.7334894374933572, 0.7274372212691411, 0.7214038418473345, 0.7153892406006326, 0.709393359084201, 0.7034161390351081, 0.6974575223717587, 0.6915174511933297, 0.6855958677792071, 0.6796927145884262, 0.6738079342591106, 0.6679414696079167, 0.6620932636294772, 0.6562632594958469, 0.650451400555951, 0.6446576303350344, 0.6388818925341131, 0.6331241310294267, 0.6273842898718933, 0.6216623132865664, 0.6159581456720917, 0.610271731600168, 0.6046030158150077, 0.5989519432328005, 0.593318458941178, 0.5877025081986798, 0.5821040364342214, 0.5765229892465653, 0.5709593124037904, 0.5654129518427666, 0.5598838536686288, 0.5543719641542528, 0.5488772297397344, 0.5433995970318672, 0.5379390128036261, 0.5324954239936475, 0.5270687777057159, 0.5216590212082486, 0.5162661019337835, 0.510889967478469, 0.5055305656015536, 0.5001878442248797, 0.4948617514323759, 0.48955223546955384, 0.48425924474300475, 0.4789827278198988, 0.47372263342748333, 0.4684789104525875, 0.46325150794112346, 0.45804037509759166, 0.4528454612845878, 0.44766671602231045, 0.4425040889880707, 0.4373575300158026, 0.4322269890955768, 0.4271124163731128, 0.42201376214929653, 0.4169309768796967, 0.4118640111740821, 0.40681281579594364, 0.4017773416620145, 0.39675753984179396, 0.39175336155707163, 0.3867647581814535, 0.38179168123988916, 0.3768340824082015, 0.3718919135126162, 0.36696512652929414, 0.3620536735838651, 0.3571575069509616, 0.3522765790537561, 0.34741084246349785, 0.34256024989905276, 0.3377247542264439, 0.3329043084583925, 0.3280988657538626, 0.32330837941760526, 0.3185328028997052, 0.3137720897951277, 0.30902619384326835, 0.3042950689275039, 0.29957866907474284, 0.29487694845498, 0.29018986138085023, 0.28551736230718494, 0.28085940583057, 0.2762159466889029, 0.2715869397609554, 0.2669723400659325, 0.26237210276303724, 0.2577861831510344, 0.25321453666781535, 0.24865711888996622, 0.2441138855323357, 0.2395847924476049, 0.2350697956258576, 0.23056885119415393, 0.22608191541610267, 0.22160894469143755, 0.2171498955555926, 0.2127047246792797, 0.208273388868069, 0.2038558450619672, 0.19945205033500057, 0.19506196189479752, 0.19068553708217229, 0.1863227333707107, 0.18197350836635717, 0.17763781980700277, 0.1733156255620738, 0.16900688363212346, 0.16471155214842303, 0.16042958937255514, 0.15616095369600846, 0.151905603639773, 0.1476634978539375, 0.14343459511728707, 0.13921885433690329, 0.13501623454776412, 0.13082669491234666, 0.1266501947202301, 0.12248669338769891, 0.11833615045735102, 0.11419852559770227, 0.11007377860279544, 0.10596186939181007, 0.10186275800867217, 0.09777640462166604, 0.0937027695230479, 0.08964181312865938, 0.08559349597754307, 0.08155777873155934, 0.07753462217500329, 0.07352398721422504, 0.06952583487724806, 0.06554012631339234, 0.061566822792895604, 0.05760588570653713, 0.0536572765652632, 0.04972095699981249, 0.04579688876034349, 0.04188503371606256, 0.03798535385485424, 0.03409781128291023, 0.030222368224363416, 0.026358987020918656, 0.02250763013148771, 0.01866826013182532, 0.014840839714164167, 0.011025331686852935, 0.00722169897399505, 0.003429904615088075, 0.00035008823533533295, 0.004118316308064696, 0.007874816219570313, 0.011619624472357426, 0.015352777455321709, 0.01907431144410321, 0.0227842626014374, 0.02648266697750823, 0.030169560510297844, 0.033844979025935196, 0.0375089582390451, 0.04116153375309439, 0.044802741060739004, 0.04843261554416767, 0.05205119247544654, 0.05565850701686159, 0.059254594221260115, 0.06283948903239223, 0.06641322628524904, 0.06997584070640217, 0.07352736691434147, 0.07706783941980988, 0.08059729262614046, 0.08411576082958994, 0.08762327821967197, 0.09111987887948891, 0.09460559678606417, 0.09808046581067154, 0.10154451971916423, 0.10499779217230398, 0.10844031672608612, 0.1118721268320686, 0.11529325583769401, 0.11870373698661552, 0.12210360341901949, 0.12549288817194726, 0.12887162417961617, 0.13223984427374025, 0.1355975811838479, 0.1389448675376017, 0.14228173586111348, 0.14560821857926243, 0.14892434801600873, 0.15223015639470772, 0.15552567583842403, 0.15881093837024252, 0.16208597591358043, 0.16535082029249693, 0.16860550323200285, 0.17185005635836825, 0.17508451119943058, 0.17830889918490045, 0.18152325164666738, 0.18472759981910403, 0.1879219748393699, 0.1911064077477136, 0.19428092948777476, 0.19744557090688475, 0.20060036275636595, 0.20374533569183106, 0.20688052027348136, 0.21000594696640218, 0.2131216461408607, 0.21622764807259987, 0.21932398294313293, 0.22241068084003712, 0.22548777175724521, 0.2285552855953381, 0.23161325216183393, 0.2346617011714789, 0.23770066224653552, 0.24073016491707067, 0.2437502386212419, 0.24676091270558498, 0.24976221642529717, 0.25275417894452257, 0.2557368293366358, 0.25871019658452366, 0.26167430958086735, 0.2646291971284228, 0.26757488794030104, 0.270511410640247, 0.27343879376291746, 0.2763570657541583, 0.27926625497128166, 0.2821663896833403, 0.28505749807140324, 0.28793960822882925, 0.29081274816154, 0.2936769457882915, 0.2965322289409469, 0.2993786253647448, 0.3022161627185713, 0.3050448685752267, 0.30786477042169424, 0.3106758956594078, 0.3134782716045168, 0.31627192548815297, 0.319056884456694, 0.3218331755720283, 0.32460082581181626, 0.327359862069755, 0.3301103111558368, 0.33285219979661207, 0.3355855546354475, 0.3383104022327854, 0.3410267690664023, 0.3437346815316654, 0.34643416594178944, 0.349125248528093, 0.3518079554402521, 0.3544823127465553, 0.3571483464341568, 0.35980608240932876, 0.36245554649771305, 0.3650967644445726, 0.36772976191504103, 0.3703545644943723, 0.37297119768818954, 0.37557968692273225, 0.3781800575451044, 0.38077233482351935, 0.3833565439475468, 0.3859327100283567, 0.3885008580989634, 0.3910610131144687, 0.3936131999523055, 0.3961574434124776, 0.39869376821780267, 0.4012221990141507, 0.4037427603706849, 0.4062554767800999, 0.40876037265885934, 0.41125747234743393, 0.4137468001105372, 0.4162283801373622, 0.41870223654181504, 0.42116839336275136, 0.4236268745642079, 0.4260777040356363, 0.4285209055921353, 0.430956502974682, 0.4333845198503625, 0.4358049798126019, 0.43821790638139324, 0.440623323003527, 0.4430212530528178, 0.44541171983033245, 0.4477947465646157, 0.45017035641191605, 0.4525385724564115, 0.45489941771043274, 0.4572529151146877, 0.45959908753848366, 0.4619379577799505, 0.464269548566261, 0.46659388255385303, 0.46891098232864814, 0.4712208704062727, 0.47352356923227523, 0.4758191011823457, 0.47810748856253193, 0.4803887536094571, 0.4826629184905358, 0.48493000530418817, 0.48719003608005707, 0.4894430327792194, 0.49168901729440206, 0.4939280114501923, 0.4961600370032515, 0.4983851156425261, 0.5006032689894581, 0.5028145185981954, 0.505018885955801, 0.5072163924824625, 0.5094070595316988, 0.5115909083905698, 0.5137679602798806, 0.5159382363543898, 0.5181017577030145, 0.5202585453490345, 0.5224086202502976, 0.5245520032994224, 0.5266887153240023, 0.5288187770868066, 0.5309422092859837, 0.5330590325552603, 0.5351692674641448, 0.5372729345181237, 0.539370054158864, 0.5414606467644094, 0.54354473264938, 0.545622332065169, 0.5476934652001392, 0.5497581521798199, 0.551816413067102, 0.553868267862433, 0.5559137365040113, 0.5579528388679801, 0.5599855947686205, 0.5620120239585439, 0.5640321461288843, 0.5660459809094892, 0.5680535478691103, 0.5700548665155943, 0.5720499562960724, 0.5740388365971477, 0.5760215267450858, 0.5779980460060015, 0.5799684135860457, 0.5819326486315926, 0.5838907702294258, 0.5858427974069238, 0.5877887491322438, 0.5897286443145074, 0.5916625018039837, 0.5935903403922732, 0.5955121788124886, 0.5974280357394389, 0.5993379297898097, 0.6012418795223443, 0.6031399034380243, 0.6050320199802491, 0.6069182475350154, 0.6087986044310952, 0.610673108940215, 0.6125417792772321, 0.6144046336003128, 0.616261690011108, 0.6181129665549292, 0.6199584812209243, 0.6217982519422522, 0.6236322965962564, 0.6254606330046399, 0.6272832789336377, 0.6291002520941892, 0.6309115701421107, 0.6327172506782669, 0.6345173112487423, 0.6363117693450109, 0.6381006424041064, 0.639883947808792, 0.6416617028877295, 0.6434339249156464, 0.6452006311135058, 0.6469618386486717, 0.6487175646350775, 0.6504678261333904, 0.6522126401511793, 0.6539520236430786, 0.655685993510954, 0.6574145666040654, 0.6591377597192316, 0.6608555896009937, 0.6625680729417767, 0.664275226382053, 0.6659770665105037, 0.6676736098641789, 0.6693648729286594, 0.6710508721382168, 0.6727316238759726, 0.6744071444740584, 0.6760774502137732, 0.6777425573257431, 0.6794024819900777, 0.6810572403365284, 0.6827068484446445, 0.6843513223439296, 0.6859906780139974, 0.687624931384727, 0.6892540983364176, 0.6908781946999425, 0.6924972362569042, 0.6941112387397862, 0.6957202178321062, 0.6973241891685696, 0.6989231683352201, 0.7005171708695921, 0.7021062122608608, 0.7036903079499934, 0.7052694733298992, 0.7068437237455785, 0.708413074494272, 0.7099775408256104, 0.7115371379417609, 0.7130918809975759, 0.7146417851007403, 0.7161868653119183, 0.7177271366448992, 0.7192626140667437, 0.7207933124979298, 0.7223192468124967, 0.7238404318381901, 0.7253568823566061, 0.7268686131033353, 0.7283756387681048, 0.7298779739949222, 0.7313756333822169, 0.7328686314829829, 0.7343569828049195, 0.7358407018105724, 0.7373198029174748, 0.7387943004982864, 0.7402642088809345, 0.7417295423487515, 0.7431903151406154, 0.744646541451087, 0.7460982354305485, 0.7475454111853403, 0.748988082777899, 0.7504262642268928, 0.7518599695073596, 0.7532892125508405, 0.754714007245517, 0.7561343674363451, 0.7575503069251899, 0.7589618394709603, 0.7603689787897419, 0.7617717385549303, 0.763170132397365, 0.7645641739054604, 0.7659538766253391, 0.7673392540609629, 0.7687203196742641, 0.7700970868852762, 0.7714695690722646, 0.7728377795718563, 0.7742017316791698, 0.7755614386479441, 0.7769169136906675, 0.7782681699787057, 0.7796152206424306, 0.780958078771347, 0.7822967574142206, 0.7836312695792038, 0.7849616282339631, 0.7862878463058046, 0.7876099366817996, 0.7889279122089097], \"type\": \"scatter\", \"uid\": \"aa1a4ae8-0172-4a02-a316-ddbb26c4fcf2\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 3.0559118236472944, 6.061823647294589, 9.067735470941884, 12.073647294589179, 15.079559118236475, 18.085470941883766, 21.091382765531062, 24.097294589178357, 27.103206412825653, 30.10911823647295, 33.11503006012024, 36.12094188376753, 39.126853707414824, 42.13276553106212, 45.138677354709415, 48.14458917835671, 51.150501002004006, 54.1564128256513, 57.1623246492986, 60.16823647294589, 63.17414829659318, 66.18006012024048, 69.18597194388778, 72.19188376753506, 75.19779559118236, 78.20370741482965, 81.20961923847695, 84.21553106212424, 87.22144288577154, 90.22735470941883, 93.23326653306613, 96.23917835671342, 99.24509018036072, 102.25100200400801, 105.25691382765531, 108.2628256513026, 111.2687374749499, 114.2746492985972, 117.28056112224449, 120.28647294589179, 123.29238476953907, 126.29829659318636, 129.3042084168337, 132.31012024048098, 135.31603206412828, 138.32194388777557, 141.32785571142287, 144.33376753507014, 147.33967935871743, 150.34559118236473, 153.35150300601202, 156.35741482965932, 159.36332665330661, 162.3692384769539, 165.3751503006012, 168.3810621242485, 171.3869739478958, 174.3928857715431, 177.3987975951904, 180.40470941883768, 183.41062124248498, 186.41653306613227, 189.42244488977957, 192.42835671342687, 195.43426853707416, 198.44018036072146, 201.44609218436875, 204.45200400801605, 207.45791583166334, 210.46382765531064, 213.46973947895793, 216.47565130260523, 219.48156312625252, 222.48747494989982, 225.49338677354712, 228.4992985971944, 231.5052104208417, 234.511122244489, 237.5170340681363, 240.5229458917836, 243.52885771543086, 246.53476953907816, 249.54068136272545, 252.54659318637275, 255.55250501002004, 258.55841683366737, 261.56432865731466, 264.57024048096196, 267.57615230460925, 270.58206412825655, 273.58797595190384, 276.59388777555114, 279.59979959919843, 282.60571142284573, 285.611623246493, 288.61753507014026, 291.62344689378756, 294.62935871743485, 297.63527054108215, 300.64118236472945, 303.64709418837674, 306.65300601202404, 309.65891783567133, 312.6648296593186, 315.6707414829659, 318.6766533066132, 321.6825651302605, 324.6884769539078, 327.6943887775551, 330.7003006012024, 333.7062124248497, 336.712124248497, 339.7180360721443, 342.7239478957916, 345.7298597194389, 348.7357715430862, 351.74168336673347, 354.74759519038076, 357.75350701402806, 360.75941883767536, 363.76533066132265, 366.77124248496995, 369.77715430861724, 372.78306613226454, 375.78897795591183, 378.7948897795591, 381.8008016032064, 384.8067134268537, 387.812625250501, 390.8185370741483, 393.8244488977956, 396.8303607214429, 399.8362725450902, 402.8421843687375, 405.8480961923848, 408.8540080160321, 411.8599198396794, 414.8658316633267, 417.87174348697397, 420.87765531062126, 423.88356713426856, 426.88947895791586, 429.89539078156315, 432.90130260521045, 435.90721442885774, 438.91312625250504, 441.91903807615233, 444.9249498997996, 447.9308617234469, 450.9367735470942, 453.9426853707415, 456.9485971943888, 459.9545090180361, 462.9604208416834, 465.9663326653307, 468.972244488978, 471.9781563126253, 474.9840681362726, 477.9899799599199, 480.9958917835672, 484.0018036072144, 487.0077154308617, 490.013627254509, 493.0195390781563, 496.0254509018036, 499.0313627254509, 502.0372745490982, 505.0431863727455, 508.0490981963928, 511.0550100200401, 514.0609218436873, 517.0668336673347, 520.0727454909819, 523.0786573146293, 526.0845691382765, 529.0904809619238, 532.0963927855711, 535.1023046092184, 538.1082164328657, 541.114128256513, 544.1200400801603, 547.1259519038076, 550.1318637274549, 553.1377755511022, 556.1436873747494, 559.1495991983968, 562.155511022044, 565.1614228456914, 568.1673346693386, 571.173246492986, 574.1791583166332, 577.1850701402805, 580.1909819639278, 583.196893787575, 586.2028056112224, 589.2087174348696, 592.214629258517, 595.2205410821642, 598.2264529058116, 601.2323647294588, 604.2382765531062, 607.2441883767534, 610.2501002004008, 613.256012024048, 616.2619238476954, 619.2678356713426, 622.27374749499, 625.2796593186372, 628.2855711422845, 631.2914829659318, 634.2973947895791, 637.3033066132264, 640.3092184368737, 643.315130260521, 646.3210420841683, 649.3269539078156, 652.3328657314629, 655.3387775551101, 658.3446893787575, 661.3506012024047, 664.3565130260521, 667.3624248496993, 670.3683366733467, 673.3742484969939, 676.3801603206413, 679.3860721442885, 682.3919839679359, 685.3978957915831, 688.4038076152304, 691.4097194388777, 694.415631262525, 697.4215430861723, 700.4274549098196, 703.4333667334669, 706.4392785571142, 709.4451903807615, 712.4511022044088, 715.457014028056, 718.4629258517034, 721.4688376753506, 724.474749498998, 727.4806613226452, 730.4865731462926, 733.4924849699398, 736.4983967935872, 739.5043086172344, 742.5102204408818, 745.516132264529, 748.5220440881764, 751.5279559118236, 754.533867735471, 757.5397795591182, 760.5456913827655, 763.5516032064128, 766.5575150300601, 769.5634268537074, 772.5693386773546, 775.575250501002, 778.5811623246492, 781.5870741482966, 784.5929859719438, 787.5988977955911, 790.6048096192384, 793.6107214428857, 796.616633266533, 799.6225450901803, 802.6284569138276, 805.6343687374749, 808.6402805611222, 811.6461923847695, 814.6521042084167, 817.6580160320641, 820.6639278557113, 823.6698396793587, 826.6757515030059, 829.6816633266533, 832.6875751503005, 835.6934869739479, 838.6993987975951, 841.7053106212425, 844.7112224448897, 847.717134268537, 850.7230460921843, 853.7289579158316, 856.7348697394789, 859.7407815631262, 862.7466933867735, 865.7526052104208, 868.7585170340681, 871.7644288577154, 874.7703406813627, 877.77625250501, 880.7821643286572, 883.7880761523046, 886.7939879759518, 889.7998997995992, 892.8058116232464, 895.8117234468938, 898.817635270541, 901.8235470941884, 904.8294589178356, 907.835370741483, 910.8412825651302, 913.8471943887776, 916.8531062124248, 919.8590180360721, 922.8649298597194, 925.8708416833667, 928.876753507014, 931.8826653306613, 934.8885771543086, 937.8944889779559, 940.9004008016032, 943.9063126252505, 946.9122244488977, 949.9181362725451, 952.9240480961923, 955.9299599198397, 958.9358717434869, 961.9417835671343, 964.9476953907815, 967.9536072144288, 970.9595190380761, 973.9654308617233, 976.9713426853707, 979.9772545090179, 982.9831663326653, 985.9890781563125, 988.9949899799599, 992.0009018036071, 995.0068136272545, 998.0127254509017, 1001.0186372745491, 1004.0245490981963, 1007.0304609218437, 1010.0363727454909, 1013.0422845691382, 1016.0481963927855, 1019.0541082164328, 1022.0600200400801, 1025.0659318637274, 1028.0718436873747, 1031.077755511022, 1034.0836673346694, 1037.0895791583166, 1040.0954909819638, 1043.101402805611, 1046.1073146292586, 1049.1132264529058, 1052.119138276553, 1055.1250501002003, 1058.1309619238477, 1061.136873747495, 1064.1427855711422, 1067.1486973947895, 1070.154609218437, 1073.1605210420842, 1076.1664328657314, 1079.1723446893786, 1082.178256513026, 1085.1841683366733, 1088.1900801603206, 1091.1959919839678, 1094.2019038076153, 1097.2078156312625, 1100.2137274549098, 1103.219639278557, 1106.2255511022045, 1109.2314629258517, 1112.237374749499, 1115.2432865731462, 1118.2491983967936, 1121.2551102204409, 1124.2610220440881, 1127.2669338677354, 1130.2728456913828, 1133.27875751503, 1136.2846693386773, 1139.2905811623245, 1142.296492985972, 1145.3024048096192, 1148.3083166332665, 1151.3142284569137, 1154.320140280561, 1157.3260521042084, 1160.3319639278557, 1163.337875751503, 1166.3437875751501, 1169.3496993987976, 1172.3556112224448, 1175.361523046092, 1178.3674348697393, 1181.3733466933868, 1184.379258517034, 1187.3851703406813, 1190.3910821643285, 1193.396993987976, 1196.4029058116232, 1199.4088176352705, 1202.4147294589177, 1205.4206412825652, 1208.4265531062124, 1211.4324649298596, 1214.4383767535069, 1217.4442885771543, 1220.4502004008016, 1223.4561122244488, 1226.462024048096, 1229.4679358717435, 1232.4738476953908, 1235.479759519038, 1238.4856713426852, 1241.4915831663327, 1244.49749498998, 1247.5034068136272, 1250.5093186372744, 1253.5152304609219, 1256.5211422845691, 1259.5270541082164, 1262.5329659318636, 1265.538877755511, 1268.5447895791583, 1271.5507014028055, 1274.5566132264528, 1277.5625250501002, 1280.5684368737475, 1283.5743486973947, 1286.580260521042, 1289.5861723446894, 1292.5920841683367, 1295.597995991984, 1298.6039078156311, 1301.6098196392786, 1304.6157314629259, 1307.621643286573, 1310.6275551102203, 1313.6334669338678, 1316.639378757515, 1319.6452905811623, 1322.6512024048095, 1325.657114228457, 1328.6630260521042, 1331.6689378757515, 1334.6748496993987, 1337.6807615230462, 1340.6866733466934, 1343.6925851703406, 1346.6984969939879, 1349.704408817635, 1352.7103206412826, 1355.7162324649298, 1358.722144288577, 1361.7280561122243, 1364.7339679358718, 1367.739879759519, 1370.7457915831662, 1373.7517034068135, 1376.757615230461, 1379.7635270541082, 1382.7694388777554, 1385.7753507014027, 1388.7812625250501, 1391.7871743486974, 1394.7930861723446, 1397.7989979959918, 1400.8049098196393, 1403.8108216432865, 1406.8167334669338, 1409.822645290581, 1412.8285571142285, 1415.8344689378757, 1418.840380761523, 1421.8462925851702, 1424.8522044088177, 1427.858116232465, 1430.8640280561121, 1433.8699398797594, 1436.8758517034069, 1439.881763527054, 1442.8876753507013, 1445.8935871743486, 1448.899498997996, 1451.9054108216433, 1454.9113226452905, 1457.9172344689377, 1460.9231462925852, 1463.9290581162325, 1466.9349699398797, 1469.940881763527, 1472.9467935871744, 1475.9527054108216, 1478.9586172344689, 1481.964529058116, 1484.9704408817636, 1487.9763527054108, 1490.982264529058, 1493.9881763527053, 1496.9940881763528, 1500.0], \"y\": [0.8110132891376898, 0.8043449980931436, 0.797698941336529, 0.7910750447313755, 0.7844732343884084, 0.7778934366647248, 0.7713355781629705, 0.7647995857305236, 0.7582853864586765, 0.7517929076818235, 0.74532207697665, 0.7388728221613248, 0.7324450712946948, 0.7260387526754823, 0.7196537948414856, 0.7132901265687817, 0.7069476768709315, 0.700626374998188, 0.6943261504367078, 0.6880469329077632, 0.6817886523669601, 0.6755512390034546, 0.6693346232391757, 0.6631387357280485, 0.6569635073552211, 0.6508088692362932, 0.644674752716548, 0.6385610893701861, 0.6324678109995623, 0.6263948496344249, 0.6203421375311577, 0.6143096071720244, 0.6082971912644142, 0.6023048227400931, 0.5963324347544543, 0.5903799606857729, 0.5844473341344636, 0.578534488922338, 0.5726413590918693, 0.5667678789054533, 0.5609139828446779, 0.5550796056095904, 0.5492646821179699, 0.5434691475046014, 0.5376929371205519, 0.5319359865324489, 0.5261982315217624, 0.5204796080840886, 0.5147800524284347, 0.5090995009765089, 0.50343789036201, 0.4977951574299213, 0.49217123923580575, 0.4865660730451038, 0.4809795963324335, 0.4754117467808936, 0.46986246228136785, 0.4643316809318323, 0.4588193410366648, 0.45332538110595655, 0.4478497398548271, 0.44239235620273964, 0.43695316927282013, 0.4315321183911778, 0.4261291430862295, 0.42074418308802364, 0.41537717832756904, 0.41002806893616395, 0.4046967952447289, 0.3993832977831413, 0.39408751727957103, 0.3888093946598197, 0.3835488710466626, 0.3783058877591907, 0.37308038631215634, 0.36787230841532126, 0.36268159597280647, 0.35750819108244314, 0.352352036035128, 0.3472130733141785, 0.3420912455946925, 0.3369864957429072, 0.3318987668155633, 0.32682800205926865, 0.32177414490986633, 0.3167371389918021, 0.3117169281174976, 0.30671345628672153, 0.30172666768596623, 0.2967565066878244, 0.2918029178503698, 0.28686584591653697, 0.2819452358135064, 0.2770410326520889, 0.2721531817261149, 0.26728162851182224, 0.2624263186672502, 0.2575871980316311, 0.25276421262478754, 0.24795730864653032, 0.24316643247605696, 0.23839153067135532, 0.2336325499686065, 0.22888943728158995, 0.2241621397010931, 0.21945060449432008, 0.21475477910430274, 0.21007461114931658, 0.20541004842229382, 0.20076103889024322, 0.19612753069366828, 0.19150947214598935, 0.18690681173296686, 0.182319498112127, 0.17774748011218833, 0.17319070673249182, 0.16864912714243108, 0.16412269068088636, 0.15961134685565814, 0.15511504534290488, 0.15063373598658192, 0.1461673687978804, 0.14171589395467143, 0.13727926180094951, 0.13285742284627844, 0.12845032776523957, 0.12405792739688182, 0.11968017274417231, 0.11531701497345126, 0.11096840541388597, 0.10663429555692838, 0.10231463705577415, 0.09800938172482332, 0.09371848153914208, 0.08944188863392855, 0.08517955530397714, 0.08093143400314728, 0.07669747734383359, 0.07247763809643559, 0.0682718691888331, 0.06408012370585903, 0.059902354888777376, 0.05573851613476122, 0.05158856099637288, 0.04745244318104547, 0.04333011655056729, 0.039221535120566475, 0.035126653059998514, 0.031045424690634205, 0.026977804486551404, 0.022923747073625655, 0.018883207229025256, 0.014856139880706776, 0.010842500106911013, 0.006842243135663617, 0.002855324344274157, 0.0011183007411605939, 0.00507867644625315, 0.00902584694882047, 0.012959856279374682, 0.016880748321617123, 0.02078856681292507, 0.024683355344842006, 0.028565157363562355, 0.03243401617041597, 0.03628997492235286, 0.04013307663242238, 0.04396336417025526, 0.04778088026253968, 0.051585667493499354, 0.05537776830536845, 0.05915722499886389, 0.06292407973365899, 0.06667837452885172, 0.07042015126343548, 0.07414945167676446, 0.07786631736902061, 0.08157078980167665, 0.08526291029795918, 0.08894272004330994, 0.09261026008584405, 0.09626557133680924, 0.09990869457104146, 0.10353967042741918, 0.10715853940931885, 0.11076534188506382, 0.11436011808837687, 0.1179429081188279, 0.1215137519422822, 0.12507268939134475, 0.12861976016580612, 0.13215500383308432, 0.13567845982866666, 0.13919016745654966, 0.14269016588967665, 0.14617849417037632, 0.14965519121079618, 0.1531202957933393, 0.15657384657109374, 0.1600158820682669, 0.16344644068061243, 0.16686556067586067, 0.17027328019414445, 0.17366963724842477, 0.17705466972491468, 0.1804284153835023, 0.18379091185817198, 0.18714219665742315, 0.1904823071646904, 0.1938112806387592, 0.19712915421418153, 0.20043596490169124, 0.2037317495886155, 0.20701654503928746, 0.21029038789545518, 0.2135533146766918, 0.21680536178080145, 0.2200465654842264, 0.22327696194245095, 0.2264965871904051, 0.2297054771428667, 0.2329036675948617, 0.23609119422206348, 0.23926809258119108, 0.24243439811040568, 0.2455901461297061, 0.24873537184132177, 0.25187011033010753, 0.2549943965639324, 0.25810826539407217, 0.26121175155559584, 0.2643048896677552, 0.26738771423436913, 0.27046025964421005, 0.27352256017138643, 0.27657464997572556, 0.27961656310315475, 0.28264833348608087, 0.28566999494376877, 0.2886815811827189, 0.29168312579704303, 0.29467466226883887, 0.29765622396856395, 0.30062784415540766, 0.3035895559776619, 0.30654139247309187, 0.3094833865693032, 0.31241557108411067, 0.31533797872590286, 0.31825064209400866, 0.32115359367905916, 0.3240468658633514, 0.3269304909212092, 0.32980450101934267, 0.33266892821720806, 0.3355238044673643, 0.3383691616158301, 0.3412050314024391, 0.3440314454611937, 0.34684843532061815, 0.34965603240411014, 0.35245426803029123, 0.35524317341335665, 0.358022779663423, 0.3607931177868753, 0.36355421868671334, 0.36630611316289585, 0.36904883191268434, 0.37178240553098574, 0.37450686451069304, 0.3772222392430262, 0.37992856001787045, 0.3826258570241151, 0.3853141603499889, 0.38799349998339727, 0.3906639058122555, 0.39332540762482304, 0.39597803511003515, 0.39862181785783446, 0.40125678535950116, 0.4038829670079813, 0.40650039209821565, 0.40910908982746574, 0.4117090892956393, 0.41430041950561625, 0.4168831093635704, 0.41945718767929385, 0.42202268316651614, 0.4245796244432267, 0.42712804003199256, 0.4296679583602774, 0.43219940776075816, 0.4347224164716411, 0.43723701263697745, 0.43974322430697643, 0.4422410794383188, 0.44473060589446844, 0.4472118314459831, 0.44968478377082455, 0.4521494904546668, 0.45460597899120436, 0.4570542767824586, 0.4594944111390833, 0.46192640928066975, 0.46435029833605, 0.46676610534359964, 0.4691738572515394, 0.4715735809182352, 0.4739653031124994, 0.476349050513887, 0.4787248497129959, 0.48109272721176066, 0.48345270942375107, 0.4858048226744641, 0.4881490932016199, 0.49048554715545245, 0.49281421059900266, 0.4951351095084088, 0.49744826977319556, 0.4997537171965639, 0.5020514774956784, 0.5043415763019534, 0.5066240391613405, 0.5088988915346123, 0.5111661587976466, 0.5134258662417097, 0.5156780390737385, 0.517922702416622, 0.5201598813094804, 0.5223896007079458, 0.5246118854844399, 0.5268267604284513, 0.5290342502468124, 0.5312343795639747, 0.5334271729222838, 0.535612654782253, 0.5377908495228361, 0.5399617814416993, 0.5421254747554924, 0.5442819536001192, 0.5464312420310059, 0.5485733640233703, 0.5507083434724888, 0.5528362041939628, 0.5549569699239854, 0.5570706643196041, 0.5591773109589872, 0.5612769333416849, 0.5633695548888925, 0.5654551989437109, 0.5675338887714075, 0.5696056475596759, 0.5716704984188943, 0.5737284643823823, 0.57577956840666, 0.5778238333717023, 0.5798612820811948, 0.5818919372627879, 0.5839158215683506, 0.585932957574223, 0.5879433677814689, 0.5899470746161251, 0.5919441004294528, 0.5939344674981871, 0.5959181980247853, 0.5978953141376734, 0.5998658378914947, 0.6018297912673549, 0.6037871961730672, 0.605738074443397, 0.6076824478403056, 0.6096203380531923, 0.6115517666991371, 0.6134767553231412, 0.6153953253983682, 0.6173074983263824, 0.6192132954373889, 0.6211127379904698, 0.6230058471738237, 0.6248926441049997, 0.6267731498311346, 0.6286473853291867, 0.6305153715061703, 0.6323771291993892, 0.634232679176668, 0.6360820421365853, 0.6379252387087029, 0.6397622894537975, 0.6415932148640895, 0.6434180353634708, 0.6452367713077336, 0.6470494429847972, 0.6488560706149343, 0.6506566743509967, 0.6524512742786394, 0.6542398904165454, 0.6560225427166491, 0.6577992510643583, 0.6595700352787762, 0.6613349151129226, 0.6630939102539543, 0.6648470403233847, 0.6665943248773022, 0.6683357834065892, 0.6700714353371384, 0.6718013000300712, 0.6735253967819516, 0.6752437448250027, 0.6769563633273216, 0.6786632713930918, 0.6803644880627978, 0.6820600323134364, 0.6837499230587291, 0.6854341791493326, 0.687112819373049, 0.6887858624550366, 0.6904533270580169, 0.692115231782484, 0.6937715951669119, 0.695422435687961, 0.6970677717606849, 0.6987076217387347, 0.7003420039145647, 0.7019709365196356, 0.7035944377246195, 0.7052125256396002, 0.7068252183142775, 0.7084325337381666, 0.7100344898408006, 0.7116311044919292, 0.7132223955017181, 0.7148083806209486, 0.7163890775412147, 0.7179645038951212, 0.7195346772564791, 0.7210996151405034, 0.7226593350040067, 0.7242138542455961, 0.7257631902058648, 0.7273073601675869, 0.7288463813559105, 0.7303802709385492, 0.7319090460259734, 0.7334327236716021, 0.734951320871992, 0.7364648545670283, 0.7379733416401121, 0.7394767989183506, 0.7409752431727433, 0.7424686911183699, 0.7439571594145763, 0.7454406646651608, 0.7469192234185589, 0.7483928521680285, 0.7498615673518335, 0.7513253853534265, 0.7527843225016332, 0.7542383950708331, 0.7556876192811415, 0.7571320112985905, 0.7585715872353097, 0.7600063631497049, 0.7614363550466385, 0.7628615788776066, 0.7642820505409185, 0.765697785881873, 0.7671088006929354, 0.7685151107139137, 0.7699167316321339, 0.771313679082616, 0.7727059686482471, 0.7740936158599558, 0.7754766361968856, 0.7768550450865672, 0.7782288579050916, 0.7795980899772796, 0.7809627565768549, 0.7823228729266132, 0.7836784541985924, 0.7850295155142419, 0.786376071944591, 0.7877181385104174, 0.7890557301824144, 0.7903888618813583, 0.7917175484782741, 0.7930418047946026, 0.7943616456023646, 0.7956770856243256, 0.7969881395341617, 0.798294821956621, 0.7995971474676888, 0.8008951305947483, 0.8021887858167442, 0.8034781275643436, 0.8047631702200968, 0.8060439281185978, 0.8073204155466447, 0.8085926467433984, 0.8098606359005418, 0.8111243971624381], \"type\": \"scatter\", \"uid\": \"c41b98a7-25e1-477d-8151-19390ed73b41\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 3.256312625250501, 6.462625250501002, 9.668937875751505, 12.875250501002006, 16.081563126252508, 19.28787575150301, 22.49418837675351, 25.70050100200401, 28.90681362725451, 32.11312625250501, 35.31943887775551, 38.52575150300601, 41.73206412825651, 44.938376753507015, 48.14468937875751, 51.351002004008016, 54.55731462925852, 57.76362725450902, 60.96993987975952, 64.17625250501003, 67.38256513026052, 70.58887775551102, 73.79519038076153, 77.00150300601203, 80.20781563126253, 83.41412825651302, 86.62044088176353, 89.82675350701403, 93.03306613226454, 96.23937875751503, 99.44569138276553, 102.65200400801604, 105.85831663326654, 109.06462925851704, 112.27094188376753, 115.47725450901804, 118.68356713426854, 121.88987975951905, 125.09619238476954, 128.30250501002007, 131.50881763527056, 134.71513026052105, 137.92144288577157, 141.12775551102206, 144.33406813627258, 147.54038076152307, 150.74669338677356, 153.95300601202408, 157.15931863727457, 160.36563126252508, 163.57194388777557, 166.77825651302607, 169.98456913827658, 173.19088176352707, 176.39719438877756, 179.60350701402808, 182.80981963927857, 186.0161322645291, 189.22244488977958, 192.42875751503007, 195.6350701402806, 198.84138276553108, 202.0476953907816, 205.2540080160321, 208.46032064128258, 211.6666332665331, 214.8729458917836, 218.0792585170341, 221.2855711422846, 224.49188376753509, 227.6981963927856, 230.9045090180361, 234.1108216432866, 237.3171342685371, 240.5234468937876, 243.7297595190381, 246.9360721442886, 250.1423847695391, 253.3486973947896, 256.55501002004013, 259.7613226452906, 262.9676352705411, 266.1739478957916, 269.3802605210421, 272.5865731462926, 275.7928857715431, 278.9991983967936, 282.2055110220441, 285.4118236472946, 288.61813627254514, 291.8244488977956, 295.0307615230461, 298.23707414829664, 301.4433867735471, 304.6496993987976, 307.85601202404814, 311.0623246492986, 314.2686372745491, 317.47494989979964, 320.68126252505016, 323.8875751503006, 327.09388777555114, 330.30020040080166, 333.5065130260521, 336.71282565130264, 339.91913827655316, 343.1254509018036, 346.33176352705414, 349.53807615230465, 352.7443887775551, 355.95070140280563, 359.15701402805615, 362.3633266533067, 365.56963927855713, 368.77595190380765, 371.98226452905817, 375.18857715430863, 378.39488977955915, 381.60120240480967, 384.80751503006013, 388.01382765531065, 391.22014028056117, 394.4264529058117, 397.63276553106215, 400.83907815631267, 404.0453907815632, 407.25170340681365, 410.45801603206417, 413.6643286573147, 416.87064128256515, 420.07695390781566, 423.2832665330662, 426.48957915831664, 429.69589178356716, 432.9022044088177, 436.1085170340682, 439.31482965931866, 442.5211422845692, 445.7274549098197, 448.93376753507016, 452.1400801603207, 455.3463927855712, 458.55270541082166, 461.7590180360722, 464.9653306613227, 468.1716432865732, 471.3779559118237, 474.5842685370742, 477.7905811623247, 480.9968937875752, 484.2032064128257, 487.4095190380762, 490.6158316633267, 493.8221442885772, 497.0284569138277, 500.2347695390782, 503.4410821643287, 506.6473947895792, 509.8537074148297, 513.0600200400802, 516.2663326653307, 519.4726452905811, 522.6789579158317, 525.8852705410821, 529.0915831663326, 532.2978957915832, 535.5042084168336, 538.7105210420841, 541.9168336673347, 545.1231462925851, 548.3294589178356, 551.5357715430862, 554.7420841683366, 557.9483967935871, 561.1547094188377, 564.3610220440881, 567.5673346693387, 570.7736472945892, 573.9799599198396, 577.1862725450902, 580.3925851703407, 583.5988977955911, 586.8052104208417, 590.0115230460922, 593.2178356713426, 596.4241482965932, 599.6304609218437, 602.8367735470941, 606.0430861723447, 609.2493987975952, 612.4557114228456, 615.6620240480962, 618.8683366733467, 622.0746492985971, 625.2809619238477, 628.4872745490982, 631.6935871743486, 634.8998997995992, 638.1062124248497, 641.3125250501002, 644.5188376753507, 647.7251503006012, 650.9314629258517, 654.1377755511022, 657.3440881763527, 660.5504008016032, 663.7567134268537, 666.9630260521042, 670.1693386773547, 673.3756513026052, 676.5819639278557, 679.7882765531062, 682.9945891783567, 686.2009018036072, 689.4072144288577, 692.6135270541082, 695.8198396793587, 699.0261523046092, 702.2324649298597, 705.4387775551102, 708.6450901803607, 711.8514028056112, 715.0577154308618, 718.2640280561122, 721.4703406813627, 724.6766533066133, 727.8829659318637, 731.0892785571142, 734.2955911823648, 737.5019038076152, 740.7082164328657, 743.9145290581163, 747.1208416833667, 750.3271543086172, 753.5334669338678, 756.7397795591182, 759.9460921843687, 763.1524048096193, 766.3587174348697, 769.5650300601202, 772.7713426853708, 775.9776553106212, 779.1839679358717, 782.3902805611223, 785.5965931863727, 788.8029058116233, 792.0092184368738, 795.2155310621242, 798.4218436873748, 801.6281563126253, 804.8344689378757, 808.0407815631263, 811.2470941883768, 814.4534068136272, 817.6597194388778, 820.8660320641283, 824.0723446893787, 827.2786573146293, 830.4849699398798, 833.6912825651302, 836.8975951903808, 840.1039078156313, 843.3102204408817, 846.5165330661323, 849.7228456913828, 852.9291583166332, 856.1354709418838, 859.3417835671343, 862.5480961923848, 865.7544088176353, 868.9607214428858, 872.1670340681363, 875.3733466933868, 878.5796593186373, 881.7859719438878, 884.9922845691383, 888.1985971943888, 891.4049098196393, 894.6112224448898, 897.8175350701403, 901.0238476953908, 904.2301603206413, 907.4364729458918, 910.6427855711423, 913.8490981963928, 917.0554108216432, 920.2617234468938, 923.4680360721443, 926.6743486973947, 929.8806613226453, 933.0869739478958, 936.2932865731464, 939.4995991983968, 942.7059118236473, 945.9122244488979, 949.1185370741483, 952.3248496993988, 955.5311623246494, 958.7374749498998, 961.9437875751503, 965.1501002004009, 968.3564128256513, 971.5627254509018, 974.7690380761524, 977.9753507014028, 981.1816633266533, 984.3879759519039, 987.5942885771543, 990.8006012024048, 994.0069138276554, 997.2132264529058, 1000.4195390781563, 1003.6258517034069, 1006.8321643286573, 1010.0384769539079, 1013.2447895791584, 1016.4511022044088, 1019.6574148296594, 1022.8637274549098, 1026.0700400801604, 1029.2763527054108, 1032.4826653306613, 1035.688977955912, 1038.8952905811623, 1042.1016032064128, 1045.3079158316634, 1048.5142284569138, 1051.7205410821643, 1054.926853707415, 1058.1331663326653, 1061.3394789579158, 1064.5457915831664, 1067.7521042084168, 1070.9584168336673, 1074.164729458918, 1077.3710420841683, 1080.5773547094188, 1083.7836673346694, 1086.9899799599198, 1090.1962925851703, 1093.402605210421, 1096.6089178356713, 1099.8152304609218, 1103.0215430861724, 1106.2278557114228, 1109.4341683366733, 1112.640480961924, 1115.8467935871743, 1119.0531062124248, 1122.2594188376754, 1125.465731462926, 1128.6720440881763, 1131.878356713427, 1135.0846693386775, 1138.2909819639278, 1141.4972945891784, 1144.703607214429, 1147.9099198396793, 1151.11623246493, 1154.3225450901805, 1157.5288577154308, 1160.7351703406814, 1163.941482965932, 1167.1477955911823, 1170.354108216433, 1173.5604208416835, 1176.7667334669338, 1179.9730460921844, 1183.179358717435, 1186.3856713426853, 1189.591983967936, 1192.7982965931865, 1196.0046092184368, 1199.2109218436874, 1202.417234468938, 1205.6235470941883, 1208.829859719439, 1212.0361723446895, 1215.2424849699398, 1218.4487975951904, 1221.655110220441, 1224.8614228456913, 1228.067735470942, 1231.2740480961925, 1234.4803607214428, 1237.6866733466934, 1240.892985971944, 1244.0992985971943, 1247.305611222445, 1250.5119238476955, 1253.7182364729458, 1256.9245490981964, 1260.130861723447, 1263.3371743486973, 1266.543486973948, 1269.7497995991985, 1272.956112224449, 1276.1624248496994, 1279.36873747495, 1282.5750501002005, 1285.781362725451, 1288.9876753507015, 1292.193987975952, 1295.4003006012024, 1298.606613226453, 1301.8129258517035, 1305.019238476954, 1308.2255511022045, 1311.431863727455, 1314.6381763527054, 1317.844488977956, 1321.0508016032065, 1324.2571142284569, 1327.4634268537075, 1330.669739478958, 1333.8760521042084, 1337.082364729459, 1340.2886773547095, 1343.4949899799599, 1346.7013026052105, 1349.907615230461, 1353.1139278557114, 1356.320240480962, 1359.5265531062125, 1362.7328657314629, 1365.9391783567135, 1369.145490981964, 1372.3518036072144, 1375.558116232465, 1378.7644288577155, 1381.9707414829659, 1385.1770541082165, 1388.383366733467, 1391.5896793587174, 1394.795991983968, 1398.0023046092185, 1401.2086172344689, 1404.4149298597195, 1407.62124248497, 1410.8275551102204, 1414.033867735471, 1417.2401803607215, 1420.446492985972, 1423.6528056112224, 1426.859118236473, 1430.0654308617236, 1433.271743486974, 1436.4780561122245, 1439.684368737475, 1442.8906813627254, 1446.096993987976, 1449.3033066132266, 1452.509619238477, 1455.7159318637275, 1458.922244488978, 1462.1285571142284, 1465.334869739479, 1468.5411823647296, 1471.74749498998, 1474.9538076152305, 1478.160120240481, 1481.3664328657314, 1484.572745490982, 1487.7790581162326, 1490.985370741483, 1494.1916833667335, 1497.397995991984, 1500.6043086172344, 1503.810621242485, 1507.0169338677356, 1510.223246492986, 1513.4295591182365, 1516.635871743487, 1519.8421843687374, 1523.048496993988, 1526.2548096192386, 1529.461122244489, 1532.6674348697395, 1535.87374749499, 1539.0800601202404, 1542.286372745491, 1545.4926853707416, 1548.698997995992, 1551.9053106212425, 1555.111623246493, 1558.3179358717434, 1561.524248496994, 1564.7305611222446, 1567.9368737474952, 1571.1431863727455, 1574.349498997996, 1577.5558116232467, 1580.762124248497, 1583.9684368737476, 1587.1747494989982, 1590.3810621242485, 1593.587374749499, 1596.7936873747497, 1600.0], \"y\": [0.8308755765691855, 0.8237635093713063, 0.8166767343284214, 0.8096151614957807, 0.8025787012484995, 0.7955672642804186, 0.788580761602973, 0.7816191045440612, 0.7746822047469206, 0.7677699741690052, 0.7608823250808687, 0.7540191700650514, 0.74718042201497, 0.7403659941338123, 0.7335757999334356, 0.7268097532332696, 0.7200677681592209, 0.7133497591425855, 0.7066556409189606, 0.6999853285271636, 0.6933387373081537, 0.686715782903957, 0.6801163812565958, 0.6735404486070224, 0.6669879014940558, 0.6604586567533219, 0.6539526315161983, 0.6474697432087626, 0.6410099095507447, 0.6345730485544818, 0.6281590785238784, 0.6217679180533688, 0.615399486026885, 0.6090537016168258, 0.6027304842830321, 0.596429753771764, 0.5901514301146824, 0.5838954336278344, 0.5776616849106411, 0.5714501048448912, 0.5652606145937353, 0.5590931356006867, 0.5529475895886233, 0.5468238985587943, 0.5407219847898315, 0.5346417708367606, 0.5285831795300202, 0.5225461339744819, 0.5165305575484735, 0.5105363739028081, 0.5045635069598131, 0.4986118809123663, 0.49268142022293326, 0.4867720496226078, 0.4808836941101584, 0.47501627895107434, 0.46916972967661863, 0.4633439720828818, 0.4575389322298413, 0.45175453644042207, 0.4459907112995616, 0.44024738365327853, 0.43452448060774373, 0.42882192952835596, 0.4231396580388185, 0.41747759402022244, 0.4118356656101294, 0.4062138012016616, 0.4006119294425907, 0.39502997923443406, 0.3894678797315516, 0.3839255603402467, 0.3784029507178699, 0.3728999807719271, 0.3674165806591887, 0.36195268078480414, 0.356508211801418, 0.3510831046082905, 0.3456772903504195, 0.3402907004176672, 0.33492326644389014, 0.32957492030606983, 0.3242455941234492, 0.31893522025667087, 0.31364373130691847, 0.308371060115062, 0.3031171397608039, 0.29788190356183186, 0.29266528507297007, 0.2874672180853377, 0.28228763662550826, 0.2771264749546716, 0.2719836675678, 0.26685914919281717, 0.26175285478976895, 0.25666471954999825, 0.25159467889532294, 0.24654266847721584, 0.2415086241759874, 0.2364924820999732, 0.231494178584722, 0.22651365019218805, 0.22155083370992612, 0.21660566615028887, 0.21167808474962801, 0.20676802696749652, 0.20187543048585632, 0.19700023320828675, 0.1921423732591956, 0.1873017889830353, 0.18247841894351957, 0.1776722019228434, 0.17288307692090688, 0.16811098315453998, 0.16335586005673264, 0.15861764727586403, 0.1538962846749381, 0.14919171233082018, 0.14450387053347535, 0.13983269978521218, 0.1351781407999264, 0.13054013450234847, 0.12591862202729498, 0.1213135447189202, 0.11672484412997242, 0.11215246202105122, 0.10759634035986942, 0.10305642132051673, 0.0985326472827237, 0.09402496083113321, 0.08953330475456989, 0.08505762204531409, 0.08059785589837953, 0.07615394971079126, 0.07172584708086771, 0.06731349180750446, 0.06291682788946162, 0.058535799524652266, 0.05417035110943469, 0.049820427237906806, 0.04548597270120269, 0.041166932486791374, 0.036863251777779826, 0.03257487595221664, 0.0283017505823977, 0.02404382143417738, 0.01980103446627912, 0.015573335829609292, 0.011360671866573968, 0.007162989110398366, 0.0029802342844478247, 0.0011876456984483141, 0.0053407037366703936, 0.009478992540480125, 0.01360256463268894, 0.01771147234932524, 0.021805767840298307, 0.025885503070060878, 0.029950729818267074, 0.034001499680431424, 0.03803786406858234, 0.04205987421191559, 0.046067581157443804, 0.0500610357706448, 0.05404028873610689, 0.05800539055817233, 0.061956391561578394, 0.0658933418920955, 0.06981629151716451, 0.07372529022653063, 0.07762038763287471, 0.08150163317244385, 0.08536907610567868, 0.08922276551783748, 0.09306275031962064, 0.09688907924779078, 0.10070180086579095, 0.10450096356436189, 0.10828661556215513, 0.11205880490634601, 0.11581757947324256, 0.11956298696889389, 0.12329507492969549, 0.12701389072299207, 0.13071948154767932, 0.13441189443480273, 0.1380911762481547, 0.14175737368486874, 0.14541053327601272, 0.14905070138717957, 0.152677924219075, 0.1562922478081048, 0.1598937180269584, 0.16348238058519104, 0.1670582810298047, 0.17062146474582573, 0.17417197695688036, 0.17770986272576939, 0.18123516695504027, 0.18474793438755588, 0.18824820960706368, 0.19173603703876085, 0.19521146094985808, 0.1986745254501423, 0.20212527449253492, 0.20556375187365128, 0.20899000123435574, 0.21240406606031514, 0.21580598968255205, 0.21919581527799348, 0.22257358587001885, 0.22593934432900753, 0.22929313337288093, 0.23263499556764633, 0.23596497332793598, 0.23928310891754645, 0.24258944444997377, 0.2458840218889491, 0.24916688304897094, 0.25243806959583526, 0.2556976230471656, 0.2589455847729386, 0.2621819959960098, 0.26540689779263715, 0.2686203310930012, 0.27182233668172606, 0.27501295519839597, 0.27819222713807124, 0.2813601928518026, 0.2845168925471432, 0.2876623662886586, 0.2907966539984356, 0.293919795456589, 0.29703183030176594, 0.3001327980316496, 0.30322273800346056, 0.30630168943445546, 0.30936969140242554, 0.31242678284619274, 0.3154730025661028, 0.3185083892245191, 0.3215329813463126, 0.32454681731935053, 0.32754993539498445, 0.3305423736885351, 0.3335241701797764, 0.3364953627134173, 0.33945598899958207, 0.3424060866142894, 0.3453456929999289, 0.34827484546573617, 0.3511935811882666, 0.35410193721186756, 0.35699995044914756, 0.3598876576814457, 0.36276509555929803, 0.36563230060290286, 0.36848930920258416, 0.37133615761925376, 0.37417288198487075, 0.37699951830290124, 0.3798161024487744, 0.3826226701703379, 0.38541925708831226, 0.38820589869674205, 0.39098263036344705, 0.39374948733047066, 0.396506504714528, 0.3992537175074503, 0.4019911605766302, 0.4047188686654636, 0.407436876393791, 0.41014521825833705, 0.41284392863314734, 0.4155330417700258, 0.4182125917989693, 0.42088261272859995, 0.4235431384465981, 0.42619420272013087, 0.428835839196282, 0.4314680814024784, 0.4340909627469156, 0.4367045165189819, 0.43930877588968087, 0.44190377391205204, 0.4444895435215913, 0.4470661175366677, 0.4496335286589408, 0.4521918094737757, 0.454740992450656, 0.4572811099435967, 0.4598121941915543, 0.46233427731883603, 0.4648473913355077, 0.4673515681378001, 0.46984683950851325, 0.4723332371174207, 0.47481079252167047, 0.47727953716618676, 0.4797395023840674, 0.4821907193969829, 0.484633219315573, 0.48706703313983946, 0.48949219175954206, 0.4919087259545891, 0.4943166663954277, 0.4967160436434348, 0.49910688815130355, 0.5014892302634303, 0.5038631002162997, 0.5062285281388684, 0.5085855440529479, 0.5109341778735847, 0.5132744594094408, 0.5156064183631717, 0.517930084331803, 0.520245486807107, 0.5225526551759762, 0.5248516187207962, 0.5271424066198184, 0.5294250479475286, 0.5316995716750181, 0.5339660066703495, 0.5362243816989242, 0.538474725423847, 0.5407170664062906, 0.5429514331058568, 0.5451778538809389, 0.5473963569890815, 0.5496069705873381, 0.5518097227326297, 0.5540046413821006, 0.5561917543934725, 0.5583710895253986, 0.5605426744378167, 0.5627065366922986, 0.5648627037524011, 0.5670112029840143, 0.5691520616557091, 0.5712853069390821, 0.5734109659091027, 0.5755290655444548, 0.5776396327278794, 0.5797426942465174, 0.5818382767922474, 0.5839264069620261, 0.586007111258225, 0.5880804160889672, 0.5901463477684623, 0.5922049325173405, 0.5942561964629856, 0.5963001656398659, 0.5983368659898654, 0.600366323362613, 0.6023885635158099, 0.6044036121155574, 0.6064114947366818, 0.6084122368630595, 0.6104058638879406, 0.6123924011142707, 0.6143718737550125, 0.616344306933465, 0.6183097256835839, 0.6202681549502974, 0.6222196195898243, 0.624164144369989, 0.6261017539705355, 0.6280324729834408, 0.6299563259132279, 0.6318733371772751, 0.6337835311061274, 0.6356869319438049, 0.6375835638481101, 0.6394734508909343, 0.6413566170585647, 0.6432330862519868, 0.6451028822871889, 0.6469660288954644, 0.6488225497237124, 0.6506724683347384, 0.652515808207553, 0.6543525927376699, 0.6561828452374033, 0.658006588936163, 0.6598238469807501, 0.6616346424356498, 0.6634389982833251, 0.6652369374245078, 0.6670284826784895, 0.6688136567834112, 0.6705924823965517, 0.672364982094615, 0.674131178374018, 0.6758910936511741, 0.6776447502627791, 0.6793921704660952, 0.6811333764392312, 0.6828683902814263, 0.6845972340133295, 0.6863199295772795, 0.6880364988375826, 0.6897469635807905, 0.6914513455159776, 0.6931496662750151, 0.6948419474128462, 0.6965282104077607, 0.6982084766616654, 0.6998827675003577, 0.7015511041737956, 0.703213507856367, 0.7048699996471587, 0.7065206005702247, 0.7081653315748524, 0.7098042135358285, 0.7114372672537044, 0.71306451345506, 0.7146859727927659, 0.7163016658462477, 0.7179116131217447, 0.7195158350525716, 0.7211143519993775, 0.7227071842504045, 0.7242943520217449, 0.7258758754575976, 0.7274517746305246, 0.7290220695417048, 0.7305867801211887, 0.7321459262281506, 0.7336995276511409, 0.7352476041083378, 0.7367901752477966, 0.7383272606476998, 0.7398588798166057, 0.7413850521936949, 0.7429057971490183, 0.7444211339837423, 0.7459310819303943, 0.7474356601531053, 0.7489348877478553, 0.7504287837427144, 0.7519173670980837, 0.7534006567069378, 0.7548786713950628, 0.7563514299212962, 0.7578189509777646, 0.7592812531901216, 0.7607383551177829, 0.7621902752541629, 0.7636370320269095, 0.7650786437981373, 0.7665151288646608, 0.7679465054582273, 0.7693727917457476, 0.7707940058295262, 0.7722101657474925, 0.7736212894734283, 0.7750273949171969, 0.7764284999249693, 0.7778246222794523, 0.7792157797001122, 0.780601989843402, 0.7819832703029832, 0.7833596386099508, 0.7847311122330551, 0.7860977085789231, 0.7874594449922803, 0.7888163387561702, 0.7901684070921735, 0.7915156671606274, 0.7928581360608429, 0.7941958308313215, 0.7955287684499721, 0.7968569658343267, 0.798180439841754, 0.799499207269674, 0.8008132848557716, 0.8021226892782087, 0.803427437155835, 0.8047275450484006, 0.8060230294567651, 0.8073139068231066, 0.8086001935311319, 0.809881905906283, 0.8111590602159451, 0.8124316726696527, 0.8136997594192954, 0.8149633365593232, 0.8162224201269501, 0.8174770261023585, 0.8187271704089014, 0.8199728689133045, 0.8212141374258679, 0.8224509917006668, 0.8236834474357508, 0.8249115202733444, 0.8261352258000437, 0.8273545795470161, 0.8285695969901963, 0.8297802935504827, 0.8309866845939338], \"type\": \"scatter\", \"uid\": \"d2845e01-24fe-4b1a-a4a0-9a4ad841f33e\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 3.456713426853707, 6.863426853707415, 10.270140280561122, 13.67685370741483, 17.083567134268538, 20.490280561122244, 23.896993987975954, 27.30370741482966, 30.710420841683366, 34.11713426853707, 37.52384769539078, 40.930561122244484, 44.33727454909819, 47.7439879759519, 51.15070140280561, 54.557414829659315, 57.96412825651302, 61.37084168336673, 64.77755511022043, 68.18426853707415, 71.59098196392785, 74.99769539078156, 78.40440881763527, 81.81112224448897, 85.21783567134268, 88.62454909819638, 92.0312625250501, 95.43797595190381, 98.84468937875751, 102.25140280561122, 105.65811623246492, 109.06482965931863, 112.47154308617235, 115.87825651302605, 119.28496993987976, 122.69168336673346, 126.09839679358717, 129.50511022044088, 132.9118236472946, 136.3185370741483, 139.72525050100202, 143.1319639278557, 146.53867735470942, 149.94539078156313, 153.35210420841685, 156.75881763527056, 160.16553106212424, 163.57224448897796, 166.97895791583167, 170.38567134268538, 173.7923847695391, 177.19909819639278, 180.6058116232465, 184.0125250501002, 187.41923847695392, 190.82595190380763, 194.23266533066132, 197.63937875751503, 201.04609218436875, 204.45280561122246, 207.85951903807617, 211.26623246492986, 214.67294589178357, 218.07965931863728, 221.486372745491, 224.8930861723447, 228.2997995991984, 231.7065130260521, 235.11322645290582, 238.51993987975953, 241.92665330661325, 245.33336673346693, 248.74008016032064, 252.14679358717436, 255.55350701402807, 258.96022044088176, 262.3669338677355, 265.7736472945892, 269.18036072144287, 272.5870741482966, 275.9937875751503, 279.40050100200403, 282.8072144288577, 286.2139278557114, 289.62064128256515, 293.02735470941883, 296.4340681362726, 299.84078156312626, 303.24749498997994, 306.6542084168337, 310.06092184368737, 313.4676352705411, 316.8743486973948, 320.2810621242485, 323.6877755511022, 327.0944889779559, 330.50120240480965, 333.90791583166333, 337.314629258517, 340.72134268537076, 344.12805611222444, 347.5347695390782, 350.94148296593187, 354.34819639278555, 357.7549098196393, 361.161623246493, 364.5683366733467, 367.9750501002004, 371.3817635270541, 374.78847695390783, 378.1951903807615, 381.60190380761526, 385.00861723446894, 388.4153306613226, 391.82204408817637, 395.22875751503005, 398.6354709418838, 402.0421843687375, 405.44889779559117, 408.8556112224449, 412.2623246492986, 415.66903807615233, 419.075751503006, 422.4824649298597, 425.88917835671344, 429.29589178356713, 432.70260521042087, 436.10931863727455, 439.51603206412824, 442.922745490982, 446.32945891783567, 449.7361723446894, 453.1428857715431, 456.5495991983968, 459.9563126252505, 463.3630260521042, 466.76973947895794, 470.17645290581163, 473.5831663326653, 476.98987975951906, 480.39659318637274, 483.8033066132265, 487.21002004008017, 490.61673346693385, 494.0234468937876, 497.4301603206413, 500.836873747495, 504.2435871743487, 507.6503006012024, 511.05701402805613, 514.4637274549098, 517.8704408817634, 521.2771543086171, 524.6838677354709, 528.0905811623246, 531.4972945891783, 534.904008016032, 538.3107214428857, 541.7174348697395, 545.1241482965931, 548.5308617234468, 551.9375751503005, 555.3442885771542, 558.751002004008, 562.1577154308617, 565.5644288577154, 568.971142284569, 572.3778557114227, 575.7845691382765, 579.1912825651302, 582.5979959919839, 586.0047094188376, 589.4114228456913, 592.8181362725451, 596.2248496993988, 599.6315631262524, 603.0382765531061, 606.4449899799598, 609.8517034068136, 613.2584168336673, 616.665130260521, 620.0718436873747, 623.4785571142284, 626.8852705410821, 630.2919839679358, 633.6986973947895, 637.1054108216432, 640.5121242484969, 643.9188376753507, 647.3255511022044, 650.732264529058, 654.1389779559117, 657.5456913827654, 660.9524048096192, 664.3591182364729, 667.7658316633266, 671.1725450901803, 674.579258517034, 677.9859719438878, 681.3926853707414, 684.7993987975951, 688.2061122244488, 691.6128256513025, 695.0195390781563, 698.42625250501, 701.8329659318637, 705.2396793587174, 708.646392785571, 712.0531062124248, 715.4598196392785, 718.8665330661322, 722.2732464929859, 725.6799599198396, 729.0866733466934, 732.4933867735471, 735.9001002004007, 739.3068136272544, 742.7135270541081, 746.1202404809619, 749.5269539078156, 752.9336673346693, 756.340380761523, 759.7470941883766, 763.1538076152304, 766.5605210420841, 769.9672344689378, 773.3739478957915, 776.7806613226452, 780.187374749499, 783.5940881763527, 787.0008016032064, 790.40751503006, 793.8142284569137, 797.2209418837675, 800.6276553106212, 804.0343687374749, 807.4410821643286, 810.8477955911823, 814.2545090180361, 817.6612224448897, 821.0679358717434, 824.4746492985971, 827.8813627254508, 831.2880761523046, 834.6947895791583, 838.101503006012, 841.5082164328657, 844.9149298597193, 848.3216432865731, 851.7283567134268, 855.1350701402805, 858.5417835671342, 861.9484969939879, 865.3552104208417, 868.7619238476954, 872.168637274549, 875.5753507014027, 878.9820641282564, 882.3887775551102, 885.7954909819639, 889.2022044088176, 892.6089178356713, 896.015631262525, 899.4223446893787, 902.8290581162324, 906.2357715430861, 909.6424849699398, 913.0491983967935, 916.4559118236473, 919.862625250501, 923.2693386773547, 926.6760521042083, 930.082765531062, 933.4894789579158, 936.8961923847695, 940.3029058116232, 943.7096192384769, 947.1163326653306, 950.5230460921844, 953.929759519038, 957.3364729458917, 960.7431863727454, 964.1498997995991, 967.5566132264529, 970.9633266533066, 974.3700400801603, 977.776753507014, 981.1834669338676, 984.5901803607214, 987.9968937875751, 991.4036072144288, 994.8103206412825, 998.2170340681362, 1001.62374749499, 1005.0304609218437, 1008.4371743486973, 1011.843887775551, 1015.2506012024047, 1018.6573146292585, 1022.0640280561122, 1025.4707414829659, 1028.8774549098196, 1032.2841683366732, 1035.690881763527, 1039.0975951903806, 1042.5043086172343, 1045.9110220440882, 1049.317735470942, 1052.7244488977956, 1056.1311623246493, 1059.537875751503, 1062.9445891783566, 1066.3513026052103, 1069.758016032064, 1073.1647294589177, 1076.5714428857714, 1079.9781563126253, 1083.384869739479, 1086.7915831663327, 1090.1982965931863, 1093.60501002004, 1097.0117234468937, 1100.4184368737474, 1103.825150300601, 1107.2318637274548, 1110.6385771543085, 1114.0452905811624, 1117.452004008016, 1120.8587174348697, 1124.2654308617234, 1127.672144288577, 1131.0788577154308, 1134.4855711422845, 1137.8922845691382, 1141.2989979959918, 1144.7057114228455, 1148.1124248496994, 1151.5191382765531, 1154.9258517034068, 1158.3325651302605, 1161.7392785571142, 1165.1459919839679, 1168.5527054108215, 1171.9594188376752, 1175.366132264529, 1178.7728456913826, 1182.1795591182365, 1185.5862725450902, 1188.9929859719439, 1192.3996993987976, 1195.8064128256513, 1199.213126252505, 1202.6198396793586, 1206.0265531062123, 1209.433266533066, 1212.8399799599197, 1216.2466933867736, 1219.6534068136273, 1223.060120240481, 1226.4668336673346, 1229.8735470941883, 1233.280260521042, 1236.6869739478957, 1240.0936873747494, 1243.500400801603, 1246.9071142284567, 1250.3138276553107, 1253.7205410821643, 1257.127254509018, 1260.5339679358717, 1263.9406813627254, 1267.347394789579, 1270.7541082164328, 1274.1608216432865, 1277.5675350701401, 1280.9742484969938, 1284.3809619238477, 1287.7876753507014, 1291.194388777555, 1294.6011022044088, 1298.0078156312625, 1301.4145290581162, 1304.8212424849698, 1308.2279559118235, 1311.6346693386772, 1315.041382765531, 1318.4480961923848, 1321.8548096192385, 1325.2615230460922, 1328.6682364729459, 1332.0749498997995, 1335.4816633266532, 1338.888376753507, 1342.2950901803606, 1345.7018036072143, 1349.108517034068, 1352.5152304609219, 1355.9219438877756, 1359.3286573146293, 1362.735370741483, 1366.1420841683366, 1369.5487975951903, 1372.955511022044, 1376.3622244488977, 1379.7689378757514, 1383.175651302605, 1386.582364729459, 1389.9890781563126, 1393.3957915831663, 1396.80250501002, 1400.2092184368737, 1403.6159318637274, 1407.022645290581, 1410.4293587174348, 1413.8360721442884, 1417.2427855711421, 1420.649498997996, 1424.0562124248497, 1427.4629258517034, 1430.869639278557, 1434.2763527054108, 1437.6830661322645, 1441.0897795591181, 1444.4964929859718, 1447.9032064128255, 1451.3099198396792, 1454.716633266533, 1458.1233466933868, 1461.5300601202405, 1464.9367735470942, 1468.3434869739478, 1471.7502004008015, 1475.1569138276552, 1478.563627254509, 1481.9703406813626, 1485.3770541082163, 1488.7837675350702, 1492.1904809619239, 1495.5971943887776, 1499.0039078156312, 1502.410621242485, 1505.8173346693386, 1509.2240480961923, 1512.630761523046, 1516.0374749498997, 1519.4441883767533, 1522.8509018036073, 1526.257615230461, 1529.6643286573146, 1533.0710420841683, 1536.477755511022, 1539.8844689378757, 1543.2911823647294, 1546.697895791583, 1550.1046092184367, 1553.5113226452904, 1556.9180360721443, 1560.324749498998, 1563.7314629258517, 1567.1381763527054, 1570.544889779559, 1573.9516032064128, 1577.3583166332664, 1580.7650300601201, 1584.1717434869738, 1587.5784569138275, 1590.9851703406814, 1594.391883767535, 1597.7985971943888, 1601.2053106212425, 1604.6120240480961, 1608.0187374749498, 1611.4254509018035, 1614.8321643286572, 1618.2388777555109, 1621.6455911823646, 1625.0523046092185, 1628.4590180360722, 1631.8657314629259, 1635.2724448897795, 1638.6791583166332, 1642.085871743487, 1645.4925851703406, 1648.8992985971943, 1652.306012024048, 1655.7127254509016, 1659.1194388777556, 1662.5261523046092, 1665.932865731463, 1669.3395791583166, 1672.7462925851703, 1676.153006012024, 1679.5597194388777, 1682.9664328657313, 1686.373146292585, 1689.7798597194387, 1693.1865731462926, 1696.5932865731463, 1700.0], \"y\": [0.8486491322847558, 0.8410933877370947, 0.8335661894131259, 0.8260674294628705, 0.8185970004438161, 0.811154795319377, 0.8037407074573604, 0.7963546306284388, 0.7889964590046277, 0.7816660871577694, 0.7743634100580226, 0.7670883230723571, 0.7598407219630552, 0.7526205028862178, 0.7454275623902762, 0.7382617974145109, 0.7311231052875735, 0.7240113837260171, 0.7169265308328296, 0.7098684450959745, 0.7028370253869358, 0.6958321709592694, 0.6888537814471598, 0.6819017568639816, 0.6749759976008671, 0.6680764044252792, 0.6612028784795889, 0.6543553212796607, 0.6475336347134388, 0.640737721039544, 0.6339674828858712, 0.6272228232481956, 0.6205036454887822, 0.6138098533350012, 0.6071413508779491, 0.6004980425710733, 0.5938798332288049, 0.5872866280251932, 0.5807183324925482, 0.574174852520086, 0.5676560943525819, 0.5611619645890251, 0.5546923701812823, 0.5482472184327631, 0.5418264169970928, 0.5354298738767889, 0.5290574974219429, 0.522709196328907, 0.516384879638986, 0.5100844567371348, 0.5038078373506587, 0.49755493154792085, 0.4913256497370535, 0.4851199026646744, 0.47893760141460806, 0.4727786574066113, 0.4666429823951046, 0.46053048846790734, 0.4544410880449783, 0.44837469387716133, 0.4423312190449338, 0.43631057695716335, 0.430312681349865, 0.42433744628496717, 0.41838478614907815, 0.41245461565226194, 0.4065468498268141, 0.40066140402604544, 0.3947981939230689, 0.3889571355095911, 0.38313814509470934, 0.3773411393037118, 0.371566035076883, 0.36581274966831434, 0.36008120064471716, 0.3543713058842437, 0.3486829835753087, 0.3430161522154176, 0.3373707306099991, 0.33174663787124214, 0.3261437934169358, 0.3205621169693156, 0.31500152855391317, 0.30946194849841024, 0.30394329743149684, 0.29844549628173467, 0.2929684662764236, 0.2875121289404734, 0.28207640609527895, 0.27666121985760084, 0.2712664926384478, 0.2658921471419675, 0.26053810636433705, 0.2552042935926604, 0.24989063240386855, 0.24459704666362647, 0.23932346052523945, 0.2340697984285689, 0.2288359850989481, 0.22362194554610415, 0.218427605063084, 0.21325288922518348, 0.20809772388888037, 0.20296203519077394, 0.19784574954652445, 0.19274879364980047, 0.18767109447122765, 0.18261257925734253, 0.17757317552955065, 0.17255281108308695, 0.1675514139859824, 0.16256891257803274, 0.1576052354697719, 0.1526603115414491, 0.14773406994200955, 0.14282644008807988, 0.1379373516629565, 0.1330667346155976, 0.12821451915962068, 0.12338063577230152, 0.11856501519357865, 0.1137675884250604, 0.10898828672903726, 0.10422704162749596, 0.0994837849011394, 0.09475844858840765, 0.09005096498450582, 0.08536126664043331, 0.08068928636201722, 0.07603495720894982, 0.07139821249382883, 0.06677898578120334, 0.06217721088662054, 0.057592821875678046, 0.053025753063079106, 0.048475939011690894, 0.04394331453160838, 0.03942781467921841, 0.03492937475627089, 0.030447930308950655, 0.0259834171269544, 0.021535771242570778, 0.01710492892976312, 0.01269082670325794, 0.008293401317633453, 0.003912589766414509, 0.0004516707188297886, 0.004799442669386922, 0.009130788380295574, 0.013445769911238914, 0.017744449087433, 0.022026887500513626, 0.026293146509418497, 0.030543287241265427, 0.03477737059223007, 0.03899545722841613, 0.043197607586726416, 0.047383881875728395, 0.05155434007651616, 0.0557090419435704, 0.059848047005614635, 0.0639714145664676, 0.06807920370589393, 0.07217147328044948, 0.07624828192432576, 0.08030968805018879, 0.08435574985001715, 0.08838652529593571, 0.09240207214104501, 0.09640244792025054, 0.10038770995108526, 0.10435791533453287, 0.10831312095584367, 0.11225338348535185, 0.11617875937928601, 0.12008930488057801, 0.12398507601967013, 0.12786612861531665, 0.13173251827538368, 0.13558430039764713, 0.13942153017058434, 0.14324426257416722, 0.14705255238064785, 0.15084645415534514, 0.15462602225742528, 0.1583913108406807, 0.16214237385430708, 0.16587926504367523, 0.1696020379511014, 0.1733107459166151, 0.17700544207872215, 0.18068617937516707, 0.18435301054369135, 0.1880059881227888, 0.1916451644524585, 0.19527059167495464, 0.19888232173553377, 0.20248040638319909, 0.2060648971714416, 0.2096358454589794, 0.2131933024104924, 0.2167373189973567, 0.2202679459983743, 0.22378523400050065, 0.22728923339956952, 0.23077999440101493, 0.23425756702059097, 0.23772200108508768, 0.24117334623304587, 0.24461165191546763, 0.24803696739652492, 0.2514493417542659, 0.2548488238813176, 0.25823546248558693, 0.26160930609095845, 0.2649704030379887, 0.2683188014846005, 0.2716545494067716, 0.27497769459922305, 0.278288284676103, 0.2815863670716694, 0.2848719890409702, 0.2881451976605196, 0.2914060398289726, 0.29465456226779785, 0.29789081152194574, 0.3011148339605165, 0.3043266757774241, 0.3075263829920577, 0.310714001449942, 0.3138895768233929, 0.317053154612173, 0.320204780144143, 0.32334449857591097, 0.32647235489348003, 0.3295883939128921, 0.3326926602808704, 0.3357851984754595, 0.33886605280666204, 0.3419352674170738, 0.34499288628251634, 0.34803895321266676, 0.3510735118516858, 0.35409660567884294, 0.35710827800913925, 0.3601085719939283, 0.3630975306215344, 0.36607519671786803, 0.3690416129470405, 0.37199682181197413, 0.3749408656550116, 0.37787378665852334, 0.3807956268455105, 0.38370642808020883, 0.38660623206868683, 0.389495080359444, 0.39237301434400695, 0.3952400752575208, 0.3980963041793416, 0.400941742033624, 0.40377642958990734, 0.4066004074637011, 0.40941371611706556, 0.412216395859192, 0.41500848684698055, 0.4177900290856149, 0.42056106242913616, 0.4233216265810136, 0.4260717610947131, 0.42881150537426493, 0.43154089867482714, 0.43425998010324895, 0.4369687886186303, 0.4396673630328811, 0.44235574201127625, 0.44503396407300955, 0.44770206759174713, 0.45036009079617567, 0.4530080717705509, 0.4556460484552429, 0.4582740586472801, 0.46089214000089074, 0.46350033002804203, 0.4660986660989779, 0.468687185442755, 0.47126592514777466, 0.4738349221623156, 0.47639421329506326, 0.4789438352156362, 0.48148382445511273, 0.48401421740655326, 0.48653505032552247, 0.48904635933060847, 0.49154818040394044, 0.49404054939170416, 0.49652350200465545, 0.4989970738186319, 0.5014613002750631, 0.5039162166814773, 0.5063618582120086, 0.5087982599079002, 0.5112254566780063, 0.513643483299293, 0.5160523744173359, 0.5184521645468166, 0.5208428880720182, 0.5232245792473161, 0.5255972721976707, 0.5279610009191149, 0.530315799279242, 0.5326617010176907, 0.5349987397466291, 0.537326948951235, 0.5396463619901769, 0.5419570120960913, 0.544258932376059, 0.5465521558120802, 0.5488367152615454, 0.5511126434577078, 0.5533799730101515, 0.5556387364052591, 0.5578889660066764, 0.5601306940557776, 0.5623639526721257, 0.5645887738539334, 0.5668051894785218, 0.5690132313027763, 0.5712129309636031, 0.5734043199783807, 0.5755874297454128, 0.5777622915443775, 0.5799289365367759, 0.5820873957663784, 0.5842377001596692, 0.5863798805262901, 0.5885139675594813, 0.5906399918365213, 0.5927579838191656, 0.594867973854082, 0.5969699921732866, 0.5990640688945764, 0.6011502340219609, 0.6032285174460915, 0.6052989489446912, 0.6073615581829794, 0.6094163747140985, 0.6114634279795362, 0.6135027473095483, 0.6155343619235781, 0.6175583009306758, 0.6195745933299148, 0.621583268010808, 0.6235843537537211, 0.6255778792302853, 0.6275638730038082, 0.6295423635296826, 0.6315133791557946, 0.6334769481229298, 0.6354330985651772, 0.6373818585103337, 0.6393232558803045, 0.6412573184915035, 0.643184074055252, 0.6451035501781754, 0.6470157743625997, 0.6489207740069441, 0.6508185764061146, 0.6527092087518951, 0.6545926981333359, 0.6564690715371432, 0.6583383558480655, 0.6602005778492781, 0.6620557642227671, 0.6639039415497123, 0.6657451363108674, 0.6675793748869396, 0.6694066835589678, 0.6712270885086987, 0.6730406158189624, 0.6748472914740458, 0.6766471413600652, 0.678440191265337, 0.6802264668807471, 0.6820059938001191, 0.6837787975205812, 0.6855449034429313, 0.6873043368720009, 0.6890571230170179, 0.6908032869919677, 0.6925428538159526, 0.6942758484135512, 0.6960022956151746, 0.697722220157423, 0.6994356466834393, 0.7011425997432625, 0.7028431037941802, 0.7045371832010774, 0.7062248622367876, 0.7079061650824385, 0.7095811158278005, 0.7112497384716299, 0.7129120569220144, 0.7145680949967149, 0.7162178764235068, 0.7178614248405197, 0.719498763796577, 0.7211299167515319, 0.7227549070766053, 0.7243737580547189, 0.7259864928808302, 0.7275931346622636, 0.7291937064190428, 0.7307882310842195, 0.7323767315042029, 0.7339592304390858, 0.7355357505629726, 0.7371063144643021, 0.7386709446461726, 0.7402296635266635, 0.7417824934391575, 0.7433294566326591, 0.7448705752721152, 0.7464058714387307, 0.7479353671302865, 0.7494590842614541, 0.7509770446641094, 0.7524892700876457, 0.7539957821992851, 0.7554966025843894, 0.7569917527467694, 0.7584812541089923, 0.7599651280126889, 0.7614433957188601, 0.7629160784081808, 0.7643831971813035, 0.7658447730591608, 0.7673008269832663, 0.768751379816015, 0.7701964523409821, 0.7716360652632206, 0.7730702392095582, 0.7744989947288927, 0.7759223522924865, 0.77734033229426, 0.7787529550510833, 0.7801602408030683, 0.7815622097138577, 0.7829588818709146, 0.7843502772858091, 0.7857364158945073, 0.7871173175576545, 0.7884930020608615, 0.7898634891149872, 0.7912287983564211, 0.7925889493473652, 0.7939439615761134, 0.7952938544573316, 0.7966386473323357, 0.7979783594693677, 0.7993130100638732, 0.8006426182387758, 0.8019672030447512, 0.8032867834604998, 0.804601378393019, 0.8059110066778743, 0.8072156870794682, 0.8085154382913105, 0.8098102789362851, 0.811100227566917, 0.8123853026656384, 0.813665522645053, 0.8149409058482007, 0.8162114705488195, 0.817477234951608, 0.8187382171924857, 0.8199944353388533, 0.821245907389851, 0.8224926512766176, 0.8237346848625455, 0.8249720259435386, 0.8262046922482659, 0.8274327014384162, 0.8286560711089511, 0.829874818788357, 0.8310889619388959, 0.8322985179568565, 0.8335035041728022, 0.8347039378518206, 0.8358998361937704, 0.8370912163335276, 0.8382780953412312, 0.839460490222528, 0.8406384179188159, 0.841811895307487, 0.8429809392021692, 0.8441455663529669, 0.8453057934467014, 0.8464616371071498, 0.8476131138952834, 0.8487602403095043], \"type\": \"scatter\", \"uid\": \"1de55532-93d9-403d-92ed-d6b76dfa0159\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 3.657114228456914, 7.264228456913828, 10.871342685370742, 14.478456913827657, 18.08557114228457, 21.692685370741483, 25.299799599198398, 28.906913827655313, 32.514028056112224, 36.12114228456914, 39.728256513026054, 43.33537074148296, 46.942484969939876, 50.54959919839679, 54.156713426853706, 57.76382765531062, 61.370941883767536, 64.97805611222445, 68.58517034068136, 72.19228456913828, 75.79939879759519, 79.40651302605211, 83.01362725450902, 86.62074148296593, 90.22785571142285, 93.83496993987976, 97.44208416833668, 101.04919839679359, 104.65631262525051, 108.26342685370741, 111.87054108216434, 115.47765531062124, 119.08476953907815, 122.69188376753507, 126.29899799599198, 129.90611222444892, 133.51322645290583, 137.12034068136273, 140.72745490981967, 144.33456913827658, 147.94168336673349, 151.5487975951904, 155.1559118236473, 158.76302605210424, 162.37014028056115, 165.97725450901805, 169.58436873747496, 173.19148296593187, 176.7985971943888, 180.4057114228457, 184.01282565130262, 187.61993987975953, 191.22705410821646, 194.83416833667337, 198.44128256513028, 202.0483967935872, 205.6555110220441, 209.26262525050103, 212.86973947895794, 216.47685370741485, 220.08396793587175, 223.6910821643287, 227.2981963927856, 230.9053106212425, 234.5124248496994, 238.11953907815632, 241.72665330661326, 245.33376753507017, 248.94088176352707, 252.54799599198398, 256.1551102204409, 259.7622244488978, 263.36933867735473, 266.97645290581164, 270.58356713426855, 274.19068136272546, 277.79779559118236, 281.40490981963933, 285.01202404809624, 288.61913827655314, 292.22625250501005, 295.83336673346696, 299.44048096192387, 303.0475951903808, 306.6547094188377, 310.2618236472946, 313.86893787575156, 317.47605210420846, 321.08316633266537, 324.6902805611223, 328.2973947895792, 331.9045090180361, 335.511623246493, 339.1187374749499, 342.7258517034068, 346.3329659318637, 349.9400801603207, 353.5471943887776, 357.1543086172345, 360.7614228456914, 364.3685370741483, 367.97565130260523, 371.58276553106214, 375.18987975951904, 378.79699398797595, 382.4041082164329, 386.0112224448898, 389.61833667334673, 393.22545090180364, 396.83256513026055, 400.43967935871746, 404.04679358717436, 407.65390781563127, 411.2610220440882, 414.86813627254514, 418.47525050100205, 422.08236472945896, 425.68947895791587, 429.2965931863728, 432.9037074148297, 436.5108216432866, 440.1179358717435, 443.7250501002004, 447.33216432865737, 450.9392785571143, 454.5463927855712, 458.1535070140281, 461.760621242485, 465.3677354709419, 468.9748496993988, 472.5819639278557, 476.18907815631263, 479.7961923847696, 483.4033066132265, 487.0104208416834, 490.6175350701403, 494.2246492985972, 497.83176352705414, 501.43887775551104, 505.04599198396795, 508.65310621242486, 512.2602204408818, 515.8673346693387, 519.4744488977956, 523.0815631262525, 526.6886773547094, 530.2957915831663, 533.9029058116232, 537.5100200400801, 541.117134268537, 544.7242484969939, 548.3313627254508, 551.9384769539078, 555.5455911823647, 559.1527054108216, 562.7598196392786, 566.3669338677355, 569.9740480961924, 573.5811623246493, 577.1882765531062, 580.7953907815631, 584.40250501002, 588.009619238477, 591.6167334669339, 595.2238476953908, 598.8309619238477, 602.4380761523046, 606.0451903807615, 609.6523046092184, 613.2594188376753, 616.8665330661322, 620.4736472945891, 624.080761523046, 627.687875751503, 631.29498997996, 634.9021042084169, 638.5092184368738, 642.1163326653307, 645.7234468937876, 649.3305611222445, 652.9376753507014, 656.5447895791583, 660.1519038076152, 663.7590180360721, 667.366132264529, 670.9732464929859, 674.5803607214428, 678.1874749498998, 681.7945891783567, 685.4017034068136, 689.0088176352705, 692.6159318637274, 696.2230460921844, 699.8301603206413, 703.4372745490982, 707.0443887775551, 710.651503006012, 714.2586172344689, 717.8657314629259, 721.4728456913828, 725.0799599198397, 728.6870741482966, 732.2941883767535, 735.9013026052104, 739.5084168336673, 743.1155310621242, 746.7226452905811, 750.329759519038, 753.9368737474949, 757.5439879759518, 761.1511022044089, 764.7582164328658, 768.3653306613227, 771.9724448897796, 775.5795591182365, 779.1866733466934, 782.7937875751503, 786.4009018036072, 790.0080160320641, 793.615130260521, 797.2222444889779, 800.8293587174348, 804.4364729458918, 808.0435871743487, 811.6507014028056, 815.2578156312625, 818.8649298597194, 822.4720440881763, 826.0791583166333, 829.6862725450902, 833.2933867735471, 836.900501002004, 840.5076152304609, 844.1147294589179, 847.7218436873748, 851.3289579158317, 854.9360721442886, 858.5431863727455, 862.1503006012024, 865.7574148296593, 869.3645290581162, 872.9716432865731, 876.57875751503, 880.1858717434869, 883.7929859719438, 887.4001002004007, 891.0072144288578, 894.6143286573147, 898.2214428857716, 901.8285571142285, 905.4356713426854, 909.0427855711423, 912.6498997995992, 916.2570140280561, 919.864128256513, 923.4712424849699, 927.0783567134268, 930.6854709418838, 934.2925851703407, 937.8996993987976, 941.5068136272545, 945.1139278557114, 948.7210420841683, 952.3281563126252, 955.9352705410821, 959.5423847695391, 963.149498997996, 966.7566132264529, 970.3637274549098, 973.9708416833668, 977.5779559118237, 981.1850701402806, 984.7921843687375, 988.3992985971944, 992.0064128256513, 995.6135270541082, 999.2206412825651, 1002.827755511022, 1006.4348697394789, 1010.0419839679358, 1013.6490981963927, 1017.2562124248497, 1020.8633266533066, 1024.4704408817636, 1028.0775551102204, 1031.6846693386774, 1035.2917835671342, 1038.8988977955912, 1042.506012024048, 1046.113126252505, 1049.7202404809618, 1053.3273547094188, 1056.9344689378759, 1060.5415831663327, 1064.1486973947897, 1067.7558116232465, 1071.3629258517035, 1074.9700400801603, 1078.5771543086173, 1082.184268537074, 1085.7913827655311, 1089.398496993988, 1093.005611222445, 1096.6127254509017, 1100.2198396793588, 1103.8269539078156, 1107.4340681362726, 1111.0411823647294, 1114.6482965931864, 1118.2554108216432, 1121.8625250501002, 1125.4696392785572, 1129.076753507014, 1132.683867735471, 1136.2909819639278, 1139.8980961923849, 1143.5052104208416, 1147.1123246492987, 1150.7194388777555, 1154.3265531062125, 1157.9336673346693, 1161.5407815631263, 1165.147895791583, 1168.7550100200401, 1172.362124248497, 1175.969238476954, 1179.5763527054107, 1183.1834669338677, 1186.7905811623245, 1190.3976953907816, 1194.0048096192386, 1197.6119238476954, 1201.2190380761524, 1204.8261523046092, 1208.4332665330662, 1212.040380761523, 1215.64749498998, 1219.2546092184368, 1222.8617234468938, 1226.4688376753506, 1230.0759519038077, 1233.6830661322645, 1237.2901803607215, 1240.8972945891783, 1244.5044088176353, 1248.111523046092, 1251.718637274549, 1255.3257515030061, 1258.932865731463, 1262.53997995992, 1266.1470941883767, 1269.7542084168338, 1273.3613226452906, 1276.9684368737476, 1280.5755511022044, 1284.1826653306614, 1287.7897795591182, 1291.3968937875752, 1295.004008016032, 1298.611122244489, 1302.2182364729458, 1305.8253507014028, 1309.4324649298596, 1313.0395791583167, 1316.6466933867734, 1320.2538076152305, 1323.8609218436875, 1327.4680360721443, 1331.0751503006013, 1334.682264529058, 1338.2893787575151, 1341.896492985972, 1345.503607214429, 1349.1107214428857, 1352.7178356713428, 1356.3249498997995, 1359.9320641282566, 1363.5391783567134, 1367.1462925851704, 1370.7534068136272, 1374.3605210420842, 1377.967635270541, 1381.574749498998, 1385.1818637274548, 1388.7889779559118, 1392.3960921843689, 1396.0032064128256, 1399.6103206412827, 1403.2174348697395, 1406.8245490981965, 1410.4316633266533, 1414.0387775551103, 1417.645891783567, 1421.2530060120241, 1424.860120240481, 1428.467234468938, 1432.0743486973947, 1435.6814629258517, 1439.2885771543085, 1442.8956913827656, 1446.5028056112224, 1450.1099198396794, 1453.7170340681364, 1457.3241482965932, 1460.9312625250502, 1464.538376753507, 1468.145490981964, 1471.7526052104208, 1475.3597194388778, 1478.9668336673346, 1482.5739478957917, 1486.1810621242485, 1489.7881763527055, 1493.3952905811623, 1497.0024048096193, 1500.609519038076, 1504.216633266533, 1507.82374749499, 1511.430861723447, 1515.0379759519037, 1518.6450901803607, 1522.2522044088178, 1525.8593186372746, 1529.4664328657316, 1533.0735470941884, 1536.6806613226454, 1540.2877755511022, 1543.8948897795592, 1547.502004008016, 1551.109118236473, 1554.7162324649298, 1558.3233466933868, 1561.9304609218436, 1565.5375751503007, 1569.1446893787574, 1572.7518036072145, 1576.3589178356713, 1579.9660320641283, 1583.5731462925853, 1587.180260521042, 1590.7873747494991, 1594.394488977956, 1598.001603206413, 1601.6087174348697, 1605.2158316633268, 1608.8229458917835, 1612.4300601202406, 1616.0371743486974, 1619.6442885771544, 1623.2514028056112, 1626.8585170340682, 1630.465631262525, 1634.072745490982, 1637.6798597194388, 1641.2869739478958, 1644.8940881763526, 1648.5012024048096, 1652.1083166332667, 1655.7154308617235, 1659.3225450901805, 1662.9296593186373, 1666.5367735470943, 1670.143887775551, 1673.7510020040081, 1677.358116232465, 1680.965230460922, 1684.5723446893787, 1688.1794589178357, 1691.7865731462925, 1695.3936873747496, 1699.0008016032064, 1702.6079158316634, 1706.2150300601202, 1709.8221442885772, 1713.429258517034, 1717.036372745491, 1720.643486973948, 1724.2506012024048, 1727.8577154308618, 1731.4648296593186, 1735.0719438877757, 1738.6790581162325, 1742.2861723446895, 1745.8932865731463, 1749.5004008016033, 1753.10751503006, 1756.714629258517, 1760.321743486974, 1763.928857715431, 1767.5359719438877, 1771.1430861723447, 1774.7502004008015, 1778.3573146292586, 1781.9644288577156, 1785.5715430861724, 1789.1786573146294, 1792.7857715430862, 1796.3928857715432, 1800.0], \"y\": [0.8645536087386387, 0.8565542856227495, 0.8485869588695429, 0.8406515004972872, 0.8327477830361625, 0.824875679526214, 0.817035063515311, 0.8092258090571176, 0.8014477907090682, 0.7937008835303527, 0.7859849630799101, 0.7782999054144286, 0.770645587086356, 0.7630218851419153, 0.7554286771191308, 0.7478658410458601, 0.7403332554378355, 0.7328307992967118, 0.7253583521081239, 0.7179157938397493, 0.7105030049393815, 0.703119866333008, 0.6957662594228999, 0.6884420660857045, 0.6811471686705488, 0.6738814499971497, 0.6666447933539319, 0.6594370824961526, 0.6522582016440344, 0.6451080354809056, 0.6379864691513479, 0.6308933882593513, 0.6238286788664764, 0.6167922274900244, 0.6097839211012139, 0.6028036471233662, 0.5958512934300955, 0.5889267483435086, 0.5820299006324112, 0.5751606395105204, 0.5683188546346862, 0.5615044361031176, 0.5547172744536188, 0.5479572606618297, 0.5412242861394743, 0.5345182427326183, 0.5278390227199299, 0.5211865188109499, 0.514560624144369, 0.5079612322863101, 0.50138823722862, 0.4948415333871654, 0.48832101560013697, 0.48182657912636095, 0.47535811964361563, 0.4689155332469561, 0.46249871644704577, 0.4561075661684926, 0.4497419797481945, 0.4434018549336898, 0.4370870898815147, 0.4307975831555677, 0.4245332337254797, 0.4182939409649913, 0.41207960465033633, 0.4058901249586324, 0.39972540246627686, 0.39358533814734975, 0.3874698333720237, 0.38137878990497875, 0.375312109903825, 0.36926969591753056, 0.3632514508848568, 0.3572572781327983, 0.3512870813750306, 0.345340764710363, 0.3394182326211994, 0.3335193899720017, 0.3276441420077638, 0.3217923943524885, 0.3159640530076713, 0.31015902435079057, 0.3043772151338049, 0.29861853248165304, 0.292882883890764, 0.2871701772275699, 0.28148032072702667, 0.2758132229911394, 0.2701687929874952, 0.26454694004779955, 0.25894757386642064, 0.25337060449893944, 0.24781594236070315, 0.24228349822538764, 0.236773183223564, 0.23128490884127006, 0.22581858691858958, 0.22037412964823555, 0.2149514495741407, 0.20955045959005036, 0.2041710729381263, 0.19881320320755047, 0.19347676433313876, 0.18816167059395705, 0.1828678366119456, 0.17759517735054686, 0.1723436081133396, 0.16711304454267828, 0.16190340261833835, 0.15671459865616622, 0.1515465493067354, 0.14639917155400717, 0.14127238271399745, 0.13616610043344846, 0.13108024268850604, 0.1260147277834014, 0.12096947434913985, 0.1159444013421933, 0.1109394280431979, 0.10595447405565817, 0.10098945930465497, 0.09604430403555986, 0.09111892881275385, 0.08621325451835027, 0.08132720235092572, 0.07646069382425313, 0.07161365076604076, 0.06678599531667762, 0.061977649927981826, 0.05718853736195473, 0.052418580689541416, 0.04766770328939418, 0.042935828846641044, 0.03822288135166163, 0.03352878509886459, 0.02885346468547234, 0.02419684501030983, 0.01955885127259749, 0.014939408970750412, 0.01033844390118177, 0.00575588215710976, 0.0011916501273718794, 0.0033543255047592258, 0.007882117762751717, 0.012391799377988733, 0.01688344279093612, 0.02135712015230662, 0.025812903324217817, 0.030250863881348344, 0.03467107311208539, 0.03907360201967136, 0.0434585213233436, 0.0478259014594713, 0.052175812582685666, 0.05650832456700816, 0.06082350700697181, 0.06512142921874009, 0.06940216024121937, 0.07366576883716847, 0.07791232349430355, 0.08214189242639769, 0.08635454357437644, 0.0905503446074103, 0.09472936292400025, 0.0988916656530614, 0.10303731965500096, 0.1071663915227925, 0.11127894758304491, 0.11537505389706904, 0.11945477626193735, 0.1235181802115426, 0.12756533101764855, 0.13159629369094072, 0.1356111329820684, 0.13960991338268613, 0.14359269912648953, 0.1475595541902467, 0.15151054229482608, 0.15544572690622038, 0.15936517123656524, 0.16326893824515532, 0.1671570906394555, 0.1710296908761081, 0.1748868011619359, 0.17872848345494186, 0.18255479946530395, 0.1863658106563667, 0.1901615782456284, 0.19394216320572455, 0.19770762626540694, 0.2014580279105197, 0.20519342838497046, 0.20891388769169816, 0.2126194655936372, 0.21631022161467695, 0.219986215040618, 0.2236475049201252, 0.227294150065675, 0.23092620905450123, 0.2345437402295354, 0.23814680170034375, 0.24173545134406182, 0.24530974680632256, 0.24886974550218322, 0.2524155046170481, 0.2559470811075858, 0.25946453170264505, 0.2629679129041661, 0.26645728098808774, 0.2699326920052514, 0.2733942017823021, 0.2768418659225844, 0.280275739807036, 0.2836958785950775, 0.28710233722549794, 0.29049517041733774, 0.2938744326707676, 0.2972401782679638, 0.30059246127397987, 0.3039313355376162, 0.3072568546922835, 0.31056907215686536, 0.3138680411365762, 0.3171538146238154, 0.3204264453990191, 0.3236859860315081, 0.32693248888033155, 0.3301660060951086, 0.3333865896168663, 0.3365942911788734, 0.33978916230747147, 0.3429712543229029, 0.346140618340135, 0.34929730526968106, 0.35244136581841845, 0.3555728504904029, 0.35869180958767943, 0.36179829321109125, 0.36489235126108377, 0.3679740334385061, 0.37104338924541036, 0.37410046798584584, 0.37714531876665125, 0.3801779904982441, 0.3831985318954053, 0.3862069914780629, 0.38920341757207055, 0.39218785830998426, 0.3951603616318351, 0.39812097528589996, 0.40106974682946794, 0.40400672362960466, 0.4069319528639127, 0.4098454815212903, 0.412747356402685, 0.4156376241218461, 0.41851633110607356, 0.4213835235969634, 0.4242392476511503, 0.4270835491410484, 0.42991647375558706, 0.4327380670009454, 0.4355483742012831, 0.4383474404994684, 0.4411353108578031, 0.4439120300587457, 0.4466776427056295, 0.44943219322337946, 0.45217572585922683, 0.4549082846834184, 0.4576299135899251, 0.4603406562971475, 0.4630405563486173, 0.46572965711369707, 0.4684080017882776, 0.4710756333954702, 0.4737325947862996, 0.4763789286403908, 0.4790146774666554, 0.4816398836039746, 0.4842545892218787, 0.48685883632122495, 0.48945266673487176, 0.49203612212835135, 0.4946092440005384, 0.4971720736843168, 0.4997246523472445, 0.5022670209922127, 0.5047992204581068, 0.5073212914204611, 0.5098332743921127, 0.5123352097238514, 0.5148271376050695, 0.5173090980644055, 0.5197811309703885, 0.5222432760320782, 0.5246955727997021, 0.5271380606652921, 0.5295707788633162, 0.5319937664713089, 0.5344070624104995, 0.5368107054464368, 0.5392047341896115, 0.5415891870960774, 0.5439641024680684, 0.5463295184546136, 0.5486854730521507, 0.5510320041051362, 0.5533691493066527, 0.5556969461990153, 0.5580154321743741, 0.5603246444753148, 0.5626246201954571, 0.5649153962800507, 0.5671970095265685, 0.5694694965852977, 0.5717328939599289, 0.5739872380081416, 0.5762325649421894, 0.5784689108294812, 0.5806963115931596, 0.5829148030126795, 0.5851244207243822, 0.5873252002220672, 0.5895171768575637, 0.5917003858412968, 0.5938748622428551, 0.5960406409915516, 0.5981977568769874, 0.600346244549608, 0.6024861385212623, 0.6046174731657553, 0.6067402827194004, 0.6088546012815703, 0.610960462815244, 0.6130579011475525, 0.6151469499703222, 0.6172276428406162, 0.6193000131812729, 0.6213640942814438, 0.623419919297127, 0.6254675212517015, 0.6275069330364552, 0.6295381874111158, 0.6315613170043756, 0.6335763543144155, 0.635583331709428, 0.6375822814281367, 0.6395732355803131, 0.6415562261472942, 0.6435312849824957, 0.645498443811922, 0.6474577342346783, 0.6494091877234769, 0.6513528356251425, 0.6532887091611163, 0.6552168394279577, 0.6571372573978429, 0.6590499939190636, 0.6609550797165216, 0.6628525453922223, 0.6647424214257673, 0.6666247381748435, 0.6684995258757094, 0.670366814643683, 0.6722266344736243, 0.6740790152404174, 0.67592398669945, 0.6777615784870921, 0.6795918201211715, 0.6814147410014478, 0.6832303704100859, 0.6850387375121243, 0.6868398713559456, 0.6886338008737418, 0.6904205548819797, 0.6922001620818635, 0.693972651059796, 0.6957380502878373, 0.6974963881241633, 0.6992476928135198, 0.7009919924876774, 0.7027293151658826, 0.7044596887553083, 0.7061831410515018, 0.7078996997388318, 0.7096093923909323, 0.7113122464711461, 0.7130082893329659, 0.7146975482204738, 0.7163800502687783, 0.7180558225044509, 0.7197248918459601, 0.7213872851041032, 0.7230430289824378, 0.7246921500777103, 0.726334674880283, 0.7279706297745602, 0.7296000410394115, 0.7312229348485936, 0.732839337271172, 0.7344492742719386, 0.736052771711829, 0.7376498553483384, 0.7392405508359348, 0.740824883726471, 0.742402879469596, 0.7439745634131631, 0.7455399608036364, 0.7470990967864979, 0.74865199640665, 0.7501986846088191, 0.7517391862379548, 0.7532735260396302, 0.7548017286604389, 0.7563238186483914, 0.7578398204533081, 0.759349758427214, 0.7608536568247277, 0.7623515398034536, 0.763843431424367, 0.765329355652203, 0.7668093363558404, 0.7682833973086849, 0.7697515621890518, 0.7712138545805457, 0.7726702979724394, 0.7741209157600515, 0.7755657312451223, 0.7770047676361869, 0.7784380480489501, 0.7798655955066561, 0.7812874329404587, 0.7827035831897895, 0.7841140690027257, 0.7855189130363545, 0.786918137857137, 0.788311765941272, 0.7896998196750552, 0.7910823213552401, 0.7924592931893959, 0.793830757296264, 0.7951967357061132, 0.796557250361094, 0.7979123231155908, 0.7992619757365731, 0.8006062299039449, 0.8019451072108933, 0.8032786291642348, 0.8046068171847616, 0.8059296926075847, 0.8072472766824776, 0.808559590574217, 0.809866655362923, 0.8111684920443973, 0.8124651215304617, 0.8137565646492921, 0.8150428421457548, 0.816323974681739, 0.8175999828364884, 0.8188708871069322, 0.8201367079080146, 0.8213974655730223, 0.8226531803539108, 0.8239038724216305, 0.8251495618664506, 0.8263902686982808, 0.8276260128469941, 0.8288568141627461, 0.8300826924162943, 0.831303667299315, 0.8325197584247206, 0.8337309853269739, 0.834937367462402, 0.8361389242095092, 0.8373356748692878, 0.8385276386655287, 0.8397148347451294, 0.8408972821784024, 0.8420749999593812, 0.843248007006125, 0.8444163221610235, 0.8455799641910984, 0.846738951788306, 0.8478933035698368, 0.8490430380784146, 0.8501881737825945, 0.8513287290770597, 0.8524647222829166, 0.8535961716479894, 0.854723095347113, 0.8558455114824252, 0.8569634380836573, 0.8580768931084239, 0.859185894442511, 0.8602904599001638, 0.8613906072243723, 0.8624863540871568, 0.8635777180898516, 0.8646647167633874], \"type\": \"scatter\", \"uid\": \"62830f94-8aa7-406b-96ab-435357620f39\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 3.85751503006012, 7.66503006012024, 11.472545090180361, 15.280060120240481, 19.0875751503006, 22.89509018036072, 26.702605210420842, 30.510120240480962, 34.317635270541075, 38.1251503006012, 41.93266533066132, 45.74018036072144, 49.547695390781556, 53.35521042084168, 57.1627254509018, 60.97024048096192, 64.77775551102204, 68.58527054108215, 72.39278557114228, 76.2003006012024, 80.00781563126252, 83.81533066132265, 87.62284569138276, 91.43036072144288, 95.237875751503, 99.04539078156311, 102.85290581162324, 106.66042084168336, 110.46793587174348, 114.27545090180361, 118.08296593186373, 121.89048096192384, 125.69799599198396, 129.5055110220441, 133.31302605210422, 137.12054108216432, 140.92805611222445, 144.73557114228458, 148.5430861723447, 152.35060120240482, 156.15811623246495, 159.96563126252505, 163.77314629258518, 167.5806613226453, 171.38817635270541, 175.19569138276555, 179.00320641282565, 182.81072144288578, 186.6182364729459, 190.425751503006, 194.23326653306614, 198.04078156312625, 201.84829659318638, 205.6558116232465, 209.4633266533066, 213.27084168336674, 217.07835671342687, 220.88587174348697, 224.6933867735471, 228.50090180360723, 232.30841683366734, 236.11593186372747, 239.92344689378757, 243.7309619238477, 247.53847695390783, 251.34599198396793, 255.15350701402807, 258.96102204408817, 262.7685370741483, 266.57605210420843, 270.38356713426856, 274.19108216432863, 277.99859719438876, 281.8061122244489, 285.613627254509, 289.42114228456916, 293.2286573146293, 297.03617234468936, 300.8436873747495, 304.6512024048096, 308.45871743486975, 312.2662324649299, 316.07374749498996, 319.8812625250501, 323.6887775551102, 327.49629258517035, 331.3038076152305, 335.1113226452906, 338.9188376753507, 342.7263527054108, 346.53386773547095, 350.3413827655311, 354.1488977955912, 357.9564128256513, 361.7639278557114, 365.57144288577155, 369.3789579158317, 373.1864729458918, 376.9939879759519, 380.801503006012, 384.60901803607214, 388.4165330661323, 392.2240480961924, 396.0315631262525, 399.8390781563126, 403.64659318637274, 407.45410821643287, 411.261623246493, 415.06913827655313, 418.8766533066132, 422.68416833667334, 426.49168336673347, 430.2991983967936, 434.10671342685373, 437.9142284569138, 441.72174348697393, 445.52925851703407, 449.3367735470942, 453.1442885771543, 456.95180360721446, 460.75931863727453, 464.56683366733466, 468.3743486973948, 472.1818637274549, 475.98937875751506, 479.79689378757513, 483.60440881763526, 487.4119238476954, 491.2194388777555, 495.02695390781565, 498.8344689378757, 502.64198396793586, 506.449498997996, 510.2570140280561, 514.0645290581161, 517.8720440881763, 521.6795591182364, 525.4870741482965, 529.2945891783567, 533.1021042084168, 536.9096192384769, 540.717134268537, 544.5246492985972, 548.3321643286572, 552.1396793587173, 555.9471943887775, 559.7547094188376, 563.5622244488977, 567.3697394789579, 571.177254509018, 574.9847695390781, 578.7922845691382, 582.5997995991984, 586.4073146292585, 590.2148296593185, 594.0223446893787, 597.8298597194388, 601.6373747494989, 605.444889779559, 609.2524048096192, 613.0599198396793, 616.8674348697394, 620.6749498997996, 624.4824649298597, 628.2899799599198, 632.0974949899799, 635.90501002004, 639.7125250501001, 643.5200400801602, 647.3275551102204, 651.1350701402805, 654.9425851703406, 658.7501002004008, 662.5576152304609, 666.365130260521, 670.1726452905812, 673.9801603206412, 677.7876753507013, 681.5951903807614, 685.4027054108216, 689.2102204408817, 693.0177354709418, 696.825250501002, 700.6327655310621, 704.4402805611222, 708.2477955911824, 712.0553106212424, 715.8628256513025, 719.6703406813626, 723.4778557114228, 727.2853707414829, 731.092885771543, 734.9004008016032, 738.7079158316633, 742.5154308617234, 746.3229458917835, 750.1304609218437, 753.9379759519037, 757.7454909819638, 761.553006012024, 765.3605210420841, 769.1680360721442, 772.9755511022043, 776.7830661322645, 780.5905811623246, 784.3980961923847, 788.2056112224449, 792.0131262525049, 795.820641282565, 799.6281563126252, 803.4356713426853, 807.2431863727454, 811.0507014028055, 814.8582164328657, 818.6657314629258, 822.4732464929859, 826.2807615230461, 830.0882765531062, 833.8957915831662, 837.7033066132263, 841.5108216432865, 845.3183366733466, 849.1258517034067, 852.9333667334669, 856.740881763527, 860.5483967935871, 864.3559118236473, 868.1634268537074, 871.9709418837675, 875.7784569138275, 879.5859719438877, 883.3934869739478, 887.2010020040079, 891.0085170340681, 894.8160320641282, 898.6235470941883, 902.4310621242485, 906.2385771543086, 910.0460921843687, 913.8536072144288, 917.6611222444889, 921.468637274549, 925.2761523046091, 929.0836673346693, 932.8911823647294, 936.6986973947895, 940.5062124248497, 944.3137274549098, 948.1212424849699, 951.92875751503, 955.7362725450901, 959.5437875751502, 963.3513026052103, 967.1588176352705, 970.9663326653306, 974.7738476953907, 978.5813627254508, 982.388877755511, 986.1963927855711, 990.0039078156312, 993.8114228456914, 997.6189378757514, 1001.4264529058115, 1005.2339679358716, 1009.0414829659318, 1012.8489979959919, 1016.656513026052, 1020.4640280561122, 1024.2715430861722, 1028.0790581162323, 1031.8865731462924, 1035.6940881763526, 1039.5016032064127, 1043.3091182364728, 1047.116633266533, 1050.924148296593, 1054.7316633266532, 1058.5391783567134, 1062.3466933867735, 1066.1542084168336, 1069.9617234468938, 1073.769238476954, 1077.576753507014, 1081.3842685370741, 1085.1917835671343, 1088.9992985971944, 1092.8068136272545, 1096.6143286573144, 1100.4218436873746, 1104.2293587174347, 1108.0368737474948, 1111.844388777555, 1115.651903807615, 1119.4594188376752, 1123.2669338677354, 1127.0744488977955, 1130.8819639278556, 1134.6894789579158, 1138.4969939879759, 1142.304509018036, 1146.1120240480961, 1149.9195390781563, 1153.7270541082164, 1157.5345691382765, 1161.3420841683367, 1165.1495991983968, 1168.957114228457, 1172.764629258517, 1176.5721442885772, 1180.379659318637, 1184.1871743486972, 1187.9946893787574, 1191.8022044088175, 1195.6097194388776, 1199.4172344689377, 1203.2247494989979, 1207.032264529058, 1210.8397795591181, 1214.6472945891783, 1218.4548096192384, 1222.2623246492985, 1226.0698396793587, 1229.8773547094188, 1233.684869739479, 1237.492384769539, 1241.2998997995992, 1245.1074148296593, 1248.9149298597195, 1252.7224448897796, 1256.5299599198397, 1260.3374749498996, 1264.1449899799597, 1267.9525050100199, 1271.76002004008, 1275.5675350701401, 1279.3750501002003, 1283.1825651302604, 1286.9900801603205, 1290.7975951903807, 1294.6051102204408, 1298.412625250501, 1302.220140280561, 1306.0276553106212, 1309.8351703406813, 1313.6426853707414, 1317.4502004008016, 1321.2577154308617, 1325.0652304609218, 1328.872745490982, 1332.680260521042, 1336.4877755511022, 1340.2952905811624, 1344.1028056112223, 1347.9103206412824, 1351.7178356713425, 1355.5253507014027, 1359.3328657314628, 1363.140380761523, 1366.947895791583, 1370.7554108216432, 1374.5629258517033, 1378.3704408817634, 1382.1779559118236, 1385.9854709418837, 1389.7929859719438, 1393.600501002004, 1397.408016032064, 1401.2155310621242, 1405.0230460921844, 1408.8305611222445, 1412.6380761523046, 1416.4455911823648, 1420.2531062124249, 1424.0606212424848, 1427.868136272545, 1431.675651302605, 1435.4831663326652, 1439.2906813627253, 1443.0981963927854, 1446.9057114228456, 1450.7132264529057, 1454.5207414829658, 1458.328256513026, 1462.135771543086, 1465.9432865731462, 1469.7508016032064, 1473.5583166332665, 1477.3658316633266, 1481.1733466933867, 1484.9808617234469, 1488.788376753507, 1492.5958917835671, 1496.4034068136273, 1500.2109218436874, 1504.0184368737473, 1507.8259519038074, 1511.6334669338676, 1515.4409819639277, 1519.2484969939878, 1523.056012024048, 1526.863527054108, 1530.6710420841682, 1534.4785571142284, 1538.2860721442885, 1542.0935871743486, 1545.9011022044087, 1549.7086172344689, 1553.516132264529, 1557.3236472945891, 1561.1311623246493, 1564.9386773547094, 1568.7461923847695, 1572.5537074148297, 1576.3612224448898, 1580.16873747495, 1583.9762525050098, 1587.78376753507, 1591.59128256513, 1595.3987975951902, 1599.2063126252503, 1603.0138276553105, 1606.8213426853706, 1610.6288577154307, 1614.4363727454909, 1618.243887775551, 1622.0514028056111, 1625.8589178356713, 1629.6664328657314, 1633.4739478957915, 1637.2814629258517, 1641.0889779559118, 1644.896492985972, 1648.704008016032, 1652.5115230460922, 1656.3190380761523, 1660.1265531062124, 1663.9340681362726, 1667.7415831663325, 1671.5490981963926, 1675.3566132264527, 1679.1641282565129, 1682.971643286573, 1686.7791583166331, 1690.5866733466933, 1694.3941883767534, 1698.2017034068135, 1702.0092184368737, 1705.8167334669338, 1709.624248496994, 1713.431763527054, 1717.2392785571142, 1721.0467935871743, 1724.8543086172344, 1728.6618236472946, 1732.4693386773547, 1736.2768537074148, 1740.084368737475, 1743.891883767535, 1747.699398797595, 1751.5069138276551, 1755.3144288577153, 1759.1219438877754, 1762.9294589178355, 1766.7369739478956, 1770.5444889779558, 1774.352004008016, 1778.159519038076, 1781.9670340681362, 1785.7745490981963, 1789.5820641282564, 1793.3895791583166, 1797.1970941883767, 1801.0046092184368, 1804.812124248497, 1808.619639278557, 1812.4271543086172, 1816.2346693386773, 1820.0421843687375, 1823.8496993987976, 1827.6572144288577, 1831.4647294589176, 1835.2722444889778, 1839.079759519038, 1842.887274549098, 1846.6947895791582, 1850.5023046092183, 1854.3098196392784, 1858.1173346693386, 1861.9248496993987, 1865.7323647294588, 1869.539879759519, 1873.347394789579, 1877.1549098196392, 1880.9624248496993, 1884.7699398797595, 1888.5774549098196, 1892.3849699398797, 1896.1924849699399, 1900.0], \"y\": [0.8787855595829217, 0.870342756658365, 0.8619355961745003, 0.8535639276619174, 0.8452276012864326, 0.8369264678464081, 0.8286603787700808, 0.8204291861129038, 0.8122327425548981, 0.8040709013980158, 0.7959435165635151, 0.7878504425893451, 0.779791534627543, 0.7717666484416414, 0.7637756404040867, 0.7558183674936687, 0.7478946872929599, 0.7400044579857687, 0.7321475383545986, 0.7243237877781226, 0.7165330662286655, 0.7087752342696982, 0.701050153053342, 0.6933576843178828, 0.6856976903852976, 0.6780700341587897, 0.6704745791203353, 0.6629111893282402, 0.6553797294147059, 0.6478800645834082, 0.6404120606070833, 0.6329755838251268, 0.6255705011411996, 0.618196680020848, 0.6108539884891302, 0.6035422951282541, 0.5962614690752261, 0.5890113800195085, 0.5817918982006871, 0.5746028944061492, 0.5674442399687705, 0.5603158067646123, 0.5532174672106291, 0.5461490942623839, 0.5391105614117755, 0.5321017426847738, 0.525122512639165, 0.5181727463623069, 0.5112523194688929, 0.504361108098726, 0.4974989889145016, 0.4906658390996004, 0.48386153635589046, 0.4770859589015375, 0.47033898546882646, 0.46362049530199, 0.4569303681550474, 0.4502684842896536, 0.4436347244729544, 0.4370289699754537, 0.43045110256888774, 0.4239010045241103, 0.41737855860898376, 0.4108836480862825, 0.4044161567116029, 0.3979759687312827, 0.3915629688803297, 0.38517704238035844, 0.37881807493753583, 0.372485952740536, 0.36618056245850306, 0.3599017912390228, 0.3536495267061024, 0.34742365695816013, 0.34122407056602166, 0.33505065657092614, 0.32890330448254024, 0.3227819042769806, 0.3166863463948446, 0.3106165217392498, 0.3045723216738805, 0.29855363802104473, 0.29256036305973665, 0.2865923895237099, 0.28064961059955684, 0.27473191992479684, 0.2688392115859737, 0.2629713801167588, 0.25712832049606393, 0.25130992814616215, 0.24551609893081472, 0.23974672915340922, 0.23400171555510196, 0.22828095531297055, 0.222584346038174, 0.21691178577411896, 0.21126317299463637, 0.20563840660216326, 0.20003738592593434, 0.19446001072017904, 0.18890618116232805, 0.18337579785122693, 0.1778687618053567, 0.1723849744610617, 0.16692433767078718, 0.1614867537013207, 0.15607212523204428, 0.15068035535319213, 0.14531134756411634, 0.13996500577155935, 0.13464123428793462, 0.12933993782961317, 0.12406102151522003, 0.11880439086393357, 0.11356995179379648, 0.10835761062003124, 0.1031672740533629, 0.09799884919835034, 0.09285224355172295, 0.08772736500072531, 0.0826241218214685, 0.07754242267728872, 0.07248217661711198, 0.06744329307382646, 0.062425681862662286, 0.05742925317957659, 0.05245391759964635, 0.047499586075468114, 0.04256616993556395, 0.03765358088279536, 0.032761730992781235, 0.027890532712326, 0.023039898857851293, 0.018209742613836122, 0.01339997753126343, 0.008610517526072003, 0.003841276877616373, 0.0009078297728675189, 0.0056368874237902045, 0.010345980714729919, 0.015035193927946944, 0.01970461098989329, 0.024354315472713273, 0.028984390595740983, 0.03359491922698732, 0.03818598388462635, 0.04275766673846926, 0.047310049611436256, 0.05184321398102165, 0.0563572409807509, 0.060852211401633216, 0.06532820569360798, 0.06978530396698379, 0.07422358599387269, 0.0786431312096183, 0.08304401871421674, 0.087426327273733, 0.09179013532171054, 0.09613552096057454, 0.10046256196303016, 0.10477133577345477, 0.1090619195092839, 0.11333438996239109, 0.11758882360046252, 0.12182529656836572, 0.12604388468951233, 0.13024466346721486, 0.1344277080860391, 0.13859309341314807, 0.1427408939996433, 0.1468711840818988, 0.15098403758288936, 0.155079528113514, 0.15915772897391323, 0.16321871315478143, 0.16726255333867246, 0.17128932190130075, 0.17529909091283724, 0.1792919321391987, 0.18326791704333223, 0.1872271167864944, 0.19116960222952495, 0.19509544393411482, 0.19900471216406923, 0.20289747688656523, 0.20677380777340393, 0.21063377420225715, 0.21447744525791002, 0.21830488973349638, 0.22211617613173062, 0.22591137266613392, 0.22969054726225413, 0.2334537675588827, 0.23720110090926472, 0.24093261438230407, 0.24464837476376444, 0.24834844855746407, 0.25203290198646655, 0.25570180099426554, 0.2593552112459655, 0.26299319812945676, 0.26661582675658546, 0.2702231619643195, 0.27381526831590874, 0.2773922101020402, 0.28095405134198925, 0.284500855784765, 0.28803268691025197, 0.2915496079303449, 0.2950516817900818, 0.2985389711687688, 0.3020115384811035, 0.30546944587829084, 0.3089127552491564, 0.3123415282212534, 0.31575582616196607, 0.319155710179608, 0.32254124112451543, 0.3259124795901369, 0.3292694859141171, 0.3326123201793779, 0.33594104221519216, 0.3392557115982556, 0.34255638765375307, 0.3458431294564196, 0.34911599583159847, 0.35237504535629394, 0.3556203363602193, 0.35885192692684065, 0.36206987489441766, 0.36527423785703717, 0.36846507316564514, 0.3716424379290727, 0.37480638901505814, 0.3779569830512649, 0.381094276426295, 0.38421832529069855, 0.38732918555797813, 0.3904269129055902, 0.3935115627759408, 0.39658319037737877, 0.39964185068518343, 0.4026875984425481, 0.40572048816156037, 0.40874057412417786, 0.41174791038319947, 0.41474255076323263, 0.4177245488616571, 0.42069395804958387, 0.42365083147281046, 0.42659522205277245, 0.42952718248749033, 0.43244676525251247, 0.43535402260185474, 0.43824900656893573, 0.4411317689675077, 0.4440023613925841, 0.446860835221363, 0.44970724161414666, 0.45254163151525717, 0.45536405565394855, 0.4581745645453138, 0.46097320849118983, 0.4637600375810579, 0.4665351016929391, 0.469298450494288, 0.47205013344288105, 0.4747901997877024, 0.47751869856982443, 0.480235678623286, 0.4829411885759669, 0.4856352768504574, 0.48831799166492484, 0.49098938103397793, 0.4936494927695243, 0.4962983744816276, 0.498936073579359, 0.5015626372716456, 0.5041781125681161, 0.5067825462799409, 0.5093759850206716, 0.5119584752070738, 0.5145300630599584, 0.517090794605009, 0.5196407156736055, 0.5221798719036442, 0.5247083087403552, 0.5272260714371152, 0.5297332050562574, 0.5322297544698786, 0.5347157643606418, 0.5371912792225759, 0.5396563433618723, 0.5421110008976779, 0.5445552957628846, 0.5469892717049155, 0.549412972286508, 0.5518264408864937, 0.5542297207005741, 0.5566228547420948, 0.5590058858428144, 0.5613788566536713, 0.5637418096455472, 0.5660947871100274, 0.5684378311601572, 0.5707709837311962, 0.5730942865813686, 0.5754077812926106, 0.5777115092713144, 0.5800055117490697, 0.5822898297834009, 0.5845645042585035, 0.586829575885974, 0.5890850852055395, 0.5913310725857833, 0.5935675782248672, 0.5957946421512507, 0.5980123042244082, 0.6002206041355415, 0.6024195814082908, 0.604609275399442, 0.6067897252996305, 0.6089609701340437, 0.6111230487631185, 0.6132759998832371, 0.6154198620274199, 0.617554673566015, 0.6196804727073845, 0.621797297498589, 0.623905185826068, 0.6260041754163186, 0.6280943038365698, 0.6301756084954564, 0.6322481266436866, 0.6343118953747098, 0.6363669516253809, 0.6384133321766206, 0.6404510736540736, 0.6424802125287647, 0.6445007851177516, 0.6465128275847742, 0.6485163759409025, 0.6505114660451805, 0.6524981336052689, 0.6544764141780832, 0.6564463431704308, 0.6584079558396445, 0.6603612872942133, 0.6623063724944109, 0.6642432462529215, 0.6661719432354631, 0.6680924979614071, 0.6700049448043974, 0.671909317992964, 0.6738056516111376, 0.6756939795990574, 0.6775743357535805, 0.6794467537288855, 0.6813112670370756, 0.6831679090487779, 0.6850167129937412, 0.6868577119614299, 0.6886909389016169, 0.6905164266249735, 0.6923342078036557, 0.6941443149718902, 0.6959467805265556, 0.6977416367277625, 0.6995289156994318, 0.7013086494298679, 0.7030808697723332, 0.7048456084456165, 0.7066028970346019, 0.7083527669908332, 0.7100952496330775, 0.7118303761478855, 0.7135581775901494, 0.7152786848836592, 0.7169919288216559, 0.7186979400673823, 0.7203967491546326, 0.7220883864882981, 0.7237728823449121, 0.7254502668731907, 0.727120570094574, 0.7287838219037617, 0.7304400520692496, 0.7320892902338614, 0.7337315659152794, 0.7353669085065736, 0.7369953472767264, 0.738616911371158, 0.7402316298122467, 0.7418395314998489, 0.7434406452118167, 0.745034999604512, 0.7466226232133206, 0.7482035444531621, 0.7497777916189983, 0.7513453928863404, 0.7529063763117525, 0.7544607698333545, 0.7560086012713213, 0.7575498983283813, 0.7590846885903124, 0.760612999526435, 0.762134858490104, 0.7636502927191986, 0.7651593293366095, 0.7666619953507245, 0.7681583176559116, 0.7696483230330009, 0.7711320381497634, 0.7726094895613884, 0.774080703710959, 0.7755457069299252, 0.777004525438575, 0.7784571853465043, 0.7799037126530834, 0.7813441332479232, 0.7827784729113373, 0.7842067573148048, 0.7856290120214293, 0.7870452624863957, 0.7884555340574267, 0.7898598519752364, 0.7912582413739813, 0.7926507272817108, 0.7940373346208152, 0.7954180882084712, 0.7967930127570868, 0.798162132874743, 0.7995254730656343, 0.8008830577305076, 0.8022349111670988, 0.8035810575705673, 0.8049215210339296, 0.8062563255484902, 0.8075854950042711, 0.8089090531904393, 0.8102270237957325, 0.811539430408883, 0.8128462965190406, 0.814147645516192, 0.81544350069158, 0.8167338852381204, 0.8180188222508167, 0.8192983347271741, 0.82057244556761, 0.8218411775758653, 0.8231045534594116, 0.8243625958298575, 0.8256153272033542, 0.8268627700009973, 0.828104946549229, 0.8293418790802374, 0.8305735897323543, 0.8318001005504516, 0.8330214334863357, 0.8342376103991407, 0.835448653055719, 0.8366545831310315, 0.8378554222085354, 0.8390511917805701, 0.8402419132487425, 0.8414276079243095, 0.8426082970285598, 0.8437840016931931, 0.8449547429606993, 0.8461205417847344, 0.8472814190304956, 0.8484373954750948, 0.8495884918079306, 0.8507347286310585, 0.8518761264595596, 0.8530127057219077, 0.8541444867603352, 0.8552714898311967, 0.8563937351053322, 0.8575112426684277, 0.8586240325213744, 0.8597321245806274, 0.8608355386785618, 0.861934294563827, 0.8630284119017015, 0.8641179102744442, 0.8652028091816442, 0.8662831280405708, 0.8673588861865207, 0.868430102873164, 0.8694967972728886, 0.8705589884771439, 0.871616695496782, 0.8726699372623978, 0.8737187326246687, 0.8747631003546907, 0.875803059144316, 0.8768386276064856, 0.8778698242755639, 0.8788966676076704], \"type\": \"scatter\", \"uid\": \"e2072076-0e72-4bd1-936f-2690155d4399\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 4.057915831663326, 8.065831663326653, 12.07374749498998, 16.081663326653306, 20.08957915831663, 24.09749498997996, 28.105410821643286, 32.11332665330661, 36.12124248496993, 40.12915831663326, 44.137074148296584, 48.14498997995992, 52.15290581162324, 56.16082164328657, 60.16873747494989, 64.17665330661322, 68.18456913827654, 72.19248496993987, 76.2004008016032, 80.20831663326652, 84.21623246492985, 88.22414829659317, 92.2320641282565, 96.23997995991984, 100.24789579158316, 104.25581162324649, 108.26372745490981, 112.27164328657314, 116.27955911823646, 120.28747494989979, 124.29539078156311, 128.30330661322645, 132.31122244488978, 136.3191382765531, 140.32705410821643, 144.33496993987976, 148.34288577154308, 152.3508016032064, 156.35871743486973, 160.36663326653306, 164.37454909819638, 168.3824649298597, 172.39038076152303, 176.39829659318636, 180.40621242484968, 184.414128256513, 188.42204408817634, 192.4299599198397, 196.43787575150301, 200.44579158316634, 204.45370741482967, 208.461623246493, 212.46953907815632, 216.47745490981964, 220.48537074148297, 224.4932865731463, 228.50120240480962, 232.50911823647294, 236.51703406813627, 240.5249498997996, 244.53286573146292, 248.54078156312625, 252.54869739478957, 256.5566132264529, 260.56452905811625, 264.57244488977955, 268.5803607214429, 272.5882765531062, 276.59619238476955, 280.60410821643285, 284.6120240480962, 288.6199398797595, 292.62785571142285, 296.63577154308615, 300.6436873747495, 304.6516032064128, 308.65951903807616, 312.66743486973945, 316.6753507014028, 320.6832665330661, 324.69118236472946, 328.69909819639275, 332.7070140280561, 336.7149298597194, 340.72284569138276, 344.73076152304606, 348.7386773547094, 352.7465931863727, 356.75450901803606, 360.76242484969936, 364.7703406813627, 368.778256513026, 372.78617234468936, 376.79408817635266, 380.802004008016, 384.80991983967937, 388.81783567134266, 392.825751503006, 396.8336673346693, 400.84158316633267, 404.84949899799597, 408.8574148296593, 412.8653306613226, 416.87324649298597, 420.88116232464927, 424.8890781563126, 428.8969939879759, 432.9049098196393, 436.91282565130257, 440.9207414829659, 444.9286573146292, 448.9365731462926, 452.94448897795587, 456.9524048096192, 460.9603206412825, 464.9682364729459, 468.9761523046092, 472.9840681362725, 476.9919839679358, 480.9998997995992, 485.0078156312625, 489.0157314629258, 493.0236472945891, 497.0315631262525, 501.0394789579158, 505.04739478957913, 509.0553106212424, 513.0632264529057, 517.0711422845691, 521.0790581162324, 525.0869739478957, 529.094889779559, 533.1028056112224, 537.1107214428857, 541.118637274549, 545.1265531062123, 549.1344689378757, 553.142384769539, 557.1503006012023, 561.1582164328656, 565.166132264529, 569.1740480961923, 573.1819639278556, 577.1898797595189, 581.1977955911823, 585.2057114228456, 589.2136272545089, 593.2215430861722, 597.2294589178356, 601.2373747494989, 605.2452905811622, 609.2532064128255, 613.2611222444889, 617.2690380761522, 621.2769539078155, 625.2848697394788, 629.2927855711422, 633.3007014028055, 637.3086172344688, 641.3165330661321, 645.3244488977955, 649.3323647294588, 653.3402805611222, 657.3481963927854, 661.3561122244488, 665.3640280561121, 669.3719438877755, 673.3798597194387, 677.3877755511021, 681.3956913827654, 685.4036072144288, 689.411523046092, 693.4194388777554, 697.4273547094188, 701.4352705410821, 705.4431863727453, 709.4511022044087, 713.459018036072, 717.4669338677354, 721.4748496993986, 725.482765531062, 729.4906813627254, 733.4985971943887, 737.506513026052, 741.5144288577153, 745.5223446893787, 749.530260521042, 753.5381763527052, 757.5460921843686, 761.554008016032, 765.5619238476953, 769.5698396793587, 773.5777555110219, 777.5856713426853, 781.5935871743486, 785.601503006012, 789.6094188376752, 793.6173346693386, 797.6252505010019, 801.6331663326653, 805.6410821643285, 809.6489979959919, 813.6569138276552, 817.6648296593186, 821.6727454909818, 825.6806613226452, 829.6885771543085, 833.6964929859719, 837.7044088176351, 841.7123246492985, 845.7202404809618, 849.7281563126252, 853.7360721442884, 857.7439879759518, 861.7519038076151, 865.7598196392785, 869.7677354709417, 873.7756513026051, 877.7835671342684, 881.7914829659318, 885.799398797595, 889.8073146292584, 893.8152304609217, 897.8231462925851, 901.8310621242484, 905.8389779559117, 909.846893787575, 913.8548096192384, 917.8627254509017, 921.870641282565, 925.8785571142283, 929.8864729458917, 933.894388777555, 937.9023046092183, 941.9102204408816, 945.918136272545, 949.9260521042083, 953.9339679358716, 957.9418837675349, 961.9497995991983, 965.9577154308616, 969.9656312625249, 973.9735470941882, 977.9814629258516, 981.9893787575149, 985.9972945891782, 990.0052104208415, 994.0131262525049, 998.0210420841682, 1002.0289579158315, 1006.0368737474948, 1010.0447895791582, 1014.0527054108215, 1018.0606212424848, 1022.0685370741481, 1026.0764529058115, 1030.0843687374747, 1034.0922845691382, 1038.1002004008014, 1042.108116232465, 1046.1160320641281, 1050.1239478957914, 1054.1318637274549, 1058.139779559118, 1062.1476953907813, 1066.1556112224448, 1070.163527054108, 1074.1714428857715, 1078.1793587174348, 1082.187274549098, 1086.1951903807615, 1090.2031062124247, 1094.211022044088, 1098.2189378757514, 1102.2268537074146, 1106.2347695390781, 1110.2426853707414, 1114.2506012024046, 1118.258517034068, 1122.2664328657313, 1126.2743486973945, 1130.282264529058, 1134.2901803607213, 1138.2980961923847, 1142.306012024048, 1146.3139278557112, 1150.3218436873747, 1154.329759519038, 1158.3376753507014, 1162.3455911823646, 1166.3535070140279, 1170.3614228456913, 1174.3693386773546, 1178.3772545090178, 1182.3851703406813, 1186.3930861723445, 1190.401002004008, 1194.4089178356712, 1198.4168336673345, 1202.424749498998, 1206.4326653306612, 1210.4405811623244, 1214.4484969939879, 1218.4564128256511, 1222.4643286573146, 1226.4722444889778, 1230.480160320641, 1234.4880761523045, 1238.4959919839678, 1242.503907815631, 1246.5118236472945, 1250.5197394789577, 1254.5276553106212, 1258.5355711422844, 1262.5434869739477, 1266.5514028056111, 1270.5593186372744, 1274.5672344689376, 1278.575150300601, 1282.5830661322643, 1286.5909819639278, 1290.598897795591, 1294.6068136272543, 1298.6147294589177, 1302.622645290581, 1306.6305611222444, 1310.6384769539077, 1314.646392785571, 1318.6543086172344, 1322.6622244488976, 1326.6701402805609, 1330.6780561122243, 1334.6859719438876, 1338.693887775551, 1342.7018036072143, 1346.7097194388775, 1350.717635270541, 1354.7255511022042, 1358.7334669338675, 1362.741382765531, 1366.7492985971942, 1370.7572144288577, 1374.765130260521, 1378.7730460921841, 1382.7809619238476, 1386.7888777555108, 1390.796793587174, 1394.8047094188375, 1398.8126252505008, 1402.8205410821643, 1406.8284569138275, 1410.8363727454907, 1414.8442885771542, 1418.8522044088174, 1422.860120240481, 1426.8680360721442, 1430.8759519038074, 1434.8838677354709, 1438.891783567134, 1442.8996993987973, 1446.9076152304608, 1450.915531062124, 1454.9234468937875, 1458.9313627254508, 1462.939278557114, 1466.9471943887775, 1470.9551102204407, 1474.963026052104, 1478.9709418837674, 1482.9788577154306, 1486.9867735470941, 1490.9946893787574, 1495.0026052104206, 1499.010521042084, 1503.0184368737473, 1507.0263527054105, 1511.034268537074, 1515.0421843687373, 1519.0501002004007, 1523.058016032064, 1527.0659318637272, 1531.0738476953907, 1535.081763527054, 1539.0896793587174, 1543.0975951903806, 1547.1055110220439, 1551.1134268537073, 1555.1213426853706, 1559.1292585170338, 1563.1371743486973, 1567.1450901803605, 1571.153006012024, 1575.1609218436872, 1579.1688376753505, 1583.176753507014, 1587.1846693386772, 1591.1925851703404, 1595.2005010020039, 1599.2084168336671, 1603.2163326653306, 1607.2242484969938, 1611.232164328657, 1615.2400801603205, 1619.2479959919838, 1623.255911823647, 1627.2638276553105, 1631.2717434869737, 1635.2796593186372, 1639.2875751503004, 1643.2954909819637, 1647.3034068136271, 1651.3113226452904, 1655.3192384769536, 1659.327154308617, 1663.3350701402803, 1667.3429859719438, 1671.350901803607, 1675.3588176352703, 1679.3667334669337, 1683.374649298597, 1687.3825651302604, 1691.3904809619237, 1695.398396793587, 1699.4063126252504, 1703.4142284569136, 1707.4221442885769, 1711.4300601202403, 1715.4379759519036, 1719.445891783567, 1723.4538076152303, 1727.4617234468935, 1731.469639278557, 1735.4775551102202, 1739.4854709418835, 1743.493386773547, 1747.5013026052102, 1751.5092184368737, 1755.517134268537, 1759.5250501002001, 1763.5329659318636, 1767.5408817635268, 1771.54879759519, 1775.5567134268535, 1779.5646292585168, 1783.5725450901803, 1787.5804609218435, 1791.5883767535067, 1795.5962925851702, 1799.6042084168334, 1803.612124248497, 1807.6200400801602, 1811.6279559118234, 1815.6358717434869, 1819.64378757515, 1823.6517034068133, 1827.6596192384768, 1831.66753507014, 1835.6754509018035, 1839.6833667334668, 1843.69128256513, 1847.6991983967935, 1851.7071142284567, 1855.71503006012, 1859.7229458917834, 1863.7308617234467, 1867.7387775551101, 1871.7466933867734, 1875.7546092184366, 1879.7625250501, 1883.7704408817633, 1887.7783567134265, 1891.78627254509, 1895.7941883767533, 1899.8021042084167, 1903.81002004008, 1907.8179358717432, 1911.8258517034067, 1915.83376753507, 1919.8416833667332, 1923.8495991983966, 1927.8575150300599, 1931.8654308617233, 1935.8733466933866, 1939.8812625250498, 1943.8891783567133, 1947.8970941883765, 1951.90501002004, 1955.9129258517032, 1959.9208416833665, 1963.92875751503, 1967.9366733466932, 1971.9445891783564, 1975.9525050100199, 1979.9604208416831, 1983.9683366733466, 1987.9762525050098, 1991.984168336673, 1995.9920841683365, 2000.0], \"y\": [0.8915208687533558, 0.882634684757704, 0.8737879850885673, 0.8649805943037041, 0.8562123377404216, 0.8474830415121135, 0.8387925325048096, 0.8301406383737446, 0.8215271875399386, 0.8129520091867959, 0.8044149332567165, 0.7959157904477239, 0.7874544122101077, 0.7790306307430812, 0.7706442789914532, 0.7622951906423152, 0.7539832001217437, 0.745708142591516, 0.7374698539458413, 0.729268170808107, 0.7211029305276375, 0.7129739711764698, 0.7048811315461412, 0.6968242511444933, 0.6888031701924884, 0.6808177296210414, 0.6728677710678652, 0.6649531368743293, 0.657073670082335, 0.6492292144312004, 0.6414196143545638, 0.633644714977297, 0.6259043621124347, 0.6181984022581162, 0.6105266825945419, 0.6028890509809426, 0.5952853559525613, 0.5877154467176511, 0.5801791731544832, 0.5726763858083708, 0.5652069358887053, 0.5577706752660045, 0.5503674564689764, 0.5429971326815932, 0.5356595577401808, 0.5283545861305199, 0.5210820729849603, 0.5138418740795474, 0.506633845831163, 0.49945784529467696, 0.4923137301601128, 0.48520135874982606, 0.4781205900156933, 0.4710712835363162, 0.4640532995142359, 0.4570664987731614, 0.4501107427552089, 0.4431858935181543, 0.43629181373269743, 0.42942836667973916, 0.42259541624766883, 0.41579282692966646, 0.40902046382101465, 0.40227819261642317, 0.395565879607366, 0.3888833916794294, 0.3822305963096715, 0.37560736156399543, 0.36901355609453224, 0.36244904913703513, 0.35591371050828857, 0.34940741060352387, 0.34293002039385123, 0.33648141142369914, 0.3300614558082686, 0.32367002623099483, 0.3173069959410253, 0.3109722387507028, 0.30466562903306604, 0.2983870417193559, 0.292136352296537, 0.2859134368048266, 0.27971817183523817, 0.2735504345271327, 0.26741010256578224, 0.26129705417994553, 0.2552111681394513, 0.24915232375279595, 0.24312040086474807, 0.23711527985396752, 0.23113684163063186, 0.22518496763407514, 0.21925953983043667, 0.21336044071032023, 0.20748755328646373, 0.20164076109141904, 0.19581994817524206, 0.19002499910319437, 0.18425579895345212, 0.17851223331482924, 0.17279418828450654, 0.1671015504657738, 0.1614342069657806, 0.1557920453932986, 0.1501749538564907, 0.14458282096069364, 0.1390155358062084, 0.13347298798610097, 0.12795506758401243, 0.12246166517197987, 0.11699267180826545, 0.11154797903519698, 0.1061274788770159, 0.100731063837737, 0.09535862689901542, 0.09001006151802615, 0.08468526162534928, 0.07938412162286723, 0.07410653638167108, 0.06885240123997538, 0.06362161200104133, 0.05841406493111312, 0.053229656757358024, 0.04806828466582025, 0.04292984629938035, 0.037814239755727286, 0.03272136358533562, 0.027651116789455088, 0.022603398818107134, 0.01757810956809025, 0.012575149380995798, 0.007594419041231593, 0.0026358197740530276, 0.002300746756394245, 0.007215378449024978, 0.012108172767756109, 0.016979226743439657, 0.021828636975785853, 0.026656499635280717, 0.031462910465090976, 0.036247964782965214, 0.04101175748312258, 0.045754383038134616, 0.05047593550079954, 0.055176508506007416, 0.059856195272596224, 0.06451508860520128, 0.06915328089609551, 0.07377086412702205, 0.07836792987101715, 0.08294456929422744, 0.0875008731577176, 0.09203693181926997, 0.09655283523517699, 0.10104867296202413, 0.10552453415846719, 0.10998050758699973, 0.11441668161571317, 0.11883314422005009, 0.1232299829845479, 0.12760728510457642, 0.13196513738806692, 0.1363036262572337, 0.1406228377502876, 0.1449228575231425, 0.1492037708511147, 0.15346566263061268, 0.15770861738082165, 0.1619327192453791, 0.16613805199404463, 0.17032469902435976, 0.17449274336330267, 0.1786422676689342, 0.18277335423203833, 0.18688608497775216, 0.19098054146719223, 0.1950568048990713, 0.1991149561113087, 0.20315507558263357, 0.20717724343418042, 0.21118153943107898, 0.21516804298403525, 0.21913683315090648, 0.22308798863826884, 0.22702158780297899, 0.2309377086537273, 0.23483642885258516, 0.23871782571654498, 0.24258197621905342, 0.24642895699153855, 0.2502588443249284, 0.25407171417116514, 0.25786764214471025, 0.2616467035240446, 0.2654089732531618, 0.26915452594305334, 0.27288343587318886, 0.2765957769929891, 0.280291622923293, 0.2839710469578166, 0.28763412206460715, 0.29128092088749036, 0.29491151574751084, 0.29852597864436625, 0.3021243812578349, 0.30570679494919784, 0.309273290762654, 0.31282393942672826, 0.3163588113556751, 0.3198779766508747, 0.32338150510222263, 0.32686946618951485, 0.3303419290838244, 0.33379896264887443, 0.3372406354424029, 0.34066701571752256, 0.3440781714240744, 0.3474741702099754, 0.3508550794225598, 0.3542209661099147, 0.35757189702221037, 0.3609079386130226, 0.3642291570406522, 0.3675356181694357, 0.3708273875710525, 0.3741045305258244, 0.37736711202401096, 0.38061519676709776, 0.3838488491690796, 0.3870681333577388, 0.3902731131759154, 0.39346385218277447, 0.39664041365506597, 0.3998028605883802, 0.4029512556983963, 0.40608566142212654, 0.4092061399191542, 0.4123127530728672, 0.4154055624916836, 0.4184846295102749, 0.42155001519078195, 0.42460178032402573, 0.4276399854307128, 0.4306646907626359, 0.4336759563038687, 0.43667384177195523, 0.43965840661909394, 0.44262971003331775, 0.4455878109396665, 0.448532768001356, 0.45146463962094185, 0.45438348394147754, 0.45728935884766675, 0.46018232196701203, 0.4630624306709572, 0.4659297420760259, 0.46878431304495305, 0.4716262001878134, 0.4744554598631444, 0.4772721481790624, 0.4800763209943776, 0.48286803391969935, 0.48564734231854123, 0.4884143013084177, 0.4911689657619368, 0.4939113903078899, 0.4966416293323339, 0.4993597369796693, 0.5020657671537156, 0.5047597735187788, 0.5074418095007164, 0.5101119282879971, 0.5127701828327542, 0.5154166258518378, 0.5180513098278586, 0.5206742870102293, 0.5232856094162011, 0.5258853288318944, 0.5284734968133267, 0.5310501646874347, 0.5336153835530917, 0.5361692042821217, 0.5387116775203082, 0.5412428536883979, 0.543762782983101, 0.546271515378087, 0.5487691006249754, 0.5512555882543223, 0.5537310275766028, 0.5561954676831887, 0.5586489574473226, 0.5610915455250861, 0.5635232803563661, 0.565944210165814, 0.568354382963803, 0.5707538465473803, 0.5731426485012139, 0.5755208361985374, 0.5778884568020892, 0.5802455572650475, 0.5825921843319616, 0.5849283845396788, 0.5872542042182678, 0.5895696894919369, 0.5918748862799488, 0.5941698402975314, 0.5964545970567845, 0.5987292018675822, 0.6009936998384712, 0.603248135877566, 0.605492554693439, 0.6077270007960072, 0.6099515184974148, 0.6121661519129127, 0.6143709449617322, 0.6165659413679567, 0.6187511846613891, 0.6209267181784139, 0.6230925850628581, 0.6252488282668457, 0.6273954905516497, 0.6295326144885406, 0.63166024245963, 0.6337784166587117, 0.6358871790920984, 0.6379865715794537, 0.640076635754623, 0.6421574130664581, 0.6442289447796397, 0.6462912719754954, 0.6483444355528143, 0.6503884762286589, 0.6524234345391717, 0.6544493508403791, 0.6564662653089927, 0.6584742179432044, 0.6604732485634812, 0.6624633968133546, 0.6644447021602058, 0.666417203896049, 0.6683809411383115, 0.6703359528306074, 0.6722822777435123, 0.6742199544753305, 0.6761490214528605, 0.6780695169321586, 0.6799814789992952, 0.6818849455711122, 0.6837799543959744, 0.6856665430545168, 0.6875447489603919, 0.6894146093610098, 0.6912761613382785, 0.6931294418093381, 0.6949744875272935, 0.6968113350819429, 0.6986400209005038, 0.7004605812483353, 0.702273052229657, 0.7040774697882654, 0.7058738697082462, 0.707662287614685, 0.7094427589743721, 0.7112153190965079, 0.712980003133401, 0.7147368460811674, 0.7164858827804226, 0.7182271479169738, 0.7199606760225078, 0.7216865014752747, 0.723404658500771, 0.7251151811724172, 0.7268181034122343, 0.7285134589915165, 0.7302012815315005, 0.7318816045040322, 0.733554461232231, 0.7352198848911504, 0.7368779085084359, 0.73852856496498, 0.740171886995574, 0.7418079071895576, 0.7434366579914653, 0.7450581717016689, 0.7466724804770195, 0.7482796163314837, 0.7498796111367795, 0.7514724966230082, 0.7530583043792833, 0.7546370658543571, 0.7562088123572448, 0.7577735750578447, 0.7593313849875567, 0.7608822730398977, 0.7624262699711144, 0.7639634064007932, 0.7654937128124666, 0.7670172195542191, 0.7685339568392884, 0.770043954746664, 0.7715472432216848, 0.7730438520766321, 0.774533810991321, 0.7760171495136898, 0.7774938970603846, 0.7789640829173438, 0.7804277362403782, 0.7818848860557492, 0.7833355612607455, 0.7847797906242547, 0.7862176027873347, 0.7876490262637812, 0.7890740894406939, 0.7904928205790387, 0.7919052478142086, 0.7933113991565812, 0.7947113024920751, 0.7961049855827018, 0.7974924760671167, 0.7988738014611679, 0.8002489891584408, 0.8016180664308017, 0.802981060428939, 0.8043379981829015, 0.8056889066026341, 0.8070338124785119, 0.808372742481871, 0.8097057231655378, 0.8110327809643559, 0.8123539421957094, 0.8136692330600456, 0.8149786796413943, 0.816282307907885, 0.8175801437122623, 0.818872212792398, 0.8201585407718018, 0.8214391531601299, 0.8227140753536899, 0.8239833326359451, 0.8252469501780164, 0.82650495303918, 0.8277573661673658, 0.8290042143996517, 0.8302455224627554, 0.8314813149735261, 0.8327116164394317, 0.833936451259045, 0.8351558437225278, 0.8363698180121129, 0.8375783982025822, 0.8387816082617463, 0.8399794720509182, 0.8411720133253866, 0.8423592557348883, 0.8435412228240757, 0.8447179380329843, 0.845889424697498, 0.847055706049811, 0.8482168052188892, 0.8493727452309286, 0.8505235490098124, 0.8516692393775647, 0.8528098390548036, 0.8539453706611922, 0.8550758567158865, 0.8562013196379825, 0.8573217817469602, 0.8584372652631267, 0.8595477923080572, 0.8606533849050324, 0.8617540649794768, 0.8628498543593928, 0.8639407747757928, 0.865026847863132, 0.8661080951597359, 0.8671845381082275, 0.8682561980559539, 0.8693230962554077, 0.8703852538646504, 0.8714426919477304, 0.8724954314751016, 0.8735434933240391, 0.8745868982790533, 0.8756256670323017, 0.8766598201839998, 0.8776893782428293, 0.8787143616263446, 0.8797347906613786, 0.8807506855844444, 0.881762066542138, 0.8827689535915371, 0.8837713667005989, 0.8847693257485564, 0.8857628505263123, 0.8867519607368316, 0.8877366759955324, 0.8887170158306746, 0.8896929996837479, 0.8906646469098568, 0.891631976778104], \"type\": \"scatter\", \"uid\": \"035df50f-7fe1-4404-be8d-44d7023904f5\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 4.258316633266532, 8.466633266533066, 12.674949899799598, 16.88326653306613, 21.091583166332665, 25.299899799599196, 29.508216432865726, 33.71653306613226, 37.92484969939879, 42.133166332665326, 46.34148296593185, 50.54979959919839, 54.75811623246492, 58.96643286573145, 63.17474949899798, 67.38306613226452, 71.59138276553105, 75.79969939879759, 80.00801603206412, 84.21633266533065, 88.42464929859717, 92.63296593186371, 96.84128256513024, 101.04959919839678, 105.25791583166331, 109.46623246492985, 113.67454909819638, 117.8828657314629, 122.09118236472943, 126.29949899799597, 130.50781563126253, 134.71613226452905, 138.92444889779557, 143.13276553106212, 147.34108216432864, 151.5493987975952, 155.7577154308617, 159.96603206412826, 164.17434869739478, 168.38266533066133, 172.59098196392785, 176.79929859719437, 181.0076152304609, 185.21593186372743, 189.42424849699398, 193.6325651302605, 197.84088176352705, 202.04919839679357, 206.2575150300601, 210.46583166332664, 214.67414829659316, 218.8824649298597, 223.09078156312623, 227.29909819639278, 231.5074148296593, 235.71573146292582, 239.92404809619237, 244.13236472945889, 248.34068136272543, 252.54899799599195, 256.7573146292585, 260.96563126252505, 265.17394789579157, 269.3822645290581, 273.5905811623246, 277.79889779559113, 282.0072144288577, 286.2155310621242, 290.42384769539075, 294.63216432865727, 298.84048096192384, 303.04879759519036, 307.2571142284569, 311.4654308617234, 315.6737474949899, 319.8820641282565, 324.090380761523, 328.29869739478954, 332.50701402805606, 336.71533066132264, 340.92364729458916, 345.1319639278557, 349.3402805611222, 353.5485971943887, 357.7569138276553, 361.9652304609218, 366.17354709418834, 370.38186372745486, 374.5901803607214, 378.79849699398795, 383.0068136272545, 387.215130260521, 391.4234468937875, 395.6317635270541, 399.8400801603206, 404.04839679358713, 408.25671342685365, 412.46503006012017, 416.67334669338675, 420.88166332665327, 425.0899799599198, 429.2982965931863, 433.5066132264529, 437.7149298597194, 441.9232464929859, 446.13156312625244, 450.33987975951896, 454.54819639278554, 458.75651302605206, 462.9648296593186, 467.1731462925851, 471.3814629258516, 475.5897795591182, 479.7980961923847, 484.00641282565124, 488.21472945891776, 492.42304609218434, 496.63136272545086, 500.8396793587174, 505.0479959919839, 509.2563126252504, 513.4646292585169, 517.6729458917835, 521.88126252505, 526.0895791583165, 530.2978957915831, 534.5062124248495, 538.7145290581161, 542.9228456913827, 547.1311623246492, 551.3394789579157, 555.5477955911822, 559.7561122244488, 563.9644288577153, 568.1727454909818, 572.3810621242484, 576.5893787575149, 580.7976953907814, 585.006012024048, 589.2143286573145, 593.422645290581, 597.6309619238476, 601.8392785571141, 606.0475951903807, 610.2559118236471, 614.4642284569137, 618.6725450901803, 622.8808617234467, 627.0891783567133, 631.2974949899798, 635.5058116232464, 639.7141282565129, 643.9224448897794, 648.130761523046, 652.3390781563124, 656.547394789579, 660.7557114228456, 664.964028056112, 669.1723446893786, 673.3806613226452, 677.5889779559117, 681.7972945891783, 686.0056112224447, 690.2139278557113, 694.4222444889779, 698.6305611222443, 702.8388777555109, 707.0471943887774, 711.255511022044, 715.4638276553105, 719.672144288577, 723.8804609218436, 728.08877755511, 732.2970941883766, 736.5054108216432, 740.7137274549096, 744.9220440881762, 749.1303607214427, 753.3386773547093, 757.5469939879758, 761.7553106212423, 765.9636272545089, 770.1719438877755, 774.3802605210419, 778.5885771543085, 782.796893787575, 787.0052104208415, 791.2135270541081, 795.4218436873746, 799.6301603206412, 803.8384769539076, 808.0467935871742, 812.2551102204408, 816.4634268537072, 820.6717434869738, 824.8800601202403, 829.0883767535069, 833.2966933867734, 837.5050100200399, 841.7133266533065, 845.9216432865729, 850.1299599198395, 854.3382765531061, 858.5465931863725, 862.7549098196391, 866.9632264529057, 871.1715430861722, 875.3798597194387, 879.5881763527052, 883.7964929859718, 888.0048096192384, 892.2131262525048, 896.4214428857714, 900.6297595190379, 904.8380761523044, 909.046392785571, 913.2547094188375, 917.463026052104, 921.6713426853705, 925.8796593186371, 930.0879759519037, 934.2962925851701, 938.5046092184367, 942.7129258517032, 946.9212424849698, 951.1295591182363, 955.3378757515028, 959.5461923847694, 963.754509018036, 967.9628256513024, 972.171142284569, 976.3794589178354, 980.587775551102, 984.7960921843686, 989.0044088176351, 993.2127254509016, 997.4210420841681, 1001.6293587174347, 1005.8376753507013, 1010.0459919839677, 1014.2543086172343, 1018.4626252505008, 1022.6709418837673, 1026.8792585170338, 1031.0875751503004, 1035.295891783567, 1039.5042084168335, 1043.7125250501, 1047.9208416833665, 1052.129158316633, 1056.3374749498996, 1060.5457915831662, 1064.7541082164328, 1068.9624248496991, 1073.1707414829657, 1077.3790581162323, 1081.5873747494988, 1085.7956913827654, 1090.0040080160318, 1094.2123246492984, 1098.420641282565, 1102.6289579158315, 1106.837274549098, 1111.0455911823644, 1115.253907815631, 1119.4622244488976, 1123.6705410821642, 1127.8788577154307, 1132.087174348697, 1136.2954909819637, 1140.5038076152302, 1144.7121242484968, 1148.9204408817634, 1153.1287575150297, 1157.3370741482963, 1161.545390781563, 1165.7537074148295, 1169.962024048096, 1174.1703406813626, 1178.378657314629, 1182.5869739478956, 1186.7952905811621, 1191.0036072144287, 1195.2119238476953, 1199.4202404809616, 1203.6285571142282, 1207.8368737474948, 1212.0451903807614, 1216.253507014028, 1220.4618236472943, 1224.6701402805609, 1228.8784569138274, 1233.086773547094, 1237.2950901803606, 1241.503406813627, 1245.7117234468935, 1249.92004008016, 1254.1283567134267, 1258.3366733466933, 1262.5449899799596, 1266.7533066132262, 1270.9616232464928, 1275.1699398797593, 1279.378256513026, 1283.5865731462923, 1287.7948897795588, 1292.0032064128254, 1296.211523046092, 1300.4198396793586, 1304.628156312625, 1308.8364729458915, 1313.044789579158, 1317.2531062124247, 1321.4614228456912, 1325.6697394789576, 1329.8780561122242, 1334.0863727454907, 1338.2946893787573, 1342.503006012024, 1346.7113226452905, 1350.9196392785568, 1355.1279559118234, 1359.33627254509, 1363.5445891783565, 1367.7529058116231, 1371.9612224448895, 1376.169539078156, 1380.3778557114226, 1384.5861723446892, 1388.7944889779558, 1393.0028056112221, 1397.2111222444887, 1401.4194388777553, 1405.6277555110219, 1409.8360721442884, 1414.0443887775548, 1418.2527054108214, 1422.461022044088, 1426.6693386773545, 1430.877655310621, 1435.0859719438874, 1439.294288577154, 1443.5026052104206, 1447.7109218436872, 1451.9192384769538, 1456.12755511022, 1460.3358717434867, 1464.5441883767533, 1468.7525050100198, 1472.9608216432864, 1477.1691382765528, 1481.3774549098193, 1485.585771543086, 1489.7940881763525, 1494.002404809619, 1498.2107214428854, 1502.419038076152, 1506.6273547094186, 1510.8356713426851, 1515.0439879759517, 1519.252304609218, 1523.4606212424846, 1527.6689378757512, 1531.8772545090178, 1536.0855711422844, 1540.293887775551, 1544.5022044088173, 1548.7105210420839, 1552.9188376753505, 1557.127154308617, 1561.3354709418836, 1565.54378757515, 1569.7521042084165, 1573.9604208416831, 1578.1687374749497, 1582.3770541082163, 1586.5853707414826, 1590.7936873747492, 1595.0020040080158, 1599.2103206412824, 1603.418637274549, 1607.6269539078153, 1611.8352705410819, 1616.0435871743484, 1620.251903807615, 1624.4602204408816, 1628.668537074148, 1632.8768537074145, 1637.085170340681, 1641.2934869739477, 1645.5018036072142, 1649.7101202404806, 1653.9184368737472, 1658.1267535070137, 1662.3350701402803, 1666.543386773547, 1670.7517034068132, 1674.9600200400798, 1679.1683366733464, 1683.376653306613, 1687.5849699398796, 1691.793286573146, 1696.0016032064125, 1700.209919839679, 1704.4182364729456, 1708.6265531062122, 1712.8348697394788, 1717.0431863727451, 1721.2515030060117, 1725.4598196392783, 1729.6681362725449, 1733.8764529058114, 1738.0847695390778, 1742.2930861723444, 1746.501402805611, 1750.7097194388775, 1754.918036072144, 1759.1263527054105, 1763.334669338677, 1767.5429859719436, 1771.7513026052102, 1775.9596192384768, 1780.167935871743, 1784.3762525050097, 1788.5845691382763, 1792.7928857715428, 1797.0012024048094, 1801.2095190380758, 1805.4178356713423, 1809.626152304609, 1813.8344689378755, 1818.042785571142, 1822.2511022044084, 1826.459418837675, 1830.6677354709416, 1834.8760521042082, 1839.0843687374747, 1843.292685370741, 1847.5010020040077, 1851.7093186372742, 1855.9176352705408, 1860.1259519038074, 1864.3342685370737, 1868.5425851703403, 1872.750901803607, 1876.9592184368735, 1881.16753507014, 1885.3758517034064, 1889.584168336673, 1893.7924849699396, 1898.0008016032061, 1902.2091182364727, 1906.4174348697393, 1910.6257515030056, 1914.8340681362722, 1919.0423847695388, 1923.2507014028054, 1927.459018036072, 1931.6673346693383, 1935.8756513026049, 1940.0839679358714, 1944.292284569138, 1948.5006012024046, 1952.708917835671, 1956.9172344689375, 1961.125551102204, 1965.3338677354707, 1969.5421843687373, 1973.7505010020036, 1977.9588176352702, 1982.1671342685368, 1986.3754509018033, 1990.58376753507, 1994.7920841683363, 1999.0004008016028, 2003.2087174348694, 2007.417034068136, 2011.6253507014026, 2015.833667334669, 2020.0419839679355, 2024.250300601202, 2028.4586172344686, 2032.6669338677352, 2036.8752505010016, 2041.0835671342682, 2045.2918837675347, 2049.5002004008015, 2053.708517034068, 2057.9168336673347, 2062.125150300601, 2066.333466933868, 2070.541783567134, 2074.7501002004005, 2078.9584168336673, 2083.1667334669337, 2087.3750501002005, 2091.583366733467, 2095.791683366733, 2100.0], \"y\": [0.9029169241108466, 0.893587457759689, 0.8843015132975458, 0.8750588876951382, 0.8658593788703175, 0.8567027856836469, 0.8475889079340033, 0.8385175463542005, 0.8294885026066321, 0.8205015792789352, 0.8115565798796736, 0.8026533088340428, 0.7937915714795929, 0.7849711740619729, 0.7761919237306945, 0.7674536285349152, 0.758756097419242, 0.7500991402195534, 0.7414825676588424, 0.7329061913430779, 0.7243698237570853, 0.7158732782604469, 0.707416369083421, 0.6989989113228805, 0.6906207209382698, 0.6822816147475814, 0.6739814104233504, 0.6657199264886673, 0.6574969823132124, 0.6493123981093039, 0.6411659949279687, 0.633057594655029, 0.6249870200072087, 0.6169540945282566, 0.6089586425850884, 0.6010004893639467, 0.5930794608665795, 0.5851953839064348, 0.5773480861048748, 0.5695373958874064, 0.5617631424799308, 0.5540251559050082, 0.5463232669781433, 0.5386573073040841, 0.531027109273142, 0.5234325060575258, 0.5158733316076951, 0.5083494206487289, 0.5008606086767124, 0.4934067319551412, 0.48598762751133884, 0.4786031331328968, 0.4712530873641254, 0.4639373295025242, 0.4566556995952693, 0.44940803843571553, 0.4421941875599149, 0.4350139892431528, 0.42786728649649963, 0.42075392306337744, 0.41367374341614394, 0.40662659275269264, 0.3996123169930672, 0.39263076277609343, 0.3856817774560255, 0.3787652090992093, 0.37188090648075933, 0.36502871908125356, 0.35820849708344205, 0.3514200913689707, 0.34466335351512156, 0.3379381357915676, 0.3312442911571427, 0.3245816732566267, 0.317950136417545, 0.3113495356469844, 0.30477972662842245, 0.2982405657185718, 0.2917319099442406, 0.28525361699920526, 0.2788055452411, 0.27238755368831935, 0.2659995020169361, 0.2596412505576331, 0.2533126602926494, 0.2470135928527406, 0.24074391051415422, 0.23450347619561795, 0.22829215345534237, 0.22210980648803802, 0.215956300121946, 0.209831499815883, 0.2037352716562988, 0.19766748235434917, 0.19162799924298102, 0.18561669027403283, 0.17963342401534566, 0.17367806964789123, 0.1677504969629109, 0.16185057635906897, 0.15597817883961884, 0.15013317600958276, 0.1443154400729445, 0.13852484382985564, 0.13276126067385374, 0.1270245645890946, 0.12131463014759669, 0.1156313325064997, 0.10997454740533374, 0.1043441511633032, 0.09874002067658294, 0.09316203341562512, 0.08761006742248245, 0.08208400130813964, 0.0765837142498611, 0.07110908598854748, 0.06565999682610801, 0.0602363276228417, 0.0548379597948343, 0.04946477531136395, 0.044116656692321676, 0.03879348700564167, 0.033495149864746, 0.02822152942599887, 0.022972510386173983, 0.01774797797993455, 0.012547817977321962, 0.007371916681260471, 0.002220160925069603, 0.0029075619300085176, 0.008011363997273868, 0.0130913568670179, 0.018147651608964477, 0.023180358774698595, 0.02818958840008201, 0.033175450007660645, 0.03813805260905867, 0.04307750470736105, 0.04799391429948785, 0.05288738887855349, 0.05775803543621816, 0.06260596046502642, 0.0674312699607369, 0.07223406942463728, 0.07701446386585431, 0.08177255780364612, 0.08650845526969109, 0.09122225981035914, 0.09591407448897837, 0.10058400188808603, 0.10523214411167381, 0.10985860278741844, 0.1144634790689042, 0.11904687363783473, 0.12360888670623493, 0.12814961801864044, 0.1326691668542802, 0.13716763202924576, 0.14164511189865225, 0.14610170435878977, 0.15053750684926226, 0.1549526163551187, 0.15934712940897378, 0.16372114209311817, 0.16807475004161976, 0.17240804844241353, 0.17672113203938378, 0.18101409513443578, 0.1852870315895565, 0.18954003482886783, 0.1937731978406686, 0.19798661317946809, 0.2021803729680095, 0.20635456889928416, 0.2105092922385362, 0.21464463382525822, 0.21876068407517713, 0.2228575329822312, 0.2269352701205377, 0.23099398464635157, 0.23503376530001407, 0.23905470040789356, 0.24305687788431696, 0.24704038523349092, 0.2510053095514161, 0.2549517375277909, 0.25887975544790653, 0.26278944919453484, 0.2666809042498044, 0.27055420569707045, 0.2744094382227755, 0.2782466861182997, 0.28206603328180546, 0.28586756322007023, 0.28965135905031303, 0.293417503502012, 0.2971660789187127, 0.30089716725982896, 0.30461085010243394, 0.30830720864304484, 0.31198632369939805, 0.315648275712215, 0.31929314474696247, 0.3229210104956022, 0.3265319522783333, 0.3301260490453274, 0.3337033793784536, 0.33726402149299717, 0.34080805323937025, 0.3443355521048127, 0.34784659521508765, 0.35134125933616656, 0.35481962087590846, 0.3582817558857305, 0.36172774006227026, 0.36515764874904133, 0.3685715569380802, 0.37196953927158605, 0.37535167004355274, 0.3787180232013937, 0.3820686723475578, 0.385403690741139, 0.3887231512994781, 0.3920271265997577, 0.39531568888058755, 0.39858891004358554, 0.40184686165494854, 0.405089614947018, 0.4083172408198369, 0.41152980984270016, 0.4147273922556971, 0.41791005797124825, 0.4210778765756328, 0.4242309173305103, 0.42736924917443564, 0.4304929407243654, 0.4336020602771591, 0.4366966758110715, 0.43977685498723973, 0.4428426651511619, 0.4458941733341698, 0.4489314462548951, 0.45195455032072707, 0.45496355162926505, 0.457958515969764, 0.460939508824572, 0.4639065953705628, 0.4668598404805602, 0.4697993087247574, 0.47272506437212736, 0.4756371713918296, 0.4785356934546072, 0.4814206939341804, 0.4842922359086309, 0.48715038216178186, 0.4899951951845708, 0.492826737176415, 0.4956450700465721, 0.4984502554154936, 0.5012423546161716, 0.5040214286954813, 0.5067875384155135, 0.509540744254905, 0.5122811064101602, 0.5150086847969668, 0.5177235390515071, 0.5204257285317604, 0.5231153123188015, 0.5257923492180928, 0.5284568977607693, 0.5311090162049191, 0.5337487625368565, 0.5363761944723899, 0.5389913694580845, 0.5415943446725169, 0.5441851770275269, 0.5467639231694605, 0.549330639480409, 0.5518853820794419, 0.5544282068238333, 0.5569591693102837, 0.5594783248761357, 0.5619857286005834, 0.5644814353058766, 0.5669654995585203, 0.5694379756704665, 0.5718989177003031, 0.5743483794544345, 0.576786414488259, 0.5792130761073391, 0.5816284173685673, 0.5840324910813266, 0.586425349808644, 0.5888070458683408, 0.5911776313341754, 0.5935371580369835, 0.5958856775658096, 0.598223241269036, 0.6005499002555053, 0.6028657053956372, 0.6051707073225421, 0.6074649564331267, 0.6097485028891967, 0.6120213966185534, 0.6142836873160852, 0.6165354244448542, 0.618776657237178, 0.6210074346957055, 0.6232278055944889, 0.6254378184800493, 0.6276375216724392, 0.6298269632662982, 0.6320061911319046, 0.6341752529162228, 0.6363341960439435, 0.6384830677185227, 0.640621914923212, 0.6427507844220863, 0.6448697227610671, 0.646978776268939, 0.6490779910583633, 0.6511674130268861, 0.6532470878579422, 0.6553170610218527, 0.6573773777768208, 0.6594280831699202, 0.66146922203808, 0.6635008390090661, 0.6655229785024557, 0.667535684730609, 0.6695390016996361, 0.6715329732103588, 0.6735176428592686, 0.6754930540394797, 0.6774592499416772, 0.6794162735550626, 0.6813641676682928, 0.6833029748704162, 0.6852327375518034, 0.6871534979050743, 0.6890652979260206, 0.6909681794145237, 0.6928621839754694, 0.6947473530196564, 0.6966237277647029, 0.698491349235947, 0.7003502582673435, 0.702200495502358, 0.7040421013948538, 0.7058751162099778, 0.7076995800250401, 0.70951553273039, 0.7113230140302897, 0.7131220634437803, 0.7149127203055474, 0.7166950237667804, 0.7184690127960287, 0.7202347261800539, 0.7219922025246777, 0.7237414802556252, 0.7254825976193671, 0.7272155926839531, 0.7289405033398471, 0.7306573673007533, 0.7323662221044424, 0.7340671051135712, 0.7357600535165005, 0.737445104328107, 0.7391222943905941, 0.7407916603742959, 0.7424532387784801, 0.7441070659321454, 0.745753177994816, 0.7473916109573324, 0.7490224006426378, 0.7506455827065619, 0.7522611926386003, 0.7538692657626898, 0.7554698372379818, 0.7570629420596107, 0.7586486150594585, 0.7602268909069166, 0.7617978041096445, 0.7633613890143234, 0.7649176798074073, 0.7664667105158712, 0.768008515007954, 0.7695431269938996, 0.7710705800266942, 0.7725909075027994, 0.7741041426628824, 0.7756103185925431, 0.7771094682230374, 0.778601624331997, 0.7800868195441462, 0.7815650863320154, 0.7830364570166506, 0.7845009637683205, 0.7859586386072199, 0.7874095134041696, 0.788853619881313, 0.7902909896128101, 0.7917216540255276, 0.7931456443997267, 0.7945629918697453, 0.7959737274246808, 0.7973778819090664, 0.7987754860235459, 0.8001665703255443, 0.8015511652299371, 0.8029293010097143, 0.8043010077966429, 0.805666315581925, 0.8070252542168544, 0.8083778534134687, 0.809724142745199, 0.8110641516475166, 0.8123979094185765, 0.8137254452198581, 0.8150467880768029, 0.8163619668794486, 0.8176710103830613, 0.818973947208764, 0.8202708058441622, 0.8215616146439673, 0.8228464018306159, 0.8241251954948869, 0.8253980235965168, 0.8266649139648091, 0.8279258942992447, 0.8291809921700859, 0.8304302350189805, 0.831673650159561, 0.8329112647780417, 0.834143105933814, 0.8353692005600375, 0.8365895754642279, 0.8378042573288449, 0.8390132727118744, 0.8402166480474097, 0.8414144096462292, 0.8426065836963712, 0.843793196263708, 0.8449742732925138, 0.8461498406060338, 0.8473199239070474, 0.8484845487784308, 0.8496437406837165, 0.8507975249676497, 0.8519459268567426, 0.8530889714598258, 0.8542266837685975, 0.8553590886581698, 0.8564862108876125, 0.8576080751004946, 0.8587247058254233, 0.8598361274765794, 0.8609423643542525, 0.862043440645371, 0.8631393804240314, 0.8642302076520252, 0.8653159461793621, 0.8663966197447915, 0.867472251976322, 0.8685428663917376, 0.8696084863991118, 0.8706691352973202, 0.8717248362765485, 0.8727756124188011, 0.8738214866984046, 0.874862481982511, 0.8758986210315965, 0.8769299264999606, 0.8779564209362201, 0.8789781267838027, 0.8799950663814382, 0.881007261963646, 0.8820147356612216, 0.8830175095017208, 0.8840156054099406, 0.8850090452083994, 0.8859978506178134, 0.8869820432575721, 0.8879616446462106, 0.88893667620188, 0.8899071592428163, 0.8908731149878056, 0.8918345645566491, 0.8927915289706237, 0.8937440291529428, 0.8946920859292125, 0.8956357200278882, 0.8965749520807268, 0.8975098026232384, 0.8984402920951354, 0.8993664408407784, 0.9002882691096223, 0.9012057970566583, 0.9021190447428544, 0.9030280321355949], \"type\": \"scatter\", \"uid\": \"045bcade-d09f-4c8c-be3a-bcf3d70d911e\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 4.458717434869739, 8.86743486973948, 13.27615230460922, 17.68486973947896, 22.0935871743487, 26.502304609218438, 30.911022044088178, 35.31973947895791, 39.72845691382766, 44.13717434869739, 48.54589178356713, 52.95460921843687, 57.363326653306615, 61.77204408817635, 66.18076152304609, 70.58947895791583, 74.99819639278557, 79.40691382765532, 83.81563126252505, 88.22434869739479, 92.63306613226453, 97.04178356713426, 101.450501002004, 105.85921843687375, 110.26793587174349, 114.67665330661323, 119.08537074148296, 123.4940881763527, 127.90280561122245, 132.3115230460922, 136.72024048096193, 141.12895791583168, 145.53767535070142, 149.94639278557116, 154.3551102204409, 158.76382765531065, 163.17254509018036, 167.5812625250501, 171.98997995991985, 176.3986973947896, 180.80741482965934, 185.21613226452908, 189.62484969939882, 194.03356713426854, 198.44228456913828, 202.85100200400802, 207.25971943887777, 211.6684368737475, 216.07715430861725, 220.485871743487, 224.89458917835674, 229.30330661322648, 233.7120240480962, 238.12074148296594, 242.52945891783568, 246.93817635270543, 251.34689378757517, 255.7556112224449, 260.1643286573146, 264.57304609218437, 268.9817635270541, 273.39048096192386, 277.7991983967936, 282.20791583166334, 286.6166332665331, 291.02535070140283, 295.4340681362726, 299.8427855711423, 304.25150300601206, 308.6602204408818, 313.06893787575154, 317.4776553106213, 321.886372745491, 326.2950901803607, 330.70380761523046, 335.1125250501002, 339.52124248496995, 343.9299599198397, 348.33867735470943, 352.7473947895792, 357.1561122244489, 361.56482965931866, 365.9735470941884, 370.38226452905815, 374.7909819639279, 379.19969939879763, 383.6084168336674, 388.01713426853706, 392.4258517034068, 396.83456913827655, 401.2432865731463, 405.65200400801604, 410.0607214428858, 414.4694388777555, 418.87815631262526, 423.286873747495, 427.69559118236475, 432.1043086172345, 436.51302605210424, 440.921743486974, 445.3304609218437, 449.73917835671347, 454.1478957915832, 458.55661322645295, 462.96533066132264, 467.3740480961924, 471.7827655310621, 476.19148296593187, 480.6002004008016, 485.00891783567135, 489.4176352705411, 493.82635270541084, 498.2350701402806, 502.6437875751503, 507.05250501002007, 511.4612224448898, 515.8699398797595, 520.2786573146292, 524.687374749499, 529.0960921843687, 533.5048096192385, 537.9135270541082, 542.322244488978, 546.7309619238476, 551.1396793587174, 555.5483967935871, 559.9571142284569, 564.3658316633266, 568.7745490981963, 573.1832665330661, 577.5919839679358, 582.0007014028056, 586.4094188376753, 590.8181362725451, 595.2268537074148, 599.6355711422846, 604.0442885771542, 608.453006012024, 612.8617234468937, 617.2704408817635, 621.6791583166332, 626.087875751503, 630.4965931863727, 634.9053106212425, 639.3140280561122, 643.7227454909819, 648.1314629258517, 652.5401803607214, 656.9488977955912, 661.3576152304609, 665.7663326653307, 670.1750501002003, 674.5837675350701, 678.9924849699398, 683.4012024048096, 687.8099198396793, 692.2186372745491, 696.6273547094188, 701.0360721442886, 705.4447895791583, 709.853507014028, 714.2622244488978, 718.6709418837675, 723.0796593186373, 727.4883767535069, 731.8970941883767, 736.3058116232464, 740.7145290581162, 745.1232464929859, 749.5319639278557, 753.9406813627254, 758.3493987975952, 762.7581162324649, 767.1668336673347, 771.5755511022044, 775.9842685370741, 780.3929859719439, 784.8017034068135, 789.2104208416833, 793.619138276553, 798.0278557114228, 802.4365731462925, 806.8452905811623, 811.254008016032, 815.6627254509018, 820.0714428857715, 824.4801603206413, 828.888877755511, 833.2975951903808, 837.7063126252505, 842.1150300601203, 846.52374749499, 850.9324649298596, 855.3411823647294, 859.7498997995991, 864.1586172344689, 868.5673346693386, 872.9760521042084, 877.3847695390781, 881.7934869739479, 886.2022044088176, 890.6109218436874, 895.0196392785571, 899.4283567134269, 903.8370741482966, 908.2457915831664, 912.654509018036, 917.0632264529058, 921.4719438877755, 925.8806613226452, 930.289378757515, 934.6980961923847, 939.1068136272545, 943.5155310621242, 947.924248496994, 952.3329659318637, 956.7416833667335, 961.1504008016032, 965.559118236473, 969.9678356713426, 974.3765531062124, 978.7852705410821, 983.1939879759519, 987.6027054108216, 992.0114228456913, 996.4201402805611, 1000.8288577154308, 1005.2375751503006, 1009.6462925851703, 1014.0550100200401, 1018.4637274549098, 1022.8724448897796, 1027.2811623246494, 1031.689879759519, 1036.0985971943887, 1040.5073146292584, 1044.9160320641283, 1049.324749498998, 1053.7334669338677, 1058.1421843687374, 1062.550901803607, 1066.959619238477, 1071.3683366733467, 1075.7770541082164, 1080.185771543086, 1084.594488977956, 1089.0032064128256, 1093.4119238476953, 1097.820641282565, 1102.229358717435, 1106.6380761523046, 1111.0467935871743, 1115.455511022044, 1119.864228456914, 1124.2729458917836, 1128.6816633266533, 1133.090380761523, 1137.4990981963927, 1141.9078156312626, 1146.3165330661323, 1150.725250501002, 1155.1339679358716, 1159.5426853707415, 1163.9514028056112, 1168.360120240481, 1172.7688376753506, 1177.1775551102205, 1181.5862725450902, 1185.9949899799599, 1190.4037074148296, 1194.8124248496995, 1199.2211422845692, 1203.6298597194389, 1208.0385771543085, 1212.4472945891782, 1216.8560120240481, 1221.2647294589178, 1225.6734468937875, 1230.0821643286572, 1234.490881763527, 1238.8995991983968, 1243.3083166332665, 1247.7170340681362, 1252.125751503006, 1256.5344689378758, 1260.9431863727455, 1265.3519038076151, 1269.760621242485, 1274.1693386773547, 1278.5780561122244, 1282.9867735470941, 1287.3954909819638, 1291.8042084168337, 1296.2129258517034, 1300.621643286573, 1305.0303607214428, 1309.4390781563127, 1313.8477955911824, 1318.256513026052, 1322.6652304609217, 1327.0739478957917, 1331.4826653306613, 1335.891382765531, 1340.3001002004007, 1344.7088176352704, 1349.1175350701403, 1353.52625250501, 1357.9349699398797, 1362.3436873747494, 1366.7524048096193, 1371.161122244489, 1375.5698396793587, 1379.9785571142284, 1384.3872745490983, 1388.795991983968, 1393.2047094188376, 1397.6134268537073, 1402.0221442885772, 1406.430861723447, 1410.8395791583166, 1415.2482965931863, 1419.657014028056, 1424.065731462926, 1428.4744488977956, 1432.8831663326653, 1437.291883767535, 1441.7006012024049, 1446.1093186372746, 1450.5180360721442, 1454.926753507014, 1459.3354709418838, 1463.7441883767535, 1468.1529058116232, 1472.561623246493, 1476.9703406813628, 1481.3790581162325, 1485.7877755511022, 1490.1964929859719, 1494.6052104208416, 1499.0139278557115, 1503.4226452905812, 1507.8313627254508, 1512.2400801603205, 1516.6487975951904, 1521.0575150300601, 1525.4662324649298, 1529.8749498997995, 1534.2836673346694, 1538.692384769539, 1543.1011022044088, 1547.5098196392785, 1551.9185370741482, 1556.327254509018, 1560.7359719438878, 1565.1446893787574, 1569.5534068136271, 1573.962124248497, 1578.3708416833667, 1582.7795591182364, 1587.188276553106, 1591.596993987976, 1596.0057114228457, 1600.4144288577154, 1604.823146292585, 1609.231863727455, 1613.6405811623247, 1618.0492985971944, 1622.458016032064, 1626.8667334669337, 1631.2754509018037, 1635.6841683366733, 1640.092885771543, 1644.5016032064127, 1648.9103206412826, 1653.3190380761523, 1657.727755511022, 1662.1364729458917, 1666.5451903807616, 1670.9539078156313, 1675.362625250501, 1679.7713426853707, 1684.1800601202406, 1688.5887775551103, 1692.99749498998, 1697.4062124248496, 1701.8149298597193, 1706.2236472945892, 1710.632364729459, 1715.0410821643286, 1719.4497995991983, 1723.8585170340682, 1728.2672344689379, 1732.6759519038076, 1737.0846693386773, 1741.4933867735472, 1745.9021042084169, 1750.3108216432865, 1754.7195390781562, 1759.1282565130261, 1763.5369739478958, 1767.9456913827655, 1772.3544088176352, 1776.763126252505, 1781.1718436873748, 1785.5805611222445, 1789.9892785571142, 1794.3979959919839, 1798.8067134268538, 1803.2154308617235, 1807.6241482965931, 1812.0328657314628, 1816.4415831663327, 1820.8503006012024, 1825.2590180360721, 1829.6677354709418, 1834.0764529058117, 1838.4851703406814, 1842.893887775551, 1847.3026052104208, 1851.7113226452905, 1856.1200400801604, 1860.52875751503, 1864.9374749498998, 1869.3461923847694, 1873.7549098196394, 1878.163627254509, 1882.5723446893787, 1886.9810621242484, 1891.3897795591183, 1895.798496993988, 1900.2072144288577, 1904.6159318637274, 1909.024649298597, 1913.433366733467, 1917.8420841683367, 1922.2508016032064, 1926.659519038076, 1931.068236472946, 1935.4769539078156, 1939.8856713426853, 1944.294388777555, 1948.703106212425, 1953.1118236472946, 1957.5205410821643, 1961.929258517034, 1966.337975951904, 1970.7466933867736, 1975.1554108216433, 1979.564128256513, 1983.9728456913826, 1988.3815631262526, 1992.7902805611222, 1997.198997995992, 2001.6077154308616, 2006.0164328657315, 2010.4251503006012, 2014.833867735471, 2019.2425851703406, 2023.6513026052105, 2028.0600200400802, 2032.4687374749499, 2036.8774549098196, 2041.2861723446895, 2045.6948897795592, 2050.103607214429, 2054.512324649299, 2058.9210420841687, 2063.3297595190384, 2067.738476953908, 2072.1471943887777, 2076.5559118236474, 2080.964629258517, 2085.373346693387, 2089.782064128257, 2094.1907815631266, 2098.5994989979963, 2103.008216432866, 2107.4169338677357, 2111.8256513026054, 2116.234368737475, 2120.6430861723447, 2125.0518036072144, 2129.4605210420846, 2133.8692384769543, 2138.277955911824, 2142.6866733466936, 2147.0953907815633, 2151.504108216433, 2155.9128256513027, 2160.3215430861724, 2164.7302605210425, 2169.138977955912, 2173.547695390782, 2177.9564128256516, 2182.3651302605213, 2186.773847695391, 2191.1825651302606, 2195.5912825651303, 2200.0], \"y\": [0.9131145625013224, 0.90334191248827, 0.8936170174723381, 0.8839396440941263, 0.8743095601345667, 0.8647265345093529, 0.8551903372633942, 0.8457007395652973, 0.8362575137018762, 0.8268604330726865, 0.8175092721845896, 0.8082038066463402, 0.798943813163203, 0.7897290695315933, 0.7805593546337464, 0.7714344484324105, 0.7623541319655669, 0.7533181873411763, 0.7443263977319499, 0.7353785473701457, 0.7264744215423926, 0.7176138065845361, 0.7087964898765131, 0.7000222598372481, 0.6912909059195778, 0.682602218605197, 0.6739559893996327, 0.6653520108272399, 0.6567900764262236, 0.6482699807436838, 0.6397915193306862, 0.6313544887373561, 0.6229586865079961, 0.6146039111762283, 0.606289962260159, 0.5980166402575691, 0.5897837466411269, 0.5815910838536227, 0.5734384553032295, 0.5653256653587855, 0.557252519345099, 0.549218823538278, 0.5412243851610803, 0.5332690123782888, 0.5253525142921074, 0.5174747009375809, 0.5096353832780354, 0.5018343732005439, 0.4940714835114106, 0.4863465279316803, 0.4786593210926675, 0.471009678531509, 0.46339741668673673, 0.45582235289387385, 0.448284305381051, 0.4407830932646446, 0.4333185365449359, 0.4258904561017931, 0.4184986736903713, 0.4111430119368369, 0.40382329433411, 0.39653934523763, 0.3892909898611405, 0.3820780542724944, 0.3749003653894818, 0.36775775097567465, 0.3606500396362955, 0.3535770608141038, 0.3465386447853036, 0.3395346226554703, 0.33256482635549833, 0.32562908863756834, 0.318727243071133, 0.3118591240389246, 0.3050245667329796, 0.2982234071506846, 0.29145548209084104, 0.2847206291497486, 0.27801868671730845, 0.2713494939731447, 0.2647128908827461, 0.25810871819362546, 0.251536817431498, 0.24499703089647928, 0.2384892016593001, 0.23201317355754125, 0.22556879119188666, 0.2191558999223937, 0.21277434586478305, 0.20642397588674521, 0.200104637604267, 0.19381617937797424, 0.18755845030949292, 0.18133130023782917, 0.1751345797357644, 0.16896814010627148, 0.1628318333789449, 0.15672551230645126, 0.1506490303609953, 0.14460224173080394, 0.13858500131662743, 0.13259716472825733, 0.12663858828106234, 0.12070912899253972, 0.11480864457888407, 0.10893699345157448, 0.10309403471397505, 0.09727962815795554, 0.09149363426052592, 0.0857359141804892, 0.08000632975510835, 0.07430474349679295, 0.06863101858979825, 0.06298501888694297, 0.057366608906342265, 0.051775653828157076, 0.04621201949135734, 0.04067557239050479, 0.03516617967254798, 0.029683709133634606, 0.024228029215939806, 0.018799009004507816, 0.013396518224112253, 0.008020427236129057, 0.00267060703542521, 0.0026530707527354647, 0.007950733875774052, 0.013222509456861653, 0.018468523997969388, 0.023688903382904636, 0.02888377288033106, 0.034053257146775096, 0.03919748022961711, 0.04431656557006791, 0.049410636006130826, 0.05447981377554911, 0.059524220518740734, 0.06454397728171446, 0.0695392045189771, 0.07451002209642255, 0.07945654929420831, 0.08437890480961796, 0.08927720675990991, 0.09415157268515018, 0.09900211955103477, 0.10382896375169504, 0.10863222111249138, 0.11341200689279252, 0.11816843578874081, 0.12290162193600529, 0.12761167891251934, 0.13229871974120777, 0.13696285689269705, 0.14160420228801573, 0.14622286730127898, 0.15081896276236217, 0.15539259895955904, 0.15994388564222983, 0.16447293202343305, 0.16897984678254774, 0.17346473806788032, 0.17792771349926018, 0.18236888017062214, 0.186788344652576, 0.19118621299496386, 0.19556259072940552, 0.19991758287182992, 0.20425129392499564, 0.2085638278809987, 0.21285528822376698, 0.21712577793154508, 0.2213753994793639, 0.2256042548415006, 0.22981244549392454, 0.2340000724167337, 0.23816723609657664, 0.24231403652906436, 0.24644057322116986, 0.250546945193615, 0.2546332509832483, 0.25869958864540776, 0.26274605575627485, 0.26677274941521534, 0.27077976624710987, 0.274767202404672, 0.2787351535707563, 0.28268371496065303, 0.2866129813243745, 0.2905230469489273, 0.2944140056605762, 0.2982859508270943, 0.3021389753600042, 0.3059731717168074, 0.30978863190320294, 0.31358544747529526, 0.3173637095417907, 0.3211235087661847, 0.3248649353689359, 0.32858807912963295, 0.33229302938914707, 0.3359798750517774, 0.33964870458738283, 0.3432996060335066, 0.34693266699748737, 0.35054797465856247, 0.3541456157699592, 0.357725676660977, 0.36128824323905895, 0.364833400991853, 0.3683612349892631, 0.3718718298854916, 0.37536526992106967, 0.37884163892487877, 0.38230102031616253, 0.38574349710652855, 0.3891691519019401, 0.39257806690469843, 0.3959703239154154, 0.39934600433497636, 0.402705189166493, 0.40604795901724755, 0.4093743941006277, 0.4126845742380497, 0.4159785788608755, 0.41925648701231766, 0.42251837734933617, 0.42576432814452714, 0.42899441728799903, 0.4322087222892437, 0.4354073202789943, 0.4385902880110786, 0.4417577018642581, 0.4449096378440629, 0.44804617158461435, 0.4511673783504405, 0.4542733330382822, 0.45736411017889, 0.4604397839388126, 0.46350042812217696, 0.46654611617245867, 0.4695769211742451, 0.47259291585498886, 0.4755941725867524, 0.4785807633879451, 0.48155275992505175, 0.48451023351435174, 0.4874532551236309, 0.49038189537388355, 0.4932962245410083, 0.4961963125574932, 0.49908222901409527, 0.5019540431615087, 0.504811823912028, 0.507655639841201, 0.5104855591894747, 0.5133016498638319, 0.5161039794394223, 0.5188926151611822, 0.5216676239454499, 0.52442907238157, 0.5271770267334918, 0.5299115529413598, 0.5326327166230952, 0.5353405830759717, 0.53803521727818, 0.5407166838903904, 0.5433850472573016, 0.5460403714091858, 0.5486827200634252, 0.551312156626041, 0.5539287441932146, 0.5565325455528018, 0.5591236231858395, 0.5617020392680451, 0.5642678556713083, 0.5668211339651757, 0.5693619354183289, 0.5718903210000531, 0.5744063513817024, 0.5769100869381538, 0.5794015877492568, 0.5818809136012749, 0.5843481239883201, 0.5868032781137811, 0.5892464348917434, 0.5916776529484027, 0.5940969906234725, 0.5965045059715837, 0.5989002567636774, 0.6012843004883919, 0.6036566943534412, 0.6060174952869886, 0.6083667599390119, 0.6107045446826644, 0.6130309056156256, 0.6153458985614485, 0.6176495790708991, 0.6199420024232891, 0.6222232236278024, 0.6244932974248155, 0.6267522782872106, 0.6290002204216829, 0.6312371777700414, 0.633463204010503, 0.6356783525589813, 0.6378826765703676, 0.6400762289398068, 0.642259062303966, 0.6444312290422991, 0.6465927812783021, 0.6487437708807648, 0.6508842494650151, 0.6530142683941571, 0.6551338787803052, 0.6572431314858087, 0.6593420771244731, 0.6614307660627751, 0.6635092484210706, 0.6655775740747976, 0.6676357926556725, 0.6696839535528821, 0.671722105914268, 0.6737502986475061, 0.6757685804212801, 0.6777769996664498, 0.6797756045772123, 0.68176444311226, 0.6837435629959299, 0.6857130117193495, 0.6876728365415765, 0.6896230844907324, 0.6915638023651317, 0.6934950367344038, 0.6954168339406116, 0.6973292400993629, 0.6992323011009172, 0.7011260626112864, 0.7030105700733318, 0.7048858687078527, 0.7067520035146742, 0.7086090192737236, 0.7104569605461077, 0.7122958716751815, 0.7141257967876112, 0.7159467797944343, 0.7177588643921121, 0.7195620940635796, 0.7213565120792884, 0.723142161498244, 0.7249190851690405, 0.7266873257308881, 0.7284469256146364, 0.7301979270437928, 0.731940372035535, 0.7336743024017198, 0.7353997597498867, 0.7371167854842555, 0.7388254208067206, 0.7405257067178392, 0.7422176840178155, 0.7439013933074792, 0.7455768749892604, 0.747244169268159, 0.7489033161527088, 0.7505543554559384, 0.7521973267963263, 0.7538322695987512, 0.7554592230954382, 0.7570782263269009, 0.7586893181428771, 0.7602925372032621, 0.7618879219790351, 0.7634755107531843, 0.7650553416216235, 0.7666274524941075, 0.768191881095141, 0.7697486649648849, 0.7712978414600562, 0.7728394477548247, 0.7743735208417049, 0.7759000975324438, 0.7774192144589046, 0.7789309080739452, 0.7804352146522927, 0.7819321702914148, 0.7834218109123853, 0.7849041722607459, 0.7863792899073647, 0.787847199249289, 0.789307935510595, 0.7907615337432334, 0.7922080288278699, 0.7936474554747224, 0.7950798482243941, 0.7965052414487022, 0.7979236693515027, 0.7993351659695112, 0.8007397651731192, 0.802137500667208, 0.8035284059919563, 0.8049125145236453, 0.8062898594754602, 0.8076604738982865, 0.8090243906815036, 0.8103816425537734, 0.8117322620838265, 0.8130762816812427, 0.8144137335972298, 0.8157446499253966, 0.8170690626025237, 0.818387003409329, 0.8196985039712317, 0.8210035957591095, 0.822302310090055, 0.8235946781281269, 0.8248807308850975, 0.8261604992211973, 0.8274340138458549, 0.8287013053184349, 0.8299624040489701, 0.8312173402988923, 0.8324661441817571, 0.8337088456639681, 0.8349454745654946, 0.8361760605605881, 0.837400633178494, 0.8386192218041599, 0.8398318556789411, 0.8410385639013025, 0.8422393754275164, 0.843434319072357, 0.8446234235097931, 0.8458067172736751, 0.8469842287584196, 0.8481559862196918, 0.8493220177750822, 0.8504823514047827, 0.8516370149522564, 0.8527860361249076, 0.8539294424947449, 0.855067261499044, 0.8561995204410058, 0.8573262464904113, 0.8584474666842737, 0.8595632079274873, 0.860673496993473, 0.861778360524821, 0.8628778250339295, 0.8639719169036417, 0.8650606623878785, 0.8661440876122679, 0.8672222185747733, 0.868295081146316, 0.8693627010713968, 0.8704251039687133, 0.8714823153317752, 0.8725343605295154, 0.873581264806899, 0.8746230532855295, 0.875659750964251, 0.8766913827197483, 0.8777179733071443, 0.8787395473605928, 0.8797561293938713, 0.8807677438009679, 0.881774414856667, 0.8827761667171323, 0.8837730234204859, 0.8847650088873852, 0.8857521469215972, 0.8867344612105692, 0.8877119753259979, 0.8886847127243944, 0.8896526967476472, 0.8906159506235828, 0.8915744974665221, 0.8925283602778359, 0.893477561946497, 0.8944221252496283, 0.8953620728530507, 0.896297427311826, 0.8972282110707989, 0.8981544464651345, 0.899076155720856, 0.8999933609553759, 0.9009060841780284, 0.9018143472905971, 0.9027181720878401, 0.9036175802580134, 0.9045125933833915, 0.9054032329407846, 0.9062895203020547, 0.9071714767346278, 0.908049123402005, 0.90892248136427, 0.9097915715785936, 0.910656414899738, 0.9115170320805567, 0.9123734437724917, 0.9132256705260707], \"type\": \"scatter\", \"uid\": \"360ca871-42c6-4e40-b9d9-8f3de93c4ff4\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 4.6591182364729455, 9.268236472945892, 13.877354709418839, 18.486472945891784, 23.09559118236473, 27.704709418837677, 32.31382765531062, 36.92294589178356, 41.53206412825651, 46.14118236472945, 50.7503006012024, 55.35941883767535, 59.968537074148294, 64.57765531062124, 69.18677354709418, 73.79589178356713, 78.40501002004008, 83.01412825651302, 87.62324649298597, 92.23236472945891, 96.84148296593186, 101.4506012024048, 106.05971943887775, 110.6688376753507, 115.27795591182364, 119.88707414829659, 124.49619238476953, 129.1053106212425, 133.71442885771543, 138.32354709418837, 142.93266533066134, 147.54178356713427, 152.1509018036072, 156.76002004008018, 161.36913827655312, 165.97825651302605, 170.587374749499, 175.19649298597196, 179.8056112224449, 184.41472945891783, 189.0238476953908, 193.63296593186374, 198.24208416833667, 202.8512024048096, 207.46032064128258, 212.06943887775552, 216.67855711422845, 221.28767535070142, 225.89679358717436, 230.5059118236473, 235.11503006012023, 239.7241482965932, 244.33326653306614, 248.94238476953907, 253.551503006012, 258.160621242485, 262.76973947895794, 267.37885771543085, 271.9879759519038, 276.59709418837673, 281.2062124248497, 285.81533066132266, 290.42444889779557, 295.03356713426854, 299.6426853707415, 304.2518036072144, 308.8609218436874, 313.47004008016035, 318.07915831663325, 322.6882765531062, 327.29739478957913, 331.9065130260521, 336.51563126252506, 341.12474949899797, 345.73386773547094, 350.3429859719439, 354.9521042084168, 359.5612224448898, 364.17034068136275, 368.77945891783565, 373.3885771543086, 377.9976953907816, 382.6068136272545, 387.21593186372746, 391.8250501002004, 396.43416833667334, 401.0432865731463, 405.6524048096192, 410.2615230460922, 414.87064128256515, 419.47975951903805, 424.088877755511, 428.697995991984, 433.3071142284569, 437.91623246492986, 442.52535070140283, 447.13446893787574, 451.7435871743487, 456.3527054108216, 460.9618236472946, 465.57094188376755, 470.18006012024046, 474.7891783567134, 479.3982965931864, 484.0074148296593, 488.61653306613226, 493.22565130260523, 497.83476953907814, 502.4438877755511, 507.053006012024, 511.662124248497, 516.2712424849699, 520.8803607214428, 525.4894789579158, 530.0985971943887, 534.7077154308616, 539.3168336673345, 543.9259519038076, 548.5350701402805, 553.1441883767534, 557.7533066132264, 562.3624248496993, 566.9715430861722, 571.5806613226453, 576.1897795591182, 580.7988977955911, 585.4080160320641, 590.017134268537, 594.6262525050099, 599.2353707414829, 603.8444889779558, 608.4536072144288, 613.0627254509018, 617.6718436873747, 622.2809619238476, 626.8900801603206, 631.4991983967935, 636.1083166332664, 640.7174348697395, 645.3265531062124, 649.9356713426853, 654.5447895791582, 659.1539078156312, 663.7630260521041, 668.372144288577, 672.98126252505, 677.590380761523, 682.1994989979959, 686.8086172344689, 691.4177354709418, 696.0268537074147, 700.6359719438877, 705.2450901803606, 709.8542084168336, 714.4633266533066, 719.0724448897795, 723.6815631262524, 728.2906813627254, 732.8997995991983, 737.5089178356712, 742.1180360721443, 746.7271543086172, 751.3362725450901, 755.9453907815631, 760.554509018036, 765.1636272545089, 769.7727454909818, 774.3818637274549, 778.9909819639278, 783.6001002004007, 788.2092184368737, 792.8183366733466, 797.4274549098195, 802.0365731462925, 806.6456913827654, 811.2548096192384, 815.8639278557114, 820.4730460921843, 825.0821643286572, 829.6912825651302, 834.3004008016031, 838.909519038076, 843.5186372745491, 848.127755511022, 852.7368737474949, 857.3459919839679, 861.9551102204408, 866.5642284569137, 871.1733466933867, 875.7824649298597, 880.3915831663326, 885.0007014028056, 889.6098196392785, 894.2189378757514, 898.8280561122243, 903.4371743486973, 908.0462925851702, 912.6554108216432, 917.2645290581162, 921.8736472945891, 926.482765531062, 931.091883767535, 935.7010020040079, 940.3101202404808, 944.9192384769539, 949.5283567134268, 954.1374749498997, 958.7465931863727, 963.3557114228456, 967.9648296593185, 972.5739478957915, 977.1830661322645, 981.7921843687374, 986.4013026052104, 991.0104208416833, 995.6195390781562, 1000.2286573146292, 1004.8377755511021, 1009.446893787575, 1014.056012024048, 1018.665130260521, 1023.2742484969939, 1027.8833667334668, 1032.4924849699398, 1037.1016032064128, 1041.7107214428856, 1046.3198396793587, 1050.9289579158317, 1055.5380761523045, 1060.1471943887775, 1064.7563126252503, 1069.3654308617233, 1073.9745490981963, 1078.5836673346691, 1083.1927855711422, 1087.8019038076152, 1092.411022044088, 1097.020140280561, 1101.629258517034, 1106.2383767535068, 1110.8474949899799, 1115.4566132264529, 1120.0657314629257, 1124.6748496993987, 1129.2839679358717, 1133.8930861723445, 1138.5022044088175, 1143.1113226452906, 1147.7204408817634, 1152.3295591182364, 1156.9386773547094, 1161.5477955911822, 1166.1569138276552, 1170.7660320641282, 1175.375150300601, 1179.984268537074, 1184.593386773547, 1189.2025050100199, 1193.811623246493, 1198.420741482966, 1203.0298597194387, 1207.6389779559117, 1212.2480961923848, 1216.8572144288576, 1221.4663326653306, 1226.0754509018036, 1230.6845691382764, 1235.2936873747494, 1239.9028056112224, 1244.5119238476952, 1249.1210420841683, 1253.7301603206413, 1258.339278557114, 1262.948396793587, 1267.5575150300601, 1272.166633266533, 1276.775751503006, 1281.384869739479, 1285.9939879759518, 1290.6031062124248, 1295.2122244488978, 1299.8213426853706, 1304.4304609218436, 1309.0395791583164, 1313.6486973947895, 1318.2578156312625, 1322.8669338677353, 1327.4760521042083, 1332.0851703406813, 1336.694288577154, 1341.3034068136271, 1345.9125250501002, 1350.521643286573, 1355.130761523046, 1359.739879759519, 1364.3489979959918, 1368.9581162324648, 1373.5672344689378, 1378.1763527054106, 1382.7854709418837, 1387.3945891783567, 1392.0037074148295, 1396.6128256513025, 1401.2219438877755, 1405.8310621242483, 1410.4401803607213, 1415.0492985971944, 1419.6584168336672, 1424.2675350701402, 1428.8766533066132, 1433.485771543086, 1438.094889779559, 1442.704008016032, 1447.3131262525048, 1451.9222444889779, 1456.531362725451, 1461.1404809619237, 1465.7495991983967, 1470.3587174348697, 1474.9678356713425, 1479.5769539078156, 1484.1860721442886, 1488.7951903807614, 1493.4043086172344, 1498.0134268537074, 1502.6225450901802, 1507.2316633266532, 1511.8407815631263, 1516.449899799599, 1521.059018036072, 1525.668136272545, 1530.277254509018, 1534.886372745491, 1539.4954909819637, 1544.1046092184367, 1548.7137274549098, 1553.3228456913826, 1557.9319639278556, 1562.5410821643286, 1567.1502004008014, 1571.7593186372744, 1576.3684368737474, 1580.9775551102202, 1585.5866733466933, 1590.1957915831663, 1594.804909819639, 1599.414028056112, 1604.0231462925851, 1608.632264529058, 1613.241382765531, 1617.850501002004, 1622.4596192384768, 1627.0687374749498, 1631.6778557114228, 1636.2869739478956, 1640.8960921843686, 1645.5052104208416, 1650.1143286573144, 1654.7234468937875, 1659.3325651302605, 1663.9416833667333, 1668.5508016032063, 1673.1599198396793, 1677.7690380761521, 1682.3781563126252, 1686.9872745490982, 1691.596392785571, 1696.205511022044, 1700.814629258517, 1705.4237474949898, 1710.0328657314628, 1714.6419839679359, 1719.2511022044087, 1723.8602204408817, 1728.4693386773547, 1733.0784569138275, 1737.6875751503005, 1742.2966933867735, 1746.9058116232463, 1751.5149298597194, 1756.1240480961924, 1760.7331663326652, 1765.3422845691382, 1769.9514028056112, 1774.560521042084, 1779.169639278557, 1783.7787575150298, 1788.3878757515029, 1792.9969939879759, 1797.6061122244487, 1802.2152304609217, 1806.8243486973947, 1811.4334669338675, 1816.0425851703405, 1820.6517034068136, 1825.2608216432864, 1829.8699398797594, 1834.4790581162324, 1839.0881763527052, 1843.6972945891782, 1848.3064128256513, 1852.915531062124, 1857.524649298597, 1862.13376753507, 1866.742885771543, 1871.352004008016, 1875.961122244489, 1880.5702404809617, 1885.1793587174348, 1889.7884769539078, 1894.3975951903806, 1899.0067134268536, 1903.6158316633266, 1908.2249498997994, 1912.8340681362724, 1917.4431863727455, 1922.0523046092183, 1926.6614228456913, 1931.2705410821643, 1935.879659318637, 1940.4887775551101, 1945.0978957915831, 1949.707014028056, 1954.316132264529, 1958.925250501002, 1963.5343687374748, 1968.1434869739478, 1972.7526052104208, 1977.3617234468936, 1981.9708416833666, 1986.5799599198397, 1991.1890781563125, 1995.7981963927855, 2000.4073146292585, 2005.0164328657313, 2009.6255511022043, 2014.2346693386771, 2018.8437875751501, 2023.4529058116232, 2028.062024048096, 2032.671142284569, 2037.280260521042, 2041.8893787575148, 2046.4984969939878, 2051.107615230461, 2055.716733466934, 2060.325851703407, 2064.93496993988, 2069.544088176353, 2074.153206412826, 2078.7623246492985, 2083.3714428857716, 2087.9805611222446, 2092.5896793587176, 2097.1987975951906, 2101.8079158316636, 2106.417034068136, 2111.0261523046092, 2115.6352705410823, 2120.2443887775553, 2124.8535070140283, 2129.462625250501, 2134.071743486974, 2138.680861723447, 2143.28997995992, 2147.899098196393, 2152.508216432866, 2157.1173346693386, 2161.7264529058116, 2166.3355711422846, 2170.9446893787576, 2175.5538076152307, 2180.1629258517037, 2184.7720440881762, 2189.3811623246493, 2193.9902805611223, 2198.5993987975953, 2203.2085170340683, 2207.8176352705414, 2212.426753507014, 2217.035871743487, 2221.64498997996, 2226.254108216433, 2230.863226452906, 2235.472344689379, 2240.0814629258516, 2244.6905811623246, 2249.2996993987977, 2253.9088176352707, 2258.5179358717437, 2263.1270541082167, 2267.7361723446893, 2272.3452905811623, 2276.9544088176353, 2281.5635270541084, 2286.1726452905814, 2290.7817635270544, 2295.390881763527, 2300.0], \"y\": [0.9222398102717757, 0.9120240752684661, 0.9018605237849893, 0.8917488892600318, 0.8816889064939153, 0.8716803116416418, 0.8617228422059737, 0.8518162370305484, 0.8419602362930299, 0.832154581498294, 0.8223990154716487, 0.8126932823520892, 0.803037127585587, 0.7934302979184149, 0.7838725413905034, 0.7743636073288334, 0.7649032463408616, 0.7554912103079792, 0.7461272523790052, 0.7368111269637116, 0.7275425897263825, 0.7183213975794054, 0.7091473086768965, 0.7000200824083576, 0.6909394793923644, 0.6819052614702905, 0.6729171917000585, 0.6639750343499273, 0.6550785548923101, 0.6462275199976213, 0.6374216975281588, 0.6286608565320146, 0.6199447672370184, 0.6112732010447106, 0.6026459305243472, 0.5940627294069352, 0.585523372579297, 0.5770276360781679, 0.568575297084321, 0.5601661339167243, 0.5517999260267255, 0.5434764539922683, 0.5351954995121377, 0.526956845400234, 0.518760275579877, 0.5106055750781393, 0.502492530020207, 0.4944209276237719, 0.4863905561934492, 0.4784012051152269, 0.47045266485094084, 0.4625447269327796, 0.45467718395781676, 0.4468498295825716, 0.43906245851759707, 0.4313148665220954, 0.42360685039856216, 0.4159382079874563, 0.40830873816189817, 0.4007182408223948, 0.3931665168915919, 0.38565336830905195, 0.37817859802606035, 0.37074201000045703, 0.36334340919149555, 0.35598260155472583, 0.3486593940369076, 0.34137359457094485, 0.33412501207084944, 0.32691345642673, 0.3197387384998045, 0.31260067011744086, 0.3054990640682207, 0.29843373409703067, 0.2914044949001764, 0.28441116212052253, 0.2774535523426582, 0.2705314830880863, 0.26364477281043674, 0.25679324089070676, 0.24997670763252233, 0.2431949942574254, 0.23644792290018568, 0.2297353166041356, 0.22305699931652834, 0.21641279588392193, 0.2098025320475838, 0.2032260344389223, 0.19668313057493814, 0.19017364885370114, 0.18369741854985056, 0.1772542698101156, 0.17084403364886258, 0.16446654194366173, 0.15812162743087743, 0.15180912370128286, 0.1455288651956943, 0.13928068720062958, 0.1330644258439877, 0.1268799180907514, 0.12072700173871054, 0.11460551541420871, 0.10851529856791076, 0.10245619147059126, 0.0964280352089466, 0.09043067168142538, 0.08446394359408371, 0.07852769445645857, 0.07262176857746372, 0.06674601106130718, 0.06090026780342761, 0.05508438548645289, 0.04929821157617953, 0.04354159431757232, 0.037814382730782414, 0.03211642660719072, 0.026447576505464587, 0.020807683747641414, 0.015196600415227746, 0.009614179345320606, 0.004060274126747254, 0.0014652609037755226, 0.006962570665459467, 0.012431799337248028, 0.017873090361596455, 0.023286586448234114, 0.02867242957790772, 0.03403076100610525, 0.039361721266759186, 0.04466545017593426, 0.04994208683549339, 0.0551917696367461, 0.06041463626407828, 0.06561082369856308, 0.0707804682215536, 0.07592370541825688, 0.08104067018129102, 0.08613149671422105, 0.09119631853508092, 0.09623526847987407, 0.10124847870605691, 0.10623608069600621, 0.11119820526046664, 0.11613498254198185, 0.12104654201830767, 0.1259330125058079, 0.13079452216283305, 0.13563119849308103, 0.140443168348942, 0.14523055793482453, 0.14999349281046637, 0.15473209789422682, 0.15944649746636363, 0.16413681517229173, 0.16880317402582667, 0.17344569641241148, 0.178064504092325, 0.1826597182038764, 0.18723145926658236, 0.19177984718432717, 0.19630500124850814, 0.20080704014116424, 0.2052860819380884, 0.20974224411192466, 0.2141756435352491, 0.21858639648363454, 0.22297461863870105, 0.2273404250911495, 0.23168393034378, 0.23600524831449465, 0.2403044923392862, 0.24458177517520963, 0.24883720900333994, 0.2530709054317143, 0.2572829754982593, 0.2614735296737025, 0.2656426778644707, 0.269790529415572, 0.2739171931134633, 0.27802277718890445, 0.2821073893197956, 0.2861711366340023, 0.29021412571216443, 0.2942364625904922, 0.2982382527635463, 0.30221960118700597, 0.3061806122804205, 0.3101213899299482, 0.3140420374910814, 0.3179426577913571, 0.3218233531330531, 0.3256842252958724, 0.3295253755396116, 0.3333469046068166, 0.3371489127254256, 0.340931499611397, 0.34469476447132563, 0.34843880600504284, 0.3521637224082075, 0.3558696113748797, 0.35955657010008346, 0.3632246952823558, 0.36687408312628333, 0.37050482934502493, 0.37411702916282197, 0.37771077731749636, 0.38128616806293447, 0.38484329517156013, 0.3883822519367929, 0.39190313117549547, 0.39540602523040835, 0.3988910259725711, 0.4023582248037323, 0.40580771265874593, 0.409239580007958, 0.4126539168595774, 0.41605081276203826, 0.419430356806347, 0.42279263762842, 0.4261377434114083, 0.42946576188800956, 0.43277678034277, 0.43607088561437257, 0.4393481640979159, 0.4426087017471787, 0.4458525840768751, 0.44907989616489685, 0.4522907226545456, 0.45548514775675153, 0.4586632552522827, 0.46182512849394297, 0.46497085040875663, 0.46810050350014487, 0.47121416985008857, 0.4743119311212812, 0.4773938685592717, 0.48046006299459343, 0.4835105948448857, 0.48654554411700246, 0.4895649904091103, 0.4925690129127762, 0.49555769041504527, 0.4985311013005056, 0.5014893235533454, 0.5044324347593983, 0.5073605121081767, 0.5102736323948981, 0.5131718720224984, 0.5160553070036353, 0.5189240129626824, 0.5217780651377132, 0.5246175383824732, 0.5274425071683433, 0.5302530455862942, 0.5330492273488281, 0.5358311257919126, 0.5385988138769044, 0.5413523641924625, 0.5440918489564516, 0.5468173400178371, 0.549528908858569, 0.5522266265954562, 0.5549105639820329, 0.5575807914104131, 0.5602373789131372, 0.562880396165009, 0.5655099124849227, 0.5681259968376811, 0.5707287178358045, 0.57331814374133, 0.5758943424676018, 0.5784573815810528, 0.5810073283029755, 0.5835442495112869, 0.5860682117422811, 0.5885792811923743, 0.591077523719842, 0.5935630048465455, 0.5960357897596502, 0.598495943313336, 0.6009435300304977, 0.6033786141044374, 0.6058012594005477, 0.6082115294579882, 0.6106094874913494, 0.6129951963923134, 0.6153687187313013, 0.6177301167591153, 0.6200794524085711, 0.622416787296122, 0.6247421827234754, 0.6270556996792003, 0.6293573988403265, 0.6316473405739367, 0.6339255849387493, 0.6361921916866939, 0.6384472202644775, 0.6406907298151454, 0.6429227791796306, 0.6451434268982974, 0.647352731212478, 0.6495507500659983, 0.6517375411066985, 0.6539131616879452, 0.6560776688701351, 0.6582311194221918, 0.6603735698230548, 0.6625050762631604, 0.6646256946459155, 0.6667354805891645, 0.6688344894266474, 0.6709227762094501, 0.6730003957074504, 0.6750674024107528, 0.6771238505311181, 0.6791697940033852, 0.6812052864868856, 0.6832303813668511, 0.6852451317558135, 0.6872495904949978, 0.6892438101557077, 0.6912278430407055, 0.6932017411855822, 0.6951655563601237, 0.6971193400696678, 0.6990631435564552, 0.7009970178009735, 0.7029210135232944, 0.7048351811844038, 0.706739570987525, 0.7086342328794359, 0.7105192165517785, 0.7123945714423625, 0.7142603467364619, 0.7161165913681046, 0.7179633540213562, 0.719800683131597, 0.7216286268867914, 0.7234472332287532, 0.7252565498544015, 0.7270566242170127, 0.7288475035274644, 0.7306292347554741, 0.7324018646308311, 0.7341654396446213, 0.7359200060504477, 0.7376656098656422, 0.739402296872474, 0.7411301126193489, 0.7428491024220047, 0.7445593113647001, 0.7462607843013958, 0.7479535658569321, 0.7496377004281987, 0.7513132321852996, 0.7529802050727108, 0.7546386628104336, 0.7562886488951406, 0.7579302066013172, 0.7595633789823957, 0.7611882088718855, 0.7628047388844956, 0.7644130114172528, 0.7660130686506132, 0.767604952549569, 0.7691887048647488, 0.7707643671335127, 0.7723319806810416, 0.7738915866214213, 0.7754432258587204, 0.7769869390880634, 0.7785227667966981, 0.7800507492650572, 0.7815709265678147, 0.7830833385749374, 0.7845880249527302, 0.7860850251648761, 0.7875743784734724, 0.7890561239400591, 0.7905303004266441, 0.7919969465967223, 0.7934561009162895, 0.7949078016548515, 0.7963520868864278, 0.7977889944905499, 0.7992185621532546, 0.8006408273680734, 0.8020558274370145, 0.8034635994715426, 0.8048641803935506, 0.806257606936329, 0.8076439156455294, 0.8090231428801227, 0.810395324813352, 0.8117604974336828, 0.8131186965457458, 0.814469957771276, 0.8158143165500475, 0.8171518081408025, 0.8184824676221762, 0.8198063298936171, 0.8211234296763015, 0.8224338015140451, 0.8237374797742087, 0.8250344986485989, 0.8263248921543658, 0.8276086941348945, 0.8288859382606932, 0.8301566580302759, 0.8314208867710411, 0.8326786576401461, 0.8339300036253761, 0.83517495754601, 0.8364135520536808, 0.8376458196332318, 0.838871792603569, 0.8400915031185088, 0.8413049831676203, 0.842512264577066, 0.8437133790104345, 0.844908357969573, 0.8460972327954118, 0.8472800346687873, 0.8484567946112593, 0.8496275434859252, 0.8507923119982282, 0.8519511306967643, 0.8531040299740824, 0.8542510400674812, 0.8553921910598034, 0.8565275128802234, 0.8576570353050335, 0.8587807879584234, 0.8598988003132586, 0.8610111016918525, 0.8621177212667355, 0.8632186880614207, 0.8643140309511644, 0.865403778663724, 0.8664879597801107, 0.8675666027353401, 0.8686397358191771, 0.8697073871768785, 0.8707695848099304, 0.8718263565767833, 0.8728777301935831, 0.8739237332348961, 0.8749643931344351, 0.8759997371857762, 0.8770297925430762, 0.8780545862217844, 0.879074145099351, 0.8800884959159322, 0.8810976652750913, 0.8821016796444968, 0.8831005653566161, 0.8840943486094066, 0.8850830554670022, 0.8860667118603978, 0.8870453435881283, 0.8880189763169463, 0.8889876355824943, 0.8899513467899752, 0.8909101352148181, 0.8918640260033414, 0.8928130441734125, 0.8937572146151033, 0.894696562091344, 0.8956311112385714, 0.8965608865673764, 0.8974859124631455, 0.8984062131867012, 0.8993218128749377, 0.900232735541455, 0.9011390050771872, 0.9020406452510307, 0.902937679710466, 0.9038301319821792, 0.9047180254726783, 0.9056013834689075, 0.9064802291388576, 0.9073545855321739, 0.9082244755807605, 0.909089922099382, 0.9099509477862616, 0.9108075752236768, 0.911659826878551, 0.9125077251030436, 0.9133512921351354, 0.9141905500992127, 0.9150255210066464, 0.9158562267563707, 0.916682689135456, 0.917504929819682, 0.9183229703741044, 0.9191368322536217, 0.9199465368035373, 0.9207521052601201, 0.9215535587511601, 0.922350918296524], \"type\": \"scatter\", \"uid\": \"b594357a-c254-42b0-a2b8-4e455a9f3130\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 4.859519038076152, 9.669038076152304, 14.478557114228456, 19.28807615230461, 24.097595190380762, 28.907114228456912, 33.71663326653306, 38.52615230460921, 43.335671342685366, 48.14519038076152, 52.954709418837666, 57.76422845691382, 62.57374749498997, 67.38326653306612, 72.19278557114228, 77.00230460921843, 81.81182364729457, 86.62134268537073, 91.43086172344688, 96.24038076152304, 101.04989979959919, 105.85941883767534, 110.6689378757515, 115.47845691382764, 120.28797595190379, 125.09749498997995, 129.90701402805612, 134.71653306613226, 139.52605210420842, 144.33557114228458, 149.1450901803607, 153.95460921843687, 158.76412825651303, 163.57364729458916, 168.38316633266533, 173.1926853707415, 178.00220440881762, 182.81172344689378, 187.62124248496994, 192.4307615230461, 197.24028056112223, 202.0497995991984, 206.85931863727455, 211.6688376753507, 216.47835671342685, 221.287875751503, 226.09739478957914, 230.9069138276553, 235.71643286573146, 240.5259519038076, 245.33547094188376, 250.14498997995992, 254.95450901803605, 259.76402805611224, 264.57354709418837, 269.3830661322645, 274.1925851703407, 279.0021042084168, 283.81162324649296, 288.62114228456915, 293.4306613226453, 298.2401803607214, 303.0496993987976, 307.85921843687373, 312.66873747494986, 317.47825651302605, 322.2877755511022, 327.0972945891783, 331.9068136272545, 336.71633266533064, 341.5258517034068, 346.33537074148296, 351.1448897795591, 355.9544088176352, 360.7639278557114, 365.57344689378755, 370.3829659318637, 375.19248496993987, 380.002004008016, 384.8115230460922, 389.6210420841683, 394.43056112224446, 399.24008016032064, 404.0495991983968, 408.8591182364729, 413.6686372745491, 418.47815631262523, 423.28767535070136, 428.09719438877755, 432.9067134268537, 437.7162324649298, 442.525751503006, 447.33527054108214, 452.14478957915827, 456.95430861723446, 461.7638276553106, 466.5733466933867, 471.3828657314629, 476.19238476953905, 481.0019038076152, 485.81142284569137, 490.6209418837675, 495.43046092184363, 500.2399799599198, 505.04949899799595, 509.8590180360721, 514.6685370741482, 519.4780561122244, 524.2875751503005, 529.0970941883767, 533.9066132264528, 538.7161322645289, 543.5256513026051, 548.3351703406813, 553.1446893787574, 557.9542084168336, 562.7637274549097, 567.5732464929858, 572.382765531062, 577.1922845691382, 582.0018036072144, 586.8113226452905, 591.6208416833666, 596.4303607214428, 601.2398797595189, 606.0493987975951, 610.8589178356713, 615.6684368737474, 620.4779559118235, 625.2874749498997, 630.0969939879759, 634.906513026052, 639.7160320641282, 644.5255511022043, 649.3350701402804, 654.1445891783566, 658.9541082164328, 663.763627254509, 668.5731462925851, 673.3826653306612, 678.1921843687373, 683.0017034068135, 687.8112224448897, 692.6207414829659, 697.430260521042, 702.2397795591181, 707.0492985971943, 711.8588176352704, 716.6683366733466, 721.4778557114228, 726.2873747494989, 731.096893787575, 735.9064128256512, 740.7159318637273, 745.5254509018035, 750.3349699398797, 755.1444889779558, 759.9540080160319, 764.7635270541081, 769.5730460921843, 774.3825651302604, 779.1920841683366, 784.0016032064127, 788.8111222444888, 793.620641282565, 798.4301603206412, 803.2396793587174, 808.0491983967935, 812.8587174348696, 817.6682364729458, 822.4777555110219, 827.2872745490981, 832.0967935871743, 836.9063126252504, 841.7158316633265, 846.5253507014027, 851.3348697394788, 856.144388777555, 860.9539078156312, 865.7634268537073, 870.5729458917834, 875.3824649298596, 880.1919839679357, 885.001503006012, 889.8110220440881, 894.6205410821642, 899.4300601202403, 904.2395791583165, 909.0490981963926, 913.8586172344689, 918.668136272545, 923.4776553106211, 928.2871743486972, 933.0966933867734, 937.9062124248496, 942.7157314629258, 947.5252505010019, 952.334769539078, 957.1442885771542, 961.9538076152303, 966.7633266533065, 971.5728456913827, 976.3823647294588, 981.1918837675349, 986.0014028056111, 990.8109218436872, 995.6204408817634, 1000.4299599198396, 1005.2394789579157, 1010.0489979959918, 1014.858517034068, 1019.6680360721441, 1024.4775551102202, 1029.2870741482964, 1034.0965931863725, 1038.9061122244489, 1043.715631262525, 1048.5251503006011, 1053.3346693386773, 1058.1441883767534, 1062.9537074148295, 1067.7632264529057, 1072.5727454909818, 1077.382264529058, 1082.191783567134, 1087.0013026052102, 1091.8108216432865, 1096.6203406813627, 1101.4298597194388, 1106.239378757515, 1111.048897795591, 1115.8584168336672, 1120.6679358717433, 1125.4774549098195, 1130.2869739478956, 1135.0964929859717, 1139.9060120240479, 1144.715531062124, 1149.5250501002004, 1154.3345691382765, 1159.1440881763526, 1163.9536072144288, 1168.763126252505, 1173.572645290581, 1178.3821643286572, 1183.1916833667333, 1188.0012024048094, 1192.8107214428856, 1197.6202404809617, 1202.4297595190378, 1207.2392785571142, 1212.0487975951903, 1216.8583166332664, 1221.6678356713426, 1226.4773547094187, 1231.2868737474948, 1236.096392785571, 1240.905911823647, 1245.7154308617232, 1250.5249498997994, 1255.3344689378755, 1260.1439879759519, 1264.953507014028, 1269.7630260521041, 1274.5725450901803, 1279.3820641282564, 1284.1915831663325, 1289.0011022044087, 1293.8106212424848, 1298.620140280561, 1303.429659318637, 1308.2391783567132, 1313.0486973947893, 1317.8582164328657, 1322.6677354709418, 1327.477254509018, 1332.286773547094, 1337.0962925851702, 1341.9058116232463, 1346.7153306613225, 1351.5248496993986, 1356.3343687374747, 1361.1438877755509, 1365.953406813627, 1370.7629258517031, 1375.5724448897795, 1380.3819639278556, 1385.1914829659318, 1390.001002004008, 1394.810521042084, 1399.6200400801602, 1404.4295591182363, 1409.2390781563124, 1414.0485971943885, 1418.8581162324647, 1423.6676352705408, 1428.4771543086172, 1433.2866733466933, 1438.0961923847694, 1442.9057114228456, 1447.7152304609217, 1452.5247494989978, 1457.334268537074, 1462.14378757515, 1466.9533066132262, 1471.7628256513024, 1476.5723446893785, 1481.3818637274546, 1486.191382765531, 1491.0009018036071, 1495.8104208416833, 1500.6199398797594, 1505.4294589178355, 1510.2389779559117, 1515.0484969939878, 1519.858016032064, 1524.66753507014, 1529.4770541082162, 1534.2865731462923, 1539.0960921843687, 1543.9056112224448, 1548.715130260521, 1553.524649298597, 1558.3341683366732, 1563.1436873747493, 1567.9532064128255, 1572.7627254509016, 1577.5722444889777, 1582.3817635270539, 1587.19128256513, 1592.0008016032061, 1596.8103206412825, 1601.6198396793586, 1606.4293587174348, 1611.2388777555109, 1616.048396793587, 1620.8579158316631, 1625.6674348697393, 1630.4769539078154, 1635.2864729458915, 1640.0959919839677, 1644.9055110220438, 1649.71503006012, 1654.5245490981963, 1659.3340681362724, 1664.1435871743486, 1668.9531062124247, 1673.7626252505008, 1678.572144288577, 1683.381663326653, 1688.1911823647292, 1693.0007014028054, 1697.8102204408815, 1702.6197394789576, 1707.429258517034, 1712.2387775551101, 1717.0482965931863, 1721.8578156312624, 1726.6673346693385, 1731.4768537074146, 1736.2863727454908, 1741.095891783567, 1745.905410821643, 1750.7149298597192, 1755.5244488977953, 1760.3339679358714, 1765.1434869739478, 1769.953006012024, 1774.7625250501, 1779.5720440881762, 1784.3815631262523, 1789.1910821643285, 1794.0006012024046, 1798.8101202404807, 1803.6196392785569, 1808.429158316633, 1813.2386773547091, 1818.0481963927853, 1822.8577154308616, 1827.6672344689377, 1832.4767535070139, 1837.28627254509, 1842.0957915831661, 1846.9053106212423, 1851.7148296593184, 1856.5243486973945, 1861.3338677354707, 1866.1433867735468, 1870.952905811623, 1875.7624248496993, 1880.5719438877754, 1885.3814629258516, 1890.1909819639277, 1895.0005010020038, 1899.81002004008, 1904.619539078156, 1909.4290581162322, 1914.2385771543084, 1919.0480961923845, 1923.8576152304606, 1928.6671342685368, 1933.4766533066131, 1938.2861723446892, 1943.0956913827654, 1947.9052104208415, 1952.7147294589176, 1957.5242484969938, 1962.33376753507, 1967.143286573146, 1971.9528056112222, 1976.7623246492983, 1981.5718436873744, 1986.3813627254506, 1991.190881763527, 1996.000400801603, 2000.8099198396792, 2005.6194388777553, 2010.4289579158315, 2015.2384769539076, 2020.0479959919837, 2024.8575150300599, 2029.667034068136, 2034.4765531062121, 2039.2860721442883, 2044.0955911823646, 2048.9051102204407, 2053.714629258517, 2058.524148296593, 2063.3336673346694, 2068.1431863727453, 2072.9527054108216, 2077.762224448898, 2082.571743486974, 2087.3812625250503, 2092.190781563126, 2097.0003006012025, 2101.8098196392784, 2106.619338677355, 2111.4288577154307, 2116.238376753507, 2121.047895791583, 2125.8574148296593, 2130.6669338677357, 2135.4764529058116, 2140.285971943888, 2145.095490981964, 2149.90501002004, 2154.714529058116, 2159.5240480961925, 2164.3335671342684, 2169.1430861723447, 2173.9526052104206, 2178.762124248497, 2183.5716432865734, 2188.3811623246493, 2193.1906813627256, 2198.0002004008015, 2202.809719438878, 2207.619238476954, 2212.42875751503, 2217.238276553106, 2222.0477955911824, 2226.8573146292583, 2231.6668336673347, 2236.4763527054106, 2241.285871743487, 2246.0953907815633, 2250.904909819639, 2255.7144288577156, 2260.5239478957915, 2265.333466933868, 2270.1429859719437, 2274.95250501002, 2279.762024048096, 2284.5715430861724, 2289.3810621242483, 2294.1905811623246, 2299.000100200401, 2303.809619238477, 2308.6191382765533, 2313.428657314629, 2318.2381763527055, 2323.0476953907814, 2327.857214428858, 2332.6667334669337, 2337.47625250501, 2342.285771543086, 2347.0952905811623, 2351.9048096192387, 2356.7143286573146, 2361.523847695391, 2366.333366733467, 2371.142885771543, 2375.952404809619, 2380.7619238476955, 2385.5714428857714, 2390.3809619238477, 2395.1904809619236, 2400.0], \"y\": [0.93040544075245, 0.9197467194085522, 0.9091448053908726, 0.8985993959358616, 0.8881101898935948, 0.8776768877191736, 0.8672991914641714, 0.8569768047681239, 0.8467094328500666, 0.8364967825001164, 0.8263385620710981, 0.8162344814702158, 0.8061842521507689, 0.7961875871039115, 0.786244200850456, 0.7763538094327214, 0.7665161304064236, 0.7567308828326094, 0.7469977872696338, 0.7373165657651799, 0.7276869418483214, 0.7181086405216268, 0.7085813882533067, 0.6991049129694025, 0.6896789440460158, 0.6803032123015813, 0.670977449989179, 0.6617013907888873, 0.6524747698001796, 0.6432973235343573, 0.6341687899070261, 0.6250889082306124, 0.6160574192069166, 0.6070740649197106, 0.5981385888273711, 0.589250735755553, 0.5804102518899033, 0.5716168847688126, 0.5628703832762045, 0.5541704976343658, 0.5455169793968127, 0.5369095814411955, 0.5283480579622419, 0.5198321644647377, 0.5113616577565436, 0.5029362959416519, 0.49455583841327666, 0.48622004584698386, 0.4779286801938565, 0.46968150467369707, 0.4614782837682647, 0.45331878321454977, 0.44520276999808495, 0.4371300123462889, 0.4291002797218495, 0.4211133428161389, 0.4131689735426658, 0.40526694503056104, 0.3974070316181004, 0.38958900884625836, 0.38181265345229853, 0.3740777433633997, 0.36638405769031146, 0.3587313767210474, 0.35111948191461084, 0.34354815589475374, 0.3360171824437683, 0.3285263464963135, 0.32107543413327244, 0.3136642325756436, 0.3062925301784647, 0.2989601164247686, 0.29166678191957085, 0.2844123183838907, 0.277196518648803, 0.2700191766495217, 0.2628800874195154, 0.2557790470846537, 0.24871585285738562, 0.2416903030309483, 0.23470219697360628, 0.227751335122923, 0.22083751898006043, 0.21396055110411183, 0.2071202351064625, 0.2003163756451818, 0.19354877841944385, 0.18681725016398065, 0.1801215986435607, 0.1734616326475007, 0.16683716198420484, 0.16024799747573315, 0.15369395095239868, 0.14717483524739494, 0.14069046419145015, 0.1342406526075104, 0.12782521630545252, 0.121443972076823, 0.11509673768960682, 0.10878333188302292, 0.10250357436234814, 0.0962572857937678, 0.09004428779925555, 0.08386440295147812, 0.0777174547687296, 0.07160326770989078, 0.06552166716941588, 0.059472479472347795, 0.05345553186935592, 0.04747065253180538, 0.04151767054684874, 0.035596415912545254, 0.0297067195330063, 0.023848413213565678, 0.01802132965597769, 0.012225302453638953, 0.006460166086835972, 0.0007257559180180451, 0.004978091812903429, 0.010651539993231651, 0.016294750642137368, 0.021907884915283615, 0.02749110310943026, 0.033044564667009446, 0.0385684281806804, 0.044062851397857816, 0.04952799122521667, 0.05496400373317334, 0.06037104416034289, 0.06574926691797067, 0.07109882559434455, 0.07641987295917851, 0.08171256096797663, 0.08697704076637258, 0.09221346269444519, 0.09742197629101301, 0.10260273029790334, 0.10775587266420095, 0.11288155055047255, 0.11797991033296962, 0.12305109760780863, 0.1280952571951285, 0.13311253314322669, 0.13810306873267264, 0.14306700648039927, 0.14800448814377365, 0.1529156547246443, 0.15780064647336844, 0.1626596028928171, 0.16749266274235908, 0.1722999640418228, 0.1770816440754388, 0.18183783939575981, 0.18656868582756003, 0.1912743184717146, 0.19595487170905712, 0.20061047920421737, 0.20524127390943891, 0.20984738806837522, 0.21442895321986655, 0.2189861002016963, 0.2235189591543273, 0.22802765952461834, 0.2325123300695212, 0.23697309885975704, 0.24141009328347407, 0.24582344004988554, 0.2502132651928878, 0.25457969407465997, 0.25892285138924387, 0.26324286116610474, 0.2675398467736734, 0.2718139309228693, 0.2760652356706047, 0.28029388242327047, 0.28449999194020315, 0.2886836843371333, 0.2928450790896162, 0.2969842950364433, 0.3011014503830356, 0.3051966627048205, 0.3092700489505882, 0.31332172544583237, 0.3173518078960714, 0.32136041139015337, 0.32534765040354185, 0.3293136388015857, 0.33325848984277073, 0.3371823161819536, 0.34108522987357925, 0.34496734237488136, 0.3488287645490642, 0.35266960666846947, 0.35648997841772534, 0.360289988896878, 0.36406974662450875, 0.36782935954083107, 0.37156893501077504, 0.37528857982705166, 0.37898840021320446, 0.3826685018266408, 0.3863289897616514, 0.3899699685524096, 0.39359154217595815, 0.3971938140551774, 0.40077688706173953, 0.40434086351904575, 0.4078858452051489, 0.41141193335565984, 0.41491922866663766, 0.41840783129746695, 0.4218778408737168, 0.42532935648998593, 0.42876247671273326, 0.4321772995830919, 0.43557392261966976, 0.4389524428213343, 0.44231295666998116, 0.445655560133292, 0.4489803486674725, 0.45228741721998056, 0.45557686023223576, 0.45884877164231797, 0.4621032448876493, 0.46534037290766217, 0.4685602481464539, 0.4717629625554264, 0.4749486075959126, 0.47811727424178696, 0.48126905298206557, 0.4844040338234883, 0.48752230629309024, 0.49062395944075843, 0.493709081841774, 0.4967777615993426, 0.49983008634711, 0.5028661432516647, 0.5058860190150272, 0.5088897998771258, 0.5118775716182602, 0.5148494195615494, 0.5178054285753708, 0.5207456830757814, 0.5236702670289303, 0.5265792639534553, 0.5294727569228692, 0.5323508285679309, 0.5352135610790059, 0.5380610362084133, 0.5408933352727603, 0.5437105391552646, 0.5465127283080644, 0.5492999827545149, 0.5520723820914749, 0.5548300054915788, 0.5575729317054987, 0.5603012390641918, 0.563015005481139, 0.5657143084545685, 0.5683992250696697, 0.5710698320007948, 0.5737262055136472, 0.5763684214674611, 0.5789965553171665, 0.5816106821155449, 0.5842108765153717, 0.5867972127715493, 0.5893697647432263, 0.5919286058959081, 0.5944738093035535, 0.5970054476506625, 0.5995235932343517, 0.6020283179664188, 0.6045196933753962, 0.6069977906085943, 0.6094626804341318, 0.6119144332429585, 0.614353119050864, 0.6167788075004783, 0.6191915678632598, 0.6215914690414737, 0.6239785795701599, 0.6263529676190902, 0.6287147009947147, 0.6310638471420984, 0.6334004731468476, 0.6357246457370247, 0.638036431285055, 0.6403358958096216, 0.6426231049775499, 0.6448981241056848, 0.6471610181627536, 0.6494118517712238, 0.6516506892091465, 0.653877594411993, 0.6560926309744808, 0.6582958621523889, 0.6604873508643654, 0.6626671596937228, 0.6648353508902265, 0.6669919863718721, 0.6691371277266529, 0.6712708362143205, 0.6733931727681317, 0.675504197996591, 0.6776039721851799, 0.6796925552980788, 0.6817700069798802, 0.6838363865572908, 0.685891753040827, 0.6879361651264984, 0.6899696811974858, 0.6919923593258075, 0.694004257273978, 0.6960054324966569, 0.6979959421422909, 0.6999758430547447, 0.7019451917749245, 0.7039040445423935, 0.7058524572969767, 0.7077904856803596, 0.7097181850376759, 0.7116356104190896, 0.7135428165813655, 0.7154398579894339, 0.717326788817946, 0.71920366295282, 0.7210705339927815, 0.7229274552508926, 0.7247744797560757, 0.7266116602546265, 0.7284390492117218, 0.7302566988129164, 0.7320646609656345, 0.733862987300651, 0.7356517291735671, 0.737430937666276, 0.7392006635884216, 0.7409609574788505, 0.742711869607054, 0.7444534499746049, 0.7461857483165841, 0.7479088141030019, 0.7496226965402104, 0.7513274445723092, 0.7530231068825415, 0.7547097318946867, 0.7563873677744415, 0.7580560624307959, 0.759715863517402, 0.7613668184339334, 0.7630089743274406, 0.7646423780936958, 0.7662670763785334, 0.7678831155791811, 0.7694905418455856, 0.7710894010817299, 0.7726797389469446, 0.7742616008572122, 0.7758350319864629, 0.777400077267866, 0.7789567813951119, 0.7805051888236894, 0.7820453437721544, 0.7835772902233933, 0.7851010719258791, 0.7866167323949198, 0.7881243149139023, 0.7896238625355275, 0.7911154180830406, 0.7925990241514533, 0.7940747231087606, 0.7955425570971506, 0.797002568034208, 0.7984547976141112, 0.7998992873088231, 0.8013360783692748, 0.8027652118265445, 0.8041867284930289, 0.8056006689636084, 0.8070070736168065, 0.8084059826159432, 0.8097974359102822, 0.8111814732361706, 0.8125581341181748, 0.8139274578702088, 0.815289483596657, 0.8166442501934907, 0.8179917963493792, 0.819332160546794, 0.8206653810631093, 0.8219914959716925, 0.8233105431429943, 0.8246225602456286, 0.8259275847474481, 0.8272256539166148, 0.8285168048226648, 0.8298010743375657, 0.8310784991367702, 0.8323491157002636, 0.8336129603136054, 0.8348700690689655, 0.836120477866155, 0.8373642224136509, 0.8386013382296168, 0.8398318606429166, 0.8410558247941231, 0.8422732656365224, 0.8434842179371111, 0.8446887162775902, 0.8458867950553517, 0.8470784884844613, 0.8482638305966356, 0.8494428552422139, 0.8506155960911247, 0.8517820866338472, 0.8529423601823684, 0.8540964498711331, 0.8552443886579912, 0.8563862093251388, 0.8575219444800537, 0.8586516265564276, 0.8597752878150914, 0.8608929603449366, 0.8620046760638324, 0.8631104667195365, 0.864210363890602, 0.8653043989872791, 0.8663926032524121, 0.8674750077623318, 0.8685516434277427, 0.869622540994606, 0.8706877310450173, 0.8717472439980802, 0.8728011101107751, 0.8738493594788227, 0.8748920220375441, 0.8759291275627156, 0.8769607056714184, 0.8779867858228849, 0.8790073973193403, 0.8800225693068385, 0.8810323307760954, 0.882036710563316, 0.8830357373510181, 0.8840294396688522, 0.8850178458944145, 0.8860009842540595, 0.8869788828237041, 0.8879515695296306, 0.8889190721492835, 0.8898814183120635, 0.8908386355001154, 0.8917907510491145, 0.8927377921490456, 0.8936797858449804, 0.8946167590378499, 0.8955487384852118, 0.896475750802016, 0.8973978224613632, 0.8983149797952619, 0.8992272489953799, 0.9001346561137924, 0.9010372270637259, 0.9019349876202987, 0.9028279634212559, 0.903716179967703, 0.9045996626248328, 0.9054784366226503, 0.9063525270566934, 0.9072219588887498, 0.9080867569475686, 0.9089469459295709, 0.9098025503995542, 0.9106535947913936, 0.9115001034087407, 0.9123421004257164, 0.9131796098876024, 0.9140126557115267, 0.9148412616871477, 0.915665451477333, 0.9164852486188347, 0.9173006765229632, 0.9181117584762534, 0.9189185176411319, 0.9197209770565768, 0.9205191596387772, 0.9213130881817859, 0.9221027853581718, 0.9228882737196665, 0.9236695756978088, 0.9244467136045852, 0.9252197096330663, 0.9259885858580422, 0.9267533642366512, 0.927514066609008, 0.9282707146988269, 0.9290233301140423, 0.9297719343474252, 0.9305165487771985], \"type\": \"scatter\", \"uid\": \"37fa23e3-9c62-4c50-b744-296fa9966367\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 5.059919839679358, 10.069839679358717, 15.079759519038074, 20.089679358717433, 25.099599198396792, 30.109519038076147, 35.119438877755506, 40.12935871743486, 45.13927855711422, 50.14919839679358, 55.159118236472935, 60.16903807615229, 65.17895791583165, 70.18887775551102, 75.19879759519037, 80.20871743486973, 85.21863727454908, 90.22855711422844, 95.2384769539078, 100.24839679358716, 105.25831663326652, 110.26823647294587, 115.27815631262523, 120.28807615230458, 125.29799599198395, 130.3079158316633, 135.3178356713427, 140.32775551102205, 145.3376753507014, 150.34759519038076, 155.3575150300601, 160.36743486973947, 165.37735470941882, 170.38727454909818, 175.39719438877754, 180.4071142284569, 185.41703406813625, 190.42695390781563, 195.43687374749499, 200.44679358717434, 205.4567134268537, 210.46663326653305, 215.4765531062124, 220.48647294589176, 225.49639278557112, 230.50631262525047, 235.51623246492983, 240.52615230460918, 245.53607214428857, 250.54599198396792, 255.55591182364728, 260.5658316633266, 265.57575150300596, 270.5856713426854, 275.5955911823647, 280.6055110220441, 285.61543086172344, 290.6253507014028, 295.63527054108215, 300.6451903807615, 305.65511022044086, 310.6650300601202, 315.67494989979957, 320.6848697394789, 325.6947895791583, 330.70470941883764, 335.714629258517, 340.72454909819635, 345.7344689378757, 350.74438877755506, 355.7543086172344, 360.76422845691377, 365.7741482965931, 370.7840681362725, 375.7939879759519, 380.80390781563125, 385.8138276553106, 390.82374749498996, 395.8336673346693, 400.84358717434867, 405.853507014028, 410.8634268537074, 415.87334669338674, 420.8832665330661, 425.89318637274545, 430.9031062124248, 435.91302605210416, 440.9229458917835, 445.93286573146287, 450.9427855711422, 455.9527054108216, 460.96262525050093, 465.9725450901803, 470.98246492985965, 475.992384769539, 481.00230460921836, 486.01222444889777, 491.0221442885771, 496.0320641282565, 501.04198396793583, 506.0519038076152, 511.06182364729455, 516.0717434869738, 521.0816633266531, 526.0915831663325, 531.1015030060119, 536.1114228456913, 541.1213426853707, 546.13126252505, 551.1411823647294, 556.1511022044087, 561.1610220440881, 566.1709418837675, 571.1808617234468, 576.1907815631262, 581.2007014028055, 586.2106212424849, 591.2205410821642, 596.2304609218436, 601.2403807615229, 606.2503006012023, 611.2602204408817, 616.270140280561, 621.2800601202404, 626.2899799599197, 631.2998997995991, 636.3098196392784, 641.3197394789578, 646.3296593186371, 651.3395791583165, 656.3494989979959, 661.3594188376752, 666.3693386773546, 671.3792585170339, 676.3891783567133, 681.3990981963926, 686.409018036072, 691.4189378757513, 696.4288577154307, 701.43877755511, 706.4486973947894, 711.4586172344688, 716.4685370741481, 721.4784569138275, 726.4883767535068, 731.4982965931862, 736.5082164328655, 741.5181362725449, 746.5280561122242, 751.5379759519037, 756.5478957915831, 761.5578156312624, 766.5677354709418, 771.5776553106211, 776.5875751503005, 781.5974949899799, 786.6074148296592, 791.6173346693386, 796.6272545090179, 801.6371743486973, 806.6470941883766, 811.657014028056, 816.6669338677353, 821.6768537074147, 826.686773547094, 831.6966933867734, 836.7066132264528, 841.7165330661321, 846.7264529058115, 851.7363727454908, 856.7462925851702, 861.7562124248495, 866.7661322645289, 871.7760521042082, 876.7859719438876, 881.795891783567, 886.8058116232463, 891.8157314629257, 896.825651302605, 901.8355711422844, 906.8454909819637, 911.8554108216431, 916.8653306613224, 921.8752505010018, 926.8851703406812, 931.8950901803605, 936.9050100200399, 941.9149298597192, 946.9248496993986, 951.9347695390779, 956.9446893787573, 961.9546092184366, 966.9645290581161, 971.9744488977955, 976.9843687374748, 981.9942885771542, 987.0042084168335, 992.0141282565129, 997.0240480961922, 1002.0339679358716, 1007.043887775551, 1012.0538076152303, 1017.0637274549097, 1022.073647294589, 1027.0835671342684, 1032.0934869739476, 1037.103406813627, 1042.1133266533063, 1047.1232464929858, 1052.133166332665, 1057.1430861723445, 1062.1530060120238, 1067.1629258517032, 1072.1728456913827, 1077.182765531062, 1082.1926853707414, 1087.2026052104206, 1092.2125250501, 1097.2224448897794, 1102.2323647294588, 1107.242284569138, 1112.2522044088175, 1117.2621242484968, 1122.2720440881762, 1127.2819639278555, 1132.291883767535, 1137.3018036072142, 1142.3117234468937, 1147.321643286573, 1152.3315631262524, 1157.3414829659316, 1162.351402805611, 1167.3613226452903, 1172.3712424849698, 1177.381162324649, 1182.3910821643285, 1187.4010020040078, 1192.4109218436872, 1197.4208416833665, 1202.430761523046, 1207.4406813627252, 1212.4506012024046, 1217.4605210420839, 1222.4704408817634, 1227.4803607214426, 1232.490280561122, 1237.5002004008013, 1242.5101202404808, 1247.52004008016, 1252.5299599198395, 1257.5398797595187, 1262.5497995991982, 1267.5597194388774, 1272.569639278557, 1277.5795591182361, 1282.5894789579156, 1287.599398797595, 1292.6093186372743, 1297.6192384769538, 1302.629158316633, 1307.6390781563125, 1312.6489979959917, 1317.6589178356712, 1322.6688376753505, 1327.67875751503, 1332.6886773547092, 1337.6985971943886, 1342.7085170340679, 1347.7184368737474, 1352.7283567134266, 1357.738276553106, 1362.7481963927853, 1367.7581162324648, 1372.768036072144, 1377.7779559118235, 1382.7878757515027, 1387.7977955911822, 1392.8077154308614, 1397.817635270541, 1402.8275551102201, 1407.8374749498996, 1412.8473947895789, 1417.8573146292583, 1422.8672344689376, 1427.877154308617, 1432.8870741482963, 1437.8969939879757, 1442.906913827655, 1447.9168336673345, 1452.9267535070137, 1457.9366733466932, 1462.9465931863724, 1467.9565130260519, 1472.9664328657311, 1477.9763527054106, 1482.9862725450898, 1487.9961923847693, 1493.0061122244485, 1498.016032064128, 1503.0259519038075, 1508.0358717434867, 1513.0457915831662, 1518.0557114228454, 1523.065631262525, 1528.0755511022041, 1533.0854709418836, 1538.0953907815629, 1543.1053106212423, 1548.1152304609216, 1553.125150300601, 1558.1350701402803, 1563.1449899799597, 1568.154909819639, 1573.1648296593185, 1578.1747494989977, 1583.1846693386772, 1588.1945891783564, 1593.2045090180359, 1598.2144288577151, 1603.2243486973946, 1608.2342685370738, 1613.2441883767533, 1618.2541082164325, 1623.264028056112, 1628.2739478957913, 1633.2838677354707, 1638.29378757515, 1643.3037074148294, 1648.3136272545087, 1653.3235470941881, 1658.3334669338674, 1663.3433867735469, 1668.353306613226, 1673.3632264529056, 1678.3731462925848, 1683.3830661322643, 1688.3929859719435, 1693.402905811623, 1698.4128256513022, 1703.4227454909817, 1708.432665330661, 1713.4425851703404, 1718.4525050100199, 1723.4624248496991, 1728.4723446893786, 1733.4822645290578, 1738.4921843687373, 1743.5021042084165, 1748.512024048096, 1753.5219438877753, 1758.5318637274547, 1763.541783567134, 1768.5517034068134, 1773.5616232464927, 1778.5715430861721, 1783.5814629258514, 1788.5913827655309, 1793.60130260521, 1798.6112224448896, 1803.6211422845688, 1808.6310621242483, 1813.6409819639275, 1818.650901803607, 1823.6608216432862, 1828.6707414829657, 1833.680661322645, 1838.6905811623244, 1843.7005010020036, 1848.7104208416831, 1853.7203406813624, 1858.7302605210418, 1863.740180360721, 1868.7501002004005, 1873.7600200400798, 1878.7699398797592, 1883.7798597194385, 1888.789779559118, 1893.7996993987972, 1898.8096192384767, 1903.819539078156, 1908.8294589178354, 1913.8393787575146, 1918.849298597194, 1923.8592184368733, 1928.8691382765528, 1933.8790581162323, 1938.8889779559115, 1943.898897795591, 1948.9088176352702, 1953.9187374749497, 1958.928657314629, 1963.9385771543084, 1968.9484969939876, 1973.9584168336671, 1978.9683366733464, 1983.9782565130258, 1988.988176352705, 1993.9980961923845, 1999.0080160320638, 2004.0179358717432, 2009.0278557114225, 2014.037775551102, 2019.0476953907812, 2024.0576152304607, 2029.06753507014, 2034.0774549098194, 2039.0873747494986, 2044.097294589178, 2049.107214428858, 2054.117134268537, 2059.1270541082163, 2064.1369739478955, 2069.146893787575, 2074.1568136272545, 2079.1667334669337, 2084.176653306613, 2089.1865731462926, 2094.196492985972, 2099.206412825651, 2104.2163326653304, 2109.22625250501, 2114.2361723446893, 2119.2460921843685, 2124.256012024048, 2129.2659318637275, 2134.2758517034067, 2139.285771543086, 2144.2956913827657, 2149.305611222445, 2154.315531062124, 2159.3254509018034, 2164.335370741483, 2169.3452905811623, 2174.3552104208416, 2179.365130260521, 2184.3750501002005, 2189.3849699398797, 2194.394889779559, 2199.404809619238, 2204.414729458918, 2209.424649298597, 2214.4345691382764, 2219.4444889779556, 2224.4544088176353, 2229.4643286573146, 2234.474248496994, 2239.484168336673, 2244.4940881763528, 2249.504008016032, 2254.5139278557112, 2259.5238476953905, 2264.53376753507, 2269.5436873747494, 2274.5536072144287, 2279.563527054108, 2284.5734468937876, 2289.583366733467, 2294.593286573146, 2299.6032064128253, 2304.613126252505, 2309.6230460921843, 2314.6329659318635, 2319.6428857715428, 2324.6528056112224, 2329.6627254509017, 2334.672645290581, 2339.68256513026, 2344.69248496994, 2349.702404809619, 2354.7123246492984, 2359.722244488978, 2364.7321643286573, 2369.7420841683365, 2374.752004008016, 2379.7619238476955, 2384.7718436873747, 2389.781763527054, 2394.791683366733, 2399.801603206413, 2404.811523046092, 2409.8214428857714, 2414.8313627254506, 2419.8412825651303, 2424.8512024048096, 2429.861122244489, 2434.871042084168, 2439.8809619238477, 2444.890881763527, 2449.900801603206, 2454.9107214428855, 2459.920641282565, 2464.9305611222444, 2469.9404809619236, 2474.950400801603, 2479.9603206412826, 2484.970240480962, 2489.980160320641, 2494.9900801603203, 2500.0], \"y\": [0.9377123679531352, 0.9266107588963544, 0.915570776124986, 0.9045920775445611, 0.8936743229596154, 0.882817174063149, 0.8720202944261417, 0.861283349487129, 0.8506060065418346, 0.8399879347328616, 0.8294288050394398, 0.8189282902672301, 0.8084860650381862, 0.7981018057804727, 0.7877751907184372, 0.7775058998626405, 0.7672936149999412, 0.757138019683635, 0.7470387992236482, 0.7369956406767884, 0.7270082328370451, 0.7170762662259482, 0.7071994330829776, 0.697377427356026, 0.6876099446919164, 0.6778966824269701, 0.6682373395776298, 0.6586316168311306, 0.6490792165362271, 0.6395798426939701, 0.630133200948533, 0.620738998578092, 0.6113969444857559, 0.6021067491905441, 0.5928681248184182, 0.5836807850933612, 0.5745444453285065, 0.565458822417316, 0.5564236348248084, 0.5474386025788349, 0.5385034472614039, 0.5296178920000527, 0.5207816614592695, 0.5119944818319613, 0.5032560808309683, 0.4945661876806282, 0.485924533108385, 0.47733084933644454, 0.4687848700734778, 0.4602863305063689, 0.45183496729200967, 0.44343051854913873, 0.43507272385022766, 0.42676132421341073, 0.4184960620944591, 0.4102766813788017, 0.4021029273735883, 0.39397454679979726, 0.3858912877843872, 0.3778528998524926, 0.36985913391966263, 0.36190974228414174, 0.35400447861919493, 0.34614309796547515, 0.33832535672343167, 0.33055101264576314, 0.3228198248299097, 0.31513155371058876, 0.30748596105237236, 0.29988280994230365, 0.29232186478255673, 0.2848028912831355, 0.27732565645461427, 0.2698899286009182, 0.26249547731214307, 0.25514207345741613, 0.24782948917779635, 0.2405574978792131, 0.23332587422544515, 0.226134394131138, 0.21898283475486013, 0.21187097449219827, 0.2047985929688898, 0.19776547103399533, 0.19077139075310612, 0.1838161354015928, 0.17689948945788836, 0.1700212385968103, 0.1631811696829195, 0.15637907076391633, 0.1496147310640712, 0.1428879409776953, 0.13619849206264423, 0.12954617703385973, 0.12293078975694582, 0.11635212524178273, 0.10980997963617312, 0.10330415021952621, 0.0968344353965771, 0.09040063469113768, 0.08400254873988677, 0.07763997928619126, 0.07131272917396236, 0.06502060234154805, 0.0587634038156557, 0.05254093970531204, 0.046353017195854385, 0.040199444542955876, 0.034080031066684224, 0.027994587145592664, 0.021942924210845316, 0.015924854740371863, 0.00994019225305931, 0.003988751302971938, 0.001929652526394765, 0.007815202627827977, 0.013668081376081442, 0.019488470133525615, 0.025276549255768055, 0.031032498097242067, 0.03675649501676426, 0.042448717383060997, 0.04810934158026536, 0.05373854301338166, 0.05933649611372149, 0.0649033743443087, 0.07043935020525383, 0.07594459523910024, 0.08141928003613896, 0.08686357423969548, 0.0922776465513857, 0.09766166473634386, 0.10301579562842089, 0.10834020513535447, 0.11363505824390929, 0.11890051902499044, 0.12413675063872631, 0.12934391533952516, 0.13452217448110304, 0.13967168852148304, 0.14479261702796753, 0.14988511868208299, 0.15494935128449672, 0.15998547175990663, 0.1649936361619041, 0.16997399967780935, 0.17492671663347992, 0.17985194049809372, 0.18474982388890349, 0.1896205185759665, 0.19446417548684725, 0.1992809447112941, 0.2040709755058906, 0.20883441629868016, 0.21357141469376495, 0.21828211747588067, 0.22296667061494369, 0.22762521927057566, 0.23225790779660027, 0.23686487974551695, 0.24144627787294903, 0.24600224414206728, 0.25053291972798875, 0.25503844502215156, 0.25951895963666516, 0.26397460240863635, 0.26840551140447144, 0.2728118239241547, 0.27719367650550253, 0.28155120492839436, 0.2858845442189806, 0.29019382865386567, 0.29447919176427007, 0.2987407663401668, 0.302978684434397, 0.3071930773667618, 0.3113840757280909, 0.31555180938428984, 0.31969640748036354, 0.3238179984444187, 0.3279167099916429, 0.33199266912826264, 0.3360460021554781, 0.34007683467337746, 0.3440852915848285, 0.34807149709934937, 0.3520355747369567, 0.3559776473319939, 0.3598978370369369, 0.3637962653261796, 0.3676730529997979, 0.3715283201872923, 0.3753621863513117, 0.3791747702913537, 0.3829661901474465, 0.38673656340381013, 0.3904860068924959, 0.39421463679700774, 0.39792256865590137, 0.4016099173663652, 0.4052767971877804, 0.40892332174526114, 0.4125496040331762, 0.4161557564186492, 0.41974189064504197, 0.42330811783541566, 0.42685454849597504, 0.43038129251949264, 0.4338884591887132, 0.43737615717974154, 0.4408444945654081, 0.44429357881861975, 0.44772351681568834, 0.4511344148396439, 0.45452637858352707, 0.4578995131536642, 0.46125392307292523, 0.46458971228396095, 0.46790698415242593, 0.4712058414701793, 0.4744863864584714, 0.47774872077111075, 0.4809929454976143, 0.48421916116633934, 0.48742746774759926, 0.49061796465676066, 0.4937907507573245, 0.4969459243639889, 0.5000835832456964, 0.5032038246286628, 0.5063067451993903, 0.5093924411076635, 0.5124610079695285, 0.5155125408702562, 0.5185471343672882, 0.5215648824931668, 0.52456587875845, 0.527550216154607, 0.5305179871569016, 0.5334692837272565, 0.536404197317104, 0.5393228188702183, 0.5422252388255352, 0.5451115471199535, 0.547981833191122, 0.550836185980211, 0.5536746939346688, 0.5564974450109611, 0.5593045266772982, 0.5620960259163437, 0.5648720292279112, 0.5676326226316439, 0.5703778916696801, 0.573107921409304, 0.5758227964455822, 0.5785226009039837, 0.5812074184429885, 0.5838773322566779, 0.5865324250773144, 0.5891727791779038, 0.5917984763747451, 0.5944095980299664, 0.5970062250540447, 0.5995884379083142, 0.602156316607459, 0.6047099407219931, 0.6072493893807248, 0.6097747412732102, 0.6122860746521903, 0.6147834673360166, 0.6172669967110618, 0.6197367397341185, 0.6221927729347829, 0.6246351724178278, 0.6270640138655588, 0.6294793725401608, 0.6318813232860299, 0.6342699405320925, 0.6366452982941114, 0.6390074701769799, 0.641356529377002, 0.6436925486841609, 0.646015600484374, 0.6483257567617369, 0.6506230891007527, 0.6529076686885515, 0.6551795663170952, 0.6574388523853716, 0.6596855969015756, 0.661919869485279, 0.6641417393695874, 0.6663512754032858, 0.6685485460529712, 0.6707336194051756, 0.6729065631684743, 0.675067444675585, 0.6772163308854537, 0.6793532883853302, 0.6814783833928302, 0.6835916817579886, 0.6856932489652989, 0.687783150135743, 0.6898614500288088, 0.691928213044497, 0.6939835032253165, 0.6960273842582694, 0.6980599194768236, 0.7000811718628757, 0.7020912040487032, 0.7040900783189044, 0.7060778566123289, 0.7080546005239965, 0.7100203713070067, 0.7119752298744353, 0.7139192368012233, 0.715852452326053, 0.7177749363532155, 0.719686748454466, 0.7215879478708703, 0.7234785935146402, 0.7253587439709592, 0.727228457499798, 0.7290877920377197, 0.7309368051996745, 0.7327755542807861, 0.734604096258126, 0.7364224877924801, 0.7382307852301031, 0.7400290446044661, 0.7418173216379915, 0.7435956717437806, 0.74536415002733, 0.74712281128824, 0.7488717100219112, 0.750610900421235, 0.7523404363782715, 0.75406037148592, 0.7557707590395795, 0.7574716520388001, 0.7591631031889258, 0.760845164902727, 0.7625178893020248, 0.7641813282193066, 0.7658355331993314, 0.7674805555007275, 0.7691164460975808, 0.7707432556810144, 0.7723610346607592, 0.7739698331667161, 0.7755697010505089, 0.7771606878870296, 0.7787428429759746, 0.7803162153433718, 0.7818808537431003, 0.7834368066584008, 0.784984122303378, 0.7865228486244948, 0.788053033302058, 0.789574723751695, 0.7910879671258246, 0.7925928103151165, 0.7940892999499454, 0.7955774824018351, 0.7970574037848963, 0.7985291099572547, 0.7999926465224729, 0.8014480588309623, 0.8028953919813893, 0.8043346908220728, 0.8057659999523732, 0.807189363724075, 0.808604826242761, 0.8100124313691789, 0.8114122227206004, 0.8128042436721725, 0.8141885373582627, 0.8155651466737937, 0.8169341142755744, 0.8182954825836207, 0.8196492937824702, 0.8209955898224892, 0.8223344124211731, 0.8236658030644386, 0.8249898030079095, 0.8263064532781945, 0.8276157946741598, 0.8289178677681918, 0.8302127129074551, 0.8315003702151431, 0.8327808795917202, 0.8340542807161594, 0.8353206130471706, 0.8365799158244245, 0.8378322280697676, 0.8390775885884322, 0.8403160359702377, 0.8415476085907876, 0.8427723446126578, 0.8439902819865794, 0.8452014584526152, 0.846405911541328, 0.8476036785749446, 0.8487947966685115, 0.8499793027310462, 0.8511572334666793, 0.8523286253757927, 0.8534935147561509, 0.8546519377040253, 0.8558039301153129, 0.8569495276866481, 0.8580887659165096, 0.8592216801063202, 0.86034830536154, 0.8614686765927555, 0.8625828285167595, 0.863690795657629, 0.8647926123477935, 0.8658883127290993, 0.8669779307538674, 0.8680615001859459, 0.8691390546017557, 0.8702106273913313, 0.8712762517593552, 0.8723359607261874, 0.8733897871288876, 0.8744377636222337, 0.8754799226797328, 0.8765162965946285, 0.8775469174809005, 0.8785718172742603, 0.8795910277331405, 0.8806045804396793, 0.8816125068006989, 0.8826148380486785, 0.8836116052427222, 0.8846028392695219, 0.8855885708443136, 0.8865688305118299, 0.8875436486472457, 0.8885130554571203, 0.8894770809803327, 0.8904357550890128, 0.891389107489467, 0.8923371677230985, 0.8932799651673229, 0.8942175290364783, 0.8951498883827311, 0.8960770720969755, 0.8969991089097293, 0.8979160273920237, 0.8988278559562889, 0.8997346228572349, 0.9006363561927262, 0.9015330839046529, 0.9024248337797967, 0.9033116334506917, 0.9041935103964805, 0.9050704919437662, 0.9059426052674584, 0.9068098773916162, 0.9076723351902849, 0.9085300053883287, 0.9093829145622594, 0.9102310891410592, 0.9110745554070008, 0.9119133394964598, 0.9127474674007271, 0.9135769649668123, 0.9144018578982455, 0.9152221717558734, 0.9160379319586519, 0.9168491637844333, 0.9176558923707494, 0.9184581427155913, 0.9192559396781828, 0.9200493079797518, 0.9208382722042955, 0.921622856799343, 0.9224030860767118, 0.9231789842132627, 0.9239505752516468, 0.9247178831010527, 0.9254809315379461, 0.9262397442068067, 0.926994344620861, 0.9277447561628112, 0.9284910020855593, 0.9292331055129281, 0.9299710894403768, 0.9307049767357147, 0.9314347901398095, 0.9321605522672912, 0.9328822856072538, 0.9336000125239519, 0.9343137552574932, 0.9350235359245284, 0.9357293765189358, 0.9364312989125039, 0.9371293248556076, 0.9378234759778837], \"type\": \"scatter\", \"uid\": \"7b7f6f9e-c4fe-4ee2-8871-5d8c44d5da82\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 5.260320641282565, 10.470641282565131, 15.680961923847697, 20.89128256513026, 26.101603206412825, 31.311923847695393, 36.522244488977954, 41.73256513026052, 46.94288577154308, 52.15320641282565, 57.36352705410821, 62.57384769539078, 67.78416833667335, 72.99448897795591, 78.20480961923847, 83.41513026052104, 88.6254509018036, 93.83577154308617, 99.04609218436873, 104.2564128256513, 109.46673346693386, 114.67705410821642, 119.88737474949899, 125.09769539078157, 130.30801603206413, 135.5183366733467, 140.72865731462926, 145.93897795591184, 151.1492985971944, 156.35961923847697, 161.56993987975952, 166.7802605210421, 171.99058116232467, 177.20090180360722, 182.4112224448898, 187.62154308617235, 192.83186372745493, 198.04218436873748, 203.25250501002006, 208.4628256513026, 213.6731462925852, 218.88346693386774, 224.09378757515032, 229.30410821643287, 234.51442885771544, 239.724749498998, 244.93507014028057, 250.14539078156315, 255.3557114228457, 260.56603206412825, 265.77635270541083, 270.9866733466934, 276.196993987976, 281.4073146292585, 286.6176352705411, 291.82795591182366, 297.03827655310624, 302.24859719438876, 307.45891783567134, 312.6692384769539, 317.8795591182365, 323.089879759519, 328.3002004008016, 333.5105210420842, 338.72084168336676, 343.93116232464934, 349.14148296593186, 354.35180360721444, 359.562124248497, 364.7724448897796, 369.9827655310621, 375.1930861723447, 380.40340681362727, 385.61372745490985, 390.82404809619237, 396.03436873747495, 401.2446893787575, 406.4550100200401, 411.6653306613226, 416.8756513026052, 422.0859719438878, 427.29629258517036, 432.50661322645294, 437.71693386773546, 442.92725450901804, 448.1375751503006, 453.3478957915832, 458.5582164328657, 463.7685370741483, 468.9788577154309, 474.18917835671346, 479.399498997996, 484.60981963927856, 489.82014028056113, 495.0304609218437, 500.2407815631263, 505.4511022044088, 510.6614228456914, 515.8717434869739, 521.0820641282564, 526.292384769539, 531.5027054108216, 536.7130260521042, 541.9233466933867, 547.1336673346693, 552.3439879759519, 557.5543086172344, 562.764629258517, 567.9749498997995, 573.1852705410821, 578.3955911823647, 583.6059118236473, 588.8162324649298, 594.0265531062124, 599.236873747495, 604.4471943887775, 609.65751503006, 614.8678356713426, 620.0781563126252, 625.2884769539078, 630.4987975951904, 635.7091182364729, 640.9194388777555, 646.129759519038, 651.3400801603206, 656.5504008016031, 661.7607214428857, 666.9710420841683, 672.1813627254509, 677.3916833667334, 682.602004008016, 687.8123246492986, 693.0226452905811, 698.2329659318636, 703.4432865731462, 708.6536072144288, 713.8639278557114, 719.074248496994, 724.2845691382765, 729.4948897795591, 734.7052104208416, 739.9155310621242, 745.1258517034067, 750.3361723446893, 755.5464929859719, 760.7568136272545, 765.967134268537, 771.1774549098196, 776.3877755511022, 781.5980961923847, 786.8084168336673, 792.0187374749498, 797.2290581162324, 802.439378757515, 807.6496993987976, 812.8600200400801, 818.0703406813627, 823.2806613226452, 828.4909819639278, 833.7013026052103, 838.9116232464929, 844.1219438877755, 849.3322645290581, 854.5425851703407, 859.7529058116232, 864.9632264529058, 870.1735470941883, 875.3838677354709, 880.5941883767534, 885.804509018036, 891.0148296593186, 896.2251503006012, 901.4354709418838, 906.6457915831663, 911.8561122244488, 917.0664328657314, 922.276753507014, 927.4870741482965, 932.6973947895791, 937.9077154308617, 943.1180360721443, 948.3283567134268, 953.5386773547094, 958.7489979959919, 963.9593186372745, 969.169639278557, 974.3799599198396, 979.5902805611222, 984.8006012024048, 990.0109218436874, 995.2212424849699, 1000.4315631262525, 1005.641883767535, 1010.8522044088176, 1016.0625250501001, 1021.2728456913827, 1026.4831663326652, 1031.6934869739478, 1036.9038076152303, 1042.114128256513, 1047.3244488977955, 1052.534769539078, 1057.7450901803606, 1062.9554108216432, 1068.1657314629258, 1073.3760521042084, 1078.586372745491, 1083.7966933867735, 1089.0070140280561, 1094.2173346693387, 1099.4276553106213, 1104.6379759519039, 1109.8482965931864, 1115.0586172344688, 1120.2689378757514, 1125.479258517034, 1130.6895791583165, 1135.899899799599, 1141.1102204408817, 1146.3205410821643, 1151.5308617234468, 1156.7411823647294, 1161.951503006012, 1167.1618236472946, 1172.3721442885771, 1177.5824649298597, 1182.7927855711423, 1188.0031062124249, 1193.2134268537075, 1198.42374749499, 1203.6340681362724, 1208.844388777555, 1214.0547094188375, 1219.2650300601201, 1224.4753507014027, 1229.6856713426853, 1234.8959919839679, 1240.1063126252504, 1245.316633266533, 1250.5269539078156, 1255.7372745490982, 1260.9475951903808, 1266.1579158316633, 1271.368236472946, 1276.5785571142285, 1281.788877755511, 1286.9991983967936, 1292.209519038076, 1297.4198396793586, 1302.6301603206412, 1307.8404809619237, 1313.0508016032063, 1318.261122244489, 1323.4714428857715, 1328.681763527054, 1333.8920841683366, 1339.1024048096192, 1344.3127254509018, 1349.5230460921844, 1354.733366733467, 1359.9436873747495, 1365.154008016032, 1370.3643286573147, 1375.5746492985973, 1380.7849699398796, 1385.9952905811622, 1391.2056112224448, 1396.4159318637273, 1401.62625250501, 1406.8365731462925, 1412.046893787575, 1417.2572144288577, 1422.4675350701402, 1427.6778557114228, 1432.8881763527054, 1438.098496993988, 1443.3088176352705, 1448.5191382765531, 1453.7294589178357, 1458.9397795591183, 1464.1501002004009, 1469.3604208416832, 1474.5707414829658, 1479.7810621242484, 1484.991382765531, 1490.2017034068135, 1495.412024048096, 1500.6223446893787, 1505.8326653306613, 1511.0429859719438, 1516.2533066132264, 1521.463627254509, 1526.6739478957916, 1531.8842685370741, 1537.0945891783567, 1542.3049098196393, 1547.5152304609219, 1552.7255511022045, 1557.9358717434868, 1563.1461923847694, 1568.356513026052, 1573.5668336673345, 1578.7771543086171, 1583.9874749498997, 1589.1977955911823, 1594.4081162324649, 1599.6184368737474, 1604.82875751503, 1610.0390781563126, 1615.2493987975952, 1620.4597194388778, 1625.6700400801603, 1630.880360721443, 1636.0906813627255, 1641.301002004008, 1646.5113226452904, 1651.721643286573, 1656.9319639278556, 1662.1422845691382, 1667.3526052104207, 1672.5629258517033, 1677.773246492986, 1682.9835671342685, 1688.193887775551, 1693.4042084168336, 1698.6145290581162, 1703.8248496993988, 1709.0351703406814, 1714.245490981964, 1719.4558116232465, 1724.666132264529, 1729.8764529058117, 1735.086773547094, 1740.2970941883766, 1745.5074148296592, 1750.7177354709418, 1755.9280561122243, 1761.138376753507, 1766.3486973947895, 1771.559018036072, 1776.7693386773547, 1781.9796593186372, 1787.1899799599198, 1792.4003006012024, 1797.610621242485, 1802.8209418837675, 1808.0312625250501, 1813.2415831663327, 1818.4519038076153, 1823.6622244488976, 1828.8725450901802, 1834.0828657314628, 1839.2931863727454, 1844.503507014028, 1849.7138276553105, 1854.924148296593, 1860.1344689378757, 1865.3447895791583, 1870.5551102204408, 1875.7654308617234, 1880.975751503006, 1886.1860721442886, 1891.3963927855712, 1896.6067134268537, 1901.8170340681363, 1907.027354709419, 1912.2376753507012, 1917.4479959919838, 1922.6583166332664, 1927.868637274549, 1933.0789579158316, 1938.2892785571141, 1943.4995991983967, 1948.7099198396793, 1953.9202404809619, 1959.1305611222444, 1964.340881763527, 1969.5512024048096, 1974.7615230460922, 1979.9718436873748, 1985.1821643286573, 1990.39248496994, 1995.6028056112225, 2000.813126252505, 2006.0234468937874, 2011.23376753507, 2016.4440881763526, 2021.6544088176352, 2026.8647294589177, 2032.0750501002003, 2037.285370741483, 2042.4956913827655, 2047.706012024048, 2052.9163326653306, 2058.126653306613, 2063.336973947896, 2068.5472945891784, 2073.757615230461, 2078.9679358717435, 2084.178256513026, 2089.3885771543087, 2094.5988977955913, 2099.809218436874, 2105.0195390781564, 2110.229859719439, 2115.4401803607216, 2120.650501002004, 2125.8608216432867, 2131.0711422845693, 2136.281462925852, 2141.4917835671345, 2146.702104208417, 2151.9124248496996, 2157.122745490982, 2162.333066132265, 2167.5433867735474, 2172.75370741483, 2177.9640280561125, 2183.174348697395, 2188.3846693386777, 2193.5949899799602, 2198.805310621243, 2204.0156312625254, 2209.225951903808, 2214.4362725450906, 2219.646593186373, 2224.8569138276553, 2230.067234468938, 2235.2775551102204, 2240.487875751503, 2245.6981963927856, 2250.908517034068, 2256.1188376753507, 2261.3291583166333, 2266.539478957916, 2271.7497995991985, 2276.960120240481, 2282.1704408817636, 2287.380761523046, 2292.591082164329, 2297.8014028056114, 2303.011723446894, 2308.2220440881765, 2313.432364729459, 2318.6426853707417, 2323.8530060120243, 2329.063326653307, 2334.2736472945894, 2339.483967935872, 2344.6942885771546, 2349.904609218437, 2355.1149298597197, 2360.3252505010023, 2365.535571142285, 2370.7458917835675, 2375.95621242485, 2381.1665330661326, 2386.376853707415, 2391.5871743486978, 2396.7974949899804, 2402.0078156312625, 2407.218136272545, 2412.4284569138276, 2417.63877755511, 2422.849098196393, 2428.0594188376754, 2433.269739478958, 2438.4800601202405, 2443.690380761523, 2448.9007014028057, 2454.1110220440883, 2459.321342685371, 2464.5316633266534, 2469.741983967936, 2474.9523046092186, 2480.162625250501, 2485.3729458917837, 2490.5832665330663, 2495.793587174349, 2501.0039078156315, 2506.214228456914, 2511.4245490981966, 2516.634869739479, 2521.845190380762, 2527.0555110220444, 2532.265831663327, 2537.4761523046095, 2542.686472945892, 2547.8967935871747, 2553.1071142284572, 2558.31743486974, 2563.5277555110224, 2568.738076152305, 2573.9483967935876, 2579.1587174348697, 2584.3690380761523, 2589.579358717435, 2594.7896793587174, 2600.0], \"y\": [0.9442508936974088, 0.9327064955334918, 0.9212287376361927, 0.909817235323255, 0.8984716061330078, 0.8871914698115486, 0.8759764482999974, 0.8648261657218268, 0.8537402483702641, 0.8427183246957664, 0.8317600252935675, 0.820864982891298, 0.8100328323366752, 0.7992632105852655, 0.7885557566883159, 0.7779101117806579, 0.7673259190686788, 0.7568028238183642, 0.7463404733434087, 0.7359385169933959, 0.7255966061420456, 0.7153143941755296, 0.7050915364808552, 0.6949276904343149, 0.6848225153900032, 0.6747756726684, 0.6647868255450191, 0.6548556392391234, 0.644981780902504, 0.6351649196083249, 0.6254047263400322, 0.615700873980326, 0.6060530373001976, 0.5964608929480295, 0.5869241194387573, 0.5774423971430962, 0.568015408276827, 0.5586428368901466, 0.5493243688570786, 0.5400596918649443, 0.5308484954038968, 0.5216904707565129, 0.5125853109874474, 0.5035327109331451, 0.4945323671916133, 0.48558397811225373, 0.4766872437857519, 0.46784186603402556, 0.45904754840023165, 0.45030399613883043, 0.4416109162057056, 0.43296801724834477, 0.4243750095960732, 0.4158316052503461, 0.407337517875096, 0.3988924627871353, 0.390496156946617, 0.3821483189475461, 0.37384866900835, 0.36559692896250007, 0.3573928222491902, 0.34923607390406675, 0.3411264105500129, 0.3330635603879868, 0.3250472531879123, 0.31707722027962126, 0.3091531945438497, 0.3012749104032848, 0.29344210381366387, 0.285654512254925, 0.27791187472240875, 0.27021393171811003, 0.2625604252419811, 0.2549510987832846, 0.24738569731199678, 0.23986396727025916, 0.23238565656388155, 0.22495051455389214, 0.2175582920481378, 0.21020874129293166, 0.20290161596475031, 0.19563667116197747, 0.18841366339669618, 0.18123235058652898, 0.17409249204652277, 0.16699384848108356, 0.15993618197595638, 0.1529192559902499, 0.14594283534851082, 0.13900668623284007, 0.1321105761750574, 0.12525427404890976, 0.11843755006232493, 0.11166017574970954, 0.1049219239642929, 0.09822256887051317, 0.09156188593644932, 0.08493965192629482, 0.07835564489287594, 0.07180964417021407, 0.06530143036612901, 0.05883078535488617, 0.052397492269886436, 0.046001335496396845, 0.039642100664325275, 0.03331957464103508, 0.027033545524201674, 0.020783802634711357, 0.014570136509599152, 0.008392338895029328, 0.0022502027393163093, 0.0038564778140166567, 0.009927907433135097, 0.01596428960475338, 0.021965826640955255, 0.027932719685973773, 0.03386516872293277, 0.03976337258054974, 0.0456275289397996, 0.05145783434053941, 0.05725448418809642, 0.06301767275981696, 0.06874759321157708, 0.074444437584257, 0.08010839681017679, 0.08573966071949668, 0.09133841804657783, 0.09690485643630886, 0.10243916245039453, 0.10794152157360837, 0.11341211822000963, 0.11885113573912343, 0.1242587564220865, 0.1296351615077559, 0.1349805311887845, 0.14029504461765896, 0.1455788799127048, 0.150832214164056, 0.15605522343959022, 0.1612480827908298, 0.1664109662588089, 0.1715440468799061, 0.17664749669164426, 0.18172148673845612, 0.1867661870774172, 0.19178176678394498, 0.1967683939574657, 0.20172623572704884, 0.20665545825700748, 0.2115562267524681, 0.21642870546490733, 0.22127305769765704, 0.22608944581137724, 0.23087803122949768, 0.23563897444362847, 0.24037243501893846, 0.24507857159950375, 0.24975754191362387, 0.2544095027791091, 0.25903461010853557, 0.2636330189144711, 0.2682048833146704, 0.2727503565372401, 0.27726959092577497, 0.28176273794446316, 0.2862299481831627, 0.2906713713624489, 0.2950871563386319, 0.29947745110874613, 0.3038424028155099, 0.30818215775225744, 0.3124968613678418, 0.31678665827150954, 0.32105169223774754, 0.32529210621110183, 0.32950804231096775, 0.33369964183635414, 0.3378670452706183, 0.34201039228617436, 0.34612982174917506, 0.3502254717241652, 0.3542974794787095, 0.3583459814879929, 0.3623711134393943, 0.36637301023703517, 0.3703518060062999, 0.37430763409833123, 0.37824062709450024, 0.382150916810849, 0.3860386343025094, 0.3899039098680943, 0.39374687305406597, 0.39756765265907645, 0.40136637673828557, 0.4051431726076521, 0.4088981668482009, 0.41263148531026494, 0.41634325311770437, 0.420033594672099, 0.42370263365691796, 0.4273504930416654, 0.43097729508600124, 0.43458316134383945, 0.43816821266742123, 0.4417325692113665, 0.4452763504366992, 0.4487996751148534, 0.45230266133165153, 0.4557854264912642, 0.45924808732014366, 0.46269075987093644, 0.466113559526373, 0.4695166010031345, 0.4728999983556983, 0.47626386498015905, 0.4796083136180316, 0.4829334563600267, 0.4862394046498104, 0.48952626928773724, 0.49279416043456514, 0.4960431876151462, 0.4992734597220987, 0.502485085019456, 0.5056781711462948, 0.5088528251203438, 0.5120091533415689, 0.5151472615957411, 0.5182672550579799, 0.5213692382962802, 0.5244533152750155, 0.5275195893584231, 0.5305681633140683, 0.5335991393162887, 0.536612618949618, 0.5396087032121916, 0.5425874925191313, 0.5455490867059101, 0.5484935850316993, 0.5514210861826941, 0.5543316882754225, 0.5572254888600318, 0.5601025849235602, 0.5629630728931858, 0.5658070486394589, 0.5686346074795151, 0.5714458441802703, 0.5742408529615963, 0.5770197274994786, 0.5797825609291565, 0.5825294458482442, 0.5852604743198346, 0.587975737875584, 0.590675327518781, 0.5933593337273955, 0.5960278464571118, 0.598680955144343, 0.6013187487092291, 0.6039413155586162, 0.6065487435890209, 0.6091411201895749, 0.6117185322449545, 0.6142810661382926, 0.6168288077540738, 0.6193618424810126, 0.6218802552149155, 0.6243841303615265, 0.6268735518393557, 0.6293486030824917, 0.6318093670433984, 0.634255926195695, 0.63668836253692, 0.6391067575912794, 0.6415111924123791, 0.6439017475859419, 0.6462785032325072, 0.6486415390101177, 0.6509909341169882, 0.6533267672941597, 0.6556491168281402, 0.6579580605535259, 0.6602536758556125, 0.6625360396729865, 0.6648052285001057, 0.6670613183898617, 0.6693043849561293, 0.6715345033763009, 0.6737517483938058, 0.6759561943206152, 0.6781479150397334, 0.6803269840076732, 0.6824934742569184, 0.6846474583983716, 0.6867890086237869, 0.6889181967081905, 0.6910350940122858, 0.6931397714848453, 0.6952322996650877, 0.6973127486850434, 0.6993811882719039, 0.7014376877503591, 0.7034823160449208, 0.7055151416822327, 0.7075362327933672, 0.7095456571161084, 0.7115434819972233, 0.7135297743947175, 0.7155046008800812, 0.7174680276405185, 0.719420120481167, 0.7213609448273027, 0.723290565726533, 0.7252090478509766, 0.7271164554994312, 0.7290128525995283, 0.730898302709876, 0.7327728690221889, 0.7346366143634064, 0.7364896011977984, 0.7383318916290577, 0.7401635474023831, 0.7419846299065477, 0.7437952001759569, 0.7455953188926934, 0.7473850463885517, 0.7491644426470598, 0.7509335673054895, 0.7526924796568553, 0.7544412386519017, 0.7561799029010786, 0.7579085306765063, 0.7596271799139276, 0.7613359082146507, 0.7630347728474788, 0.7647238307506297, 0.7664031385336443, 0.7680727524792839, 0.7697327285454164, 0.7713831223668918, 0.7730239892574067, 0.7746553842113586, 0.7762773619056883, 0.7778899767017133, 0.7794932826469491, 0.7810873334769209, 0.7826721826169647, 0.7842478831840172, 0.785814487988397, 0.787372049535574, 0.7889206200279293, 0.7904602513665042, 0.7919909951527409, 0.7935129026902108, 0.7950260249863348, 0.796530412754092, 0.7980261164137203, 0.7995131860944054, 0.8009916716359615, 0.8024616225905014, 0.8039230882240973, 0.8053761175184322, 0.8068207591724412, 0.8082570616039438, 0.809685072951267, 0.811104841074858, 0.8125164135588887, 0.8139198377128505, 0.8153151605731399, 0.8167024289046346, 0.8180816892022615, 0.8194529876925543, 0.8208163703352033, 0.8221718828245954, 0.8235195705913458, 0.8248594788038209, 0.8261916523696514, 0.8275161359372378, 0.8288329738972473, 0.8301422103841005, 0.8314438892774516, 0.8327380542036584, 0.834024748537245, 0.8353040154023548, 0.8365758976741964, 0.8378404379804805, 0.8390976787028483, 0.8403476619782924, 0.8415904297005686, 0.8428260235216002, 0.8440544848528739, 0.845275854866828, 0.8464901744982316, 0.8476974844455577, 0.8488978251723459, 0.8500912369085598, 0.8512777596519343, 0.8524574331693168, 0.8536302969979996, 0.8547963904470455, 0.8559557525986049, 0.8571084223092253, 0.8582544382111545, 0.8593938387136348, 0.8605266620041901, 0.8616529460499065, 0.8627727285987037, 0.8638860471806016, 0.8649929391089768, 0.8660934414818137, 0.8671875911829479, 0.8682754248833026, 0.8693569790421172, 0.870432289908169, 0.8715013935209892, 0.8725643257120698, 0.8736211221060647, 0.8746718181219838, 0.8757164489743803, 0.8767550496745303, 0.8777876550316072, 0.8788142996538473, 0.87983501794971, 0.8808498441290317, 0.8818588122041715, 0.8828619559911519, 0.8838593091107911, 0.8848509049898309, 0.8858367768620565, 0.8868169577694103, 0.8877914805630998, 0.8887603779046975, 0.8897236822672373, 0.8906814259363011, 0.8916336410111021, 0.8925803594055597, 0.89352161284937, 0.8944574328890688, 0.8953878508890885, 0.89631289803281, 0.8972326053236075, 0.8981470035858876, 0.8990561234661223, 0.8999599954338764, 0.9008586497828283, 0.9017521166317857, 0.9026404259256948, 0.9035236074366445, 0.9044016907648628, 0.9052747053397104, 0.9061426804206666, 0.9070056450983093, 0.9078636282952907, 0.9087166587673063, 0.909564765104059, 0.910407975730217, 0.9112463189063664, 0.9120798227299586, 0.9129085151362519, 0.9137324238992478, 0.9145515766326219, 0.9153660007906489, 0.9161757236691238, 0.9169807724062755, 0.9177811739836774, 0.918576955227151, 0.919368142807665, 0.92015476324223, 0.920936842894786, 0.921714407977087, 0.9224874845495791, 0.9232560985222739, 0.9240202756556167, 0.9247800415613507, 0.9255354217033744, 0.9262864413985954, 0.9270331258177792, 0.9277754999863923, 0.9285135887854414, 0.9292474169523071, 0.9299770090815727, 0.9307023896258491, 0.9314235828965939, 0.9321406130649263, 0.9328535041624375, 0.9335622800819954, 0.9342669645785462, 0.9349675812699099, 0.9356641536375725, 0.9363567050274726, 0.9370452586507838, 0.9377298375846925, 0.9384104647731722, 0.9390871630277513, 0.9397599550282786, 0.9404288633236826, 0.9410939103327279, 0.9417551183447666, 0.9424125095204845, 0.9430661058926451, 0.9437159293668265, 0.9443620017221571], \"type\": \"scatter\", \"uid\": \"8a07b4ee-4331-46cb-b241-33f0684c36f9\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 5.460721442885771, 10.871442885771543, 16.282164328657313, 21.692885771543086, 27.10360721442886, 32.51432865731462, 37.925050100200394, 43.33577154308617, 48.74649298597194, 54.15721442885771, 59.56793587174348, 64.97865731462925, 70.38937875751502, 75.80010020040079, 81.21082164328656, 86.62154308617234, 92.03226452905811, 97.44298597194388, 102.85370741482966, 108.26442885771543, 113.67515030060119, 119.08587174348696, 124.49659318637273, 129.9073146292585, 135.31803607214428, 140.72875751503005, 146.13947895791583, 151.5502004008016, 156.96092184368737, 162.37164328657315, 167.78236472945892, 173.1930861723447, 178.60380761523047, 184.01452905811624, 189.425250501002, 194.83597194388778, 200.24669338677356, 205.65741482965933, 211.0681362725451, 216.47885771543088, 221.88957915831662, 227.3003006012024, 232.71102204408817, 238.12174348697394, 243.5324649298597, 248.9431863727455, 254.35390781563126, 259.764629258517, 265.1753507014028, 270.58607214428855, 275.99679358717435, 281.4075150300601, 286.8182364729459, 292.22895791583164, 297.63967935871744, 303.0504008016032, 308.461122244489, 313.87184368737474, 319.28256513026054, 324.6932865731463, 330.1040080160321, 335.5147294589178, 340.92545090180363, 346.3361723446894, 351.7468937875751, 357.1576152304609, 362.56833667334666, 367.97905811623247, 373.3897795591182, 378.800501002004, 384.21122244488976, 389.62194388777556, 395.0326653306613, 400.4433867735471, 405.85410821643285, 411.26482965931865, 416.6755511022044, 422.0862725450902, 427.49699398797594, 432.90771543086174, 438.3184368737475, 443.72915831663323, 449.13987975951903, 454.5506012024048, 459.9613226452906, 465.3720440881763, 470.7827655310621, 476.19348697394787, 481.60420841683367, 487.0149298597194, 492.4256513026052, 497.83637274549096, 503.24709418837676, 508.6578156312625, 514.0685370741483, 519.4792585170339, 524.8899799599197, 530.3007014028055, 535.7114228456913, 541.122144288577, 546.5328657314628, 551.9435871743486, 557.3543086172344, 562.7650300601201, 568.1757515030059, 573.5864729458917, 578.9971943887775, 584.4079158316632, 589.818637274549, 595.2293587174348, 600.6400801603206, 606.0508016032063, 611.4615230460921, 616.8722444889779, 622.2829659318636, 627.6936873747494, 633.1044088176352, 638.515130260521, 643.9258517034067, 649.3365731462925, 654.7472945891783, 660.1580160320641, 665.5687374749498, 670.9794589178356, 676.3901803607214, 681.8009018036072, 687.2116232464929, 692.6223446893787, 698.0330661322645, 703.4437875751502, 708.854509018036, 714.2652304609218, 719.6759519038076, 725.0866733466933, 730.4973947895791, 735.9081162324649, 741.3188376753507, 746.7295591182364, 752.1402805611222, 757.551002004008, 762.9617234468938, 768.3724448897794, 773.7831663326652, 779.193887775551, 784.6046092184367, 790.0153306613225, 795.4260521042083, 800.8367735470941, 806.2474949899798, 811.6582164328656, 817.0689378757514, 822.4796593186372, 827.8903807615229, 833.3011022044087, 838.7118236472945, 844.1225450901803, 849.533266533066, 854.9439879759518, 860.3547094188376, 865.7654308617234, 871.1761523046091, 876.5868737474949, 881.9975951903807, 887.4083166332664, 892.8190380761522, 898.229759519038, 903.6404809619238, 909.0512024048095, 914.4619238476953, 919.8726452905811, 925.2833667334669, 930.6940881763526, 936.1048096192384, 941.5155310621242, 946.92625250501, 952.3369739478957, 957.7476953907815, 963.1584168336673, 968.569138276553, 973.9798597194388, 979.3905811623246, 984.8013026052104, 990.212024048096, 995.6227454909819, 1001.0334669338677, 1006.4441883767535, 1011.8549098196391, 1017.265631262525, 1022.6763527054107, 1028.0870741482966, 1033.4977955911822, 1038.908517034068, 1044.3192384769538, 1049.7299599198395, 1055.1406813627254, 1060.5514028056111, 1065.9621242484968, 1071.3728456913827, 1076.7835671342684, 1082.194288577154, 1087.60501002004, 1093.0157314629257, 1098.4264529058116, 1103.8371743486973, 1109.247895791583, 1114.658617234469, 1120.0693386773546, 1125.4800601202403, 1130.8907815631262, 1136.301503006012, 1141.7122244488976, 1147.1229458917835, 1152.5336673346692, 1157.944388777555, 1163.3551102204408, 1168.7658316633265, 1174.1765531062124, 1179.587274549098, 1184.9979959919838, 1190.4087174348697, 1195.8194388777554, 1201.2301603206413, 1206.640881763527, 1212.0516032064127, 1217.4623246492986, 1222.8730460921843, 1228.28376753507, 1233.6944889779559, 1239.1052104208416, 1244.5159318637272, 1249.9266533066132, 1255.3373747494988, 1260.7480961923848, 1266.1588176352705, 1271.5695390781561, 1276.980260521042, 1282.3909819639277, 1287.8017034068134, 1293.2124248496993, 1298.623146292585, 1304.0338677354707, 1309.4445891783566, 1314.8553106212423, 1320.2660320641282, 1325.676753507014, 1331.0874749498996, 1336.4981963927855, 1341.9089178356712, 1347.319639278557, 1352.7303607214428, 1358.1410821643285, 1363.5518036072144, 1368.9625250501, 1374.3732464929858, 1379.7839679358717, 1385.1946893787574, 1390.605410821643, 1396.016132264529, 1401.4268537074147, 1406.8375751503004, 1412.2482965931863, 1417.659018036072, 1423.069739478958, 1428.4804609218436, 1433.8911823647293, 1439.3019038076152, 1444.7126252505009, 1450.1233466933866, 1455.5340681362725, 1460.9447895791582, 1466.355511022044, 1471.7662324649298, 1477.1769539078155, 1482.5876753507014, 1487.998396793587, 1493.4091182364728, 1498.8198396793587, 1504.2305611222444, 1509.64128256513, 1515.052004008016, 1520.4627254509016, 1525.8734468937876, 1531.2841683366732, 1536.694889779559, 1542.1056112224448, 1547.5163326653305, 1552.9270541082162, 1558.3377755511021, 1563.7484969939878, 1569.1592184368735, 1574.5699398797594, 1579.9806613226451, 1585.391382765531, 1590.8021042084167, 1596.2128256513024, 1601.6235470941883, 1607.034268537074, 1612.4449899799597, 1617.8557114228456, 1623.2664328657313, 1628.6771543086172, 1634.087875751503, 1639.4985971943886, 1644.9093186372745, 1650.3200400801602, 1655.7307615230459, 1661.1414829659318, 1666.5522044088175, 1671.9629258517032, 1677.373647294589, 1682.7843687374748, 1688.1950901803607, 1693.6058116232464, 1699.016533066132, 1704.427254509018, 1709.8379759519037, 1715.2486973947894, 1720.6594188376753, 1726.070140280561, 1731.4808617234469, 1736.8915831663326, 1742.3023046092183, 1747.7130260521042, 1753.1237474949899, 1758.5344689378755, 1763.9451903807615, 1769.3559118236471, 1774.7666332665328, 1780.1773547094188, 1785.5880761523044, 1790.9987975951904, 1796.409519038076, 1801.8202404809617, 1807.2309619238476, 1812.6416833667333, 1818.052404809619, 1823.463126252505, 1828.8738476953906, 1834.2845691382763, 1839.6952905811622, 1845.106012024048, 1850.5167334669338, 1855.9274549098195, 1861.3381763527052, 1866.7488977955911, 1872.1596192384768, 1877.5703406813625, 1882.9810621242484, 1888.391783567134, 1893.80250501002, 1899.2132264529057, 1904.6239478957914, 1910.0346693386773, 1915.445390781563, 1920.8561122244487, 1926.2668336673346, 1931.6775551102203, 1937.088276553106, 1942.4989979959919, 1947.9097194388776, 1953.3204408817635, 1958.7311623246492, 1964.1418837675349, 1969.5526052104208, 1974.9633266533065, 1980.3740480961922, 1985.784769539078, 1991.1954909819638, 1996.6062124248494, 2002.0169338677354, 2007.427655310621, 2012.838376753507, 2018.2490981963927, 2023.6598196392783, 2029.0705410821643, 2034.48126252505, 2039.8919839679356, 2045.3027054108215, 2050.7134268537075, 2056.1241482965934, 2061.534869739479, 2066.9455911823648, 2072.3563126252507, 2077.767034068136, 2083.177755511022, 2088.588476953908, 2093.999198396794, 2099.4099198396793, 2104.8206412825652, 2110.231362725451, 2115.6420841683366, 2121.0528056112225, 2126.4635270541085, 2131.874248496994, 2137.28496993988, 2142.6956913827657, 2148.106412825651, 2153.517134268537, 2158.927855711423, 2164.3385771543085, 2169.7492985971944, 2175.1600200400803, 2180.570741482966, 2185.9814629258517, 2191.3921843687376, 2196.8029058116235, 2202.213627254509, 2207.624348697395, 2213.035070140281, 2218.4457915831663, 2223.856513026052, 2229.267234468938, 2234.6779559118236, 2240.0886773547095, 2245.4993987975954, 2250.910120240481, 2256.320841683367, 2261.7315631262527, 2267.142284569138, 2272.553006012024, 2277.96372745491, 2283.3744488977954, 2288.7851703406814, 2294.1958917835673, 2299.606613226453, 2305.0173346693387, 2310.4280561122246, 2315.8387775551105, 2321.249498997996, 2326.660220440882, 2332.070941883768, 2337.4816633266532, 2342.892384769539, 2348.303106212425, 2353.7138276553105, 2359.1245490981964, 2364.5352705410824, 2369.945991983968, 2375.3567134268537, 2380.7674348697396, 2386.178156312625, 2391.588877755511, 2396.999599198397, 2402.410320641283, 2407.8210420841683, 2413.231763527054, 2418.64248496994, 2424.0532064128256, 2429.4639278557115, 2434.8746492985974, 2440.285370741483, 2445.696092184369, 2451.1068136272547, 2456.51753507014, 2461.928256513026, 2467.338977955912, 2472.7496993987975, 2478.1604208416834, 2483.5711422845693, 2488.9818637274548, 2494.3925851703407, 2499.8033066132266, 2505.2140280561125, 2510.624749498998, 2516.035470941884, 2521.44619238477, 2526.8569138276553, 2532.267635270541, 2537.678356713427, 2543.0890781563126, 2548.4997995991985, 2553.9105210420844, 2559.32124248497, 2564.7319639278558, 2570.1426853707417, 2575.553406813627, 2580.964128256513, 2586.374849699399, 2591.7855711422844, 2597.1962925851703, 2602.6070140280563, 2608.0177354709417, 2613.4284569138276, 2618.8391783567135, 2624.2498997995995, 2629.660621242485, 2635.071342685371, 2640.4820641282568, 2645.892785571142, 2651.303507014028, 2656.714228456914, 2662.1249498997995, 2667.5356713426854, 2672.9463927855713, 2678.357114228457, 2683.7678356713427, 2689.1785571142286, 2694.589278557114, 2700.0], \"y\": [0.9501018236073877, 0.9381147349201273, 0.9261994953719732, 0.9143556743079992, 0.9025828436545724, 0.8908805779038802, 0.8792484540985523, 0.8676860518163727, 0.8561929531550845, 0.8447687427172856, 0.8334130075954151, 0.8221253373568294, 0.8109053240289679, 0.7997525620846071, 0.7886666484272045, 0.7776471823763282, 0.7666937656531763, 0.7558060023661806, 0.7449834989966986, 0.7342258643847905, 0.723532709715081, 0.7129036485027065, 0.7023382965793459, 0.6918362720793367, 0.6813971954258715, 0.6710206893172803, 0.6607063787133929, 0.6504538908219832, 0.6402628550852973, 0.6301329031666578, 0.6200636689371528, 0.6100547884624021, 0.6001058999894031, 0.5902166439334569, 0.580386662865171, 0.5706156014975408, 0.560903106673108, 0.5512488273511977, 0.5416524145952291, 0.532113521560104, 0.5226318034796726, 0.5132069176542697, 0.5038385234383307, 0.49452628222807826, 0.48526985744928464, 0.47606891454510714, 0.46692312096399524, 0.45783214614767154, 0.44879566151918504, 0.43981334047103404, 0.43088485835336243, 0.42200989246222553, 0.41318812202792654, 0.40441922820342247, 0.3957028940528011, 0.38703880453982453, 0.378426646516544, 0.36986610871198033, 0.36135688172087543, 0.3528986579925073, 0.34449113181957647, 0.3361339993271544, 0.32782695846170196, 0.31956970898015213, 0.31136195243905807, 0.30320339218380576, 0.2950937333378927, 0.2870326827922707, 0.2790199491947505, 0.27105524293947214, 0.26313827615643803, 0.2552687627011079, 0.24744641814405655, 0.2396709597606943, 0.2319421065210472, 0.2242595790796016, 0.21662309976520566, 0.20903239257103468, 0.20148718314461478, 0.19398719877790782, 0.18653216839745368, 0.1791218225545732, 0.17175589341562958, 0.16443411475234848, 0.1571562219321947, 0.14992195190880797, 0.1427310432124962, 0.13558323594078336, 0.1284782717490185, 0.1214158938410359, 0.1143958469598747, 0.1074178773785528, 0.10048173289089668, 0.09358716280242607, 0.08673391792129204, 0.07992175054927131, 0.07315041447281345, 0.06641966495414131, 0.05972925872240675, 0.05307895396489659, 0.04646851031829424, 0.03989768885999023, 0.03336625209944866, 0.026873963969622272, 0.020420589818421764, 0.014005896400232087, 0.007629651867484988, 0.0012916257622777039, 0.005008410991955703, 0.011270686098725502, 0.017495425896713712, 0.023682855367956668, 0.02983319814597607, 0.03594667652386163, 0.04202351146230554, 0.04806392259758807, 0.05406812824951801, 0.06003634542932079, 0.06596878984748367, 0.07186567592155124, 0.0777272167838764, 0.08355362428932223, 0.08934510902292003, 0.09510188030748001, 0.10082414621115765, 0.10651211355497292, 0.1121659879202862, 0.11778597365622823, 0.12337227388708638, 0.12892509051964585, 0.1344446242504873, 0.13993107457324072, 0.14538463978579574, 0.1508055169974689, 0.15619390213612738, 0.16154998995527114, 0.1668739740410713, 0.1721660468193673, 0.17742639956262152, 0.18265522239683307, 0.18785270430840872, 0.19301903315099422, 0.19815439565226312, 0.20325897742066712, 0.20833296295214265, 0.21337653563678072, 0.2183898777654545, 0.22337317053640782, 0.22832659406180467, 0.2332503273742388, 0.23814454843320465, 0.24300943413152898, 0.24784516030176507, 0.2526519017225469, 0.25742983212490733, 0.2621791241985564, 0.26689994959812313, 0.27159247894936, 0.2762568818553096, 0.2808933269024346, 0.28550198166671126, 0.2900830127196855, 0.2946365856344946, 0.2991628649918502, 0.3036620143859874, 0.3081341964305778, 0.31257957276460646, 0.31699830405821416, 0.32139055001850436, 0.3257564693953162, 0.33009621998696126, 0.33440995864592793, 0.3386978412845494, 0.34296002288064, 0.347196657483096, 0.351407898217463, 0.3555938972914713, 0.3597548060005369, 0.36389077473322906, 0.3680019529767067, 0.37208848932212124, 0.3761505314699869, 0.3801882262355186, 0.38420171955393967, 0.3881911564857553, 0.3921566812219953, 0.39609843708942705, 0.40001656655573403, 0.40391121123466645, 0.4077825118911591, 0.4116306084464184, 0.41545563998298085, 0.4192577447497392, 0.4230370601669391, 0.4267937228311459, 0.43052786852018265, 0.43423963219803585, 0.43792914801973515, 0.4415965493362012, 0.4452419686990652, 0.4488655378654607, 0.45246738780278506, 0.4560476486934326, 0.45960644993950106, 0.4631439201674673, 0.4666601872328372, 0.4701553782247664, 0.4736296194706534, 0.4770830365407063, 0.4805157542524804, 0.48392789667538993, 0.4873195871351923, 0.4906909482184457, 0.49404210177693897, 0.49737316893209704, 0.500684270079357, 0.5039755248925211, 0.5072470523280815, 0.5104989706295192, 0.5137313973315789, 0.5169444492645162, 0.5201382425583203, 0.5233128926469118, 0.5264685142723142, 0.5296052214888018, 0.5327231276670213, 0.5358223454980896, 0.5389029869976671, 0.541965163510006, 0.5450089857119745, 0.5480345636170576, 0.5510420065793327, 0.554031423297422, 0.5570029218184225, 0.5599566095418087, 0.5628925932233171, 0.5658109789788028, 0.5687118722880757, 0.5715953779987124, 0.5744616003298462, 0.5773106428759337, 0.5801426086104988, 0.5829575998898553, 0.585755718456805, 0.5885370654443165, 0.5913017413791793, 0.5940498461856382, 0.5967814791890038, 0.5994967391192434, 0.6021957241145486, 0.6048785317248832, 0.6075452589155077, 0.6101960020704857, 0.6128308569961658, 0.6154499189246455, 0.6180532825172127, 0.6206410418677668, 0.6232132905062204, 0.6257701214018794, 0.6283116269668022, 0.6308378990591416, 0.6333490289864635, 0.6358451075090474, 0.6383262248431671, 0.6407924706643506, 0.6432439341106224, 0.6456807037857244, 0.6481028677623181, 0.6505105135851688, 0.6529037282743093, 0.6552825983281845, 0.6576472097267785, 0.6599976479347219, 0.662333997904381, 0.6646563440789277, 0.6669647703953918, 0.6692593602876955, 0.6715401966896677, 0.673807362038042, 0.676060938275437, 0.6783010068533168, 0.6805276487349354, 0.6827409443982633, 0.6849409738388954, 0.6871278165729433, 0.6893015516399087, 0.69146225760554, 0.6936100125646725, 0.6957448941440503, 0.6978669795051322, 0.6999763453468814, 0.7020730679085361, 0.7041572229723663, 0.7062288858664123, 0.7082881314672074, 0.7103350342024839, 0.7123696680538637, 0.7143921065595318, 0.7164024228168944, 0.7184006894852208, 0.7203869787882695, 0.7223613625168986, 0.7243239120316608, 0.7262746982653823, 0.7282137917257264, 0.7301412624977426, 0.7320571802463989, 0.7339616142191001, 0.7358546332481903, 0.7377363057534415, 0.7396066997445256, 0.7414658828234728, 0.7433139221871155, 0.7451508846295158, 0.7469768365443812, 0.7487918439274628, 0.7505959723789415, 0.752389287105799, 0.7541718529241739, 0.7559437342617052, 0.7577049951598605, 0.75945569927625, 0.7611959098869292, 0.762925689888684, 0.7646451018013045, 0.7663542077698451, 0.7680530695668706, 0.7697417485946882, 0.7714203058875675, 0.7730888021139459, 0.7747472975786218, 0.7763958522249343, 0.778034525636929, 0.7796633770415121, 0.7812824653105914, 0.7828918489632033, 0.7844915861676285, 0.7860817347434941, 0.7876623521638633, 0.7892334955573128, 0.7907952217099982, 0.792347587067705, 0.7938906477378903, 0.7954244594917095, 0.7969490777660325, 0.798464557665448, 0.799970953964254, 0.8014683211084382, 0.8029567132176461, 0.8044361840871357, 0.8059067871897242, 0.807368575677718, 0.8088216023848361, 0.8102659198281179, 0.8117015802098227, 0.8131286354193156, 0.8145471370349431, 0.8159571363258975, 0.81735868425407, 0.8187518314758923, 0.8201366283441678, 0.8215131249098913, 0.8228813709240579, 0.8242414158394618, 0.8255933088124826, 0.8269370987048632, 0.8282728340854749, 0.8296005632320732, 0.8309203341330424, 0.8322321944891309, 0.8335361917151739, 0.8348323729418086, 0.8361207850171766, 0.8374014745086173, 0.8386744877043518, 0.8399398706151546, 0.8411976689760177, 0.842447928247803, 0.8436906936188856, 0.8449260100067869, 0.8461539220597984, 0.8473744741585951, 0.8485877104178398, 0.8497936746877771, 0.850992410555819, 0.8521839613481197, 0.8533683701311419, 0.8545456797132129, 0.8557159326460724, 0.8568791712264101, 0.8580354374973946, 0.8591847732501927, 0.8603272200254805, 0.8614628191149438, 0.8625916115627716, 0.863713638167139, 0.8648289394816815, 0.8659375558169612, 0.867039527241924, 0.8681348935853471, 0.8692236944372789, 0.8703059691504702, 0.8713817568417959, 0.8724510963936691, 0.8735140264554471, 0.8745705854448269, 0.8756208115492351, 0.8766647427272071, 0.87770241670976, 0.8787338710017556, 0.8797591428832557, 0.880778269410871, 0.8817912874190983, 0.8827982335216538, 0.883799144112795, 0.8847940553686372, 0.8857830032484598, 0.8867660234960076, 0.8877431516407811, 0.8887144229993214, 0.8896798726764868, 0.8906395355667216, 0.8915934463553162, 0.8925416395196627, 0.8934841493304992, 0.8944210098531497, 0.895352254948754, 0.8962779182754937, 0.8971980332898062, 0.8981126332475956, 0.8990217512054343, 0.8999254200217575, 0.9008236723580506, 0.901716540680031, 0.9026040572588198, 0.903486254172109, 0.9043631633053213, 0.9052348163527618, 0.9061012448187635, 0.9069624800188272, 0.9078185530807512, 0.9086694949457588, 0.9095153363696146, 0.9103561079237372, 0.9111918399963039, 0.9120225627933489, 0.9128483063398553, 0.9136691004808399, 0.9144849748824322, 0.9152959590329466, 0.9161020822439483, 0.9169033736513122, 0.917699862216277, 0.9184915767264905, 0.9192785457970511, 0.9200607978715424, 0.92083836122306, 0.921611263955234, 0.9223795340032453, 0.9231431991348344, 0.9239022869513054, 0.9246568248885236, 0.9254068402179072, 0.9261523600474126, 0.9268934113225148, 0.9276300208271805, 0.928362215184837, 0.9290900208593336, 0.929813464155899, 0.9305325712220914, 0.9312473680487438, 0.9319578804709029, 0.9326641341687639, 0.9333661546685978, 0.9340639673436744, 0.9347575974151787, 0.9354470699531239, 0.9361324098772559, 0.9368136419579549, 0.9374907908171306, 0.938163880929112, 0.9388329366215317, 0.9394979820762057, 0.9401590413300072, 0.9408161382757352, 0.9414692966629781, 0.9421185400989723, 0.9427638920494555, 0.9434053758395146, 0.9440430146544282, 0.9446768315405061, 0.9453068494059206, 0.9459330910215356, 0.9465555790217293, 0.9471743359052118, 0.9477893840358392, 0.9484007456434211, 0.9490084428245245, 0.9496124975432718, 0.9502129316321359], \"type\": \"scatter\", \"uid\": \"453023bd-1bbe-4592-a678-6c2fd71881e6\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 5.661122244488977, 11.272244488977956, 16.883366733466932, 22.49448897795591, 28.10561122244489, 33.71673346693386, 39.32785571142284, 44.93897795591182, 50.55010020040079, 56.16122244488977, 61.77234468937875, 67.38346693386772, 72.9945891783567, 78.60571142284569, 84.21683366733465, 89.82795591182364, 95.43907815631262, 101.05020040080159, 106.66132264529057, 112.27244488977955, 117.88356713426852, 123.4946893787575, 129.1058116232465, 134.71693386773546, 140.32805611222446, 145.93917835671343, 151.5503006012024, 157.1614228456914, 162.77254509018036, 168.38366733466933, 173.99478957915832, 179.6059118236473, 185.21703406813626, 190.82815631262525, 196.43927855711422, 202.0504008016032, 207.66152304609219, 213.27264529058115, 218.88376753507012, 224.49488977955912, 230.10601202404808, 235.71713426853705, 241.32825651302605, 246.93937875751502, 252.55050100200398, 258.161623246493, 263.77274549098195, 269.3838677354709, 274.9949899799599, 280.6061122244489, 286.2172344689379, 291.82835671342684, 297.4394789579158, 303.0506012024048, 308.66172344689375, 314.27284569138277, 319.88396793587174, 325.4950901803607, 331.1062124248497, 336.71733466933864, 342.3284569138276, 347.93957915831663, 353.5507014028056, 359.16182364729457, 364.77294589178354, 370.3840681362725, 375.9951903807615, 381.6063126252505, 387.21743486973946, 392.82855711422843, 398.4396793587174, 404.05080160320637, 409.6619238476954, 415.27304609218436, 420.8841683366733, 426.4952905811623, 432.10641282565126, 437.71753507014023, 443.32865731462925, 448.9397795591182, 454.5509018036072, 460.16202404809616, 465.7731462925851, 471.3842685370741, 476.9953907815631, 482.6065130260521, 488.21763527054105, 493.82875751503, 499.439879759519, 505.05100200400796, 510.662124248497, 516.2732464929859, 521.8843687374748, 527.4954909819638, 533.1066132264529, 538.7177354709418, 544.3288577154308, 549.9399799599197, 555.5511022044087, 561.1622244488977, 566.7733466933867, 572.3844689378757, 577.9955911823646, 583.6067134268536, 589.2178356713426, 594.8289579158316, 600.4400801603206, 606.0512024048095, 611.6623246492985, 617.2734468937874, 622.8845691382764, 628.4956913827655, 634.1068136272544, 639.7179358717434, 645.3290581162323, 650.9401803607213, 656.5513026052104, 662.1624248496993, 667.7735470941883, 673.3846693386772, 678.9957915831662, 684.6069138276551, 690.2180360721442, 695.8291583166332, 701.4402805611221, 707.0514028056111, 712.6625250501, 718.2736472945891, 723.8847695390781, 729.495891783567, 735.107014028056, 740.7181362725449, 746.329258517034, 751.940380761523, 757.5515030060119, 763.1626252505009, 768.7737474949898, 774.3848697394789, 779.9959919839678, 785.6071142284568, 791.2182364729458, 796.8293587174347, 802.4404809619238, 808.0516032064127, 813.6627254509017, 819.2738476953907, 824.8849699398796, 830.4960921843686, 836.1072144288576, 841.7183366733466, 847.3294589178355, 852.9405811623245, 858.5517034068135, 864.1628256513025, 869.7739478957915, 875.3850701402804, 880.9961923847694, 886.6073146292584, 892.2184368737474, 897.8295591182364, 903.4406813627253, 909.0518036072143, 914.6629258517033, 920.2740480961922, 925.8851703406813, 931.4962925851702, 937.1074148296592, 942.7185370741481, 948.3296593186371, 953.9407815631262, 959.5519038076151, 965.1630260521041, 970.774148296593, 976.385270541082, 981.9963927855711, 987.60751503006, 993.218637274549, 998.8297595190379, 1004.4408817635269, 1010.0520040080158, 1015.6631262525049, 1021.2742484969939, 1026.8853707414828, 1032.4964929859718, 1038.1076152304609, 1043.7187374749496, 1049.3298597194387, 1054.9409819639277, 1060.5521042084167, 1066.1632264529057, 1071.7743486973945, 1077.3854709418836, 1082.9965931863726, 1088.6077154308616, 1094.2188376753506, 1099.8299599198394, 1105.4410821643285, 1111.0522044088175, 1116.6633266533065, 1122.2744488977955, 1127.8855711422843, 1133.4966933867734, 1139.1078156312624, 1144.7189378757514, 1150.3300601202404, 1155.9411823647292, 1161.5523046092183, 1167.1634268537073, 1172.7745490981963, 1178.3856713426853, 1183.9967935871741, 1189.6079158316631, 1195.2190380761522, 1200.8301603206412, 1206.44128256513, 1212.052404809619, 1217.663527054108, 1223.274649298597, 1228.885771543086, 1234.496893787575, 1240.108016032064, 1245.719138276553, 1251.330260521042, 1256.941382765531, 1262.5525050100198, 1268.1636272545088, 1273.7747494989978, 1279.3858717434869, 1284.9969939879759, 1290.6081162324647, 1296.2192384769537, 1301.8303607214427, 1307.4414829659318, 1313.0526052104208, 1318.6637274549096, 1324.2748496993986, 1329.8859719438876, 1335.4970941883766, 1341.1082164328657, 1346.7193386773545, 1352.3304609218435, 1357.9415831663325, 1363.5527054108215, 1369.1638276553103, 1374.7749498997994, 1380.3860721442884, 1385.9971943887774, 1391.6083166332664, 1397.2194388777552, 1402.8305611222443, 1408.4416833667333, 1414.0528056112223, 1419.6639278557113, 1425.2750501002001, 1430.8861723446892, 1436.4972945891782, 1442.1084168336672, 1447.7195390781562, 1453.330661322645, 1458.941783567134, 1464.552905811623, 1470.164028056112, 1475.7751503006011, 1481.38627254509, 1486.997394789579, 1492.608517034068, 1498.219639278557, 1503.830761523046, 1509.4418837675348, 1515.0530060120238, 1520.6641282565129, 1526.275250501002, 1531.8863727454907, 1537.4974949899797, 1543.1086172344687, 1548.7197394789578, 1554.3308617234468, 1559.9419839679356, 1565.5531062124246, 1571.1642284569136, 1576.7753507014027, 1582.3864729458917, 1587.9975951903805, 1593.6087174348695, 1599.2198396793585, 1604.8309619238476, 1610.4420841683366, 1616.0532064128254, 1621.6643286573144, 1627.2754509018034, 1632.8865731462924, 1638.4976953907815, 1644.1088176352703, 1649.7199398797593, 1655.3310621242483, 1660.9421843687373, 1666.5533066132264, 1672.1644288577152, 1677.7755511022042, 1683.3866733466932, 1688.9977955911822, 1694.608917835671, 1700.22004008016, 1705.831162324649, 1711.442284569138, 1717.0534068136271, 1722.664529058116, 1728.275651302605, 1733.886773547094, 1739.497895791583, 1745.109018036072, 1750.7201402805608, 1756.3312625250499, 1761.9423847695389, 1767.553507014028, 1773.164629258517, 1778.7757515030057, 1784.3868737474947, 1789.9979959919838, 1795.6091182364728, 1801.2202404809618, 1806.8313627254506, 1812.4424849699396, 1818.0536072144287, 1823.6647294589177, 1829.2758517034067, 1834.8869739478955, 1840.4980961923845, 1846.1092184368736, 1851.7203406813626, 1857.3314629258514, 1862.9425851703404, 1868.5537074148294, 1874.1648296593185, 1879.7759519038075, 1885.3870741482963, 1890.9981963927853, 1896.6093186372743, 1902.2204408817634, 1907.8315631262524, 1913.4426853707412, 1919.0538076152302, 1924.6649298597192, 1930.2760521042082, 1935.8871743486973, 1941.498296593186, 1947.109418837675, 1952.7205410821641, 1958.3316633266531, 1963.9427855711422, 1969.553907815631, 1975.16503006012, 1980.776152304609, 1986.387274549098, 1991.998396793587, 1997.6095190380759, 2003.2206412825649, 2008.831763527054, 2014.442885771543, 2020.0540080160317, 2025.6651302605208, 2031.2762525050098, 2036.8873747494988, 2042.4984969939878, 2048.109619238477, 2053.720741482966, 2059.331863727455, 2064.942985971944, 2070.5541082164327, 2076.165230460922, 2081.7763527054108, 2087.3874749498996, 2092.998597194389, 2098.6097194388776, 2104.220841683367, 2109.8319639278557, 2115.4430861723445, 2121.0542084168337, 2126.6653306613225, 2132.2764529058118, 2137.8875751503006, 2143.4986973947894, 2149.1098196392786, 2154.7209418837674, 2160.3320641282567, 2165.9431863727455, 2171.5543086172343, 2177.1654308617235, 2182.7765531062123, 2188.3876753507016, 2193.9987975951904, 2199.609919839679, 2205.2210420841684, 2210.832164328657, 2216.4432865731465, 2222.0544088176352, 2227.665531062124, 2233.2766533066133, 2238.887775551102, 2244.4988977955913, 2250.11002004008, 2255.721142284569, 2261.332264529058, 2266.943386773547, 2272.5545090180362, 2278.165631262525, 2283.776753507014, 2289.387875751503, 2294.998997995992, 2300.610120240481, 2306.22124248497, 2311.8323647294587, 2317.443486973948, 2323.054609218437, 2328.665731462926, 2334.276853707415, 2339.8879759519036, 2345.499098196393, 2351.1102204408817, 2356.721342685371, 2362.3324649298597, 2367.9435871743485, 2373.554709418838, 2379.1658316633266, 2384.776953907816, 2390.3880761523046, 2395.9991983967934, 2401.6103206412827, 2407.2214428857715, 2412.8325651302603, 2418.4436873747495, 2424.0548096192383, 2429.6659318637276, 2435.2770541082164, 2440.888176352705, 2446.4992985971944, 2452.110420841683, 2457.7215430861725, 2463.3326653306613, 2468.94378757515, 2474.5549098196393, 2480.166032064128, 2485.7771543086174, 2491.388276553106, 2496.999398797595, 2502.610521042084, 2508.221643286573, 2513.8327655310623, 2519.443887775551, 2525.05501002004, 2530.666132264529, 2536.277254509018, 2541.888376753507, 2547.499498997996, 2553.1106212424847, 2558.721743486974, 2564.332865731463, 2569.943987975952, 2575.555110220441, 2581.1662324649296, 2586.777354709419, 2592.3884769539077, 2597.999599198397, 2603.6107214428857, 2609.2218436873745, 2614.832965931864, 2620.4440881763526, 2626.055210420842, 2631.6663326653306, 2637.2774549098194, 2642.8885771543087, 2648.4996993987975, 2654.1108216432867, 2659.7219438877755, 2665.3330661322643, 2670.9441883767536, 2676.5553106212424, 2682.1664328657316, 2687.7775551102204, 2693.388677354709, 2698.9997995991985, 2704.6109218436873, 2710.2220440881765, 2715.8331663326653, 2721.444288577154, 2727.0554108216434, 2732.666533066132, 2738.277655310621, 2743.88877755511, 2749.499899799599, 2755.1110220440883, 2760.722144288577, 2766.333266533066, 2771.944388777555, 2777.555511022044, 2783.166633266533, 2788.777755511022, 2794.3888777555107, 2800.0], \"y\": [0.9553374657307618, 0.942907785082002, 0.9305553572054586, 0.9182797019608142, 0.9060803421919121, 0.8939568037082102, 0.881908615266348, 0.8699353085518304, 0.8580364181608238, 0.8462114815820654, 0.8344600391788863, 0.8227816341713448, 0.8111758126184705, 0.7996421234006212, 0.7881801182019468, 0.7767893514929631, 0.7654693805132351, 0.7542197652541651, 0.7430400684418914, 0.7319298555202898, 0.7208886946340833, 0.709916156612056, 0.6990118149503701, 0.6881752457959889, 0.6774060279302003, 0.6667037427522458, 0.6560679742630469, 0.6454983090490378, 0.6349943362660941, 0.6245556476235639, 0.6141818373683976, 0.6038725022693763, 0.5936272416014374, 0.5834456571300999, 0.573327353095983, 0.5632719361994247, 0.5532790155851928, 0.5433482028272929, 0.5334791119138709, 0.5236713592322075, 0.5139245635538079, 0.5042383460195827, 0.4946123301251226, 0.48504614170606297, 0.47553940892353963, 0.4660917622497369, 0.456702834453522, 0.44737226058617274, 0.4380996779671904, 0.4288847261702031, 0.4197270470089556, 0.4106262845233868, 0.4015820849657936, 0.39259409678708024, 0.38366197062309415, 0.3747853592810455, 0.36596391772601233, 0.3571973030675286, 0.34848517454625627, 0.33982719352073976, 0.33122302345424304, 0.3226723299016685, 0.3141747804965562, 0.3057300449381666, 0.2973377949786393, 0.28899770441023653, 0.28070944905266093, 0.27247270674045687, 0.26428715731048613, 0.2561524825894843, 0.2480683663816925, 0.24003449445656733, 0.23205055453656653, 0.22411623628501087, 0.21623123129402066, 0.20839523307252938, 0.20060793703436852, 0.19286904048642928, 0.18517824261689686, 0.17753524448355784, 0.1699397490021799, 0.1623914609349646, 0.15489008687907124, 0.14743533525521157, 0.1400269162963177, 0.1326645420362773, 0.1253479262987407, 0.11807678468599803, 0.1108508345679231, 0.1036697950709895, 0.0965333870673506, 0.08944133316399228, 0.08239335769194911, 0.07538918669558936, 0.06842854792196595, 0.06151117081023494, 0.05463678648113901, 0.04780512772655365, 0.04101592899910367, 0.03426892640183943, 0.027563857677980197, 0.020900462200720282, 0.014278480963096474, 0.00769765656792365, 0.0011577332177863386, 0.005341543294901108, 0.011800425597777497, 0.01821916474835472, 0.024598010243774393, 0.03093721003050831, 0.03723701051399364, 0.04349765656821303, 0.049719391545211655, 0.05590245728455623, 0.062047094122736124, 0.06815354090250425, 0.07422203498216207, 0.08025281224478498, 0.08624610710739089, 0.09220215253005315, 0.09812118002495418, 0.10400341966538595, 0.10984910009469173, 0.1156584485351545, 0.12143169079682792, 0.1271690512863145, 0.13287075301548845, 0.13853701761016324, 0.14416806531870718, 0.14976411502060394, 0.15532538423496034, 0.16085208912896198, 0.16634444452627506, 0.1718026639153969, 0.1772269594579542, 0.18261754199694946, 0.18797462106495744, 0.19329840489226824, 0.1985891004149829, 0.20384691328305538, 0.2090720478682877, 0.21426470727227287, 0.2194250933342896, 0.22455340663914847, 0.22964984652498788, 0.23471461109102298, 0.23974789720524525, 0.24474990051207512, 0.24972081543996705, 0.2546608352089659, 0.2595701518382185, 0.264448956153437, 0.26929743779431636, 0.2741157852219055, 0.278904185725933, 0.2836628254320871, 0.2883918893092501, 0.2930915611766888, 0.29776202371119875, 0.30240345845420535, 0.3070160458188206, 0.31159996509685506, 0.3161553944657882, 0.32068251099569267, 0.32518149065611757, 0.3296525083229297, 0.3340957377851087, 0.33851135175150404, 0.3428995218575476, 0.34726041867192525, 0.35159421170320637, 0.3559010694064336, 0.3601811591896702, 0.364434647420507, 0.36866169943252936, 0.37286247953174423, 0.3770371510029654, 0.38118587611616184, 0.3853088161327646, 0.3894061313119347, 0.39347798091679254, 0.39752452322060927, 0.40154591551295804, 0.40554231410582775, 0.40951387433969966, 0.4134607505895851, 0.41738309627102577, 0.4212810638460579, 0.42515480482913703, 0.429004469793029, 0.43283020837466135, 0.43663216928094073, 0.44041050029453266, 0.4441653482796062, 0.44789685918754185, 0.4516051780626056, 0.45529044904758587, 0.4589528153893978, 0.4625924194446497, 0.4662094026851772, 0.46980390570354225, 0.473376068218498, 0.4769260290804197, 0.4804539262767017, 0.4839598969371208, 0.4874440773391673, 0.490906602913341, 0.4943476082484166, 0.4977672270966742, 0.5011655923790989, 0.5045428361905467, 0.5078990898048804, 0.5112344836800705, 0.5145491474632679, 0.5178432099958412, 0.5211167993183873, 0.5243700426757061, 0.5276030665217479, 0.530815996524528, 0.5340089575710119, 0.5371820737719688, 0.5403354684667975, 0.5434692642283186, 0.5465835828675405, 0.549678545438393, 0.5527542722424337, 0.5558108828335235, 0.5588484960224742, 0.5618672298816656, 0.5648672017496366, 0.5678485282356445, 0.5708113252241992, 0.5737557078795663, 0.5766817906502446, 0.5795896872734136, 0.5824795107793557, 0.5853513734958486, 0.5882053870525329, 0.591041662385249, 0.5938603097403515, 0.5966614386789928, 0.5994451580813831, 0.6022115761510212, 0.6049608004189013, 0.6076929377476924, 0.6104080943358927, 0.6131063757219564, 0.615787886788397, 0.6184527317658635, 0.621101014237192, 0.6237328371414324, 0.6263483027778491, 0.6289475128098976, 0.631530568269176, 0.6340975695593523, 0.6366486164600674, 0.639183808130813, 0.641703243114786, 0.6442070193427192, 0.6466952341366878, 0.649167984213892, 0.6516253656904168, 0.654067474084968, 0.6564944043225848, 0.6589062507383293, 0.6613031070809545, 0.6636850665165468, 0.6660522216321485, 0.6684046644393558, 0.6707424863778961, 0.673065778319182, 0.6753746305698431, 0.6776691328752368, 0.6799493744229361, 0.6822154438461971, 0.6844674292274037, 0.6867054181014909, 0.6889294974593487, 0.6911397537512016, 0.6933362728899708, 0.6955191402546124, 0.6976884406934363, 0.6998442585274044, 0.7019866775534083, 0.7041157810475267, 0.7062316517682612, 0.7083343719597548, 0.7104240233549873, 0.712500687178953, 0.714564444151818, 0.7166153744920576, 0.7186535579195739, 0.7206790736587956, 0.7226920004417562, 0.7246924165111559, 0.7266803996234013, 0.7286560270516287, 0.7306193755887075, 0.7325705215502252, 0.7345095407774538, 0.7364365086402976, 0.738351500040223, 0.74025458941317, 0.7421458507324453, 0.7440253575115978, 0.7458931828072759, 0.7477493992220677, 0.7495940789073223, 0.7514272935659554, 0.7532491144552351, 0.7550596123895528, 0.7568588577431749, 0.7586469204529791, 0.7604238700211725, 0.7621897755179925, 0.7639447055843926, 0.76568872843471, 0.7674219118593171, 0.7691443232272563, 0.7708560294888593, 0.7725570971783489, 0.7742475924164252, 0.7759275809128359, 0.777597127968931, 0.7792562984801996, 0.7809051569387938, 0.7825437674360349, 0.784172193664905, 0.785790498922522, 0.7873987461126009, 0.7889969977478981, 0.7905853159526417, 0.7921637624649465, 0.7937323986392131, 0.7952912854485131, 0.7968404834869597, 0.7983800529720615, 0.799910053747065, 0.8014305452832793, 0.8029415866823884, 0.8044432366787483, 0.8059355536416704, 0.8074185955776895, 0.8088924201328196, 0.8103570845947933, 0.8118126458952899, 0.8132591606121475, 0.8146966849715627, 0.8161252748502754, 0.8175449857777416, 0.8189558729382911, 0.820357991173273, 0.8217513949831873, 0.8231361385298033, 0.8245122756382646, 0.825879859799182, 0.8272389441707115, 0.8285895815806221, 0.829931824528348, 0.8312657251870295, 0.8325913354055415, 0.8339087067105084, 0.835217890308307, 0.8365189370870572, 0.8378118976185993, 0.8390968221604607, 0.8403737606578086, 0.8416427627453922, 0.8429038777494711, 0.8441571546897328, 0.8454026422811991, 0.8466403889361184, 0.847870442765848, 0.8490928515827243, 0.8503076629019211, 0.8515149239432966, 0.8527146816332289, 0.8539069826064398, 0.8550918732078077, 0.8562693994941689, 0.8574396072361082, 0.8586025419197374, 0.8597582487484636, 0.860906772644747, 0.8620481582518457, 0.8631824499355518, 0.8643096917859157, 0.8654299276189603, 0.8665432009783837, 0.8676495551372514, 0.8687490330996792, 0.8698416776025043, 0.8709275311169464, 0.8720066358502587, 0.8730790337473684, 0.8741447664925076, 0.8752038755108327, 0.8762564019700351, 0.8773023867819416, 0.8783418706041044, 0.8793748938413812, 0.8804014966475063, 0.8814217189266509, 0.8824356003349745, 0.8834431802821658, 0.8844444979329759, 0.8854395922087386, 0.886428501788885, 0.8874112651124465, 0.8883879203795482, 0.889358505552895, 0.8903230583592459, 0.8912816162908815, 0.8922342166070611, 0.8931808963354702, 0.8941216922736607, 0.895056640990481, 0.8959857788274969, 0.8969091419004053, 0.8978267661004365, 0.8987386870957511, 0.8996449403328245, 0.9005455610378262, 0.9014405842179887, 0.9023300446629675, 0.9032139769461944, 0.9040924154262207, 0.9049653942480528, 0.9058329473444799, 0.9066951084373923, 0.9075519110390927, 0.9084033884535986, 0.9092495737779366, 0.9100904999034295, 0.910926199516974, 0.9117567051023121, 0.9125820489412932, 0.9134022631151287, 0.9142173795056399, 0.915027429796496, 0.9158324454744466, 0.9166324578305458, 0.917427497961367, 0.9182175967702136, 0.9190027849683187, 0.9197830930760391, 0.9205585514240427, 0.9213291901544862, 0.9220950392221873, 0.9228561283957887, 0.9236124872589158, 0.9243641452113263, 0.9251111314700526, 0.9258534750705383, 0.9265912048677656, 0.9273243495373785, 0.9280529375767961, 0.9287769973063205, 0.9294965568702385, 0.9302116442379142, 0.9309222872048777, 0.9316285133939041, 0.932330350256088, 0.9330278250719107, 0.9337209649522996, 0.9344097968396831, 0.9350943475090373, 0.935774643568927, 0.9364507114625396, 0.9371225774687131, 0.937790267702958, 0.9384538081184719, 0.9391132245071484, 0.9397685425005796, 0.9404197875710528, 0.94106698503254, 0.9417101600416824, 0.9423493375987678, 0.9429845425487028, 0.9436157995819779, 0.9442431332356283, 0.9448665678941862, 0.9454861277906299, 0.9461018370073252, 0.9467137194769613, 0.9473217989834812, 0.9479260991630071, 0.9485266435047572, 0.9491234553519607, 0.9497165579027638, 0.9503059742111322, 0.9508917271877466, 0.9514738396008939, 0.9520523340773518, 0.9526272331032682, 0.9531985590250358, 0.9537663340501598, 0.9543305802481219, 0.954891319551238, 0.9554485737555103], \"type\": \"scatter\", \"uid\": \"da987f13-22e8-41ff-ba4b-72ad4e165e5b\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 5.861523046092183, 11.673046092184368, 17.48456913827655, 23.296092184368735, 29.10761523046092, 34.9191382765531, 40.73066132264528, 46.542184368737466, 52.35370741482965, 58.16523046092183, 63.97675350701402, 69.7882765531062, 75.59979959919839, 81.41132264529057, 87.22284569138274, 93.03436873747494, 98.84589178356713, 104.6574148296593, 110.46893787575148, 116.28046092184367, 122.09198396793586, 127.90350701402804, 133.71503006012023, 139.52655310621242, 145.3380761523046, 151.1495991983968, 156.96112224448896, 162.77264529058115, 168.58416833667334, 174.3956913827655, 180.2072144288577, 186.0187374749499, 191.83026052104208, 197.64178356713427, 203.45330661322643, 209.26482965931862, 215.0763527054108, 220.88787575150297, 226.69939879759517, 232.51092184368736, 238.32244488977955, 244.13396793587174, 249.9454909819639, 255.7570140280561, 261.56853707414825, 267.38006012024044, 273.19158316633263, 279.0031062124248, 284.814629258517, 290.6261523046092, 296.4376753507014, 302.2491983967936, 308.0607214428857, 313.8722444889779, 319.6837675350701, 325.4952905811623, 331.3068136272545, 337.1183366733467, 342.92985971943887, 348.741382765531, 354.5529058116232, 360.3644288577154, 366.1759519038076, 371.98747494989976, 377.79899799599195, 383.61052104208414, 389.42204408817634, 395.2335671342685, 401.04509018036066, 406.85661322645285, 412.66813627254504, 418.47965931863723, 424.2911823647294, 430.1027054108216, 435.9142284569138, 441.72575150300594, 447.53727454909813, 453.3487975951903, 459.1603206412825, 464.9718436873747, 470.7833667334669, 476.5948897795591, 482.4064128256513, 488.21793587174346, 494.0294589178356, 499.8409819639278, 505.65250501002, 511.46402805611217, 517.2755511022043, 523.0870741482964, 528.8985971943887, 534.7101202404808, 540.5216432865731, 546.3331663326652, 552.1446893787574, 557.9562124248496, 563.7677354709417, 569.579258517034, 575.3907815631261, 581.2023046092183, 587.0138276553105, 592.8253507014027, 598.6368737474949, 604.4483967935871, 610.2599198396792, 616.0714428857714, 621.8829659318636, 627.6944889779558, 633.506012024048, 639.3175350701401, 645.1290581162324, 650.9405811623245, 656.7521042084167, 662.5636272545089, 668.375150300601, 674.1866733466933, 679.9981963927854, 685.8097194388777, 691.6212424849698, 697.4327655310619, 703.2442885771542, 709.0558116232463, 714.8673346693386, 720.6788577154307, 726.4903807615229, 732.3019038076151, 738.1134268537073, 743.9249498997995, 749.7364729458916, 755.5479959919838, 761.359519038076, 767.1710420841682, 772.9825651302604, 778.7940881763526, 784.6056112224447, 790.417134268537, 796.2286573146291, 802.0401803607213, 807.8517034068135, 813.6632264529056, 819.4747494989979, 825.28627254509, 831.0977955911823, 836.9093186372744, 842.7208416833665, 848.5323647294588, 854.3438877755509, 860.1554108216432, 865.9669338677353, 871.7784569138275, 877.5899799599197, 883.4015030060118, 889.213026052104, 895.0245490981962, 900.8360721442884, 906.6475951903806, 912.4591182364728, 918.270641282565, 924.0821643286572, 929.8936873747493, 935.7052104208415, 941.5167334669337, 947.3282565130258, 953.1397795591181, 958.9513026052102, 964.7628256513025, 970.5743486973946, 976.3858717434869, 982.197394789579, 988.0089178356711, 993.8204408817634, 999.6319639278555, 1005.4434869739478, 1011.2550100200399, 1017.0665330661321, 1022.8780561122243, 1028.6895791583165, 1034.5011022044087, 1040.3126252505008, 1046.124148296593, 1051.9356713426853, 1057.7471943887774, 1063.5587174348695, 1069.3702404809617, 1075.1817635270538, 1080.9932865731462, 1086.8048096192383, 1092.6163326653304, 1098.4278557114226, 1104.239378757515, 1110.050901803607, 1115.8624248496992, 1121.6739478957913, 1127.4854709418835, 1133.2969939879758, 1139.108517034068, 1144.92004008016, 1150.7315631262522, 1156.5430861723446, 1162.3546092184367, 1168.1661322645289, 1173.977655310621, 1179.7891783567131, 1185.6007014028055, 1191.4122244488976, 1197.2237474949898, 1203.035270541082, 1208.8467935871743, 1214.6583166332664, 1220.4698396793585, 1226.2813627254507, 1232.0928857715428, 1237.9044088176352, 1243.7159318637273, 1249.5274549098194, 1255.3389779559116, 1261.1505010020037, 1266.962024048096, 1272.7735470941882, 1278.5850701402803, 1284.3965931863725, 1290.2081162324648, 1296.019639278557, 1301.831162324649, 1307.6426853707412, 1313.4542084168334, 1319.2657314629257, 1325.0772545090178, 1330.88877755511, 1336.7003006012021, 1342.5118236472945, 1348.3233466933866, 1354.1348697394787, 1359.9463927855709, 1365.757915831663, 1371.5694388777554, 1377.3809619238475, 1383.1924849699396, 1389.0040080160318, 1394.815531062124, 1400.6270541082163, 1406.4385771543084, 1412.2501002004005, 1418.0616232464927, 1423.873146292585, 1429.6846693386772, 1435.4961923847693, 1441.3077154308614, 1447.1192384769536, 1452.930761523046, 1458.742284569138, 1464.5538076152302, 1470.3653306613223, 1476.1768537074147, 1481.9883767535068, 1487.799899799599, 1493.611422845691, 1499.4229458917832, 1505.2344689378756, 1511.0459919839677, 1516.8575150300599, 1522.669038076152, 1528.4805611222444, 1534.2920841683365, 1540.1036072144286, 1545.9151302605208, 1551.726653306613, 1557.5381763527052, 1563.3496993987974, 1569.1612224448895, 1574.9727454909817, 1580.784268537074, 1586.5957915831661, 1592.4073146292583, 1598.2188376753504, 1604.0303607214425, 1609.841883767535, 1615.653406813627, 1621.4649298597192, 1627.2764529058113, 1633.0879759519034, 1638.8994989979958, 1644.711022044088, 1650.52254509018, 1656.3340681362722, 1662.1455911823646, 1667.9571142284567, 1673.7686372745488, 1679.580160320641, 1685.391683366733, 1691.2032064128255, 1697.0147294589176, 1702.8262525050097, 1708.6377755511019, 1714.4492985971942, 1720.2608216432864, 1726.0723446893785, 1731.8838677354706, 1737.6953907815628, 1743.5069138276551, 1749.3184368737473, 1755.1299599198394, 1760.9414829659315, 1766.7530060120237, 1772.564529058116, 1778.3760521042082, 1784.1875751503003, 1789.9990981963924, 1795.8106212424848, 1801.622144288577, 1807.433667334669, 1813.2451903807612, 1819.0567134268533, 1824.8682364729457, 1830.6797595190378, 1836.49128256513, 1842.302805611222, 1848.1143286573144, 1853.9258517034066, 1859.7373747494987, 1865.5488977955908, 1871.360420841683, 1877.1719438877753, 1882.9834669338675, 1888.7949899799596, 1894.6065130260517, 1900.418036072144, 1906.2295591182362, 1912.0410821643284, 1917.8526052104205, 1923.6641282565126, 1929.475651302605, 1935.2871743486971, 1941.0986973947893, 1946.9102204408814, 1952.7217434869738, 1958.533266533066, 1964.344789579158, 1970.1563126252502, 1975.9678356713423, 1981.7793587174347, 1987.5908817635268, 1993.402404809619, 1999.213927855711, 2005.0254509018032, 2010.8369739478956, 2016.6484969939877, 2022.4600200400798, 2028.271543086172, 2034.0830661322643, 2039.8945891783565, 2045.7061122244486, 2051.517635270541, 2057.3291583166333, 2063.1406813627254, 2068.9522044088176, 2074.7637274549097, 2080.575250501002, 2086.386773547094, 2092.198296593186, 2098.0098196392782, 2103.821342685371, 2109.632865731463, 2115.444388777555, 2121.2559118236472, 2127.0674348697394, 2132.8789579158315, 2138.6904809619236, 2144.502004008016, 2150.313527054108, 2156.1250501002005, 2161.9365731462926, 2167.7480961923848, 2173.559619238477, 2179.371142284569, 2185.182665330661, 2190.9941883767533, 2196.8057114228454, 2202.6172344689376, 2208.42875751503, 2214.2402805611223, 2220.0518036072144, 2225.8633266533066, 2231.6748496993987, 2237.486372745491, 2243.297895791583, 2249.109418837675, 2254.9209418837672, 2260.73246492986, 2266.543987975952, 2272.355511022044, 2278.167034068136, 2283.9785571142284, 2289.7900801603205, 2295.6016032064126, 2301.4131262525048, 2307.224649298597, 2313.0361723446895, 2318.8476953907816, 2324.6592184368737, 2330.470741482966, 2336.282264529058, 2342.09378757515, 2347.9053106212423, 2353.7168336673344, 2359.5283567134265, 2365.339879759519, 2371.1514028056113, 2376.9629258517034, 2382.7744488977955, 2388.5859719438877, 2394.39749498998, 2400.209018036072, 2406.020541082164, 2411.832064128256, 2417.643587174349, 2423.455110220441, 2429.266633266533, 2435.078156312625, 2440.8896793587173, 2446.7012024048095, 2452.5127254509016, 2458.3242484969937, 2464.135771543086, 2469.947294589178, 2475.7588176352706, 2481.5703406813627, 2487.381863727455, 2493.193386773547, 2499.004909819639, 2504.8164328657313, 2510.6279559118234, 2516.4394789579155, 2522.2510020040077, 2528.0625250501002, 2533.8740480961924, 2539.6855711422845, 2545.4970941883766, 2551.308617234469, 2557.120140280561, 2562.931663326653, 2568.743186372745, 2574.5547094188373, 2580.36623246493, 2586.177755511022, 2591.989278557114, 2597.8008016032063, 2603.6123246492984, 2609.4238476953906, 2615.2353707414827, 2621.046893787575, 2626.858416833667, 2632.6699398797596, 2638.4814629258517, 2644.292985971944, 2650.104509018036, 2655.916032064128, 2661.7275551102202, 2667.5390781563124, 2673.3506012024045, 2679.1621242484966, 2684.9736472945892, 2690.7851703406814, 2696.5966933867735, 2702.4082164328656, 2708.2197394789578, 2714.03126252505, 2719.842785571142, 2725.654308617234, 2731.4658316633263, 2737.277354709419, 2743.088877755511, 2748.900400801603, 2754.7119238476953, 2760.5234468937874, 2766.3349699398796, 2772.1464929859717, 2777.958016032064, 2783.769539078156, 2789.581062124248, 2795.3925851703407, 2801.204108216433, 2807.015631262525, 2812.827154308617, 2818.638677354709, 2824.4502004008014, 2830.2617234468935, 2836.0732464929856, 2841.8847695390778, 2847.6962925851703, 2853.5078156312625, 2859.3193386773546, 2865.1308617234467, 2870.942384769539, 2876.753907815631, 2882.565430861723, 2888.3769539078153, 2894.1884769539074, 2900.0], \"y\": [0.9600225241515266, 0.9471503500811669, 0.9343610270461633, 0.9216540217804166, 0.9090288044501647, 0.8964848486318913, 0.8840216312903761, 0.8716386327568859, 0.8593353367075067, 0.8471112301416144, 0.834965803360485, 0.8228985499460428, 0.8109089667397431, 0.7989965538215937, 0.7871608144893101, 0.775401255237604, 0.7637173857376063, 0.7521087188164233, 0.7405747704368224, 0.7291150596770495, 0.7177291087107769, 0.7064164427871797, 0.6951765902111404, 0.6840090823235807, 0.6729134534819208, 0.6618892410406634, 0.6509359853321035, 0.6400532296471617, 0.6292405202163414, 0.6184974061908077, 0.6078234396235902, 0.5972181754509034, 0.5866811714735909, 0.5762119883386863, 0.5658101895210943, 0.5554753413053894, 0.5452070127677313, 0.5350047757578968, 0.5248682048814284, 0.5147968774818961, 0.5047903736232746, 0.4948482760724342, 0.48497017028174216, 0.47515564437177926, 0.465404289114165, 0.45571569791449495, 0.44608946679538697, 0.4365251943796369, 0.4270224818734827, 0.41758093304997645, 0.4082001542324629, 0.3988797542781646, 0.3896193445618734, 0.3804185389597454, 0.3712769538332015, 0.362194208012931, 0.3531699227829985, 0.34420372186505266, 0.3352952314026372, 0.32644407994560165, 0.3176498984346141, 0.30891232018577286, 0.30023098087531674, 0.2916055185244337, 0.28303557348416897, 0.27452078842042815, 0.26606080829907786, 0.2576552803711425, 0.24930385415809497, 0.24100618143724506, 0.2327619162272172, 0.22457071477352675, 0.21643223553424562, 0.20834613916576106, 0.20031208850862714, 0.1923297485735056, 0.18439878652719877, 0.17651887167877134, 0.16868967546576186, 0.160910871440483, 0.15318213525641, 0.1455031446546562, 0.1378735794505368, 0.13029312152021788, 0.12276145478745182, 0.1152782652103983, 0.10784324076852991, 0.10045607144962232, 0.09311644923682705, 0.08582406809583021, 0.07857862396208937, 0.07137981472815724, 0.06422734023108534, 0.05712090223990596, 0.050060204443199474, 0.04304495243673734, 0.036074853711208776, 0.029149617640021885, 0.0222689554671871, 0.015432580295277054, 0.008640207073463246, 0.0018915525856317839, 0.004813664561427178, 0.01147572394975116, 0.018094903361863812, 0.024671478792356316, 0.031205724459396622, 0.037697912816162304, 0.04414831456220103, 0.050557198654718305, 0.05692483231979084, 0.06325148106351008, 0.06953740868305192, 0.0757828772776763, 0.08198814725965609, 0.08815347736513457, 0.09427912466491462, 0.10036534457517665, 0.10641239086812948, 0.1124205156825907, 0.11838996953450065, 0.1243210013273679, 0.13021385836264665, 0.13606878635004982, 0.14188602941779282, 0.14766583012277357, 0.15340842946068578, 0.1591140668760681, 0.164782980272287, 0.17041540602145777, 0.17601157897429953, 0.18157173246992742, 0.18709609834558283, 0.19258490694629882, 0.19803838713450617, 0.20345676629957477, 0.20884027036729602, 0.21418912380930166, 0.2195035496524249, 0.22478376948799905, 0.23003000348109637, 0.2352424703797098, 0.2404213875238722, 0.2455669708547198, 0.2506794349234953, 0.25575899290049453, 0.2608058565839544, 0.2658202364088841, 0.2708023414558397, 0.2757523794596417, 0.2806705568180372, 0.2855570786003053, 0.2904121485558083, 0.29523596912248684, 0.300028741435301, 0.3047906653346171, 0.3095219393745394, 0.3142227608311906, 0.31889332571093554, 0.3235338287585555, 0.32814446346536785, 0.3327254220772935, 0.33727689560287366, 0.34179907382123276, 0.3462921452899933, 0.3507562973531365, 0.35519171614881484, 0.3595985866171125, 0.36397709250775745, 0.3683274163877822, 0.3726497396491373, 0.3769442425162537, 0.3812111040535576, 0.3854505021729373, 0.38966261364116095, 0.39384761408724733, 0.39800567800978826, 0.4021369787842256, 0.4062416886700797, 0.41031997881813176, 0.41437201927756073, 0.41839797900303355, 0.4223980258617491, 0.4263723266404392, 0.43032104705232166, 0.43424435174401044, 0.4381424043023807, 0.44201536726138957, 0.44586340210885367, 0.4496866692931819, 0.4534853282300665, 0.4572595373091284, 0.4610094539005233, 0.4647352343615023, 0.46843703404293213, 0.47211500729577194, 0.4757693074775091, 0.47940008695855474, 0.4830074971285957, 0.486591688402908, 0.49015281022862756, 0.49369101109098246, 0.49720643851948354, 0.5006992390940765, 0.5041695584512532, 0.5076175412901238, 0.5110433313784514, 0.5144470715586453, 0.517828903753718, 0.5211889689732019, 0.5245274073190297, 0.5278443579913757, 0.53113995929446, 0.5344143486423152, 0.537667662564516, 0.5409000367118724, 0.5441116058620848, 0.5473025039253653, 0.5504728639500198, 0.5536228181279959, 0.5567524978003957, 0.5598620334629509, 0.5629515547714656, 0.5660211905472203, 0.5690710687823453, 0.5721013166451565, 0.5751120604854576, 0.5781034258398094, 0.581075537436763, 0.5840285192020614, 0.5869624942638065, 0.5898775849575928, 0.5927739128316083, 0.5956515986517035, 0.5985107624064255, 0.6013515233120222, 0.6041739998174127, 0.6069783096091258, 0.6097645696162078, 0.6125328960150977, 0.6152834042344713, 0.618016208960054, 0.6207314241394026, 0.6234291629866575, 0.6261095379872618, 0.6287726609026528, 0.6314186427749212, 0.6340475939314416, 0.6366596239894724, 0.6392548418607269, 0.6418333557559138, 0.6443952731892498, 0.6469407009829423, 0.6494697452716434, 0.6519825115068754, 0.6544791044614278, 0.6569596282337256, 0.6594241862521704, 0.6618728812794524, 0.6643058154168358, 0.6667230901084147, 0.6691248061453452, 0.6715110636700459, 0.6738819621803742, 0.6762376005337757, 0.6785780769514047, 0.6809034890222214, 0.6832139337070591, 0.6855095073426689, 0.6877903056457353, 0.6900564237168676, 0.6923079560445655, 0.6945449965091588, 0.6967676383867214, 0.6989759743529611, 0.7011700964870838, 0.7033500962756325, 0.7055160646163023, 0.7076680918217301, 0.7098062676232606, 0.7119306811746876, 0.7140414210559718, 0.7161385752769335, 0.7182222312809227, 0.7202924759484652, 0.7223493956008854, 0.7243930760039048, 0.7264236023712188, 0.7284410593680496, 0.7304455311146762, 0.7324371011899424, 0.7344158526347413, 0.7363818679554776, 0.7383352291275083, 0.7402760175985608, 0.7422043142921284, 0.7441201996108449, 0.7460237534398368, 0.7479150551500549, 0.7497941836015829, 0.751661217146926, 0.7535162336342779, 0.7553593104107666, 0.7571905243256798, 0.7590099517336688, 0.7608176684979326, 0.7626137499933808, 0.7643982711097765, 0.7661713062548592, 0.7679329293574471, 0.7696832138705192, 0.7714222327742791, 0.773150058579197, 0.7748667633290337, 0.7765724186038441, 0.778267095522962, 0.7799508647479658, 0.7816237964856244, 0.7832859604908248, 0.7849374260694804, 0.7865782620814211, 0.7882085369432643, 0.7898283186312673, 0.7914376746841628, 0.7930366722059731, 0.7946253778688099, 0.7962038579156535, 0.7977721781631146, 0.7993304040041793, 0.8008786004109352, 0.8024168319372804, 0.8039451627216159, 0.8054636564895192, 0.8069723765564016, 0.8084713858301482, 0.8099607468137413, 0.8114405216078658, 0.8129107719134994, 0.8143715590344844, 0.8158229438800849, 0.8172649869675254, 0.8186977484245149, 0.8201212879917535, 0.8215356650254239, 0.8229409384996657, 0.8243371670090349, 0.825724408770947, 0.8271027216281042, 0.8284721630509071, 0.8298327901398517, 0.8311846596279097, 0.8325278278828938, 0.8338623509098089, 0.8351882843531865, 0.8365056834994051, 0.8378146032789958, 0.8391150982689322, 0.840407222694906, 0.8416910304335886, 0.8429665750148772, 0.8442339096241263, 0.8454930871043664, 0.8467441599585065, 0.8479871803515234, 0.8492222001126373, 0.8504492707374719, 0.8516684433902028, 0.8528797689056897, 0.8540832977915971, 0.8552790802304993, 0.856467166081973, 0.8576476048846774, 0.8588204458584179, 0.8599857379061998, 0.861143529616267, 0.8622938692641275, 0.8634368048145672, 0.8645723839236488, 0.8657006539406995, 0.8668216619102855, 0.867935454574173, 0.8690420783732773, 0.8701415794495995, 0.8712340036481503, 0.8723193965188614, 0.873397803318485, 0.8744692690124806, 0.87553383827689, 0.8765915555002004, 0.8776424647851948, 0.8786866099507908, 0.8797240345338684, 0.8807547817910846, 0.8817788947006774, 0.8827964159642578, 0.8838073880085903, 0.8848118529873618, 0.8858098527829391, 0.8868014290081161, 0.8877866230078475, 0.8887654758609739, 0.8897380283819343, 0.8907043211224674, 0.8916643943733036, 0.8926182881658434, 0.8935660422738281, 0.8945076962149972, 0.8954432892527362, 0.8963728603977146, 0.8972964484095115, 0.8982140917982321, 0.8991258288261137, 0.9000316975091204, 0.9009317356185291, 0.9018259806825039, 0.9027144699876605, 0.903597240580622, 0.9044743292695625, 0.9053457726257425, 0.9062116069850336, 0.9070718684494337, 0.9079265928885717, 0.9087758159412044, 0.909619573016701, 0.9104578992965208, 0.9112908297356791, 0.9121183990642057, 0.9129406417885918, 0.9137575921932302, 0.9145692843418437, 0.915375752078906, 0.9161770290310525, 0.9169731486084828, 0.9177641440063536, 0.9185500482061628, 0.9193308939771249, 0.9201067138775365, 0.9208775402561354, 0.921643405253448, 0.92240434080313, 0.9231603786332981, 0.9239115502678528, 0.9246578870277924, 0.9253994200325196, 0.9261361802011387, 0.926868198253745, 0.9275955047127054, 0.9283181299039315, 0.9290361039581437, 0.9297494568121278, 0.9304582182099831, 0.9311624177043625, 0.9318620846577051, 0.9325572482434603, 0.933247937447304, 0.9339341810683476, 0.9346160077203384, 0.935293445832853, 0.9359665236524829, 0.9366352692440115, 0.937299710491585, 0.937959875099875, 0.9386157905952333, 0.9392674843268396, 0.9399149834678427, 0.9405583150164928, 0.9411975057972669, 0.9418325824619882, 0.9424635714909368, 0.9430904991939538, 0.9437133917115388, 0.9443322750159393, 0.9449471749122336, 0.9455581170394074, 0.9461651268714226, 0.946768229718279, 0.9473674507270702, 0.9479628148830318, 0.9485543470105835, 0.9491420717743638, 0.9497260136802588, 0.9503061970764237, 0.9508826461542981, 0.9514553849496148, 0.9520244373434021, 0.9525898270629791, 0.9531515776829457, 0.9537097126261646, 0.9542642551647391, 0.9548152284209828, 0.9553626553683834, 0.9559065588325616, 0.9564469614922219, 0.9569838858800985, 0.9575173543838953, 0.9580473892472186, 0.9585740125705051, 0.9590972463119433, 0.959617112288389, 0.9601336321762751], \"type\": \"scatter\", \"uid\": \"92692892-00ed-4bf0-ac41-02218de15d27\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 6.0619238476953905, 12.073847695390782, 18.08577154308617, 24.097695390781563, 30.109619238476956, 36.12154308617234, 42.13346693386773, 48.14539078156312, 54.157314629258515, 60.16923847695391, 66.18116232464929, 72.19308617234468, 78.20501002004008, 84.21693386773546, 90.22885771543086, 96.24078156312625, 102.25270541082163, 108.26462925851703, 114.27655310621242, 120.28847695390782, 126.3004008016032, 132.3123246492986, 138.324248496994, 144.33617234468937, 150.3480961923848, 156.36002004008017, 162.37194388777556, 168.38386773547094, 174.39579158316633, 180.40771543086174, 186.41963927855713, 192.4315631262525, 198.4434869739479, 204.45541082164328, 210.4673346693387, 216.47925851703408, 222.49118236472947, 228.50310621242485, 234.51503006012024, 240.52695390781565, 246.53887775551104, 252.55080160320642, 258.56272545090184, 264.5746492985972, 270.5865731462926, 276.59849699398796, 282.6104208416834, 288.62234468937874, 294.63426853707415, 300.64619238476956, 306.6581162324649, 312.67004008016033, 318.6819639278557, 324.6938877755511, 330.7058116232465, 336.7177354709419, 342.7296593186373, 348.74158316633265, 354.75350701402806, 360.7654308617235, 366.77735470941883, 372.78927855711424, 378.8012024048096, 384.813126252505, 390.82505010020043, 396.8369739478958, 402.8488977955912, 408.86082164328656, 414.87274549098197, 420.8846693386774, 426.89659318637274, 432.90851703406815, 438.9204408817635, 444.9323647294589, 450.94428857715434, 456.9562124248497, 462.9681362725451, 468.98006012024047, 474.9919839679359, 481.0039078156313, 487.01583166332665, 493.02775551102206, 499.0396793587174, 505.05160320641284, 511.0635270541082, 517.0754509018036, 523.087374749499, 529.0992985971943, 535.1112224448897, 541.1231462925851, 547.1350701402805, 553.1469939879759, 559.1589178356713, 565.1708416833667, 571.182765531062, 577.1946893787574, 583.2066132264529, 589.2185370741482, 595.2304609218436, 601.2423847695391, 607.2543086172344, 613.2662324649298, 619.2781563126252, 625.2900801603206, 631.302004008016, 637.3139278557113, 643.3258517034068, 649.3377755511021, 655.3496993987975, 661.361623246493, 667.3735470941883, 673.3854709418837, 679.3973947895792, 685.4093186372745, 691.4212424849699, 697.4331663326652, 703.4450901803607, 709.457014028056, 715.4689378757514, 721.4808617234469, 727.4927855711422, 733.5047094188376, 739.5166332665331, 745.5285571142284, 751.5404809619238, 757.5524048096191, 763.5643286573146, 769.57625250501, 775.5881763527053, 781.6001002004008, 787.6120240480961, 793.6239478957915, 799.6358717434869, 805.6477955911823, 811.6597194388777, 817.671643286573, 823.6835671342685, 829.6954909819639, 835.7074148296592, 841.7193386773547, 847.73126252505, 853.7431863727454, 859.7551102204408, 865.7670340681362, 871.7789579158316, 877.790881763527, 883.8028056112224, 889.8147294589178, 895.8266533066131, 901.8385771543086, 907.850501002004, 913.8624248496993, 919.8743486973947, 925.8862725450902, 931.8981963927855, 937.9101202404809, 943.9220440881763, 949.9339679358717, 955.945891783567, 961.9578156312625, 967.9697394789579, 973.9816633266532, 979.9935871743486, 986.0055110220441, 992.0174348697394, 998.0293587174348, 1004.0412825651302, 1010.0532064128256, 1016.065130260521, 1022.0770541082163, 1028.0889779559118, 1034.1009018036073, 1040.1128256513025, 1046.124749498998, 1052.1366733466932, 1058.1485971943887, 1064.1605210420842, 1070.1724448897794, 1076.1843687374749, 1082.1962925851703, 1088.2082164328656, 1094.220140280561, 1100.2320641282565, 1106.2439879759518, 1112.2559118236472, 1118.2678356713427, 1124.279759519038, 1130.2916833667334, 1136.303607214429, 1142.3155310621241, 1148.3274549098196, 1154.3393787575149, 1160.3513026052103, 1166.3632264529058, 1172.375150300601, 1178.3870741482965, 1184.398997995992, 1190.4109218436872, 1196.4228456913827, 1202.4347695390782, 1208.4466933867734, 1214.4586172344689, 1220.4705410821643, 1226.4824649298596, 1232.494388777555, 1238.5063126252505, 1244.5182364729458, 1250.5301603206412, 1256.5420841683367, 1262.554008016032, 1268.5659318637274, 1274.5778557114227, 1280.5897795591181, 1286.6017034068136, 1292.6136272545089, 1298.6255511022043, 1304.6374749498998, 1310.649398797595, 1316.6613226452905, 1322.673246492986, 1328.6851703406812, 1334.6970941883767, 1340.7090180360722, 1346.7209418837674, 1352.7328657314629, 1358.7447895791584, 1364.7567134268536, 1370.768637274549, 1376.7805611222443, 1382.7924849699398, 1388.8044088176352, 1394.8163326653305, 1400.828256513026, 1406.8401803607214, 1412.8521042084167, 1418.8640280561121, 1424.8759519038076, 1430.8878757515029, 1436.8997995991983, 1442.9117234468938, 1448.923647294589, 1454.9355711422845, 1460.94749498998, 1466.9594188376752, 1472.9713426853707, 1478.9832665330662, 1484.9951903807614, 1491.0071142284569, 1497.0190380761521, 1503.0309619238476, 1509.042885771543, 1515.0548096192383, 1521.0667334669338, 1527.0786573146293, 1533.0905811623245, 1539.10250501002, 1545.1144288577154, 1551.1263527054107, 1557.1382765531062, 1563.1502004008016, 1569.1621242484969, 1575.1740480961923, 1581.1859719438878, 1587.197895791583, 1593.2098196392785, 1599.2217434869738, 1605.2336673346692, 1611.2455911823647, 1617.25751503006, 1623.2694388777554, 1629.281362725451, 1635.2932865731461, 1641.3052104208416, 1647.317134268537, 1653.3290581162323, 1659.3409819639278, 1665.3529058116233, 1671.3648296593185, 1677.376753507014, 1683.3886773547094, 1689.4006012024047, 1695.4125250501002, 1701.4244488977956, 1707.4363727454909, 1713.4482965931863, 1719.4602204408816, 1725.472144288577, 1731.4840681362725, 1737.4959919839678, 1743.5079158316632, 1749.5198396793587, 1755.531763527054, 1761.5436873747494, 1767.555611222445, 1773.5675350701401, 1779.5794589178356, 1785.591382765531, 1791.6033066132263, 1797.6152304609218, 1803.6271543086173, 1809.6390781563125, 1815.651002004008, 1821.6629258517032, 1827.6748496993987, 1833.6867735470942, 1839.6986973947894, 1845.7106212424849, 1851.7225450901803, 1857.7344689378756, 1863.746392785571, 1869.7583166332665, 1875.7702404809618, 1881.7821643286572, 1887.7940881763527, 1893.806012024048, 1899.8179358717434, 1905.829859719439, 1911.8417835671341, 1917.8537074148296, 1923.865631262525, 1929.8775551102203, 1935.8894789579158, 1941.901402805611, 1947.9133266533065, 1953.925250501002, 1959.9371743486972, 1965.9490981963927, 1971.9610220440882, 1977.9729458917834, 1983.9848697394789, 1989.9967935871744, 1996.0087174348696, 2002.020641282565, 2008.0325651302605, 2014.0444889779558, 2020.0564128256513, 2026.0683366733467, 2032.080260521042, 2038.0921843687374, 2044.1041082164327, 2050.1160320641284, 2056.127955911824, 2062.1398797595193, 2068.151803607215, 2074.16372745491, 2080.1756513026053, 2086.1875751503007, 2092.199498997996, 2098.2114228456917, 2104.2233466933867, 2110.235270541082, 2116.2471943887776, 2122.259118236473, 2128.2710420841686, 2134.282965931864, 2140.294889779559, 2146.3068136272545, 2152.31873747495, 2158.3306613226455, 2164.342585170341, 2170.3545090180364, 2176.3664328657314, 2182.378356713427, 2188.3902805611224, 2194.402204408818, 2200.4141282565133, 2206.4260521042083, 2212.437975951904, 2218.4498997995993, 2224.4618236472948, 2230.47374749499, 2236.4856713426857, 2242.4975951903807, 2248.509519038076, 2254.5214428857716, 2260.533366733467, 2266.5452905811626, 2272.557214428858, 2278.569138276553, 2284.5810621242485, 2290.592985971944, 2296.6049098196395, 2302.616833667335, 2308.62875751503, 2314.6406813627254, 2320.652605210421, 2326.6645290581164, 2332.676452905812, 2338.6883767535073, 2344.7003006012023, 2350.712224448898, 2356.7241482965933, 2362.7360721442888, 2368.747995991984, 2374.7599198396797, 2380.7718436873747, 2386.78376753507, 2392.7956913827657, 2398.807615230461, 2404.8195390781566, 2410.831462925852, 2416.843386773547, 2422.8553106212426, 2428.867234468938, 2434.8791583166335, 2440.891082164329, 2446.903006012024, 2452.9149298597195, 2458.926853707415, 2464.9387775551104, 2470.950701402806, 2476.9626252505013, 2482.9745490981963, 2488.986472945892, 2494.9983967935873, 2501.0103206412828, 2507.0222444889782, 2513.0341683366737, 2519.0460921843687, 2525.058016032064, 2531.0699398797597, 2537.081863727455, 2543.0937875751506, 2549.1057114228456, 2555.117635270541, 2561.1295591182366, 2567.141482965932, 2573.1534068136275, 2579.165330661323, 2585.177254509018, 2591.1891783567135, 2597.201102204409, 2603.2130260521044, 2609.2249498998, 2615.2368737474953, 2621.2487975951904, 2627.260721442886, 2633.2726452905813, 2639.2845691382768, 2645.2964929859722, 2651.3084168336673, 2657.3203406813627, 2663.332264529058, 2669.3441883767537, 2675.356112224449, 2681.3680360721446, 2687.3799599198396, 2693.391883767535, 2699.4038076152306, 2705.415731462926, 2711.4276553106215, 2717.439579158317, 2723.451503006012, 2729.4634268537075, 2735.475350701403, 2741.4872745490984, 2747.499198396794, 2753.511122244489, 2759.5230460921844, 2765.53496993988, 2771.5468937875753, 2777.5588176352708, 2783.5707414829662, 2789.5826653306613, 2795.5945891783567, 2801.606513026052, 2807.6184368737477, 2813.630360721443, 2819.6422845691386, 2825.6542084168336, 2831.666132264529, 2837.6780561122246, 2843.68997995992, 2849.7019038076155, 2855.713827655311, 2861.725751503006, 2867.7376753507015, 2873.749599198397, 2879.7615230460924, 2885.773446893788, 2891.785370741483, 2897.7972945891784, 2903.809218436874, 2909.8211422845693, 2915.833066132265, 2921.8449899799602, 2927.8569138276553, 2933.8688376753507, 2939.880761523046, 2945.8926853707417, 2951.904609218437, 2957.9165330661326, 2963.9284569138276, 2969.940380761523, 2975.9523046092186, 2981.964228456914, 2987.9761523046095, 2993.9880761523045, 3000.0], \"y\": [0.9642148986279993, 0.9509003296540002, 0.9376744044780014, 0.9245365329402362, 0.9114861288100167, 0.8985226097595773, 0.8856453973380889, 0.872853916945848, 0.8601475978086375, 0.8475258729522579, 0.8349881791772273, 0.8225339570336523, 0.8101626507962625, 0.797873708439615, 0.7856665816134609, 0.773540725618278, 0.7614955993809658, 0.7495306654307001, 0.7376453898749531, 0.7258392423756681, 0.714111696125596, 0.7024622278247887, 0.6908903176572474, 0.6793954492677294, 0.6679771097387064, 0.6566347895674773, 0.6453679826434349, 0.6341761862254802, 0.6230589009195919, 0.6120156306565407, 0.6010458826697547, 0.5901491674733321, 0.5793249988401985, 0.5685728937804115, 0.557892372519609, 0.5472829584776004, 0.5367441782471014, 0.52627556157261, 0.5158766413294222, 0.5055469535027897, 0.4952860371672132, 0.48509343446587616, 0.4749686905902153, 0.4649113537596241, 0.4549209752012968, 0.4449971091302005, 0.4351393127291858, 0.4253471461292262, 0.41562017238979165, 0.4059579574793508, 0.39636007025600417, 0.3868260824482468, 0.3773555686358563, 0.36794810623091156, 0.3586032754589359, 0.34932065934016565, 0.3400998436709446, 0.33094041700524124, 0.3218419706362894, 0.31280409857835134, 0.3038263975486022, 0.29490846694913464, 0.28604990884908355, 0.2772503279668703, 0.26850933165256397, 0.2598265298703617, 0.2512015351811836, 0.2426339627253855, 0.23412343020558635, 0.22566955786960774, 0.2172719684935307, 0.20893028736486263, 0.2006441422658174, 0.19241316345670567, 0.18423698365943775, 0.17611523804113416, 0.16804756419784672, 0.16003360213838747, 0.15207299426826526, 0.1441653853737297, 0.1363104226059204, 0.12850775546512327, 0.12075703578512975, 0.11305791771770157, 0.10541005771713818, 0.09781311452494879, 0.09026674915462207, 0.08277062487650277, 0.07532440720276479, 0.06792776387248689, 0.060580364836825495, 0.05328188224428865, 0.046031990426106395, 0.038830365881698414, 0.03167668726423978, 0.024570635366321536, 0.01751189310570722, 0.010500145511184389, 0.0035350797085103025, 0.0033836150935495635, 0.010256247617089098, 0.01708312452883698, 0.023864550453840838, 0.030600827989060386, 0.03729225771686895, 0.04393913821846629, 0.05054176608720218, 0.057100435941810246, 0.0636154404395538, 0.07008707028928618, 0.07651561426442122, 0.08290135921581887, 0.08924459008458596, 0.09554558991478923, 0.10180463986608623, 0.10802201922627053, 0.11419800542373426, 0.12033287403984705, 0.12642689882125313, 0.13248035169208605, 0.13849350276610284, 0.14446662035873603, 0.15039997099906688, 0.1562938194417186, 0.16214842867866885, 0.16796405995098607, 0.17374097276048606, 0.1794794248813112, 0.1851796723714323, 0.19084196958407518, 0.1964665691790698, 0.20205372213412387, 0.20760367775602262, 0.21311668369175285, 0.21859298593955334, 0.2240328288598914, 0.22943645518636713, 0.234804106036544, 0.24013602092270825, 0.24543243776255586, 0.2506935928898093, 0.2559197210647626, 0.261111055484757, 0.26626782779458646, 0.271390268096834, 0.27647860496213894, 0.2815330654393966, 0.28655387506588914, 0.2915412578773493, 0.2964954364179575, 0.301416631750272, 0.3063050634650928, 0.3111609496912602, 0.3159845071053883, 0.3207759509415331, 0.3255354950007966, 0.33026335166086696, 0.3349597318854952, 0.33962484523390857, 0.34425889987016134, 0.34886210257242367, 0.3534346587422077, 0.3579767724135339, 0.36248864626203414, 0.3669704816139966, 0.37142247845534804, 0.37584483544057845, 0.38023774990160497, 0.38460141785657653, 0.3889360340186212, 0.3932417918045348, 0.39751888334341046, 0.4017674994852122, 0.40598782980929116, 0.4101800626328449, 0.4143443850193196, 0.41848098278675816, 0.42259004051609106, 0.4266717415593725, 0.43072626804796255, 0.43475380090065296, 0.4387545198317415, 0.4427286033590496, 0.4466762288118894, 0.4505975723389747, 0.4544928089162834, 0.4583621123548629, 0.4622056553085867, 0.46602360928185926, 0.4698161446372672, 0.4735834306031823, 0.4773256352813121, 0.4810429256542016, 0.48473546759268304, 0.48840342586327856, 0.49204696413555116, 0.49566624498940925, 0.49926142992235967, 0.5028326793567152, 0.5063801526467517, 0.5099040080858204, 0.5134044029134087, 0.5168814933221592, 0.520335434464837, 0.5237663804612538, 0.5271744844051455, 0.530559898371002, 0.5339227734208543, 0.5372632596110145, 0.5405815059987717, 0.543877660649043, 0.5471518706409805, 0.5504042820745338, 0.5536350400769706, 0.5568442888093501, 0.5600321714729578, 0.5631988303156943, 0.5663444066384229, 0.5694690408012743, 0.5725728722299106, 0.5756560394217456, 0.5787186799521249, 0.5817609304804658, 0.5847829267563538, 0.5877848036256008, 0.5907666950362619, 0.5937287340446122, 0.5966710528210843, 0.5995937826561659, 0.6024970539662573, 0.6053809962994925, 0.6082457383415178, 0.611091407921236, 0.6139181320165079, 0.6167260367598212, 0.6195152474439156, 0.6222858885273761, 0.6250380836401851, 0.6277719555892389, 0.6304876263638286, 0.6331852171410826, 0.6358648482913734, 0.6385266393836897, 0.6411707091909711, 0.6437971756954075, 0.6464061560937053, 0.6489977668023146, 0.6515721234626255, 0.6541293409461276, 0.656669533359536, 0.6591928140498825, 0.6616992956095739, 0.6641890898814149, 0.6666623079636005, 0.6691190602146717, 0.6715594562584403, 0.6739836049888812, 0.6763916145749906, 0.6787835924656128, 0.681159645394235, 0.6835198793837496, 0.6858643997511853, 0.6881933111124068, 0.6905067173867816, 0.6928047218018187, 0.6950874268977741, 0.6973549345322259, 0.6996073458846195, 0.7018447614607831, 0.7040672810974111, 0.7062750039665207, 0.7084680285798748, 0.71064645279338, 0.712810373811452, 0.7149598881913526, 0.7170950918474992, 0.7192160800557441, 0.7213229474576257, 0.7234157880645916, 0.7254946952621943, 0.7275597618142573, 0.7296110798670141, 0.7316487409532211, 0.7336728359962412, 0.7356834553141003, 0.7376806886235191, 0.7396646250439145, 0.7416353531013777, 0.7435929607326237, 0.7455375352889148, 0.7474691635399593, 0.7493879316777826, 0.7512939253205734, 0.753187229516504, 0.7550679287475255, 0.7569361069331373, 0.7587918474341317, 0.760635233056314, 0.7624663460541965, 0.7642852681346699, 0.7660920804606486, 0.767886863654692, 0.7696696978026027, 0.7714406624569997, 0.7731998366408679, 0.7749472988510848, 0.7766831270619228, 0.7784073987285282, 0.7801201907903781, 0.7818215796747128, 0.7835116412999468, 0.7851904510790559, 0.7868580839229423, 0.7885146142437773, 0.7901601159583219, 0.7917946624912247, 0.7934183267782983, 0.7950311812697738, 0.7966332979335341, 0.7982247482583246, 0.7998056032569429, 0.8013759334694088, 0.8029358089661103, 0.8044852993509313, 0.806024473764357, 0.8075534008865595, 0.8090721489404613, 0.8105807856947811, 0.8120793784670561, 0.8135679941266475, 0.8150466990977226, 0.8165155593622201, 0.8179746404627932, 0.8194240075057354, 0.8208637251638846, 0.8222938576795094, 0.8237144688671756, 0.8251256221165937, 0.8265273803954474, 0.8279198062522032, 0.8293029618189016, 0.8306769088139299, 0.8320417085447749, 0.8333974219107597, 0.8347441094057613, 0.8360818311209082, 0.837410646747264, 0.8387306155784895, 0.8400417965134888, 0.8413442480590371, 0.8426380283323921, 0.843923195063887, 0.8451998055995061, 0.8464679169034441, 0.8477275855606476, 0.8489788677793406, 0.8502218193935316, 0.8514564958655061, 0.8526829522883005, 0.853901243388161, 0.8551114235269853, 0.8563135467047485, 0.8575076665619121, 0.8586938363818187, 0.8598721090930682, 0.8610425372718804, 0.8622051731444409, 0.8633600685892309, 0.8645072751393433, 0.8656468439847812, 0.8667788259747423, 0.8679032716198878, 0.8690202310945965, 0.8701297542392037, 0.8712318905622248, 0.8723266892425646, 0.8734141991317117, 0.8744944687559186, 0.8755675463183668, 0.876633479701317, 0.8776923164682474, 0.8787441038659742, 0.8797888888267612, 0.8808267179704129, 0.8818576376063554, 0.8828816937357029, 0.88389893205331, 0.8849093979498105, 0.8859131365136432, 0.8869101925330639, 0.8879006104981431, 0.8888844346027523, 0.8898617087465355, 0.8908324765368677, 0.8917967812908012, 0.8927546660369984, 0.8937061735176517, 0.8946513461903908, 0.8955902262301771, 0.8965228555311858, 0.897449275708675, 0.898369528100843, 0.8992836537706724, 0.900191693507763, 0.9010936878301512, 0.9019896769861185, 0.9028797009559872, 0.9037637994539045, 0.9046420119296146, 0.9055143775702187, 0.9063809353019239, 0.9072417237917801, 0.9080967814494056, 0.9089461464287004, 0.909789856629549, 0.910627949699512, 0.9114604630355049, 0.9122874337854681, 0.9131088988500233, 0.913924894884121, 0.9147354582986759, 0.9155406252621906, 0.9163404317023711, 0.917134913307729, 0.9179241055291737, 0.9187080435815952, 0.9194867624454347, 0.9202602968682457, 0.9210286813662446, 0.9217919502258506, 0.922550137505216, 0.9233032770357456, 0.9240514024236063, 0.9247945470512268, 0.9255327440787873, 0.9262660264456987, 0.9269944268720728, 0.9277179778601823, 0.9284367116959111, 0.9291506604501946, 0.9298598559804508, 0.9305643299320027, 0.931264113739489, 0.931959238628268, 0.9326497356158099, 0.9333356355130814, 0.9340169689259207, 0.9346937662564025, 0.9353660577041956, 0.9360338732679092, 0.9366972427464324, 0.9373561957402636, 0.9380107616528314, 0.9386609696918063, 0.9393068488704045, 0.9399484280086821, 0.9405857357348211, 0.9412188004864073, 0.9418476505116984, 0.9424723138708854, 0.943092818437344, 0.9437091918988789, 0.9443214617589585, 0.944929655337943, 0.9455337997743029, 0.9461339220258302, 0.9467300488708412, 0.9473222069093716, 0.9479104225643631, 0.9484947220828424, 0.9490751315370928, 0.9496516768258174, 0.9502243836752948, 0.9507932776405265, 0.9513583841063779, 0.9519197282887107, 0.9524773352355081, 0.9530312298279927, 0.9535814367817362, 0.9541279806477626, 0.9546708858136439, 0.9552101765045878, 0.9557458767845193, 0.9562780105571537, 0.9568066015670638, 0.9573316734007393, 0.9578532494876392, 0.958371353101237, 0.95888600736006, 0.9593972352287199, 0.9599050595189379, 0.9604095028905629, 0.9609105878525823, 0.9614083367641264, 0.9619027718354661, 0.9623939151290042, 0.9628817885602593, 0.9633664138988443, 0.9638478127694374, 0.9643260066527475], \"type\": \"scatter\", \"uid\": \"aa33b36b-a176-4d08-9c7b-d53404471c5d\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 6.262324649298597, 12.474649298597194, 18.68697394789579, 24.899298597194388, 31.111623246492986, 37.32394789579158, 43.53627254509018, 49.74859719438877, 55.960921843687366, 62.17324649298597, 68.38557114228456, 74.59789579158316, 80.81022044088175, 87.02254509018036, 93.23486973947895, 99.44719438877755, 105.65951903807614, 111.87184368737474, 118.08416833667334, 124.29649298597194, 130.50881763527053, 136.72114228456914, 142.93346693386775, 149.14579158316633, 155.35811623246494, 161.57044088176352, 167.78276553106213, 173.99509018036073, 180.2074148296593, 186.41973947895792, 192.6320641282565, 198.8443887775551, 205.05671342685372, 211.2690380761523, 217.4813627254509, 223.6936873747495, 229.9060120240481, 236.1183366733467, 242.33066132264528, 248.5429859719439, 254.75531062124247, 260.96763527054105, 267.1799599198397, 273.39228456913827, 279.60460921843685, 285.8169338677355, 292.02925851703407, 298.24158316633265, 304.4539078156313, 310.66623246492986, 316.87855711422844, 323.090881763527, 329.30320641282566, 335.51553106212424, 341.7278557114228, 347.94018036072146, 354.15250501002004, 360.3648296593186, 366.57715430861725, 372.78947895791583, 379.0018036072144, 385.214128256513, 391.42645290581163, 397.6387775551102, 403.8511022044088, 410.0634268537074, 416.275751503006, 422.4880761523046, 428.70040080160317, 434.9127254509018, 441.1250501002004, 447.33737474949896, 453.5496993987976, 459.7620240480962, 465.97434869739476, 472.1866733466934, 478.398997995992, 484.61132264529056, 490.82364729458914, 497.0359719438878, 503.24829659318635, 509.46062124248493, 515.6729458917835, 521.885270541082, 528.0975951903807, 534.3099198396793, 540.5222444889779, 546.7345691382765, 552.946893787575, 559.1592184368736, 565.3715430861723, 571.5838677354709, 577.7961923847695, 584.0085170340681, 590.2208416833666, 596.4331663326652, 602.6454909819638, 608.8578156312625, 615.0701402805611, 621.2824649298597, 627.4947895791582, 633.7071142284568, 639.9194388777554, 646.131763527054, 652.3440881763527, 658.5564128256513, 664.7687374749498, 670.9810621242484, 677.193386773547, 683.4057114228456, 689.6180360721442, 695.8303607214428, 702.0426853707414, 708.25501002004, 714.4673346693386, 720.6796593186372, 726.8919839679357, 733.1043086172344, 739.316633266533, 745.5289579158316, 751.7412825651302, 757.9536072144288, 764.1659318637273, 770.3782565130259, 776.5905811623246, 782.8029058116232, 789.0152304609218, 795.2275551102204, 801.4398797595189, 807.6522044088175, 813.8645290581161, 820.0768537074148, 826.2891783567134, 832.501503006012, 838.7138276553105, 844.9261523046091, 851.1384769539077, 857.3508016032063, 863.563126252505, 869.7754509018035, 875.9877755511021, 882.2001002004007, 888.4124248496993, 894.6247494989979, 900.8370741482966, 907.0493987975951, 913.2617234468937, 919.4740480961923, 925.6863727454909, 931.8986973947895, 938.111022044088, 944.3233466933867, 950.5356713426853, 956.7479959919839, 962.9603206412825, 969.172645290581, 975.3849699398796, 981.5972945891782, 987.8096192384769, 994.0219438877755, 1000.2342685370741, 1006.4465931863726, 1012.6589178356712, 1018.8712424849698, 1025.0835671342684, 1031.295891783567, 1037.5082164328655, 1043.7205410821641, 1049.932865731463, 1056.1451903807615, 1062.35751503006, 1068.5698396793587, 1074.7821643286572, 1080.9944889779558, 1087.2068136272544, 1093.419138276553, 1099.6314629258516, 1105.8437875751501, 1112.0561122244487, 1118.2684368737473, 1124.4807615230459, 1130.6930861723447, 1136.9054108216433, 1143.1177354709419, 1149.3300601202404, 1155.542384769539, 1161.7547094188376, 1167.9670340681362, 1174.1793587174348, 1180.3916833667333, 1186.604008016032, 1192.8163326653305, 1199.028657314629, 1205.2409819639277, 1211.4533066132262, 1217.665631262525, 1223.8779559118236, 1230.0902805611222, 1236.3026052104208, 1242.5149298597194, 1248.727254509018, 1254.9395791583165, 1261.151903807615, 1267.3642284569137, 1273.5765531062123, 1279.7888777555108, 1286.0012024048094, 1292.213527054108, 1298.4258517034068, 1304.6381763527054, 1310.850501002004, 1317.0628256513025, 1323.2751503006011, 1329.4874749498997, 1335.6997995991983, 1341.9121242484969, 1348.1244488977954, 1354.336773547094, 1360.5490981963926, 1366.7614228456912, 1372.9737474949898, 1379.1860721442883, 1385.3983967935872, 1391.6107214428857, 1397.8230460921843, 1404.035370741483, 1410.2476953907815, 1416.46002004008, 1422.6723446893786, 1428.8846693386772, 1435.0969939879758, 1441.3093186372744, 1447.521643286573, 1453.7339679358715, 1459.94629258517, 1466.158617234469, 1472.3709418837675, 1478.583266533066, 1484.7955911823647, 1491.0079158316632, 1497.2202404809618, 1503.4325651302604, 1509.644889779559, 1515.8572144288576, 1522.0695390781561, 1528.2818637274547, 1534.4941883767533, 1540.7065130260519, 1546.9188376753505, 1553.1311623246493, 1559.3434869739478, 1565.5558116232464, 1571.768136272545, 1577.9804609218436, 1584.1927855711422, 1590.4051102204407, 1596.6174348697393, 1602.829759519038, 1609.0420841683365, 1615.254408817635, 1621.4667334669336, 1627.6790581162322, 1633.891382765531, 1640.1037074148296, 1646.3160320641282, 1652.5283567134268, 1658.7406813627254, 1664.953006012024, 1671.1653306613225, 1677.377655310621, 1683.5899799599197, 1689.8023046092183, 1696.0146292585168, 1702.2269539078154, 1708.439278557114, 1714.6516032064126, 1720.8639278557114, 1727.07625250501, 1733.2885771543085, 1739.5009018036071, 1745.7132264529057, 1751.9255511022043, 1758.1378757515029, 1764.3502004008014, 1770.5625250501, 1776.7748496993986, 1782.9871743486972, 1789.1994989979958, 1795.4118236472943, 1801.6241482965931, 1807.8364729458917, 1814.0487975951903, 1820.261122244489, 1826.4734468937875, 1832.685771543086, 1838.8980961923846, 1845.1104208416832, 1851.3227454909818, 1857.5350701402804, 1863.747394789579, 1869.9597194388775, 1876.172044088176, 1882.3843687374747, 1888.5966933867735, 1894.809018036072, 1901.0213426853707, 1907.2336673346692, 1913.4459919839678, 1919.6583166332664, 1925.870641282565, 1932.0829659318636, 1938.2952905811621, 1944.5076152304607, 1950.7199398797593, 1956.9322645290579, 1963.1445891783565, 1969.3569138276553, 1975.5692384769538, 1981.7815631262524, 1987.993887775551, 1994.2062124248496, 2000.4185370741482, 2006.6308617234467, 2012.8431863727453, 2019.055511022044, 2025.2678356713425, 2031.480160320641, 2037.6924849699396, 2043.9048096192382, 2050.117134268537, 2056.329458917836, 2062.541783567134, 2068.754108216433, 2074.9664328657313, 2081.17875751503, 2087.3910821643285, 2093.6034068136273, 2099.815731462926, 2106.0280561122245, 2112.2403807615233, 2118.4527054108216, 2124.6650300601204, 2130.877354709419, 2137.0896793587176, 2143.302004008016, 2149.5143286573148, 2155.726653306613, 2161.938977955912, 2168.1513026052103, 2174.363627254509, 2180.575951903808, 2186.7882765531062, 2193.000601202405, 2199.2129258517034, 2205.425250501002, 2211.6375751503006, 2217.8498997995994, 2224.0622244488977, 2230.2745490981965, 2236.486873747495, 2242.6991983967937, 2248.911523046092, 2255.123847695391, 2261.3361723446897, 2267.548496993988, 2273.760821643287, 2279.973146292585, 2286.185470941884, 2292.3977955911823, 2298.610120240481, 2304.8224448897795, 2311.0347695390783, 2317.2470941883766, 2323.4594188376755, 2329.671743486974, 2335.8840681362726, 2342.096392785571, 2348.30871743487, 2354.5210420841686, 2360.733366733467, 2366.9456913827657, 2373.158016032064, 2379.370340681363, 2385.5826653306613, 2391.79498997996, 2398.0073146292584, 2404.219639278557, 2410.4319639278556, 2416.6442885771544, 2422.8566132264527, 2429.0689378757515, 2435.2812625250504, 2441.4935871743487, 2447.7059118236475, 2453.918236472946, 2460.1305611222447, 2466.342885771543, 2472.555210420842, 2478.76753507014, 2484.979859719439, 2491.1921843687373, 2497.404509018036, 2503.6168336673345, 2509.8291583166333, 2516.041482965932, 2522.2538076152305, 2528.4661322645293, 2534.6784569138276, 2540.8907815631264, 2547.103106212425, 2553.3154308617236, 2559.527755511022, 2565.7400801603208, 2571.952404809619, 2578.164729458918, 2584.3770541082163, 2590.589378757515, 2596.801703406814, 2603.0140280561122, 2609.226352705411, 2615.4386773547094, 2621.651002004008, 2627.8633266533066, 2634.0756513026054, 2640.2879759519037, 2646.5003006012025, 2652.712625250501, 2658.9249498997997, 2665.137274549098, 2671.349599198397, 2677.561923847695, 2683.774248496994, 2689.986573146293, 2696.198897795591, 2702.41122244489, 2708.6235470941883, 2714.835871743487, 2721.0481963927855, 2727.2605210420843, 2733.4728456913826, 2739.6851703406815, 2745.89749498998, 2752.1098196392786, 2758.322144288577, 2764.5344689378758, 2770.7467935871746, 2776.959118236473, 2783.1714428857717, 2789.38376753507, 2795.596092184369, 2801.8084168336673, 2808.020741482966, 2814.2330661322644, 2820.445390781563, 2826.6577154308616, 2832.8700400801604, 2839.0823647294587, 2845.2946893787575, 2851.5070140280563, 2857.7193386773547, 2863.9316633266535, 2870.143987975952, 2876.3563126252507, 2882.568637274549, 2888.780961923848, 2894.993286573146, 2901.205611222445, 2907.4179358717433, 2913.630260521042, 2919.8425851703405, 2926.0549098196393, 2932.267234468938, 2938.4795591182365, 2944.6918837675353, 2950.9042084168336, 2957.1165330661324, 2963.328857715431, 2969.5411823647296, 2975.753507014028, 2981.9658316633268, 2988.178156312625, 2994.390480961924, 3000.6028056112223, 3006.815130260521, 3013.0274549098194, 3019.2397795591182, 3025.452104208417, 3031.6644288577154, 3037.876753507014, 3044.0890781563126, 3050.3014028056114, 3056.5137274549097, 3062.7260521042085, 3068.938376753507, 3075.1507014028057, 3081.363026052104, 3087.575350701403, 3093.787675350701, 3100.0], \"y\": [0.9679664001403558, 0.9542095347587436, 0.9405473003068232, 0.9269790458359515, 0.9135041248752402, 0.9001218954007553, 0.8868317198049258, 0.8736329648661654, 0.860525001718702, 0.8475072058226147, 0.8345789569340767, 0.8217396390758043, 0.8089886405077067, 0.7963253536977404, 0.7837491752929622, 0.7712595060907823, 0.7588557510104141, 0.7465373190645219, 0.7343036233310625, 0.7221540809253204, 0.7100881129721364, 0.6981051445783266, 0.6862046048052901, 0.6743859266418075, 0.6626485469770247, 0.6509919065736223, 0.6394154500411715, 0.6279186258096712, 0.6165008861032677, 0.6051616869141567, 0.593900487976663, 0.5827167527414976, 0.5716099483501964, 0.5605795456097289, 0.549625018967286, 0.5387458464852386, 0.5279415098162703, 0.5172114941786798, 0.506555288331854, 0.4959723845519086, 0.4854622786074989, 0.4750244697357935, 0.46465846061861615, 0.4543637573587498, 0.4441398694564058, 0.4339863097858516, 0.4239025945722035, 0.4138882433683746, 0.40394277903218545, 0.39406572770362835, 0.3842566187822918, 0.37451498490493695, 0.3648403619232301, 0.35523228888162794, 0.3456903079954152, 0.3362139646288931, 0.3268028072737168, 0.3174563875273846, 0.30817426007187243, 0.29895598265241596, 0.2898011160564402, 0.28070922409263166, 0.2716798735701562, 0.2627126342780195, 0.25380707896456856, 0.2449627833171355, 0.23617932594182123, 0.22745628834341658, 0.21879325490546386, 0.2101898128704538, 0.20164555232015968, 0.19316006615610637, 0.1847329500801742, 0.17636380257533424, 0.16805222488652038, 0.15979782100162754, 0.1516001976326451, 0.14345896419691773, 0.13537373279853626, 0.12734411820985492, 0.1193697378531382, 0.11145021178233172, 0.10358516266495976, 0.09577421576414658, 0.08801699892076242, 0.0803131425356911, 0.07266227955222027, 0.06506404543855249, 0.05751807817043786, 0.050024018213923105, 0.04258150850822351, 0.035190194448708745, 0.02784972387000839, 0.020559747029232245, 0.013319916589306535, 0.006129887602425388, 0.001010682506385363, 0.00810213395559023, 0.015144804623353547, 0.022139030063638154, 0.029085143522193935, 0.03598347595243456, 0.04283435603120633, 0.049638110174448635, 0.05639506255274607, 0.06310553510677375, 0.06976984756263638, 0.07638831744710195, 0.08296126010273097, 0.08948898870290045, 0.09597181426672607, 0.10241004567388023, 0.10880398967930982, 0.11515395092785052, 0.121460231968743, 0.12772313327004792, 0.13394295323296135, 0.14011998820603322, 0.14625453249928633, 0.15234687839823924, 0.15839731617783304, 0.1644061341162607, 0.17037361850870336, 0.17630005368097024, 0.18218572200304628, 0.18803090390254518, 0.19383587787807144, 0.1996009205124888, 0.20532630648609906, 0.21101230858972908, 0.2166591977377278, 0.22226724298087475, 0.22783671151919915, 0.23336786871471016, 0.2388609781040414, 0.24431630141100635, 0.24973409855906903, 0.25511462768372806, 0.2604581451448159, 0.2657649055387129, 0.27103516171047815, 0.2762691647658966, 0.28146716408344274, 0.28662940732616293, 0.291756140453475, 0.296847607732888, 0.30190405175163926, 0.30692571342825414, 0.31191283202402353, 0.31686564515440474, 0.3217843888003419, 0.3266692973195101, 0.33152060345748147, 0.3363385383588141, 0.34112333157806574, 0.34587521109073094, 0.35059440330410274, 0.35528113306806064, 0.35993562368578325, 0.364558096924388, 0.3691487730254973, 0.37370787071573264, 0.3782356072171348, 0.38273219825751503, 0.3871978580807327, 0.39163279945690344, 0.3960372336925364, 0.4004113706406025, 0.4047554187105331, 0.4090695848781497, 0.4133540746955249, 0.41760909230077714, 0.4218348404277966, 0.4260315204159042, 0.4301993322194454, 0.4343384744173162, 0.43844914422242576, 0.44253153749109164, 0.4465858487323723, 0.45061227111733426, 0.4546109964882564, 0.45858221536776955, 0.46252611696793544, 0.4664428891992598, 0.47033271867964777, 0.47419579074329443, 0.4780322894495149, 0.4818423975915145, 0.48562629670509805, 0.4893841670773189, 0.4931161877550695, 0.49682253655361164, 0.5005033900650487, 0.5041589236667402, 0.5077893115296567, 0.5113947266266793, 0.5149753407408406, 0.5185313244735094, 0.5220628472525191, 0.525570077340241, 0.5290531818416001, 0.532512326712038, 0.5359476767654193, 0.5393593956818845, 0.5427476460156491, 0.5461125892027476, 0.5494543855687266, 0.5527731943362825, 0.5560691736328482, 0.559342480498128, 0.562593270891578, 0.5658216996998391, 0.5690279207441149, 0.5722120867875022, 0.5753743495422681, 0.5785148596770793, 0.5816337668241809, 0.5847312195865251, 0.587807365544852, 0.5908623512647213, 0.5938963223034954, 0.5969094232172741, 0.5999017975677832, 0.6028735879292133, 0.6058249358950141, 0.6087559820846399, 0.6116668661502498, 0.6145577267833615, 0.6174287017214599, 0.6202799277545585, 0.6231115407317183, 0.6259236755675194, 0.6287164662484895, 0.6314900458394879, 0.6342445464900455, 0.6369800994406605, 0.6396968350290527, 0.6423948826963723, 0.6450743709933684, 0.6477354275865125, 0.6503781792640828, 0.6530027519422039, 0.6556092706708473, 0.6581978596397882, 0.6607686421845238, 0.663321740792149, 0.6658572771071929, 0.6683753719374143, 0.6708761452595575, 0.6733597162250696, 0.6758262031657766, 0.6782757235995214, 0.6807083942357641, 0.6831243309811419, 0.6855236489449912, 0.6879064624448331, 0.6902728850118196, 0.6926230293961426, 0.6949570075724067, 0.6972749307449637, 0.6995769093532114, 0.701863053076855, 0.704133470841134, 0.7063882708220109, 0.7086275604513258, 0.7108514464219151, 0.7130600346926952, 0.7152534304937104, 0.7174317383311469, 0.7195950619923128, 0.7217435045505819, 0.7238771683703058, 0.7259961551116902, 0.7281005657356394, 0.7301905005085665, 0.73226605900717, 0.7343273401231791, 0.7363744420680652, 0.7384074623777208, 0.7404264979171074, 0.7424316448848698, 0.7444229988179211, 0.7464006545959927, 0.7483647064461566, 0.7503152479473139, 0.7522523720346534, 0.7541761710040809, 0.7560867365166147, 0.7579841596027548, 0.7598685306668186, 0.7617399394912495, 0.7635984752408935, 0.7654442264672485, 0.7672772811126831, 0.7690977265146264, 0.7709056494097296, 0.7727011359379987, 0.7744842716468983, 0.7762551414954277, 0.7780138298581696, 0.7797604205293088, 0.781494996726626, 0.783217641095462, 0.7849284357126555, 0.7866274620904541, 0.7883148011803971, 0.789990533377174, 0.7916547385224535, 0.7933074959086887, 0.794948884282894, 0.7965789818503984, 0.7981978662785704, 0.7998056147005191, 0.8014023037187695, 0.8029880094089118, 0.8045628073232263, 0.8061267724942831, 0.8076799794385174, 0.8092225021597795, 0.8107544141528609, 0.8122757884069958, 0.8137866974093395, 0.815287213148421, 0.8167774071175742, 0.8182573503183429, 0.8197271132638649, 0.8211867659822312, 0.8226363780198219, 0.8240760184446213, 0.8255057558495071, 0.8269256583555199, 0.8283357936151079, 0.8297362288153505, 0.8311270306811602, 0.8325082654784605, 0.8338799990173444, 0.8352422966552092, 0.8365952232998709, 0.8379388434126565, 0.8392732210114754, 0.8405984196738701, 0.8419145025400444, 0.8432215323158729, 0.8445195712758874, 0.8458086812662454, 0.8470889237076756, 0.8483603595984055, 0.8496230495170664, 0.8508770536255809, 0.8521224316720284, 0.8533592429934931, 0.8545875465188896, 0.8558074007717718, 0.8570188638731208, 0.8582219935441142, 0.8594168471088766, 0.8606034814972101, 0.8617819532473076, 0.862952318508446, 0.8641146330436619, 0.8652689522324082, 0.8664153310731927, 0.867553824186199, 0.8686844858158882, 0.869807369833584, 0.870922529740039, 0.8720300186679845, 0.873129889384661, 0.8742221942943333, 0.8753069854407869, 0.8763843145098078, 0.8774542328316447, 0.8785167913834555, 0.8795720407917353, 0.8806200313347292, 0.8816608129448275, 0.8826944352109445, 0.8837209473808819, 0.8847403983636748, 0.8857528367319223, 0.8867583107241009, 0.8877568682468646, 0.8887485568773252, 0.8897334238653216, 0.8907115161356689, 0.8916828802903953, 0.8926475626109625, 0.8936056090604705, 0.8945570652858473, 0.8955019766200248, 0.8964403880840974, 0.8973723443894683, 0.8982978899399787, 0.8992170688340242, 0.9001299248666561, 0.9010365015316668, 0.901936842023664, 0.9028309892401267, 0.9037189857834509, 0.9046008739629778, 0.9054766957970114, 0.9063464930148187, 0.9072103070586195, 0.9080681790855596, 0.9089201499696731, 0.9097662603038285, 0.9106065504016639, 0.9114410602995074, 0.9122698297582843, 0.9130928982654121, 0.9139103050366815, 0.9147220890181252, 0.9155282888878732, 0.9163289430579961, 0.9171240896763344, 0.9179137666283174, 0.9186980115387668, 0.9194768617736908, 0.9202503544420634, 0.9210185263975927, 0.9217814142404774, 0.9225390543191497, 0.9232914827320081, 0.9240387353291367, 0.9247808477140135, 0.9255178552452068, 0.9262497930380599, 0.926976695966364, 0.9276985986640202, 0.9284155355266891, 0.9291275407134303, 0.9298346481483292, 0.9305368915221138, 0.93123430429376, 0.9319269196920854, 0.9326147707173327, 0.9332978901427422, 0.9339763105161131, 0.9346500641613541, 0.9353191831800242, 0.9359836994528611, 0.9366436446413012, 0.937299050188988, 0.9379499473232692, 0.938596367056686, 0.93923834018845, 0.9398758973059106, 0.9405090687860123, 0.9411378847967427, 0.941762375298569, 0.942382570045866, 0.9429984985883337, 0.9436101902724053, 0.944217674242645, 0.9448209794431374, 0.9454201346188655, 0.9460151683170814, 0.9466061088886659, 0.947192984489479, 0.9477758230817019, 0.9483546524351694, 0.9489295001286924, 0.9495003935513724, 0.9500673599039063, 0.9506304261998827, 0.9511896192670684, 0.9517449657486868, 0.9522964921046881, 0.9528442246130091, 0.9533881893708253, 0.9539284122957948, 0.9544649191272931, 0.9549977354276389, 0.9555268865833128, 0.9560523978061661, 0.9565742941346229, 0.9570926004348724, 0.9576073414020538, 0.9581185415614333, 0.9586262252695719, 0.9591304167154867, 0.9596311399218028, 0.9601284187458984, 0.9606222768810407, 0.961112737857516, 0.9615998250437495, 0.9620835616474197, 0.9625639707165635, 0.9630410751406749, 0.9635148976517951, 0.9639854608255959, 0.9644527870824553, 0.9649168986885254, 0.9653778177567939, 0.965835566248137, 0.9662901659723666, 0.9667416385892684, 0.9671900056096348, 0.9676352883962891, 0.9680775081651043], \"type\": \"scatter\", \"uid\": \"7e4cc826-51ca-40d3-a67e-05f9fae164a8\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 6.462725450901803, 12.875450901803607, 19.28817635270541, 25.700901803607213, 32.11362725450901, 38.526352705410815, 44.93907815631262, 51.35180360721442, 57.764529058116224, 64.17725450901803, 70.58997995991983, 77.00270541082163, 83.41543086172344, 89.82815631262524, 96.24088176352704, 102.65360721442885, 109.06633266533065, 115.47905811623245, 121.89178356713425, 128.30450901803607, 134.71723446893787, 141.12995991983968, 147.54268537074148, 153.95541082164328, 160.3681362725451, 166.7808617234469, 173.1935871743487, 179.6063126252505, 186.0190380761523, 192.4317635270541, 198.8444889779559, 205.2572144288577, 211.6699398797595, 218.0826653306613, 224.49539078156312, 230.90811623246492, 237.32084168336672, 243.73356713426853, 250.14629258517033, 256.55901803607213, 262.97174348697393, 269.38446893787574, 275.79719438877754, 282.20991983967934, 288.62264529058115, 295.03537074148295, 301.44809619238475, 307.86082164328656, 314.27354709418836, 320.68627254509016, 327.09899799599197, 333.51172344689377, 339.92444889779557, 346.3371743486974, 352.7498997995992, 359.162625250501, 365.5753507014028, 371.9880761523046, 378.4008016032064, 384.8135270541082, 391.22625250501, 397.6389779559118, 404.0517034068136, 410.4644288577154, 416.8771543086172, 423.289879759519, 429.7026052104208, 436.1153306613226, 442.5280561122244, 448.9407815631262, 455.353507014028, 461.76623246492983, 468.17895791583163, 474.59168336673343, 481.00440881763524, 487.41713426853704, 493.82985971943884, 500.24258517034065, 506.65531062124245, 513.0680360721442, 519.480761523046, 525.8934869739478, 532.3062124248496, 538.7189378757514, 545.1316633266532, 551.544388777555, 557.9571142284568, 564.3698396793586, 570.7825651302604, 577.1952905811622, 583.608016032064, 590.0207414829658, 596.4334669338676, 602.8461923847694, 609.2589178356712, 615.671643286573, 622.0843687374748, 628.4970941883766, 634.9098196392785, 641.3225450901803, 647.7352705410821, 654.1479959919839, 660.5607214428857, 666.9734468937875, 673.3861723446893, 679.7988977955911, 686.2116232464929, 692.6243486973947, 699.0370741482965, 705.4497995991983, 711.8625250501001, 718.2752505010019, 724.6879759519037, 731.1007014028055, 737.5134268537073, 743.9261523046091, 750.3388777555109, 756.7516032064127, 763.1643286573145, 769.5770541082163, 775.9897795591181, 782.4025050100199, 788.8152304609217, 795.2279559118235, 801.6406813627253, 808.0534068136271, 814.4661322645289, 820.8788577154307, 827.2915831663325, 833.7043086172343, 840.1170340681361, 846.529759519038, 852.9424849699398, 859.3552104208416, 865.7679358717434, 872.1806613226452, 878.593386773547, 885.0061122244488, 891.4188376753506, 897.8315631262524, 904.2442885771542, 910.657014028056, 917.0697394789578, 923.4824649298596, 929.8951903807614, 936.3079158316632, 942.720641282565, 949.1333667334668, 955.5460921843686, 961.9588176352704, 968.3715430861722, 974.784268537074, 981.1969939879758, 987.6097194388776, 994.0224448897794, 1000.4351703406812, 1006.847895791583, 1013.2606212424848, 1019.6733466933866, 1026.0860721442884, 1032.4987975951901, 1038.911523046092, 1045.324248496994, 1051.7369739478956, 1058.1496993987973, 1064.5624248496993, 1070.9751503006012, 1077.3878757515029, 1083.8006012024046, 1090.2133266533065, 1096.6260521042084, 1103.03877755511, 1109.4515030060118, 1115.8642284569137, 1122.2769539078156, 1128.6896793587173, 1135.102404809619, 1141.515130260521, 1147.9278557114228, 1154.3405811623245, 1160.7533066132262, 1167.166032064128, 1173.57875751503, 1179.9914829659317, 1186.4042084168334, 1192.8169338677353, 1199.2296593186372, 1205.642384769539, 1212.0551102204406, 1218.4678356713425, 1224.8805611222444, 1231.2932865731461, 1237.7060120240478, 1244.1187374749497, 1250.5314629258517, 1256.9441883767533, 1263.356913827655, 1269.769639278557, 1276.1823647294589, 1282.5950901803606, 1289.0078156312622, 1295.4205410821642, 1301.833266533066, 1308.2459919839678, 1314.6587174348695, 1321.0714428857714, 1327.4841683366733, 1333.896893787575, 1340.3096192384767, 1346.7223446893786, 1353.1350701402805, 1359.5477955911822, 1365.9605210420839, 1372.3732464929858, 1378.7859719438877, 1385.1986973947894, 1391.611422845691, 1398.024148296593, 1404.436873747495, 1410.8495991983966, 1417.2623246492983, 1423.6750501002002, 1430.0877755511021, 1436.5005010020038, 1442.9132264529055, 1449.3259519038074, 1455.7386773547094, 1462.151402805611, 1468.5641282565127, 1474.9768537074146, 1481.3895791583166, 1487.8023046092183, 1494.21503006012, 1500.6277555110219, 1507.0404809619238, 1513.4532064128255, 1519.8659318637272, 1526.278657314629, 1532.691382765531, 1539.1041082164327, 1545.5168336673344, 1551.9295591182363, 1558.3422845691382, 1564.75501002004, 1571.1677354709416, 1577.5804609218435, 1583.9931863727454, 1590.405911823647, 1596.8186372745488, 1603.2313627254507, 1609.6440881763526, 1616.0568136272543, 1622.469539078156, 1628.882264529058, 1635.2949899799598, 1641.7077154308615, 1648.1204408817632, 1654.5331663326651, 1660.945891783567, 1667.3586172344687, 1673.7713426853704, 1680.1840681362723, 1686.5967935871743, 1693.009519038076, 1699.4222444889776, 1705.8349699398796, 1712.2476953907815, 1718.6604208416832, 1725.0731462925849, 1731.4858717434868, 1737.8985971943887, 1744.3113226452904, 1750.724048096192, 1757.136773547094, 1763.549498997996, 1769.9622244488976, 1776.3749498997993, 1782.7876753507012, 1789.200400801603, 1795.6131262525048, 1802.0258517034065, 1808.4385771543084, 1814.8513026052103, 1821.264028056112, 1827.6767535070137, 1834.0894789579156, 1840.5022044088175, 1846.9149298597192, 1853.327655310621, 1859.7403807615228, 1866.1531062124247, 1872.5658316633264, 1878.9785571142281, 1885.39128256513, 1891.804008016032, 1898.2167334669336, 1904.6294589178353, 1911.0421843687373, 1917.4549098196392, 1923.8676352705409, 1930.2803607214425, 1936.6930861723445, 1943.1058116232464, 1949.518537074148, 1955.9312625250498, 1962.3439879759517, 1968.7567134268536, 1975.1694388777553, 1981.582164328657, 1987.994889779559, 1994.4076152304608, 2000.8203406813625, 2007.2330661322642, 2013.645791583166, 2020.058517034068, 2026.4712424849697, 2032.8839679358714, 2039.2966933867733, 2045.7094188376752, 2052.122144288577, 2058.534869739479, 2064.9475951903805, 2071.3603206412827, 2077.7730460921844, 2084.185771543086, 2090.598496993988, 2097.01122244489, 2103.4239478957916, 2109.8366733466933, 2116.249398797595, 2122.662124248497, 2129.074849699399, 2135.4875751503005, 2141.9003006012026, 2148.3130260521043, 2154.725751503006, 2161.1384769539077, 2167.5512024048094, 2173.9639278557115, 2180.376653306613, 2186.789378757515, 2193.202104208417, 2199.6148296593187, 2206.0275551102204, 2212.440280561122, 2218.853006012024, 2225.265731462926, 2231.6784569138276, 2238.0911823647293, 2244.5039078156315, 2250.916633266533, 2257.329358717435, 2263.7420841683365, 2270.154809619238, 2276.5675350701404, 2282.980260521042, 2289.3929859719437, 2295.805711422846, 2302.2184368737476, 2308.6311623246493, 2315.043887775551, 2321.4566132264526, 2327.869338677355, 2334.2820641282565, 2340.694789579158, 2347.1075150300603, 2353.520240480962, 2359.9329659318637, 2366.3456913827654, 2372.758416833667, 2379.171142284569, 2385.583867735471, 2391.9965931863726, 2398.4093186372747, 2404.8220440881764, 2411.234769539078, 2417.64749498998, 2424.0602204408815, 2430.4729458917836, 2436.8856713426853, 2443.298396793587, 2449.711122244489, 2456.123847695391, 2462.5365731462925, 2468.9492985971942, 2475.362024048096, 2481.774749498998, 2488.1874749498998, 2494.6002004008014, 2501.0129258517036, 2507.4256513026053, 2513.838376753507, 2520.2511022044087, 2526.6638276553103, 2533.0765531062125, 2539.489278557114, 2545.902004008016, 2552.314729458918, 2558.7274549098197, 2565.1401803607214, 2571.552905811623, 2577.9656312625248, 2584.378356713427, 2590.7910821643286, 2597.2038076152303, 2603.6165330661324, 2610.029258517034, 2616.441983967936, 2622.8547094188375, 2629.267434869739, 2635.6801603206413, 2642.092885771543, 2648.5056112224447, 2654.918336673347, 2661.3310621242485, 2667.7437875751502, 2674.156513026052, 2680.5692384769536, 2686.9819639278558, 2693.3946893787574, 2699.807414829659, 2706.2201402805613, 2712.632865731463, 2719.0455911823647, 2725.4583166332663, 2731.871042084168, 2738.28376753507, 2744.696492985972, 2751.1092184368736, 2757.5219438877757, 2763.9346693386774, 2770.347394789579, 2776.760120240481, 2783.1728456913825, 2789.5855711422846, 2795.9982965931863, 2802.411022044088, 2808.82374749499, 2815.236472945892, 2821.6491983967935, 2828.061923847695, 2834.474649298597, 2840.887374749499, 2847.3001002004007, 2853.7128256513024, 2860.1255511022046, 2866.5382765531062, 2872.951002004008, 2879.3637274549096, 2885.7764529058113, 2892.1891783567135, 2898.601903807615, 2905.014629258517, 2911.427354709419, 2917.8400801603207, 2924.2528056112224, 2930.665531062124, 2937.0782565130257, 2943.490981963928, 2949.9037074148296, 2956.3164328657313, 2962.7291583166334, 2969.141883767535, 2975.554609218437, 2981.9673346693385, 2988.38006012024, 2994.7927855711423, 3001.205511022044, 3007.6182364729457, 3014.030961923848, 3020.4436873747495, 3026.856412825651, 3033.269138276553, 3039.6818637274546, 3046.0945891783567, 3052.5073146292584, 3058.92004008016, 3065.3327655310623, 3071.745490981964, 3078.1582164328656, 3084.5709418837673, 3090.983667334669, 3097.396392785571, 3103.809118236473, 3110.2218436873745, 3116.6345691382767, 3123.0472945891784, 3129.46002004008, 3135.8727454909817, 3142.2854709418834, 3148.6981963927856, 3155.1109218436873, 3161.523647294589, 3167.936372745491, 3174.349098196393, 3180.7618236472945, 3187.174549098196, 3193.587274549098, 3200.0], \"y\": [0.9713233911907011, 0.9571243278755726, 0.9430260768604855, 0.9290279223855606, 0.9151291537727615, 0.901329065389813, 0.8876269566143764, 0.8740221317984809, 0.8605139002332038, 0.8471015761136058, 0.833784478503911, 0.8205619313029378, 0.8074332632097727, 0.7943978076896889, 0.7814549029403075, 0.7686038918579969, 0.7558441220045136, 0.7431749455738761, 0.7305957193594788, 0.7181058047214346, 0.7057045675541529, 0.6933913782541454, 0.6811656116880627, 0.6690266471609554, 0.6569738683847626, 0.6450066634470231, 0.6331244247798089, 0.6213265491288793, 0.6096124375230543, 0.597981495243805, 0.5864331317950597, 0.5749667608732258, 0.5635818003374224, 0.5522776721799261, 0.5410538024968252, 0.5299096214588841, 0.5188445632826117, 0.5078580662015386, 0.49694957243769555, 0.4861185281732958, 0.4753643835226178, 0.4646865925040877, 0.4540846130125613, 0.44355790679179985, 0.4331059394071448, 0.422728180218384, 0.4124241023528117, 0.4021931826784788, 0.3920349017776352, 0.38194874392035816, 0.37193419703836916, 0.36199075269903624, 0.3521179060795625, 0.34231515594135464, 0.3325820046045769, 0.32291795792288336, 0.3133225252583305, 0.30379521945646837, 0.29433555682160706, 0.28494305709226087, 0.2756172434167645, 0.266357642329065, 0.25716378372468274, 0.24803520083684538, 0.2389714302127901, 0.22997201169023485, 0.22103648837401502, 0.2121644066128887, 0.20335531597650358, 0.19460876923253023, 0.18592432232395484, 0.1773015343465365, 0.16873996752642118, 0.1602391871979172, 0.15179876178142693, 0.14341826276153613, 0.13509726466525818, 0.1268353450404336, 0.11863208443428142, 0.11048706637210493, 0.10239987733614675, 0.094370106744595, 0.08639734693073842, 0.07848119312226909, 0.07062124342073295, 0.06281709878112474, 0.05506836299162954, 0.047374642653507104, 0.039735547161118934, 0.032150688682097917, 0.02461968213765786, 0.017142145183043356, 0.009717698188119295, 0.002345964218095631, 0.004973430985608207, 0.012240859024364559, 0.019456688861203775, 0.026621286839545233, 0.03373501670179779, 0.040798239607826026, 0.04781131415328577, 0.05477459638783044, 0.06168843983318739, 0.0685531955011055, 0.0753692119111764, 0.08213683510852854, 0.0888564086813951, 0.09552827377855855, 0.10215276912667004, 0.10873023104744661, 0.11526099347474605, 0.12174538797152012, 0.12818374374664854, 0.13457638767165214, 0.140923644297288, 0.14722583587002702, 0.1534832823484138, 0.15969630141931102, 0.16586520851402808, 0.1719903168243354, 0.17807193731836501, 0.18411037875639813, 0.19010594770654088, 0.1960589485602885, 0.20196968354797884, 0.20783845275413715, 0.21366555413271038, 0.21945128352219456, 0.22519593466065435, 0.23089979920063575, 0.23656316672397337, 0.24218632475649216, 0.24776955878260476, 0.2533131522598059, 0.25881738663306275, 0.26428254134910434, 0.26970889387060826, 0.2750967196902878, 0.2804462923448783, 0.2857578834290244, 0.29103176260906904, 0.29626819763674384, 0.3014674543627631, 0.30662979675032054, 0.31175548688849075, 0.3168447850055355, 0.3218979494821147, 0.32691523686440493, 0.33189690187712406, 0.33684319743646296, 0.34175437466292635, 0.34663068289408205, 0.3514723696972193, 0.3562796808819181, 0.3610528605125286, 0.36579215092056205, 0.3704977927169939, 0.37517002480447936, 0.3798090843894827, 0.3844152069943195, 0.3889886264691147, 0.39352957500367414, 0.3980382831392736, 0.4025149797803629, 0.40695989220618634, 0.41137324608232373, 0.41575526547214503, 0.4201061728481872, 0.4244261891034481, 0.42871553356260217, 0.432974423993135, 0.43720307661639857, 0.44140170611858964, 0.44557052566164845, 0.44970974689408205, 0.45381957996170785, 0.45790023351832354, 0.46195191473630093, 0.4659748293171029, 0.46996918150172706, 0.473935174081075, 0.47787300840624836, 0.48178288439877026, 0.48566500056073636, 0.48951955398489133, 0.49334674036463655, 0.4971467540039649, 0.5009197878273245, 0.5046660333894146, 0.5083856808849103, 0.5120789191581187, 0.5157459357125658, 0.5193869167205165, 0.5230020470324268, 0.526591510186328, 0.5301554884171448, 0.533694162665947, 0.5372077125891371, 0.5406963165675698, 0.5441601517156089, 0.5475993938901197, 0.5510142176993962, 0.554404796512027, 0.5577713024656961, 0.561113906475923, 0.5644327782447391, 0.5677280862693048, 0.5709999978504624, 0.5742486791012306, 0.5774742949552383, 0.5806770091750977, 0.5838569843607186, 0.5870143819575631, 0.5901493622648428, 0.593262084443657, 0.5963527065250724, 0.5994213854181472, 0.6024682769178963, 0.6054935357132025, 0.608497315394668, 0.6114797684624136, 0.6144410463338204, 0.6173812993512174, 0.6203006767895141, 0.6231993268637788, 0.6260773967367642, 0.6289350325263785, 0.6317723793131031, 0.6345895811473589, 0.6373867810568195, 0.6401641210536725, 0.6429217421418296, 0.6456597843240849, 0.6483783866092232, 0.6510776870190773, 0.6537578225955349, 0.6564189294074968, 0.6590611425577841, 0.6616845961899986, 0.6642894234953318, 0.6668757567193278, 0.6694437271685972, 0.6719934652174835, 0.6745251003146815, 0.6770387609898102, 0.679534574859938, 0.682012668636061, 0.6844731681295371, 0.6869161982584724, 0.6893418830540641, 0.6917503456668971, 0.6941417083731956, 0.6965160925810323, 0.6988736188364914, 0.7012144068297888, 0.7035385754013486, 0.7058462425478365, 0.7081375254281511, 0.7104125403693713, 0.7126714028726622, 0.7149142276191389, 0.7171411284756898, 0.7193522185007561, 0.7215476099500732, 0.723727414282368, 0.7258917421650194, 0.7280407034796762, 0.7301744073278352, 0.7322929620363808, 0.7343964751630846, 0.736485053502066, 0.7385588030892137, 0.7406178292075698, 0.7426622363926746, 0.7446921284378734, 0.7467076083995869, 0.7487087786025425, 0.7506957406449697, 0.7526685954037581, 0.7546274430395788, 0.7565723830019697, 0.758503514034384, 0.7604209341792039, 0.7623247407827181, 0.7642150305000632, 0.7660918993001326, 0.7679554424704464, 0.7698057546219912, 0.7716429296940223, 0.7734670609588331, 0.7752782410264909, 0.7770765618495381, 0.7788621147276612, 0.7806349903123252, 0.7823952786113768, 0.7841430689936135, 0.7858784501933206, 0.7876015103147772, 0.7893123368367281, 0.7910110166168257, 0.792697635896039, 0.7943722803030332, 0.7960350348585158, 0.7976859839795538, 0.799325211483859, 0.800952800594044, 0.8025688339418469, 0.8041733935723261, 0.805766560948027, 0.8073484169531161, 0.8089190418974891, 0.8104785155208466, 0.8120269169967438, 0.8135643249366091, 0.8150908173937359, 0.8166064718672449, 0.8181113653060186, 0.8196055741126083, 0.8210891741471127, 0.8225622407310296, 0.8240248486510795, 0.8254770721630028, 0.8269189849953298, 0.8283506603531234, 0.8297721709216963, 0.8311835888703003, 0.8325849858557917, 0.8339764330262673, 0.8353580010246789, 0.8367297599924176, 0.8380917795728762, 0.8394441289149847, 0.8407868766767204, 0.8421200910285944, 0.8434438396571121, 0.8447581897682095, 0.8460632080906658, 0.8473589608794905, 0.8486455139192877, 0.8499229325275952, 0.8511912815582019, 0.8524506254044386, 0.8537010280024492, 0.8549425528344349, 0.8561752629318783, 0.8573992208787433, 0.858614488814652, 0.8598211284380399, 0.8610192010092882, 0.8622087673538339, 0.8633898878652577, 0.8645626225083507, 0.8657270308221581, 0.8668831719230023, 0.8680311045074847, 0.8691708868554644, 0.8703025768330181, 0.8714262318953779, 0.8725419090898479, 0.8736496650587, 0.8747495560420511, 0.8758416378807166, 0.8769259660190465, 0.8780025955077405, 0.8790715810066417, 0.8801329767875127, 0.8811868367367905, 0.8822332143583224, 0.8832721627760824, 0.8843037347368682, 0.885327982612979, 0.8863449584048747, 0.8873547137438158, 0.8883572998944844, 0.8893527677575876, 0.8903411678724408, 0.8913225504195341, 0.8922969652230801, 0.8932644617535429, 0.8942250891301501, 0.8951788961233862, 0.8961259311574691, 0.8970662423128084, 0.8979998773284459, 0.8989268836044803, 0.8998473082044726, 0.9007611978578364, 0.9016685989622097, 0.9025695575858108, 0.9034641194697768, 0.9043523300304865, 0.9052342343618657, 0.9061098772376761, 0.9069793031137898, 0.907842556130445, 0.9086996801144877, 0.9095507185815962, 0.9103957147384911, 0.9112347114851284, 0.9120677514168772, 0.9128948768266832, 0.913716129707215, 0.9145315517529964, 0.9153411843625229, 0.9161450686403643, 0.9169432453992505, 0.9177357551621443, 0.9185226381642985, 0.9193039343552982, 0.9200796834010898, 0.9208499246859942, 0.9216146973147068, 0.9223740401142821, 0.9231279916361059, 0.9238765901578516, 0.9246198736854241, 0.925357879954889, 0.9260906464343892, 0.9268182103260458, 0.9275406085678483, 0.9282578778355285, 0.9289700545444238, 0.9296771748513251, 0.9303792746563129, 0.9310763896045795, 0.9317685550882393, 0.9324558062481252, 0.9331381779755727, 0.9338157049141916, 0.9344884214616245, 0.935156361771293, 0.9358195597541323, 0.9364780490803125, 0.9371318631809478, 0.937781035249794, 0.9384255982449337, 0.9390655848904494, 0.9397010276780854, 0.9403319588688968, 0.9409584104948874, 0.9415804143606363, 0.9421980020449127, 0.9428112049022785, 0.9434200540646808, 0.9440245804430318, 0.9446248147287789, 0.9452207873954624, 0.9458125287002627, 0.9464000686855363, 0.9469834371803412, 0.9475626638019515, 0.948137777957361, 0.9487088088447754, 0.9492757854550957, 0.9498387365733899, 0.9503976907803535, 0.9509526764537618, 0.9515037217699095, 0.952050854705042, 0.9525941030367754, 0.9531334943455065, 0.9536690560158138, 0.9542008152378468, 0.9547287990087074, 0.9552530341338197, 0.9557735472282916, 0.9562903647182655, 0.9568035128422601, 0.9573130176525025, 0.9578189050162514, 0.9583212006171095, 0.9588199299563276, 0.9593151183540998, 0.9598067909508486, 0.9602949727085017, 0.9607796884117584, 0.9612609626693488, 0.9617388199152828, 0.9622132844100906, 0.9626843802420543, 0.9631521313284311, 0.9636165614166676, 0.9640776940856052, 0.9645355527466769, 0.9649901606450968, 0.9654415408610394, 0.9658897163108117, 0.9663347097480165, 0.9667765437647081, 0.9672152407925385, 0.9676508231038966, 0.9680833128130394, 0.968512731877214, 0.9689391020977725, 0.9693624451212793, 0.9697827824406099, 0.9702001353960417, 0.9706145251763376, 0.9710259728198224, 0.9714344992154497], \"type\": \"scatter\", \"uid\": \"3e60aac3-c74f-46e8-b3d5-bb04ce7aa325\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 6.66312625250501, 13.27625250501002, 19.88937875751503, 26.50250501002004, 33.11563126252505, 39.728757515030054, 46.341883767535066, 52.95501002004008, 59.56813627254509, 66.1812625250501, 72.79438877755511, 79.40751503006011, 86.02064128256512, 92.63376753507013, 99.24689378757515, 105.86002004008016, 112.47314629258517, 119.08627254509018, 125.6993987975952, 132.31252505010022, 138.92565130260522, 145.53877755511024, 152.15190380761524, 158.76503006012024, 165.37815631262526, 171.99128256513026, 178.6044088176353, 185.2175350701403, 191.8306613226453, 198.4437875751503, 205.05691382765534, 211.67004008016033, 218.28316633266533, 224.89629258517036, 231.50941883767536, 238.12254509018038, 244.73567134268538, 251.3487975951904, 257.9619238476954, 264.57505010020043, 271.1881763527054, 277.8013026052104, 284.41442885771545, 291.0275551102205, 297.64068136272545, 304.25380761523047, 310.8669338677355, 317.48006012024047, 324.0931863727455, 330.7063126252505, 337.31943887775554, 343.9325651302605, 350.54569138276554, 357.15881763527057, 363.7719438877756, 370.38507014028056, 376.9981963927856, 383.6113226452906, 390.2244488977956, 396.8375751503006, 403.45070140280563, 410.06382765531066, 416.67695390781563, 423.29008016032066, 429.9032064128257, 436.51633266533065, 443.1294589178357, 449.7425851703407, 456.35571142284573, 462.9688376753507, 469.5819639278557, 476.19509018036075, 482.8082164328657, 489.42134268537075, 496.0344689378758, 502.6475951903808, 509.26072144288577, 515.8738476953907, 522.4869739478958, 529.1001002004008, 535.7132264529058, 542.3263527054107, 548.9394789579158, 555.5526052104208, 562.1657314629258, 568.7788577154308, 575.3919839679359, 582.0051102204409, 588.6182364729458, 595.2313627254508, 601.8444889779558, 608.4576152304609, 615.0707414829659, 621.6838677354709, 628.296993987976, 634.9101202404809, 641.5232464929859, 648.1363727454909, 654.7494989979959, 661.362625250501, 667.975751503006, 674.588877755511, 681.202004008016, 687.815130260521, 694.428256513026, 701.041382765531, 707.654509018036, 714.2676352705411, 720.8807615230461, 727.4938877755511, 734.107014028056, 740.720140280561, 747.3332665330661, 753.9463927855711, 760.5595190380761, 767.1726452905812, 773.7857715430862, 780.3988977955911, 787.0120240480961, 793.6251503006011, 800.2382765531062, 806.8514028056112, 813.4645290581162, 820.0776553106213, 826.6907815631262, 833.3039078156312, 839.9170340681362, 846.5301603206412, 853.1432865731463, 859.7564128256513, 866.3695390781563, 872.9826653306612, 879.5957915831663, 886.2089178356713, 892.8220440881763, 899.4351703406813, 906.0482965931864, 912.6614228456914, 919.2745490981963, 925.8876753507013, 932.5008016032064, 939.1139278557114, 945.7270541082164, 952.3401803607214, 958.9533066132265, 965.5664328657314, 972.1795591182364, 978.7926853707414, 985.4058116232464, 992.0189378757515, 998.6320641282565, 1005.2451903807615, 1011.8583166332664, 1018.4714428857715, 1025.0845691382765, 1031.6976953907815, 1038.3108216432865, 1044.9239478957916, 1051.5370741482966, 1058.1502004008016, 1064.7633266533066, 1071.3764529058117, 1077.9895791583167, 1084.6027054108215, 1091.2158316633265, 1097.8289579158316, 1104.4420841683366, 1111.0552104208416, 1117.6683366733466, 1124.2814629258517, 1130.8945891783567, 1137.5077154308617, 1144.1208416833667, 1150.7339679358718, 1157.3470941883768, 1163.9602204408818, 1170.5733466933868, 1177.1864729458916, 1183.7995991983967, 1190.4127254509017, 1197.0258517034067, 1203.6389779559117, 1210.2521042084168, 1216.8652304609218, 1223.4783567134268, 1230.0914829659318, 1236.7046092184369, 1243.317735470942, 1249.930861723447, 1256.543987975952, 1263.157114228457, 1269.7702404809618, 1276.3833667334668, 1282.9964929859718, 1289.6096192384769, 1296.2227454909819, 1302.835871743487, 1309.448997995992, 1316.062124248497, 1322.675250501002, 1329.288376753507, 1335.901503006012, 1342.514629258517, 1349.127755511022, 1355.740881763527, 1362.3540080160321, 1368.967134268537, 1375.580260521042, 1382.193386773547, 1388.806513026052, 1395.419639278557, 1402.032765531062, 1408.645891783567, 1415.2590180360721, 1421.8721442885771, 1428.4852705410822, 1435.0983967935872, 1441.7115230460922, 1448.3246492985973, 1454.9377755511023, 1461.550901803607, 1468.164028056112, 1474.7771543086171, 1481.3902805611222, 1488.0034068136272, 1494.6165330661322, 1501.2296593186372, 1507.8427855711423, 1514.4559118236473, 1521.0690380761523, 1527.6821643286573, 1534.2952905811624, 1540.9084168336674, 1547.5215430861724, 1554.1346693386772, 1560.7477955911822, 1567.3609218436873, 1573.9740480961923, 1580.5871743486973, 1587.2003006012023, 1593.8134268537074, 1600.4265531062124, 1607.0396793587174, 1613.6528056112224, 1620.2659318637275, 1626.8790581162325, 1633.4921843687375, 1640.1053106212426, 1646.7184368737474, 1653.3315631262524, 1659.9446893787574, 1666.5578156312624, 1673.1709418837675, 1679.7840681362725, 1686.3971943887775, 1693.0103206412825, 1699.6234468937876, 1706.2365731462926, 1712.8496993987976, 1719.4628256513026, 1726.0759519038077, 1732.6890781563127, 1739.3022044088177, 1745.9153306613225, 1752.5284569138275, 1759.1415831663326, 1765.7547094188376, 1772.3678356713426, 1778.9809619238476, 1785.5940881763527, 1792.2072144288577, 1798.8203406813627, 1805.4334669338677, 1812.0465931863728, 1818.6597194388778, 1825.2728456913828, 1831.8859719438879, 1838.4990981963927, 1845.1122244488977, 1851.7253507014027, 1858.3384769539077, 1864.9516032064128, 1871.5647294589178, 1878.1778557114228, 1884.7909819639278, 1891.4041082164329, 1898.0172344689379, 1904.630360721443, 1911.243486973948, 1917.856613226453, 1924.469739478958, 1931.0828657314628, 1937.6959919839678, 1944.3091182364728, 1950.9222444889779, 1957.535370741483, 1964.148496993988, 1970.761623246493, 1977.374749498998, 1983.987875751503, 1990.601002004008, 1997.214128256513, 2003.827254509018, 2010.440380761523, 2017.0535070140281, 2023.666633266533, 2030.279759519038, 2036.892885771543, 2043.506012024048, 2050.1191382765533, 2056.7322645290583, 2063.3453907815633, 2069.9585170340683, 2076.5716432865734, 2083.1847695390784, 2089.7978957915834, 2096.4110220440884, 2103.0241482965935, 2109.6372745490985, 2116.2504008016035, 2122.8635270541085, 2129.4766533066136, 2136.0897795591186, 2142.7029058116236, 2149.3160320641286, 2155.9291583166337, 2162.5422845691387, 2169.1554108216433, 2175.7685370741483, 2182.3816633266533, 2188.9947895791584, 2195.6079158316634, 2202.2210420841684, 2208.8341683366734, 2215.4472945891785, 2222.0604208416835, 2228.6735470941885, 2235.2866733466935, 2241.8997995991986, 2248.5129258517036, 2255.1260521042086, 2261.7391783567136, 2268.3523046092187, 2274.9654308617237, 2281.5785571142287, 2288.1916833667337, 2294.8048096192388, 2301.417935871744, 2308.031062124249, 2314.644188376754, 2321.257314629259, 2327.870440881764, 2334.483567134269, 2341.096693386774, 2347.709819639279, 2354.3229458917835, 2360.9360721442886, 2367.5491983967936, 2374.1623246492986, 2380.7754509018037, 2387.3885771543087, 2394.0017034068137, 2400.6148296593187, 2407.2279559118238, 2413.841082164329, 2420.454208416834, 2427.067334669339, 2433.680460921844, 2440.293587174349, 2446.906713426854, 2453.519839679359, 2460.132965931864, 2466.746092184369, 2473.359218436874, 2479.972344689379, 2486.585470941884, 2493.198597194389, 2499.811723446894, 2506.424849699399, 2513.037975951904, 2519.651102204409, 2526.264228456914, 2532.8773547094193, 2539.490480961924, 2546.103607214429, 2552.716733466934, 2559.329859719439, 2565.942985971944, 2572.556112224449, 2579.169238476954, 2585.782364729459, 2592.395490981964, 2599.008617234469, 2605.621743486974, 2612.234869739479, 2618.847995991984, 2625.461122244489, 2632.074248496994, 2638.687374749499, 2645.3005010020042, 2651.9136272545093, 2658.5267535070143, 2665.1398797595193, 2671.7530060120243, 2678.3661322645294, 2684.9792585170344, 2691.5923847695394, 2698.2055110220444, 2704.8186372745495, 2711.4317635270545, 2718.0448897795595, 2724.6580160320646, 2731.271142284569, 2737.884268537074, 2744.497394789579, 2751.110521042084, 2757.7236472945892, 2764.3367735470943, 2770.9498997995993, 2777.5630260521043, 2784.1761523046093, 2790.7892785571144, 2797.4024048096194, 2804.0155310621244, 2810.6286573146294, 2817.2417835671345, 2823.8549098196395, 2830.4680360721445, 2837.0811623246495, 2843.6942885771546, 2850.3074148296596, 2856.9205410821646, 2863.5336673346696, 2870.1467935871747, 2876.7599198396797, 2883.3730460921847, 2889.9861723446897, 2896.599298597195, 2903.2124248497, 2909.825551102205, 2916.4386773547094, 2923.0518036072144, 2929.6649298597195, 2936.2780561122245, 2942.8911823647295, 2949.5043086172345, 2956.1174348697396, 2962.7305611222446, 2969.3436873747496, 2975.9568136272546, 2982.5699398797597, 2989.1830661322647, 2995.7961923847697, 3002.4093186372747, 3009.0224448897798, 3015.635571142285, 3022.24869739479, 3028.861823647295, 3035.4749498998, 3042.088076152305, 3048.70120240481, 3055.314328657315, 3061.92745490982, 3068.540581162325, 3075.15370741483, 3081.766833667335, 3088.37995991984, 3094.993086172345, 3101.60621242485, 3108.2193386773547, 3114.8324649298597, 3121.4455911823648, 3128.05871743487, 3134.671843687375, 3141.28496993988, 3147.898096192385, 3154.51122244489, 3161.124348697395, 3167.7374749499, 3174.350601202405, 3180.96372745491, 3187.576853707415, 3194.18997995992, 3200.803106212425, 3207.41623246493, 3214.029358717435, 3220.64248496994, 3227.255611222445, 3233.86873747495, 3240.481863727455, 3247.0949899799602, 3253.7081162324653, 3260.3212424849703, 3266.9343687374753, 3273.5474949899804, 3280.1606212424854, 3286.7737474949904, 3293.386873747495, 3300.0], \"y\": [0.9743273587687442, 0.9596861959722718, 0.9451522209545269, 0.9307246489950562, 0.9164027011183353, 0.9021856040517104, 0.8880725901836479, 0.8740628975222884, 0.8601557696543065, 0.8463504557040693, 0.832646210293096, 0.8190422934998125, 0.8055379708196018, 0.792132513125146, 0.7788251966270603, 0.7656153028348132, 0.7525021185179337, 0.7394849356675028, 0.726563051457926, 0.7137357682089867, 0.7010023933481775, 0.6883622393733051, 0.6758146238153726, 0.6633588692017298, 0.6509943030194958, 0.6387202576792486, 0.6265360704789806, 0.6144410835683174, 0.6024346439129997, 0.590516103259624, 0.5786848181006425, 0.566940149639618, 0.5552814637567349, 0.5437081309745613, 0.5322195264240617, 0.5208150298108594, 0.5094940253817459, 0.4982559018914343, 0.487100052569557, 0.4760258750879054, 0.46503277152790834, 0.4541201483483497, 0.4432874163533209, 0.43253399066041043, 0.4218592906691234, 0.41126274002953433, 0.40074376661116884, 0.39030180247211277, 0.37993628382834843, 0.3696466510233132, 0.35943234849768446, 0.3492928247593827, 0.33922753235379477, 0.32923592783421674, 0.31931747173251135, 0.3094716285299812, 0.2996978666284551, 0.289995658321585, 0.28036447976635603, 0.27080381095480077, 0.26131313568592396, 0.25189194153783245, 0.24253971984006695, 0.2332559656461386, 0.2240401777062666, 0.21489185844031256, 0.20581051391091765, 0.1967956537968314, 0.1878467913664401, 0.17896344345148663, 0.170145130420982, 0.16139137615531074, 0.15270170802052307, 0.1440756568428172, 0.1355127568832064, 0.1270125458123743, 0.11857456468571148, 0.11019835791853683, 0.10188347326149905, 0.09362946177615883, 0.08543587781075024, 0.07730227897611841, 0.06922822612183421, 0.06121328331248366, 0.053257017804130724, 0.04535900002095228, 0.03751880353204551, 0.029736005028402124, 0.022010184300054858, 0.014340924213388284, 0.006727810688617053, 0.0008295673225706679, 0.008331617859206997, 0.01577874597307516, 0.023171353750579327, 0.030509840334453475, 0.0377946019453127, 0.04502603190304566, 0.05220452064805059, 0.059330455762316325, 0.06640422199034857, 0.07342620125994304, 0.08039677270280676, 0.08731631267502782, 0.09418519477739584, 0.10100378987557379, 0.10777246612012137, 0.11449158896637224, 0.12116152119416612, 0.12778262292743603, 0.13435525165365136, 0.14087976224312038, 0.14735650696815017, 0.15378583552206637, 0.1601680950380936, 0.16650363010809865, 0.17279278280119525, 0.1790358926822131, 0.18523329683003187, 0.19138532985578094, 0.19749232392090543, 0.20355460875510045, 0.20957251167411417, 0.21554635759741947, 0.22147646906575835, 0.22736316625855524, 0.23320676701120546, 0.23900758683223466, 0.2447659389203347, 0.2504821341812731, 0.2561564812446804, 0.26178928648071287, 0.2673808540165947, 0.2729314857530387, 0.2784414813805455, 0.28391113839558546, 0.28934075211666066, 0.2947306157002503, 0.30008102015663785, 0.30539225436562434, 0.31066460509212557, 0.31589835700165425, 0.3210937926756905, 0.3262511926269386, 0.331370835314473, 0.33645299715877197, 0.3414979525566433, 0.346505973896039, 0.3514773315707619, 0.356412293995065, 0.3613111276181441, 0.3661740969385229, 0.37100146451833527, 0.37579349099750026, 0.38055043510779585, 0.3852725536868271, 0.38996010169189443, 0.3946133322137587, 0.39923249649030623, 0.4038178439201139, 0.40836962207591465, 0.41288807671796424, 0.41737345180731056, 0.42182598951896555, 0.4262459302549808, 0.43063351265742755, 0.43498897362128097, 0.4393125483072109, 0.44360447015427895, 0.44786497089254207, 0.4520942805555641, 0.45629262749283594, 0.4604602383821046, 0.4645973382416121, 0.46870415044224445, 0.4727808967195922, 0.47682779718592205, 0.4808450703420616, 0.4848329330891964, 0.48879160074058114, 0.49272128703316465, 0.49662220413913005, 0.5004945626773505, 0.5043385717247606, 0.5081544388276458, 0.511942370012847, 0.5157025697988856, 0.519435241207005, 0.5231405857721327, 0.5268188035537611, 0.5304700931467499, 0.5340946516920475, 0.5376926748873365, 0.5412643569975987, 0.5448098908656043, 0.5483294679223241, 0.5518232781972645, 0.5552915103287288, 0.5587343515740012, 0.5621519878194574, 0.5655446035906015, 0.5689123820620283, 0.5722555050673137, 0.5755741531088322, 0.5788685053675025, 0.5821387397124618, 0.5853850327106697, 0.5886075596364407, 0.5918064944809092, 0.5949820099614214, 0.5981342775308622, 0.6012634673869126, 0.6043697484812374, 0.607453288528609, 0.6105142540159618, 0.6135528102113812, 0.6165691211730269, 0.6195633497579908, 0.6225356576310901, 0.6254862052735957, 0.6284151519918968, 0.6313226559261027, 0.6342088740585811, 0.637073962222433, 0.6399180751099074, 0.6427413662807535, 0.6455439881705111, 0.648326092098741, 0.6510878282771958, 0.6538293458179293, 0.6565507927413479, 0.6592523159842021, 0.6619340614075206, 0.664596173804485, 0.6672387969082478, 0.6698620733996925, 0.6724661449151381, 0.6750511520539855, 0.6776172343863089, 0.680164530460392, 0.682693177810208, 0.6852033129628453, 0.6876950714458794, 0.69016858779469, 0.6926239955597248, 0.6950614273137103, 0.6974810146588095, 0.6998828882337278, 0.7022671777207659, 0.7046340118528223, 0.706983518420343, 0.709315824278222, 0.7116310553526503, 0.7139293366479141, 0.7162107922531453, 0.7184755453490206, 0.7207237182144124, 0.7229554322329906, 0.7251708078997774, 0.7273699648276517, 0.7295530217538084, 0.7317200965461684, 0.7338713062097434, 0.7360067668929524, 0.7381265938938935, 0.7402309016665685, 0.7423198038270633, 0.7443934131596812, 0.7464518416230334, 0.7484952003560832, 0.7505235996841468, 0.7525371491248506, 0.7545359573940429, 0.7565201324116654, 0.7584897813075786, 0.760445010427347, 0.7623859253379803, 0.764312630833633, 0.7662252309412635, 0.7681238289262498, 0.7700085272979651, 0.7718794278153129, 0.7737366314922212, 0.7755802386030958, 0.7774103486882348, 0.7792270605592033, 0.7810304723041679, 0.7828206812931928, 0.7845977841834975, 0.7863618769246746, 0.7881130547638713, 0.7898514122509313, 0.7915770432435001, 0.7932900409120927, 0.7949904977451236, 0.7966785055539011, 0.7983541554775833, 0.8000175379881003, 0.8016687428950379, 0.803307859350487, 0.8049349758538574, 0.8065501802566555, 0.808153559767228, 0.8097452009554701, 0.8113251897575, 0.8128936114802988, 0.8144505508063158, 0.8159960917980413, 0.8175303179025453, 0.8190533119559824, 0.8205651561880651, 0.8220659322265028, 0.8235557211014095, 0.8250346032496788, 0.8265026585193268, 0.8279599661738031, 0.8294066048962705, 0.8308426527938535, 0.8322681874018549, 0.833683285687943, 0.8350880240563063, 0.8364824783517792, 0.8378667238639372, 0.8392408353311613, 0.8406048869446743, 0.8419589523525453, 0.843303104663667, 0.8446374164517031, 0.8459619597590058, 0.8472768061005067, 0.848582026467577, 0.8498776913318609, 0.8511638706490807, 0.8524406338628139, 0.8537080499082419, 0.8549661872158729, 0.8562151137152358, 0.8574548968385485, 0.8586856035243583, 0.8599073002211561, 0.8611200528909646, 0.862323927012899, 0.8635189875867024, 0.864705299136256, 0.8658829257130625, 0.8670519308997039, 0.8682123778132751, 0.8693643291087915, 0.8705078469825718, 0.8716429931755963, 0.8727698289768404, 0.8738884152265833, 0.8749988123196935, 0.8761010802088893, 0.877195278407976, 0.8782814659950586, 0.8793597016157327, 0.8804300434862498, 0.8814925493966607, 0.8825472767139362, 0.8835942823850643, 0.8846336229401246, 0.8856653544953406, 0.8866895327561096, 0.8877062130200106, 0.8887154501797894, 0.8897172987263229, 0.8907118127515606, 0.8916990459514458, 0.8926790516288144, 0.8936518826962727, 0.8946175916790545, 0.8955762307178572, 0.8965278515716564, 0.8974725056205011, 0.8984102438682877, 0.8993411169455132, 0.9002651751120099, 0.9011824682596581, 0.9020930459150803, 0.9029969572423154, 0.9038942510454726, 0.9047849757713671, 0.9056691795121353, 0.9065469100078318, 0.9074182146490071, 0.9082831404792653, 0.9091417341978054, 0.9099940421619421, 0.9108401103896085, 0.9116799845618413, 0.9125137100252465, 0.9133413317944483, 0.9141628945545195, 0.9149784426633938, 0.9157880201542611, 0.9165916707379449, 0.9173894378052622, 0.9181813644293662, 0.9189674933680724, 0.9197478670661666, 0.9205225276576969, 0.9212915169682484, 0.9220548765172019, 0.9228126475199748, 0.9235648708902475, 0.9243115872421717, 0.9250528368925628, 0.925788659863078, 0.9265190958823761, 0.9272441843882631, 0.9279639645298207, 0.9286784751695212, 0.9293877548853251, 0.930091841972764, 0.9307907744470084, 0.9314845900449202, 0.9321733262270903, 0.9328570201798607, 0.933535708817333, 0.9342094287833612, 0.9348782164535295, 0.9355421079371175, 0.9362011390790487, 0.9368553454618267, 0.9375047624074558, 0.9381494249793486, 0.9387893679842186, 0.9394246259739598, 0.9400552332475123, 0.9406812238527139, 0.9413026315881389, 0.9419194900049223, 0.9425318324085716, 0.9431396918607657, 0.9437431011811386, 0.9443420929490525, 0.9449366995053563, 0.9455269529541322, 0.9461128851644287, 0.9466945277719812, 0.9472719121809203, 0.9478450695654675, 0.9484140308716184, 0.9489788268188125, 0.9495394879015936, 0.9500960443912547, 0.9506485263374733, 0.9511969635699336, 0.9517413856999366, 0.952281822122, 0.9528183020154439, 0.9533508543459677, 0.9538795078672124, 0.9544042911223146, 0.9549252324454467, 0.9554423599633468, 0.9559557015968378, 0.9564652850623345, 0.95697113787334, 0.9574732873419314, 0.9579717605802346, 0.9584665845018878, 0.9589577858234948, 0.9594453910660673, 0.9599294265564574, 0.9604099184287782, 0.9608868926258156, 0.9613603749004284, 0.9618303908169391, 0.9622969657525142, 0.9627601248985342, 0.963219893261954, 0.9636762956666525, 0.9641293567547735, 0.9645791009880559, 0.9650255526491546, 0.9654687358429515, 0.9659086744978566, 0.9663453923671006, 0.9667789130300172, 0.9672092598933157, 0.9676364561923456, 0.9680605249923502, 0.9684814891897128, 0.9688993715131924, 0.9693141945251511, 0.969725980622772, 0.9701347520392691, 0.970540530845087, 0.9709433389490927, 0.971343198099759, 0.9717401298863382, 0.9721341557400279, 0.9725252969351283, 0.9729135745901907, 0.9732990096691576, 0.9736816229824947, 0.9740614351883148, 0.9744384667934926], \"type\": \"scatter\", \"uid\": \"9bf72911-ecd1-4f5c-95ed-bee64214c509\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 6.863527054108216, 13.677054108216433, 20.49058116232465, 27.304108216432866, 34.11763527054108, 40.93116232464929, 47.74468937875751, 54.55821643286573, 61.37174348697394, 68.18527054108216, 74.99879759519038, 81.81232464929859, 88.62585170340681, 95.43937875751503, 102.25290581162324, 109.06643286573146, 115.87995991983968, 122.69348697394788, 129.50701402805612, 136.32054108216434, 143.13406813627256, 149.94759519038078, 156.76112224448897, 163.5746492985972, 170.38817635270541, 177.20170340681364, 184.01523046092186, 190.82875751503008, 197.64228456913827, 204.4558116232465, 211.2693386773547, 218.08286573146293, 224.89639278557115, 231.70991983967937, 238.5234468937876, 245.33697394789579, 252.150501002004, 258.9640280561122, 265.7775551102204, 272.59108216432867, 279.40460921843686, 286.2181362725451, 293.0316633266533, 299.84519038076155, 306.65871743486974, 313.47224448897794, 320.2857715430862, 327.0992985971944, 333.9128256513026, 340.7263527054108, 347.53987975951907, 354.35340681362726, 361.16693386773545, 367.9804609218437, 374.7939879759519, 381.60751503006014, 388.42104208416833, 395.2345691382765, 402.0480961923848, 408.86162324649297, 415.6751503006012, 422.4886773547094, 429.30220440881766, 436.11573146292585, 442.92925851703404, 449.7427855711423, 456.5563126252505, 463.36983967935873, 470.1833667334669, 476.9968937875752, 483.81042084168337, 490.62394789579156, 497.4374749498998, 504.251002004008, 511.06452905811625, 517.8780561122244, 524.6915831663326, 531.5051102204408, 538.318637274549, 545.1321643286573, 551.9456913827655, 558.7592184368737, 565.5727454909819, 572.3862725450902, 579.1997995991983, 586.0133266533065, 592.8268537074148, 599.640380761523, 606.4539078156312, 613.2674348697394, 620.0809619238477, 626.8944889779558, 633.708016032064, 640.5215430861723, 647.3350701402805, 654.1485971943887, 660.9621242484969, 667.7756513026052, 674.5891783567133, 681.4027054108216, 688.2162324649298, 695.0297595190381, 701.8432865731462, 708.6568136272545, 715.4703406813627, 722.2838677354708, 729.0973947895791, 735.9109218436873, 742.7244488977955, 749.5379759519037, 756.351503006012, 763.1650300601202, 769.9785571142284, 776.7920841683366, 783.6056112224448, 790.419138276553, 797.2326653306612, 804.0461923847695, 810.8597194388777, 817.6732464929859, 824.4867735470941, 831.3003006012024, 838.1138276553105, 844.9273547094188, 851.740881763527, 858.5544088176352, 865.3679358717434, 872.1814629258516, 878.9949899799599, 885.808517034068, 892.6220440881763, 899.4355711422845, 906.2490981963928, 913.0626252505009, 919.8761523046091, 926.6896793587174, 933.5032064128255, 940.3167334669338, 947.130260521042, 953.9437875751503, 960.7573146292584, 967.5708416833667, 974.3843687374749, 981.197895791583, 988.0114228456913, 994.8249498997995, 1001.6384769539078, 1008.4520040080159, 1015.2655310621242, 1022.0790581162324, 1028.8925851703407, 1035.7061122244488, 1042.519639278557, 1049.3331663326653, 1056.1466933867734, 1062.9602204408816, 1069.77374749499, 1076.587274549098, 1083.4008016032064, 1090.2143286573146, 1097.0278557114227, 1103.841382765531, 1110.6549098196392, 1117.4684368737474, 1124.2819639278557, 1131.0954909819638, 1137.909018036072, 1144.7225450901803, 1151.5360721442885, 1158.3495991983966, 1165.163126252505, 1171.9766533066131, 1178.7901803607213, 1185.6037074148296, 1192.4172344689377, 1199.230761523046, 1206.0442885771542, 1212.8578156312624, 1219.6713426853707, 1226.4848697394789, 1233.298396793587, 1240.1119238476954, 1246.9254509018035, 1253.7389779559117, 1260.55250501002, 1267.3660320641281, 1274.1795591182363, 1280.9930861723446, 1287.8066132264528, 1294.6201402805611, 1301.4336673346693, 1308.2471943887774, 1315.0607214428858, 1321.874248496994, 1328.687775551102, 1335.5013026052104, 1342.3148296593185, 1349.1283567134267, 1355.941883767535, 1362.7554108216432, 1369.5689378757513, 1376.3824649298597, 1383.1959919839678, 1390.0095190380762, 1396.8230460921843, 1403.6365731462924, 1410.4501002004008, 1417.263627254509, 1424.077154308617, 1430.8906813627254, 1437.7042084168336, 1444.5177354709417, 1451.33126252505, 1458.1447895791582, 1464.9583166332663, 1471.7718436873747, 1478.5853707414828, 1485.398897795591, 1492.2124248496993, 1499.0259519038075, 1505.8394789579158, 1512.653006012024, 1519.4665330661321, 1526.2800601202405, 1533.0935871743486, 1539.9071142284567, 1546.720641282565, 1553.5341683366732, 1560.3476953907814, 1567.1612224448897, 1573.9747494989979, 1580.788276553106, 1587.6018036072144, 1594.4153306613225, 1601.2288577154309, 1608.042384769539, 1614.8559118236471, 1621.6694388777555, 1628.4829659318636, 1635.2964929859718, 1642.1100200400801, 1648.9235470941883, 1655.7370741482964, 1662.5506012024048, 1669.364128256513, 1676.177655310621, 1682.9911823647294, 1689.8047094188375, 1696.618236472946, 1703.431763527054, 1710.2452905811622, 1717.0588176352705, 1723.8723446893787, 1730.6858717434868, 1737.4993987975952, 1744.3129258517033, 1751.1264529058114, 1757.9399799599198, 1764.753507014028, 1771.567034068136, 1778.3805611222444, 1785.1940881763526, 1792.0076152304607, 1798.821142284569, 1805.6346693386772, 1812.4481963927856, 1819.2617234468937, 1826.0752505010018, 1832.8887775551102, 1839.7023046092183, 1846.5158316633265, 1853.3293587174348, 1860.142885771543, 1866.9564128256511, 1873.7699398797595, 1880.5834669338676, 1887.3969939879757, 1894.210521042084, 1901.0240480961922, 1907.8375751503006, 1914.6511022044087, 1921.4646292585169, 1928.2781563126252, 1935.0916833667334, 1941.9052104208415, 1948.7187374749499, 1955.532264529058, 1962.3457915831661, 1969.1593186372745, 1975.9728456913826, 1982.7863727454908, 1989.5998997995991, 1996.4134268537073, 2003.2269539078156, 2010.0404809619238, 2016.854008016032, 2023.6675350701403, 2030.4810621242484, 2037.2945891783565, 2044.108116232465, 2050.9216432865733, 2057.7351703406816, 2064.5486973947895, 2071.362224448898, 2078.1757515030063, 2084.989278557114, 2091.8028056112225, 2098.616332665331, 2105.429859719439, 2112.243386773547, 2119.0569138276555, 2125.8704408817634, 2132.683967935872, 2139.49749498998, 2146.311022044088, 2153.1245490981964, 2159.938076152305, 2166.751603206413, 2173.565130260521, 2180.3786573146294, 2187.192184368738, 2194.0057114228457, 2200.819238476954, 2207.6327655310624, 2214.4462925851703, 2221.2598196392787, 2228.073346693387, 2234.886873747495, 2241.7004008016033, 2248.5139278557117, 2255.3274549098196, 2262.140981963928, 2268.9545090180363, 2275.7680360721442, 2282.5815631262526, 2289.395090180361, 2296.208617234469, 2303.0221442885772, 2309.8356713426856, 2316.6491983967935, 2323.462725450902, 2330.2762525050102, 2337.089779559118, 2343.9033066132265, 2350.716833667335, 2357.530360721443, 2364.343887775551, 2371.1574148296595, 2377.970941883768, 2384.7844689378758, 2391.597995991984, 2398.4115230460925, 2405.2250501002004, 2412.0385771543088, 2418.852104208417, 2425.665631262525, 2432.4791583166334, 2439.2926853707418, 2446.1062124248497, 2452.919739478958, 2459.7332665330664, 2466.5467935871743, 2473.3603206412827, 2480.173847695391, 2486.987374749499, 2493.8009018036073, 2500.6144288577157, 2507.4279559118236, 2514.241482965932, 2521.0550100200403, 2527.868537074148, 2534.6820641282566, 2541.495591182365, 2548.309118236473, 2555.122645290581, 2561.9361723446896, 2568.749699398798, 2575.563226452906, 2582.376753507014, 2589.1902805611226, 2596.0038076152305, 2602.817334669339, 2609.630861723447, 2616.444388777555, 2623.2579158316635, 2630.071442885772, 2636.8849699398797, 2643.698496993988, 2650.5120240480965, 2657.3255511022044, 2664.1390781563127, 2670.952605210421, 2677.766132264529, 2684.5796593186374, 2691.3931863727457, 2698.2067134268536, 2705.020240480962, 2711.8337675350704, 2718.6472945891783, 2725.4608216432866, 2732.274348697395, 2739.087875751503, 2745.9014028056113, 2752.7149298597196, 2759.5284569138275, 2766.341983967936, 2773.1555110220443, 2779.9690380761526, 2786.7825651302605, 2793.596092184369, 2800.4096192384773, 2807.223146292585, 2814.0366733466935, 2820.850200400802, 2827.66372745491, 2834.477254509018, 2841.2907815631265, 2848.1043086172344, 2854.917835671343, 2861.731362725451, 2868.544889779559, 2875.3584168336674, 2882.171943887776, 2888.9854709418837, 2895.798997995992, 2902.6125250501004, 2909.4260521042083, 2916.2395791583167, 2923.053106212425, 2929.866633266533, 2936.6801603206413, 2943.4936873747497, 2950.3072144288576, 2957.120741482966, 2963.9342685370743, 2970.7477955911822, 2977.5613226452906, 2984.374849699399, 2991.1883767535073, 2998.0019038076152, 3004.8154308617236, 3011.628957915832, 3018.44248496994, 3025.2560120240482, 3032.0695390781566, 3038.8830661322645, 3045.696593186373, 3052.5101202404812, 3059.323647294589, 3066.1371743486975, 3072.950701402806, 3079.7642284569138, 3086.577755511022, 3093.3912825651305, 3100.2048096192384, 3107.0183366733468, 3113.831863727455, 3120.645390781563, 3127.4589178356714, 3134.2724448897798, 3141.0859719438877, 3147.899498997996, 3154.7130260521044, 3161.5265531062123, 3168.3400801603207, 3175.153607214429, 3181.9671342685374, 3188.7806613226453, 3195.5941883767537, 3202.407715430862, 3209.22124248497, 3216.0347695390783, 3222.8482965931867, 3229.6618236472946, 3236.475350701403, 3243.2888777555113, 3250.102404809619, 3256.9159318637276, 3263.729458917836, 3270.542985971944, 3277.356513026052, 3284.1700400801606, 3290.9835671342685, 3297.797094188377, 3304.610621242485, 3311.424148296593, 3318.2376753507015, 3325.05120240481, 3331.8647294589177, 3338.678256513026, 3345.4917835671345, 3352.3053106212424, 3359.1188376753507, 3365.932364729459, 3372.745891783567, 3379.5594188376754, 3386.3729458917837, 3393.186472945892, 3400.0], \"y\": [0.9770154270640126, 0.9619322632164486, 0.946962856604382, 0.9321063492706383, 0.9173618897287579, 0.9027286329141921, 0.8882057401358703, 0.8737923790281301, 0.8594877235030123, 0.8452909537029136, 0.8312012559535973, 0.817217822717559, 0.8033398525477426, 0.7895665500416063, 0.7758971257955352, 0.7623307963595971, 0.74886678419264, 0.7355043176177278, 0.7222426307779126, 0.7090809635923407, 0.6960185617126884, 0.6830546764799279, 0.6701885648814185, 0.6574194895083214, 0.644746718513336, 0.6321695255687549, 0.6196871898248346, 0.6072989958684814, 0.5950042336822472, 0.5828021986036369, 0.5706921912847203, 0.5586735176520492, 0.5467454888668795, 0.5349074212856879, 0.5231586364209926, 0.5114984609024638, 0.49992622643833196, 0.488441269777085, 0.4770429326694534, 0.4657305618306853, 0.454503508903102, 0.44336113041894, 0.43230278776346953, 0.4213278471383939, 0.41043567952552373, 0.399625660650726, 0.3888971709481426, 0.3782495955246825, 0.36768232412477886, 0.35719475109541254, 0.3467862753514006, 0.3364563003409444, 0.32620423401144016, 0.3160294887755448, 0.30593148147750004, 0.2959096333597082, 0.28596337002956296, 0.2760921214265264, 0.26629532178945836, 0.2565724096241897, 0.24692282767134088, 0.23734602287438245, 0.2278414463479388, 0.21840855334632758, 0.20904680323233915, 0.19975565944625018, 0.19053458947507096, 0.18138306482202604, 0.17230056097626223, 0.1632865573827882, 0.15434053741263853, 0.1454619883332644, 0.13665040127914585, 0.1279052712226274, 0.11922609694497255, 0.11061238100763648, 0.1020636297237576, 0.09357935312985965, 0.08515906495777226, 0.07680228260675959, 0.0685085271158612, 0.06027732313644085, 0.05210819890494167, 0.044000686215848406, 0.0359543203948518, 0.027968640272217016, 0.02004318815635142, 0.012177509807573372, 0.004371154412077027, 0.003376325443905648, 0.01106537379974748, 0.01869643134587573, 0.02626993544902967, 0.03378632017732941, 0.04124601632515179, 0.048649451437822844, 0.055997049836120416, 0.06328923264059583, 0.0705264177957079, 0.07770902009377834, 0.08483745119876485, 0.09191211966985524, 0.09893343098488305, 0.10590178756356805, 0.11281758879058013, 0.11968123103842965, 0.12649310769018474, 0.13325360916201878, 0.13996312292558521, 0.1466220335302264, 0.15323072262501325, 0.1597895689806189, 0.16629894851102756, 0.1727592342950799, 0.17917079659785606, 0.18553400289189603, 0.1918492178782618, 0.19811680350743988, 0.20433711900008533, 0.21051052086761113, 0.2166373629326207, 0.2227179963491871, 0.2287527696229792, 0.23474202863123517, 0.24068611664258766, 0.24658537433673644, 0.2524401398239746, 0.2582507486645673, 0.264017533887984, 0.2697408260119851, 0.2754209530615662, 0.2810582405877582, 0.2866530116862853, 0.2922055870160837, 0.29771628481767964, 0.3031854209314294, 0.3086133088156202, 0.314000259564437, 0.31934658192579235, 0.3246525823190216, 0.3299185648524451, 0.33514483134079764, 0.3403316813225278, 0.3454794120769643, 0.3505883186413552, 0.35565869382777704, 0.3606908282399178, 0.3656850102897319, 0.3706415262139706, 0.3755606600905874, 0.3804426938550196, 0.3852879073163471, 0.39009657817332943, 0.39486898203032184, 0.3996053924130718, 0.4043060807843941, 0.4089713165597323, 0.4136013671225972, 0.4181964978398933, 0.42275697207712826, 0.4272830512135056, 0.43177499465690794, 0.4362330598587626, 0.4406575023287981, 0.4450485756496887, 0.4494065314915877, 0.45373161962655173, 0.45802408794285665, 0.46228418245920433, 0.46651214733882373, 0.4707082249034642, 0.47487265564728476, 0.47900567825063645, 0.4831075295937436, 0.4871784447702794, 0.49121865710084023, 0.4952283981463186, 0.49920789772117424, 0.5031573839066061, 0.5070770830636251, 0.510967219846026, 0.5148280172132657, 0.5186596964432398, 0.5224624771449661, 0.5262365772711712, 0.5299822131307818, 0.5336995994013224, 0.5373889491412195, 0.5410504738020132, 0.5446843832404749, 0.548290885730637, 0.5518701879757284, 0.5554224951200223, 0.5589480107605937, 0.5624469369589878, 0.565919474252802, 0.5693658216671786, 0.5727861767262121, 0.5761807354642705, 0.5795496924372301, 0.5828932407336263, 0.586211571985721, 0.5895048763804855, 0.5927733426705007, 0.5960171581847753, 0.5992365088394819, 0.6024315791486141, 0.6056025522345604, 0.6087496098385998, 0.611872932331319, 0.6149726987229489, 0.6180490866736257, 0.621102272503572, 0.6241324312032039, 0.627139736443159, 0.6301243605842511, 0.6330864746873488, 0.6360262485231786, 0.638943850582057, 0.6418394480835461, 0.6447132069860373, 0.6475652919962648, 0.6503958665787433, 0.6532050929651387, 0.6559931321635656, 0.6587601439678145, 0.6615062869665118, 0.6642317185522079, 0.6669365949303985, 0.6696210711284774, 0.6722853010046217, 0.6749294372566098, 0.6775536314305735, 0.6801580339296833, 0.682742794022769, 0.6853080598528751, 0.6878539784457505, 0.6903806957182759, 0.6928883564868271, 0.6953771044755743, 0.6978470823247203, 0.700298431598675, 0.7027312927941693, 0.705145805348308, 0.7075421076465609, 0.7099203370306943, 0.7122806298066434, 0.7146231212523232, 0.7169479456253829, 0.7192552361709001, 0.7215451251290185, 0.7238177437425259, 0.7260732222643771, 0.7283116899651592, 0.7305332751404998, 0.7327381051184219, 0.7349263062666389, 0.7370980039998001, 0.7392533227866769, 0.7413923861572969, 0.7435153167100244, 0.7456222361185869, 0.7477132651390479, 0.7497885236167292, 0.7518481304930789, 0.7538922038124882, 0.7559208607290582, 0.7579342175133127, 0.7599323895588637, 0.7619154913890247, 0.7638836366633734, 0.7658369381842678, 0.76777550790331, 0.7696994569277624, 0.7716088955269176, 0.7735039331384161, 0.7753846783745202, 0.7772512390283378, 0.7791037220800018, 0.7809422337028002, 0.7827668792692625, 0.7845777633571981, 0.7863749897556905, 0.7881586614710462, 0.7899288807326975, 0.7916857489990627, 0.7934293669633603, 0.7951598345593808, 0.7968772509672135, 0.7985817146189317, 0.8002733232042338, 0.8019521736760427, 0.8036183622560615, 0.80527198444029, 0.8069131350044967, 0.808541908009651, 0.8101583968073147, 0.811762694044992, 0.8133548916714392, 0.8149350809419353, 0.8165033524235119, 0.8180597960001439, 0.8196045008779013, 0.8211375555900613, 0.8226590480021839, 0.8241690653171465, 0.825667694080142, 0.8271550201836401, 0.8286311288723087, 0.8300961047479011, 0.8315500317741034, 0.8329929932813477, 0.834425071971588, 0.8358463499230404, 0.8372569085948864, 0.8386568288319426, 0.840046190869294, 0.8414250743368923, 0.8427935582641202, 0.8441517210843206, 0.8454996406392921, 0.8468373941837504, 0.8481650583897561, 0.849482709351109, 0.8507904225877096, 0.8520882730498867, 0.8533763351226943, 0.8546546826301737, 0.8559233888395856, 0.857182526465609, 0.8584321676745081, 0.8596723840882698, 0.8609032467887078, 0.8621248263215362, 0.8633371927004136, 0.8645404154109557, 0.8657345634147173, 0.8669197051531452, 0.8680959085515008, 0.8692632410227532, 0.8704217694714423, 0.8715715602975148, 0.8727126794001283, 0.8738451921814288, 0.8749691635502996, 0.8760846579260813, 0.8771917392422632, 0.8782904709501487, 0.8793809160224909, 0.8804631369571029, 0.8815371957804388, 0.8826031540511494, 0.88366107286361, 0.8847110128514218, 0.8857530341908879, 0.8867871966044611, 0.8878135593641681, 0.8888321812950049, 0.8898431207783102, 0.8908464357551101, 0.8918421837294399, 0.892830421771639, 0.8938112065216223, 0.8947845941921266, 0.8957506405719321, 0.8967094010290597, 0.8976609305139452, 0.8986052835625877, 0.8995425142996759, 0.9004726764416902, 0.9013958232999808, 0.9023120077838239, 0.9032212824034543, 0.9041236992730741, 0.90501931011384, 0.9059081662568278, 0.9067903186459744, 0.9076658178409974, 0.9085347140202928, 0.9093970569838115, 0.9102528961559126, 0.9111022805881971, 0.9119452589623185, 0.9127818795927733, 0.91361219042967, 0.9144362390614774, 0.9152540727177522, 0.9160657382718451, 0.9168712822435888, 0.9176707508019628, 0.9184641897677402, 0.919251644616114, 0.9200331604793031, 0.920808782149139, 0.9215785540796335, 0.9223425203895261, 0.9231007248648126, 0.9238532109612548, 0.9246000218068713, 0.9253412002044088, 0.9260767886337962, 0.9268068292545779, 0.9275313639083318, 0.9282504341210663, 0.9289640811056004, 0.929672345763926, 0.9303752686895526, 0.9310728901698329, 0.9317652501882724, 0.9324523884268213, 0.9331343442681485, 0.9338111567978981, 0.934482864806931, 0.9351495067935471, 0.935811120965692, 0.936467745243147, 0.9371194172597026, 0.9377661743653147, 0.9384080536282464, 0.9390450918371916, 0.9396773255033839, 0.9403047908626889, 0.9409275238776816, 0.9415455602397074, 0.9421589353709269, 0.9427676844263472, 0.9433718422958363, 0.9439714436061225, 0.9445665227227796, 0.9451571137521961, 0.94574325054353, 0.946324966690649, 0.9469022955340558, 0.9474752701627989, 0.9480439234163694, 0.9486082878865828, 0.949168395919447, 0.9497242796170164, 0.9502759708392317, 0.9508235012057458, 0.9513669020977361, 0.9519062046597034, 0.9524414398012564, 0.9529726381988836, 0.9534998302977112, 0.9540230463132486, 0.9545423162331197, 0.9550576698187813, 0.9555691366072298, 0.9560767459126932, 0.9565805268283119, 0.9570805082278052, 0.9575767187671276, 0.9580691868861099, 0.9585579408100895, 0.9590430085515285, 0.9595244179116192, 0.960002196481877, 0.960476371645722, 0.9609469705800487, 0.9614140202567836, 0.9618775474444304, 0.9623375787096052, 0.9627941404185584, 0.9632472587386862, 0.9636969596400302, 0.9641432688967662, 0.9645862120886807, 0.9650258146026376, 0.9654621016340333, 0.9658950981882404, 0.9663248290820405, 0.9667513189450476, 0.967174592221119, 0.967594673169756, 0.9680115858674953, 0.9684253542092879, 0.9688360019098692, 0.9692435525051182, 0.969648029353406, 0.9700494556369351, 0.9704478543630677, 0.9708432483656443, 0.9712356603062928, 0.971625112675727, 0.9720116277950357, 0.972395227816962, 0.9727759347271729, 0.9731537703455199, 0.9735287563272884, 0.9739009141644406, 0.9742702651868453, 0.9746368305635023, 0.9750006313037541, 0.9753616882584911, 0.975720022121346, 0.9760756534298805, 0.9764286025667616, 0.9767788897609304, 0.9771265350887611], \"type\": \"scatter\", \"uid\": \"7e9ecabf-f7b0-494f-9608-4fcc76ea038a\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 7.063927855711422, 14.077855711422846, 21.091783567134268, 28.10571142284569, 35.11963927855711, 42.13356713426853, 49.147494989979954, 56.161422845691376, 63.1753507014028, 70.18927855711422, 77.20320641282565, 84.21713426853707, 91.23106212424848, 98.24498997995991, 105.25891783567134, 112.27284569138276, 119.28677354709417, 126.3007014028056, 133.31462925851704, 140.32855711422846, 147.34248496993987, 154.35641282565132, 161.37034068136273, 168.38426853707415, 175.39819639278556, 182.41212424849698, 189.42605210420842, 196.43997995991984, 203.45390781563125, 210.4678356713427, 217.4817635270541, 224.49569138276553, 231.50961923847694, 238.52354709418836, 245.5374749498998, 252.55140280561122, 259.56533066132266, 266.5792585170341, 273.5931863727455, 280.6071142284569, 287.6210420841683, 294.63496993987974, 301.64889779559115, 308.6628256513026, 315.67675350701404, 322.69068136272546, 329.7046092184369, 336.7185370741483, 343.7324649298597, 350.7463927855711, 357.76032064128253, 364.77424849699395, 371.7881763527054, 378.80210420841684, 385.81603206412825, 392.82995991983967, 399.8438877755511, 406.8578156312625, 413.8717434869739, 420.8856713426854, 427.8995991983968, 434.9135270541082, 441.92745490981963, 448.94138276553105, 455.95531062124246, 462.9692384769539, 469.9831663326653, 476.9970941883767, 484.0110220440882, 491.0249498997996, 498.038877755511, 505.0528056112224, 512.0667334669338, 519.0806613226453, 526.0945891783566, 533.1085170340681, 540.1224448897794, 547.1363727454909, 554.1503006012023, 561.1642284569137, 568.1781563126252, 575.1920841683366, 582.206012024048, 589.2199398797594, 596.2338677354709, 603.2477955911822, 610.2617234468937, 617.2756513026052, 624.2895791583165, 631.303507014028, 638.3174348697394, 645.3313627254508, 652.3452905811622, 659.3592184368737, 666.373146292585, 673.3870741482965, 680.401002004008, 687.4149298597193, 694.4288577154308, 701.4427855711422, 708.4567134268536, 715.470641282565, 722.4845691382765, 729.4984969939878, 736.5124248496993, 743.5263527054108, 750.5402805611221, 757.5542084168336, 764.568136272545, 771.5820641282564, 778.5959919839678, 785.6099198396793, 792.6238476953907, 799.6377755511021, 806.6517034068136, 813.6656312625249, 820.6795591182364, 827.6934869739478, 834.7074148296592, 841.7213426853707, 848.7352705410821, 855.7491983967935, 862.7631262525049, 869.7770541082164, 876.7909819639277, 883.8049098196392, 890.8188376753506, 897.832765531062, 904.8466933867735, 911.8606212424849, 918.8745490981963, 925.8884769539077, 932.9024048096192, 939.9163326653305, 946.930260521042, 953.9441883767533, 960.9581162324648, 967.9720440881763, 974.9859719438876, 981.9998997995991, 989.0138276553105, 996.027755511022, 1003.0416833667333, 1010.0556112224448, 1017.0695390781563, 1024.0834669338676, 1031.097394789579, 1038.1113226452906, 1045.1252505010018, 1052.1391783567133, 1059.1531062124247, 1066.1670340681362, 1073.1809619238477, 1080.194889779559, 1087.2088176352704, 1094.2227454909819, 1101.2366733466934, 1108.2506012024046, 1115.264529058116, 1122.2784569138275, 1129.292384769539, 1136.3063126252505, 1143.3202404809617, 1150.3341683366732, 1157.3480961923847, 1164.3620240480961, 1171.3759519038074, 1178.3898797595189, 1185.4038076152303, 1192.4177354709418, 1199.4316633266533, 1206.4455911823645, 1213.459519038076, 1220.4734468937875, 1227.487374749499, 1234.5013026052104, 1241.5152304609217, 1248.5291583166331, 1255.5430861723446, 1262.557014028056, 1269.5709418837673, 1276.5848697394788, 1283.5987975951903, 1290.6127254509017, 1297.6266533066132, 1304.6405811623245, 1311.654509018036, 1318.6684368737474, 1325.6823647294589, 1332.69629258517, 1339.7102204408816, 1346.724148296593, 1353.7380761523045, 1360.752004008016, 1367.7659318637272, 1374.7798597194387, 1381.7937875751502, 1388.8077154308617, 1395.821643286573, 1402.8355711422844, 1409.8494989979959, 1416.8634268537073, 1423.8773547094188, 1430.89128256513, 1437.9052104208415, 1444.919138276553, 1451.9330661322645, 1458.9469939879757, 1465.9609218436872, 1472.9748496993986, 1479.9887775551101, 1487.0027054108216, 1494.0166332665328, 1501.0305611222443, 1508.0444889779558, 1515.0584168336673, 1522.0723446893787, 1529.08627254509, 1536.1002004008014, 1543.114128256513, 1550.1280561122244, 1557.1419839679356, 1564.155911823647, 1571.1698396793586, 1578.18376753507, 1585.1976953907815, 1592.2116232464928, 1599.2255511022042, 1606.2394789579157, 1613.2534068136272, 1620.2673346693384, 1627.28126252505, 1634.2951903807614, 1641.3091182364728, 1648.3230460921843, 1655.3369739478956, 1662.350901803607, 1669.3648296593185, 1676.37875751503, 1683.3926853707414, 1690.4066132264527, 1697.4205410821642, 1704.4344689378756, 1711.448396793587, 1718.4623246492984, 1725.4762525050098, 1732.4901803607213, 1739.5041082164328, 1746.5180360721442, 1753.5319639278555, 1760.545891783567, 1767.5598196392784, 1774.57374749499, 1781.5876753507011, 1788.6016032064126, 1795.615531062124, 1802.6294589178356, 1809.643386773547, 1816.6573146292583, 1823.6712424849698, 1830.6851703406812, 1837.6990981963927, 1844.713026052104, 1851.7269539078154, 1858.7408817635269, 1865.7548096192384, 1872.7687374749498, 1879.782665330661, 1886.7965931863725, 1893.810521042084, 1900.8244488977955, 1907.8383767535067, 1914.8523046092182, 1921.8662324649297, 1928.8801603206412, 1935.8940881763526, 1942.9080160320639, 1949.9219438877753, 1956.9358717434868, 1963.9497995991983, 1970.9637274549098, 1977.977655310621, 1984.9915831663325, 1992.005511022044, 1999.0194388777554, 2006.0333667334667, 2013.0472945891781, 2020.0612224448896, 2027.075150300601, 2034.0890781563126, 2041.1030060120238, 2048.1169338677355, 2055.1308617234467, 2062.1447895791584, 2069.1587174348697, 2076.1726452905814, 2083.1865731462926, 2090.200501002004, 2097.2144288577156, 2104.228356713427, 2111.2422845691385, 2118.2562124248498, 2125.270140280561, 2132.2840681362727, 2139.297995991984, 2146.3119238476957, 2153.325851703407, 2160.339779559118, 2167.35370741483, 2174.367635270541, 2181.3815631262523, 2188.395490981964, 2195.4094188376753, 2202.423346693387, 2209.437274549098, 2216.4512024048095, 2223.465130260521, 2230.4790581162324, 2237.492985971944, 2244.5069138276554, 2251.5208416833666, 2258.5347695390783, 2265.5486973947895, 2272.5626252505012, 2279.5765531062125, 2286.5904809619237, 2293.6044088176354, 2300.6183366733467, 2307.6322645290584, 2314.6461923847696, 2321.660120240481, 2328.6740480961926, 2335.687975951904, 2342.701903807615, 2349.7158316633268, 2356.729759519038, 2363.7436873747497, 2370.757615230461, 2377.771543086172, 2384.785470941884, 2391.799398797595, 2398.813326653307, 2405.827254509018, 2412.8411823647293, 2419.855110220441, 2426.8690380761523, 2433.882965931864, 2440.896893787575, 2447.9108216432865, 2454.924749498998, 2461.9386773547094, 2468.952605210421, 2475.9665330661323, 2482.9804609218436, 2489.9943887775553, 2497.0083166332665, 2504.022244488978, 2511.0361723446895, 2518.0501002004007, 2525.0640280561124, 2532.0779559118237, 2539.091883767535, 2546.1058116232466, 2553.119739478958, 2560.1336673346696, 2567.147595190381, 2574.161523046092, 2581.1754509018037, 2588.189378757515, 2595.2033066132267, 2602.217234468938, 2609.231162324649, 2616.245090180361, 2623.259018036072, 2630.2729458917834, 2637.286873747495, 2644.3008016032063, 2651.314729458918, 2658.3286573146293, 2665.3425851703405, 2672.356513026052, 2679.3704408817634, 2686.384368737475, 2693.3982965931864, 2700.4122244488976, 2707.4261523046093, 2714.4400801603206, 2721.4540080160323, 2728.4679358717435, 2735.4818637274548, 2742.4957915831665, 2749.5097194388777, 2756.5236472945894, 2763.5375751503007, 2770.551503006012, 2777.5654308617236, 2784.579358717435, 2791.593286573146, 2798.607214428858, 2805.621142284569, 2812.6350701402807, 2819.648997995992, 2826.662925851703, 2833.676853707415, 2840.690781563126, 2847.704709418838, 2854.718637274549, 2861.7325651302604, 2868.746492985972, 2875.7604208416833, 2882.774348697395, 2889.7882765531062, 2896.8022044088175, 2903.816132264529, 2910.8300601202404, 2917.8439879759517, 2924.8579158316634, 2931.8718436873746, 2938.8857715430863, 2945.8996993987976, 2952.913627254509, 2959.9275551102205, 2966.9414829659318, 2973.9554108216435, 2980.9693386773547, 2987.983266533066, 2994.9971943887776, 3002.011122244489, 3009.0250501002006, 3016.038977955912, 3023.052905811623, 3030.066833667335, 3037.080761523046, 3044.0946893787577, 3051.108617234469, 3058.12254509018, 3065.136472945892, 3072.150400801603, 3079.1643286573144, 3086.178256513026, 3093.1921843687373, 3100.206112224449, 3107.2200400801603, 3114.2339679358715, 3121.2478957915832, 3128.2618236472945, 3135.275751503006, 3142.2896793587174, 3149.3036072144287, 3156.3175350701404, 3163.3314629258516, 3170.3453907815633, 3177.3593186372746, 3184.373246492986, 3191.3871743486975, 3198.4011022044087, 3205.4150300601204, 3212.4289579158317, 3219.442885771543, 3226.4568136272546, 3233.470741482966, 3240.484669338677, 3247.498597194389, 3254.5125250501, 3261.5264529058118, 3268.540380761523, 3275.5543086172343, 3282.568236472946, 3289.582164328657, 3296.596092184369, 3303.61002004008, 3310.6239478957914, 3317.637875751503, 3324.6518036072143, 3331.665731462926, 3338.6796593186373, 3345.6935871743485, 3352.70751503006, 3359.7214428857715, 3366.735370741483, 3373.7492985971944, 3380.7632264529057, 3387.7771543086174, 3394.7910821643286, 3401.80501002004, 3408.8189378757515, 3415.832865731463, 3422.8467935871745, 3429.8607214428857, 3436.874649298597, 3443.8885771543087, 3450.90250501002, 3457.9164328657316, 3464.930360721443, 3471.944288577154, 3478.958216432866, 3485.972144288577, 3492.9860721442888, 3500.0], \"y\": [0.979420816260901, 0.9638957497705836, 0.9484912038204301, 0.9332062428137646, 0.9180399384169151, 0.9029913695028309, 0.8880596220951376, 0.8732437893126275, 0.858542971314179, 0.8439562752441057, 0.8294828151779274, 0.8151217120685652, 0.800872093692951, 0.7867330945990532, 0.7727038560533137, 0.758783525988493, 0.7449712589519188, 0.7312662160541383, 0.7176675649179673, 0.7041744796279366, 0.690786140680129, 0.6775017349324075, 0.6643204555550284, 0.6512415019816391, 0.6382640798606545, 0.6253874010070135, 0.6126106833543066, 0.5999331509072792, 0.5873540336946996, 0.5748725677225954, 0.562487994927853, 0.550199563132175, 0.538006525996398, 0.5259081429751626, 0.5139036792719374, 0.5019924057943894, 0.49017359911010483, 0.47844654140264864, 0.4668105204279702, 0.4552648294711443, 0.44380876730344787, 0.43244163813977177, 0.4211627515963625, 0.40997142264889064, 0.39886697159084616, 0.3878487239922572, 0.3769160106587275, 0.36606816759079264, 0.3553045359435931, 0.3446244619868588, 0.33402729706520384, 0.32351239755873173, 0.31307912484394373, 0.3027268452549532, 0.292454930044999, 0.28226275534825906, 0.27214970214195944, 0.26211515620877757, 0.252158508099539, 0.24227915309620074, 0.23247649117512492, 0.22274992697063634, 0.21309886973886139, 0.20352273332185078, 0.1940209361119789, 0.18459290101661874, 0.17523805542309323, 0.16595583116389734, 0.15674566448219007, 0.14760699599755456, 0.13853927067202476, 0.12954193777637424, 0.12061445085666844, 0.11175626770107439, 0.10296685030693142, 0.09424566484807406, 0.08559218164240989, 0.07700587511975043, 0.06848622378988956, 0.060032710210931484, 0.051644820957862825, 0.04332204659137129, 0.03506388162690288, 0.026869824503963136, 0.01873937755565347, 0.010672046978445593, 0.0026673428021908308, 0.005275221139638742, 0.013156127239477566, 0.020975854144964612, 0.028734876788014452, 0.03643366641366197, 0.04407269060868335, 0.05165241332999537, 0.059173294932834075, 0.06663579219871374, 0.0740403583631698, 0.08138744314328694, 0.08867749276501125, 0.09591094999025374, 0.10308825414377909, 0.11020984113989052, 0.11727614350890347, 0.12428759042341608, 0.13124460772437474, 0.13814761794693753, 0.14499704034613758, 0.1517932909223454, 0.15853678244653613, 0.16522792448535772, 0.17186712342600752, 0.17845478250091285, 0.18499130181222245, 0.19147707835610617, 0.1979125060468664, 0.20429797574086306, 0.210633875260252, 0.2169205894165397, 0.22315850003395377, 0.22934798597263462, 0.23548942315164478, 0.24158318457179995, 0.24762964033832435, 0.25362915768332805, 0.2595821009881114, 0.2654888318052957, 0.27134970888078225, 0.2771650881755401, 0.28293532288722645, 0.2886607634716376, 0.2943417576639935, 0.29997865050005845, 0.3055717843370961, 0.3111214988746629, 0.31662813117523947, 0.3220920156847027, 0.3275134842526376, 0.33289286615249314, 0.33823048810157996, 0.34352667428091344, 0.3487817463549039, 0.35399602349089176, 0.359169822378533, 0.3643034572490328, 0.3693972398942309, 0.3744514796855377, 0.3794664835927247, 0.38444255620256795, 0.3893799997373468, 0.3942791140731998, 0.39914019675833834, 0.4039635430311169, 0.40874944583796535, 0.41349819585118075, 0.41821008148658134, 0.4228853889210241, 0.4275244021097848, 0.43212740280380435, 0.4366946705668012, 0.4412264827922511, 0.4457231147202334, 0.4501848394541488, 0.4546119279773059, 0.45900464916937955, 0.46336326982274134, 0.46768805465866303, 0.4719792663433945, 0.47623716550411654, 0.48046201074477135, 0.4846540586617669, 0.48881356385956287, 0.4929407789661334, 0.49703595464831063, 0.5010993396270091, 0.5051311806923316, 0.5091317227185582, 0.5131012086790184, 0.5170398796608486, 0.5209479748796344, 0.524825731693939, 0.5286733856197197, 0.5324911703446316, 0.5362793177422212, 0.5400380578860084, 0.5437676190634608, 0.5474682277898588, 0.5511401088220519, 0.554783485172111, 0.5583985781208716, 0.5619856072313745, 0.5655447903621995, 0.5690763436806994, 0.572580481676126, 0.5760574171726593, 0.5795073613423333, 0.5829305237178599, 0.5863271122053568, 0.5896973330969738, 0.5930413910834217, 0.5963594892664047, 0.599651829170956, 0.6029186107576767, 0.6061600324348811, 0.6093762910706468, 0.6125675820047711, 0.6157340990606361, 0.6188760345569793, 0.6219935793195749, 0.6250869226928232, 0.628156252551251, 0.6312017553109215, 0.6342236159407565, 0.6372220179737711, 0.6401971435182195, 0.6431491732686567, 0.6460782865169119, 0.6489846611629781, 0.6518684737258171, 0.65472989935408, 0.6575691118367458, 0.6603862836136751, 0.6631815857860844, 0.6659551881269374, 0.6687072590912564, 0.671437965826353, 0.6741474741819807, 0.676835948720407, 0.6795035527264079, 0.6821504482171864, 0.684776795952211, 0.6873827554429803, 0.6899684849627108, 0.6925341415559498, 0.6950798810481134, 0.6976058580549502, 0.7001122259919323, 0.7025991370835732, 0.7050667423726728, 0.7075151917294908, 0.7099446338608498, 0.7123552163191664, 0.7147470855114131, 0.7171203867080103, 0.7194752640516493, 0.7218118605660465, 0.7241303181646306, 0.7264307776591612, 0.7287133787682816, 0.7309782601260036, 0.7332255592901287, 0.7354554127506014, 0.7376679559378003, 0.7398633232307624, 0.7420416479653451, 0.7442030624423241, 0.7463476979354292, 0.7484756846993166, 0.7505871519774803, 0.7526822280101018, 0.7547610400418383, 0.7568237143295516, 0.7588703761499759, 0.7609011498073263, 0.7629161586408488, 0.7649155250323116, 0.7668993704134368, 0.7688678152732772, 0.7708209791655326, 0.7727589807158123, 0.7746819376288387, 0.7765899666955971, 0.7784831838004281, 0.7803617039280664, 0.7822256411706245, 0.7840751087345217, 0.7859102189473598, 0.7877310832647457, 0.7895378122770598, 0.7913305157161741, 0.7931093024621154, 0.7948742805496789, 0.7966255571749895, 0.7983632387020124, 0.8000874306690131, 0.8017982377949673, 0.803495763985921, 0.8051801123413013, 0.806851385160178, 0.8085096839474769, 0.8101551094201447, 0.811787761513266, 0.8134077393861328, 0.8150151414282674, 0.816610065265397, 0.8181926077653847, 0.8197628650441109, 0.8213209324713123, 0.8228669046763738, 0.8244008755540755, 0.8259229382702958, 0.8274331852676695, 0.8289317082712031, 0.8304185982938441, 0.8318939456420107, 0.833357839921075, 0.834810370040806, 0.8362516242207694, 0.8376816899956852, 0.8391006542207449, 0.8405086030768859, 0.8419056220760261, 0.8432917960662577, 0.844667209237, 0.8460319451241125, 0.8473860866149692, 0.8487297159534923, 0.8500629147451471, 0.8513857639618989, 0.8526983439471303, 0.8540007344205213, 0.8552930144828904, 0.8565752626209996, 0.8578475567123212, 0.8591099740297665, 0.8603625912463813, 0.8616054844399998, 0.8628387290978681, 0.8640624001212264, 0.8652765718298596, 0.8664813179666111, 0.8676767117018603, 0.8688628256379688, 0.8700397318136875, 0.8712075017085338, 0.8723662062471316, 0.8735159158035201, 0.8746567002054265, 0.8757886287385086, 0.8769117701505618, 0.8780261926556944, 0.8791319639384718, 0.8802291511580258, 0.8813178209521348, 0.8823980394412702, 0.8834698722326124, 0.8845333844240358, 0.8855886406080624, 0.8866357048757845, 0.8876746408207576, 0.8887055115428628, 0.8897283796521389, 0.8907433072725854, 0.8917503560459351, 0.8927495871353985, 0.8937410612293781, 0.8947248385451546, 0.8957009788325441, 0.8966695413775265, 0.8976305850058477, 0.8985841680865906, 0.8995303485357213, 0.9004691838196064, 0.9014007309585028, 0.9023250465300215, 0.9032421866725635, 0.9041522070887291, 0.9050551630487016, 0.9059511093936036, 0.9068401005388282, 0.9077221904773436, 0.9085974327829727, 0.9094658806136463, 0.9103275867146324, 0.9111826034217396, 0.9120309826644948, 0.9128727759692983, 0.9137080344625528, 0.9145368088737682, 0.9153591495386436, 0.9161751064021231, 0.9169847290214306, 0.9177880665690787, 0.9185851678358558, 0.9193760812337888, 0.9201608547990838, 0.920939536195044, 0.9217121727149635, 0.9224788112850005, 0.9232394984670271, 0.9239942804614572, 0.9247432031100524, 0.9254863118987068, 0.9262236519602084, 0.9269552680769816, 0.9276812046838061, 0.928401505870516, 0.9291162153846777, 0.9298253766342466, 0.930529032690204, 0.9312272262891726, 0.9319199998360119, 0.9326073954063945, 0.9332894547493604, 0.9339662192898539, 0.9346377301312385, 0.9353040280577942, 0.9359651535371936, 0.9366211467229604, 0.9372720474569078, 0.937917895271559, 0.9385587293925467, 0.939194588740997, 0.9398255119358927, 0.9404515372964184, 0.9410727028442887, 0.9416890463060565, 0.9423006051154055, 0.9429074164154222, 0.9435095170608533, 0.9441069436203431, 0.9446997323786547, 0.9452879193388743, 0.9458715402245971, 0.9464506304820973, 0.947025225282481, 0.9475953595238223, 0.9481610678332827, 0.9487223845692144, 0.9492793438232467, 0.949831979422357, 0.950380324930925, 0.9509244136527712, 0.9514642786331802, 0.9519999526609065, 0.9525314682701673, 0.9530588577426173, 0.9535821531093103, 0.954101386152644, 0.9546165884082903, 0.9551277911671111, 0.9556350254770584, 0.9561383221450597, 0.9566377117388899, 0.9571332245890269, 0.9576248907904947, 0.9581127402046902, 0.9585968024611976, 0.9590771069595875, 0.9595536828712029, 0.9600265591409307, 0.9604957644889593, 0.9609613274125239, 0.9614232761876361, 0.9618816388708021, 0.9623364433007264, 0.9627877171000028, 0.9632354876767916, 0.9636797822264844, 0.9641206277333566, 0.9645580509722049, 0.9649920785099747, 0.9654227367073728, 0.965850051720469, 0.9662740495022845, 0.9666947558043677, 0.9671121961783592, 0.9675263959775429, 0.9679373803583857, 0.9683451742820663, 0.9687498025159905, 0.9691512896352954, 0.9695496600243423, 0.9699449378781976, 0.9703371472041022, 0.9707263118229297, 0.9711124553706332, 0.9714956012996804, 0.9718757728804787, 0.9722529932027878, 0.9726272851771228, 0.9729986715361452, 0.9733671748360433, 0.9737328174579027, 0.9740956216090658, 0.9744556093244797, 0.9748128024680351, 0.9751672227338943, 0.9755188916478084, 0.9758678305684247, 0.9762140606885846, 0.9765576030366097, 0.9768984784775798, 0.9772367077145996, 0.9775723112900565, 0.9779053095868682, 0.97823572282972, 0.9785635710862943, 0.9788888742684885, 0.9792116521336247, 0.9795319242856495], \"type\": \"scatter\", \"uid\": \"2effd206-29b0-421c-a21f-11aedd7de94b\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 7.264328657314628, 14.478657314629258, 21.692985971943887, 28.907314629258515, 36.12164328657314, 43.33597194388777, 50.550300601202395, 57.764629258517026, 64.97895791583166, 72.19328657314628, 79.4076152304609, 86.62194388777554, 93.83627254509017, 101.05060120240479, 108.26492985971943, 115.47925851703405, 122.69358717434868, 129.90791583166333, 137.12224448897794, 144.33657314629258, 151.55090180360722, 158.76523046092183, 165.97955911823647, 173.1938877755511, 180.40821643286571, 187.62254509018035, 194.836873747495, 202.0512024048096, 209.26553106212424, 216.47985971943888, 223.6941883767535, 230.90851703406813, 238.12284569138276, 245.33717434869737, 252.551503006012, 259.76583166332665, 266.9801603206413, 274.19448897795587, 281.4088176352705, 288.62314629258515, 295.8374749498998, 303.0518036072144, 310.26613226452906, 317.48046092184364, 324.6947895791583, 331.9091182364729, 339.12344689378756, 346.3377755511022, 353.55210420841684, 360.7664328657314, 367.98076152304606, 375.1950901803607, 382.40941883767533, 389.62374749498997, 396.8380761523046, 404.0524048096192, 411.26673346693383, 418.48106212424847, 425.6953907815631, 432.90971943887774, 440.1240480961924, 447.33837675350696, 454.5527054108216, 461.76703406813624, 468.9813627254509, 476.1956913827655, 483.4100200400801, 490.62434869739474, 497.8386773547094, 505.053006012024, 512.2673346693385, 519.4816633266532, 526.6959919839678, 533.9103206412825, 541.1246492985971, 548.3389779559117, 555.5533066132264, 562.767635270541, 569.9819639278556, 577.1962925851702, 584.4106212424849, 591.6249498997995, 598.8392785571141, 606.0536072144288, 613.2679358717434, 620.482264529058, 627.6965931863726, 634.9109218436872, 642.1252505010019, 649.3395791583165, 656.5539078156312, 663.7682364729458, 670.9825651302605, 678.196893787575, 685.4112224448896, 692.6255511022043, 699.8398797595189, 707.0542084168336, 714.2685370741482, 721.4828657314628, 728.6971943887775, 735.911523046092, 743.1258517034067, 750.3401803607213, 757.5545090180359, 764.7688376753506, 771.9831663326652, 779.1974949899799, 786.4118236472945, 793.6261523046091, 800.8404809619237, 808.0548096192383, 815.269138276553, 822.4834669338676, 829.6977955911823, 836.9121242484969, 844.1264529058114, 851.3407815631261, 858.5551102204407, 865.7694388777554, 872.98376753507, 880.1980961923847, 887.4124248496993, 894.6267535070139, 901.8410821643286, 909.0554108216431, 916.2697394789578, 923.4840681362724, 930.698396793587, 937.9127254509017, 945.1270541082163, 952.341382765531, 959.5557114228455, 966.7700400801601, 973.9843687374748, 981.1986973947894, 988.4130260521041, 995.6273547094187, 1002.8416833667334, 1010.056012024048, 1017.2703406813625, 1024.4846693386771, 1031.698997995992, 1038.9133266533065, 1046.127655310621, 1053.3419839679357, 1060.5563126252503, 1067.770641282565, 1074.9849699398796, 1082.1992985971942, 1089.4136272545088, 1096.6279559118234, 1103.8422845691382, 1111.0566132264528, 1118.2709418837674, 1125.485270541082, 1132.6995991983968, 1139.9139278557113, 1147.128256513026, 1154.3425851703405, 1161.556913827655, 1168.77124248497, 1175.9855711422845, 1183.199899799599, 1190.4142284569136, 1197.6285571142282, 1204.842885771543, 1212.0572144288576, 1219.2715430861722, 1226.4858717434868, 1233.7002004008014, 1240.9145290581162, 1248.1288577154307, 1255.3431863727453, 1262.55751503006, 1269.7718436873745, 1276.9861723446893, 1284.2005010020039, 1291.4148296593185, 1298.629158316633, 1305.8434869739476, 1313.0578156312624, 1320.272144288577, 1327.4864729458916, 1334.7008016032062, 1341.915130260521, 1349.1294589178356, 1356.3437875751501, 1363.5581162324647, 1370.7724448897793, 1377.9867735470941, 1385.2011022044087, 1392.4154308617233, 1399.6297595190379, 1406.8440881763524, 1414.0584168336673, 1421.2727454909818, 1428.4870741482964, 1435.701402805611, 1442.9157314629256, 1450.1300601202404, 1457.344388777555, 1464.5587174348695, 1471.7730460921841, 1478.9873747494987, 1486.2017034068135, 1493.416032064128, 1500.6303607214427, 1507.8446893787573, 1515.0590180360718, 1522.2733466933867, 1529.4876753507012, 1536.7020040080158, 1543.9163326653304, 1551.1306613226452, 1558.3449899799598, 1565.5593186372744, 1572.773647294589, 1579.9879759519035, 1587.2023046092183, 1594.416633266533, 1601.6309619238475, 1608.845290581162, 1616.0596192384767, 1623.2739478957915, 1630.488276553106, 1637.7026052104206, 1644.9169338677352, 1652.1312625250498, 1659.3455911823646, 1666.5599198396792, 1673.7742484969938, 1680.9885771543084, 1688.202905811623, 1695.4172344689377, 1702.6315631262523, 1709.845891783567, 1717.0602204408815, 1724.274549098196, 1731.4888777555109, 1738.7032064128255, 1745.91753507014, 1753.1318637274546, 1760.3461923847694, 1767.560521042084, 1774.7748496993986, 1781.9891783567132, 1789.2035070140278, 1796.4178356713426, 1803.6321643286572, 1810.8464929859717, 1818.0608216432863, 1825.275150300601, 1832.4894789579157, 1839.7038076152303, 1846.9181362725449, 1854.1324649298595, 1861.346793587174, 1868.5611222444888, 1875.7754509018034, 1882.989779559118, 1890.2041082164326, 1897.4184368737472, 1904.632765531062, 1911.8470941883766, 1919.0614228456911, 1926.2757515030057, 1933.4900801603203, 1940.704408817635, 1947.9187374749497, 1955.1330661322643, 1962.3473947895789, 1969.5617234468937, 1976.7760521042082, 1983.9903807615228, 1991.2047094188374, 1998.419038076152, 2005.6333667334668, 2012.8476953907814, 2020.062024048096, 2027.2763527054105, 2034.4906813627251, 2041.70501002004, 2048.9193386773545, 2056.1336673346696, 2063.347995991984, 2070.5623246492987, 2077.7766533066133, 2084.990981963928, 2092.2053106212425, 2099.419639278557, 2106.6339679358716, 2113.848296593186, 2121.062625250501, 2128.276953907816, 2135.4912825651304, 2142.705611222445, 2149.9199398797596, 2157.134268537074, 2164.3485971943887, 2171.5629258517033, 2178.777254509018, 2185.9915831663325, 2193.205911823647, 2200.420240480962, 2207.6345691382767, 2214.8488977955913, 2222.063226452906, 2229.2775551102204, 2236.491883767535, 2243.7062124248496, 2250.920541082164, 2258.1348697394787, 2265.349198396794, 2272.5635270541084, 2279.777855711423, 2286.9921843687375, 2294.206513026052, 2301.4208416833667, 2308.6351703406813, 2315.849498997996, 2323.0638276553104, 2330.278156312625, 2337.49248496994, 2344.7068136272546, 2351.921142284569, 2359.135470941884, 2366.3497995991984, 2373.564128256513, 2380.7784569138275, 2387.992785571142, 2395.2071142284567, 2402.4214428857713, 2409.6357715430863, 2416.850100200401, 2424.0644288577155, 2431.27875751503, 2438.4930861723446, 2445.7074148296592, 2452.921743486974, 2460.1360721442884, 2467.350400801603, 2474.564729458918, 2481.7790581162326, 2488.993386773547, 2496.2077154308618, 2503.4220440881763, 2510.636372745491, 2517.8507014028055, 2525.06503006012, 2532.2793587174347, 2539.4936873747492, 2546.7080160320643, 2553.922344689379, 2561.1366733466934, 2568.351002004008, 2575.5653306613226, 2582.779659318637, 2589.9939879759518, 2597.2083166332663, 2604.422645290581, 2611.6369739478955, 2618.8513026052105, 2626.065631262525, 2633.2799599198397, 2640.4942885771543, 2647.708617234469, 2654.9229458917835, 2662.137274549098, 2669.3516032064126, 2676.565931863727, 2683.7802605210422, 2690.994589178357, 2698.2089178356714, 2705.423246492986, 2712.6375751503006, 2719.851903807615, 2727.0662324649297, 2734.2805611222443, 2741.494889779559, 2748.7092184368735, 2755.9235470941885, 2763.137875751503, 2770.3522044088177, 2777.5665330661323, 2784.780861723447, 2791.9951903807614, 2799.209519038076, 2806.4238476953906, 2813.638176352705, 2820.8525050100197, 2828.066833667335, 2835.2811623246494, 2842.495490981964, 2849.7098196392785, 2856.924148296593, 2864.1384769539077, 2871.3528056112223, 2878.567134268537, 2885.7814629258514, 2892.9957915831665, 2900.210120240481, 2907.4244488977956, 2914.63877755511, 2921.853106212425, 2929.0674348697394, 2936.281763527054, 2943.4960921843685, 2950.710420841683, 2957.9247494989977, 2965.1390781563127, 2972.3534068136273, 2979.567735470942, 2986.7820641282565, 2993.996392785571, 3001.2107214428856, 3008.4250501002, 3015.639378757515, 3022.8537074148294, 3030.068036072144, 3037.282364729459, 3044.4966933867736, 3051.711022044088, 3058.9253507014027, 3066.1396793587173, 3073.354008016032, 3080.5683366733465, 3087.782665330661, 3094.9969939879757, 3102.2113226452907, 3109.4256513026053, 3116.63997995992, 3123.8543086172344, 3131.068637274549, 3138.2829659318636, 3145.497294589178, 3152.7116232464928, 3159.9259519038073, 3167.140280561122, 3174.354609218437, 3181.5689378757515, 3188.783266533066, 3195.9975951903807, 3203.2119238476953, 3210.42625250501, 3217.6405811623245, 3224.854909819639, 3232.0692384769536, 3239.283567134268, 3246.4978957915832, 3253.712224448898, 3260.9265531062124, 3268.140881763527, 3275.3552104208416, 3282.569539078156, 3289.7838677354707, 3296.9981963927853, 3304.2125250501, 3311.426853707415, 3318.6411823647295, 3325.855511022044, 3333.0698396793587, 3340.2841683366732, 3347.498496993988, 3354.7128256513024, 3361.927154308617, 3369.1414829659316, 3376.355811623246, 3383.570140280561, 3390.7844689378758, 3397.9987975951904, 3405.213126252505, 3412.4274549098195, 3419.641783567134, 3426.8561122244487, 3434.0704408817633, 3441.284769539078, 3448.4990981963924, 3455.7134268537075, 3462.927755511022, 3470.1420841683366, 3477.356412825651, 3484.570741482966, 3491.7850701402804, 3498.999398797595, 3506.2137274549095, 3513.428056112224, 3520.642384769539, 3527.8567134268537, 3535.0710420841683, 3542.285370741483, 3549.4996993987975, 3556.714028056112, 3563.9283567134266, 3571.142685370741, 3578.357014028056, 3585.5713426853704, 3592.7856713426854, 3600.0], \"y\": [0.9815732530865173, 0.9656063823398742, 0.9497669891558409, 0.9340540557689945, 0.9184665725396266, 0.903003537888871, 0.8876639582343455, 0.8724468479263097, 0.8573512291843306, 0.8423761320344563, 0.8275205942468897, 0.8127836612741592, 0.7981643861897854, 0.7836618296274347, 0.7692750597205609, 0.7550031520425269, 0.7408451895472068, 0.7268002625100591, 0.7128674684696734, 0.6990459121697818, 0.685334705501734, 0.6717329674474313, 0.6582398240227176, 0.6448544082212198, 0.6315758599586385, 0.6184033260174844, 0.6053359599922519, 0.5923729222350353, 0.5795133798015759, 0.5667565063977409, 0.5541014823264303, 0.5415474944349059, 0.529093736062543, 0.5167394069889972, 0.5044837133827871, 0.4923258677502844, 0.48026508888511654, 0.46830060181796607, 0.4564316377667781, 0.4446574340873599, 0.43297723422437784, 0.42139028766274444, 0.40989584987939365, 0.39849318229544184, 0.3871815522287294, 0.3759602328467422, 0.36482850311990944, 0.35378564777527255, 0.34283095725052615, 0.33196372764842397, 0.3211832606915501, 0.31048886367745143, 0.29987984943412704, 0.28935553627587396, 0.2789152479594854, 0.26855831364079874, 0.25828406783158964, 0.2480918503568108, 0.23798100631217345, 0.22795088602206448, 0.2180008449978028, 0.2081302438962267, 0.19833844847861282, 0.18862482956992288, 0.1789887630183764, 0.16942962965534414, 0.15994681525556564, 0.1505397104976791, 0.14120771092507178, 0.1319502169070388, 0.12276663360025397, 0.11365637091054914, 0.1046188434549955, 0.0956534705242913, 0.08675967604544721, 0.0779368885447711, 0.06918454111114758, 0.06050207135961094, 0.05188892139520895, 0.043344537777154635, 0.03486837148326627, 0.02645987787468762, 0.018118516660894146, 0.009843751864974548, 0.0016350517891929872, 0.006508111019176255, 0.014586259801740553, 0.02259991362260938, 0.030549587401746958, 0.03843579194805935, 0.04625903399221576, 0.05401981621920948, 0.061718637300657186, 0.06935599192684228, 0.07693237083850035, 0.08444826085835289, 0.0919041449223873, 0.0993005021108887, 0.10663780767922337, 0.1139165330883759, 0.12113714603524384, 0.1283001104826893, 0.13540588668935094, 0.14245493123921837, 0.1494476970709695, 0.1563846335070751, 0.16326618628266987, 0.1700927975741925, 0.17686490602779925, 0.18358294678754805, 0.19024735152335992, 0.19685854845875472, 0.20341696239836837, 0.20992301475524766, 0.2163771235779286, 0.22277970357729848, 0.2291311661532428, 0.23543191942108033, 0.2416823682377871, 0.2478829142280089, 0.25403395580987, 0.2601358882205722, 0.2661891035417915, 0.27219399072487094, 0.2781509356158135, 0.2840603209800744, 0.2899225265271552, 0.29573792893500384, 0.30150690187421625, 0.3072298160320479, 0.3129070391362321, 0.31853893597860816, 0.3241258684385624, 0.3296681955062787, 0.33516627330580784, 0.3406204551179487, 0.3460310914029492, 0.3513985298230251, 0.356723115264699, 0.362005189860962, 0.36724509301325525, 0.3724431614132816, 0.377599729064637, 0.3827151273042739, 0.38778968482378984, 0.39282372769054885, 0.39781757936863293, 0.4027715607396254, 0.4076859901232306, 0.41256118329772595, 0.41739745352025415, 0.42219511154695044, 0.42695446565291084, 0.43167582165200036, 0.43635948291650284, 0.44100575039661494, 0.445614922639783, 0.45018729580988737, 0.45472316370627075, 0.45922281778261853, 0.4636865471656847, 0.46811463867387004, 0.4725073768356526, 0.4768650439078689, 0.481187919893851, 0.48547628256141906, 0.4897304074607276, 0.4939505679419731, 0.49813703517295616, 0.502290078156507, 0.5064099637477698, 0.5104969566713498, 0.5145513195383224, 0.5185733128631088, 0.5225631950802138, 0.526521222560833, 0.5304476496293251, 0.5343427285795542, 0.5382067096911005, 0.5420398412453422, 0.5458423695414094, 0.5496145389120095, 0.5533565917391277, 0.5570687684695996, 0.5607513076305639, 0.5644044458447861, 0.5680284178458652, 0.571623456493315, 0.5751897927875274, 0.578727655884615, 0.5822372731111362, 0.5857188699787008, 0.5891726701984619, 0.5925988956954897, 0.5959977666230314, 0.5993695013766576, 0.6027143166082948, 0.6060324272401467, 0.6093240464785047, 0.6125893858274462, 0.6158286551024262, 0.6190420624437587, 0.6222298143299898, 0.6253921155911668, 0.6285291694219979, 0.6316411773949102, 0.6347283394730006, 0.6377908540228842, 0.640828917827442, 0.6438427260984638, 0.6468324724891924, 0.6497983491067665, 0.6527405465245641, 0.6556592537944493, 0.6585546584589186, 0.6614269465631517, 0.6642763026669665, 0.6671029098566774, 0.66990694975686, 0.6726886025420213, 0.6754480469481767, 0.6781854602843349, 0.6809010184438911, 0.6835948959159286, 0.6862672657964317, 0.6889182997994066, 0.6915481682679157, 0.6941570401850234, 0.6967450831846538, 0.6993124635623618, 0.7018593462860186, 0.7043858950064121, 0.7068922720677624, 0.7093786385181524, 0.7118451541198769, 0.7142919773597083, 0.7167192654590789, 0.7191271743841849, 0.7215158588560071, 0.7238854723602524, 0.7262361671572167, 0.7285680942915681, 0.7308814036020521, 0.7331762437311204, 0.7354527621344809, 0.7377111050905728, 0.7399514177099664, 0.7421738439446866, 0.7443785265974628, 0.7465656073309048, 0.7487352266766047, 0.7508875240441681, 0.7530226377301712, 0.7551407049270463, 0.7572418617318988, 0.7593262431552508, 0.7613939831297167, 0.7634452145186097, 0.7654800691244775, 0.7674986776975731, 0.7695011699442547, 0.771487674535321, 0.7734583191142781, 0.7754132303055428, 0.777352533722577, 0.77927635397596, 0.7811848146813958, 0.7830780384676552, 0.7849561469844559, 0.786819260910279, 0.7886674999601231, 0.7905009828931968, 0.7923198275205496, 0.7941241507126418, 0.7959140684068542, 0.7976896956149373, 0.7994511464304022, 0.8011985340358507, 0.8029319707102489, 0.8046515678361408, 0.8063574359068059, 0.8080496845333587, 0.8097284224517917, 0.8113937575299626, 0.8130457967745252, 0.8146846463378048, 0.8163104115246198, 0.8179231967990475, 0.8195231057911365, 0.8211102413035659, 0.8226847053182507, 0.8242465990028943, 0.8257960227174896, 0.8273330760207677, 0.8288578576765944, 0.8303704656603171, 0.8318709971650597, 0.833359548607968, 0.8348362156364051, 0.8363010931340971, 0.8377542752272297, 0.8391958552904968, 0.8406259259530999, 0.8420445791047003, 0.8434519059013234, 0.8448479967712156, 0.8462329414206555, 0.8476068288397175, 0.8489697473079898, 0.8503217844002475, 0.8516630269920791, 0.8529935612654689, 0.8543134727143344, 0.8556228461500204, 0.8569217657067484, 0.8582103148470217, 0.8594885763669897, 0.8607566324017673, 0.8620145644307122, 0.8632624532826612, 0.8645003791411234, 0.8657284215494323, 0.866946659415857, 0.868155171018673, 0.8693540340111909, 0.8705433254267471, 0.871723121683653, 0.8728934985901053, 0.8740545313490578, 0.8752062945630524, 0.8763488622390138, 0.8774823077930038, 0.8786067040549401, 0.8797221232732744, 0.8808286371196358, 0.8819263166934357, 0.8830152325264367, 0.884095454587284, 0.8851670522860018, 0.8862300944784529, 0.8872846494707634, 0.8883307850237117, 0.8893685683570818, 0.8903980661539839, 0.8914193445651374, 0.892432469213123, 0.8934375051965986, 0.8944345170944821, 0.8954235689701012, 0.8964047243753098, 0.8973780463545716, 0.8983435974490106, 0.8993014397004304, 0.9002516346553001, 0.9011942433687095, 0.9021293264082916, 0.9030569438581151, 0.9039771553225444, 0.9048900199300703, 0.9057955963371088, 0.9066939427317698, 0.9075851168375968, 0.9084691759172753, 0.9093461767763125, 0.9102161757666873, 0.9110792287904713, 0.9119353913034206, 0.9127847183185394, 0.9136272644096146, 0.9144630837147227, 0.9152922299397085, 0.9161147563616353, 0.9169307158322094, 0.917740160781175, 0.918543143219684, 0.9193397147436372, 0.9201299265370001, 0.9209138293750917, 0.9216914736278468, 0.9224629092630531, 0.9232281858495611, 0.92398735256047, 0.9247404581762866, 0.9254875510880602, 0.9262286793004917, 0.9269638904350186, 0.9276932317328743, 0.928416750058124, 0.9291344919006758, 0.929846503379268, 0.9305528302444329, 0.9312535178814355, 0.9319486113131907, 0.9326381552031557, 0.9333221938582003, 0.9340007712314533, 0.9346739309251273, 0.9353417161933201, 0.9360041699447939, 0.9366613347457324, 0.9373132528224765, 0.9379599660642368, 0.9386015160257855, 0.9392379439301265, 0.9398692906711444, 0.940495596816232, 0.9411169026088966, 0.9417332479713467, 0.9423446725070563, 0.9429512155033104, 0.9435529159337287, 0.9441498124607706, 0.9447419434382189, 0.9453293469136445, 0.9459120606308511, 0.9464901220323003, 0.9470635682615179, 0.9476324361654803, 0.9481967622969817, 0.9487565829169835, 0.949311933996944, 0.9498628512211297, 0.950409369988908, 0.9509515254170225, 0.9514893523418487, 0.9520228853216326, 0.9525521586387116, 0.9530772063017167, 0.9535980620477584, 0.9541147593445944, 0.9546273313927793, 0.955135811127799, 0.9556402312221862, 0.9561406240876201, 0.956637021877009, 0.9571294564865565, 0.9576179595578101, 0.9581025624796958, 0.958583296390534, 0.95906019218004, 0.9595332804913101, 0.9600025917227893, 0.9604681560302254, 0.9609300033286061, 0.9613881632940818, 0.9618426653658718, 0.9622935387481564, 0.962740812411953, 0.9631845150969784, 0.9636246753134946, 0.9640613213441412, 0.9644944812457527, 0.9649241828511611, 0.9653504537709845, 0.9657733213954014, 0.96619281289591, 0.9666089552270747, 0.9670217751282583, 0.9674312991253392, 0.9678375535324167, 0.9682405644535016, 0.9686403577841932, 0.9690369592133437, 0.9694303942247082, 0.9698206880985831, 0.9702078659134299, 0.9705919525474862, 0.9709729726803654, 0.9713509507946415, 0.9717259111774227, 0.9720978779219117, 0.9724668749289542, 0.9728329259085745, 0.9731960543814986, 0.9735562836806662, 0.9739136369527295, 0.9742681371595405, 0.9746198070796269, 0.9749686693096551, 0.9753147462658825, 0.975658060185598, 0.9759986331285503, 0.9763364869783662, 0.9766716434439559, 0.9770041240609084, 0.9773339501928754, 0.9776611430329435, 0.9779857236049962, 0.9783077127650653, 0.9786271312026701, 0.9789439994421475, 0.9792583378439704, 0.9795701666060566, 0.9798795057650657, 0.9801863751976871, 0.9804907946219173, 0.9807927835983268, 0.9810923615313164, 0.9813895476703651, 0.9816843611112659], \"type\": \"scatter\", \"uid\": \"9856c152-4d09-451e-8430-0af715ba813c\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 7.4647294589178355, 14.879458917835672, 22.294188376753507, 29.708917835671343, 37.123647294589176, 44.53837675350701, 51.95310621242485, 59.36783567134268, 66.78256513026052, 74.19729458917836, 81.61202404809619, 89.02675350701402, 96.44148296593185, 103.8562124248497, 111.27094188376753, 118.68567134268537, 126.1004008016032, 133.51513026052106, 140.9298597194389, 148.34458917835673, 155.75931863727456, 163.1740480961924, 170.58877755511023, 178.00350701402806, 185.4182364729459, 192.83296593186373, 200.2476953907816, 207.66242484969942, 215.07715430861725, 222.49188376753509, 229.90661322645292, 237.32134268537075, 244.73607214428858, 252.15080160320642, 259.56553106212425, 266.9802605210421, 274.3949899799599, 281.8097194388778, 289.2244488977956, 296.63917835671344, 304.05390781563125, 311.4686372745491, 318.88336673346697, 326.2980961923848, 333.71282565130264, 341.12755511022044, 348.5422845691383, 355.9570140280561, 363.37174348697397, 370.7864729458918, 378.20120240480964, 385.61593186372744, 393.0306613226453, 400.44539078156316, 407.86012024048097, 415.2748496993988, 422.68957915831663, 430.1043086172345, 437.5190380761523, 444.93376753507016, 452.34849699398796, 459.7632264529058, 467.17795591182363, 474.5926853707415, 482.00741482965935, 489.42214428857716, 496.836873747495, 504.2516032064128, 511.6663326653307, 519.0810621242484, 526.4957915831662, 533.9105210420842, 541.325250501002, 548.7399799599198, 556.1547094188377, 563.5694388777555, 570.9841683366733, 578.3988977955911, 585.813627254509, 593.2283567134268, 600.6430861723446, 608.0578156312624, 615.4725450901803, 622.8872745490982, 630.302004008016, 637.7167334669339, 645.1314629258517, 652.5461923847695, 659.9609218436873, 667.3756513026052, 674.790380761523, 682.2051102204408, 689.6198396793586, 697.0345691382765, 704.4492985971943, 711.8640280561121, 719.2787575150301, 726.6934869739479, 734.1082164328657, 741.5229458917835, 748.9376753507014, 756.3524048096192, 763.767134268537, 771.1818637274548, 778.5965931863727, 786.0113226452905, 793.4260521042083, 800.8407815631263, 808.2555110220441, 815.6702404809619, 823.0849699398797, 830.4996993987976, 837.9144288577154, 845.3291583166332, 852.743887775551, 860.1586172344689, 867.5733466933867, 874.9880761523045, 882.4028056112224, 889.8175350701403, 897.232264529058, 904.6469939879759, 912.0617234468938, 919.4764529058116, 926.8911823647294, 934.3059118236472, 941.7206412825651, 949.1353707414829, 956.5501002004007, 963.9648296593186, 971.3795591182364, 978.7942885771542, 986.209018036072, 993.62374749499, 1001.0384769539078, 1008.4532064128256, 1015.8679358717434, 1023.2826653306613, 1030.6973947895792, 1038.112124248497, 1045.5268537074148, 1052.9415831663325, 1060.3563126252504, 1067.7710420841684, 1075.185771543086, 1082.600501002004, 1090.0152304609219, 1097.4299599198396, 1104.8446893787575, 1112.2594188376754, 1119.674148296593, 1127.088877755511, 1134.5036072144287, 1141.9183366733466, 1149.3330661322645, 1156.7477955911822, 1164.1625250501002, 1171.577254509018, 1178.9919839679358, 1186.4067134268537, 1193.8214428857716, 1201.2361723446893, 1208.6509018036072, 1216.065631262525, 1223.4803607214428, 1230.8950901803607, 1238.3098196392784, 1245.7245490981963, 1253.1392785571143, 1260.554008016032, 1267.9687374749499, 1275.3834669338678, 1282.7981963927855, 1290.2129258517034, 1297.627655310621, 1305.042384769539, 1312.457114228457, 1319.8718436873746, 1327.2865731462925, 1334.7013026052105, 1342.1160320641281, 1349.530761523046, 1356.945490981964, 1364.3602204408817, 1371.7749498997996, 1379.1896793587173, 1386.6044088176352, 1394.0191382765531, 1401.4338677354708, 1408.8485971943887, 1416.2633266533066, 1423.6780561122243, 1431.0927855711423, 1438.5075150300602, 1445.9222444889779, 1453.3369739478958, 1460.7517034068135, 1468.1664328657314, 1475.5811623246493, 1482.995891783567, 1490.410621242485, 1497.8253507014028, 1505.2400801603205, 1512.6548096192384, 1520.0695390781564, 1527.484268537074, 1534.898997995992, 1542.3137274549097, 1549.7284569138276, 1557.1431863727455, 1564.5579158316632, 1571.972645290581, 1579.387374749499, 1586.8021042084167, 1594.2168336673346, 1601.6315631262526, 1609.0462925851702, 1616.4610220440882, 1623.8757515030059, 1631.2904809619238, 1638.7052104208417, 1646.1199398797594, 1653.5346693386773, 1660.9493987975952, 1668.364128256513, 1675.7788577154308, 1683.1935871743487, 1690.6083166332664, 1698.0230460921844, 1705.437775551102, 1712.85250501002, 1720.2672344689379, 1727.6819639278556, 1735.0966933867735, 1742.5114228456914, 1749.926152304609, 1757.340881763527, 1764.755611222445, 1772.1703406813626, 1779.5850701402805, 1786.9997995991982, 1794.4145290581162, 1801.829258517034, 1809.2439879759518, 1816.6587174348697, 1824.0734468937876, 1831.4881763527053, 1838.9029058116232, 1846.3176352705411, 1853.7323647294588, 1861.1470941883767, 1868.5618236472944, 1875.9765531062124, 1883.3912825651303, 1890.806012024048, 1898.2207414829659, 1905.6354709418838, 1913.0502004008015, 1920.4649298597194, 1927.8796593186373, 1935.294388777555, 1942.709118236473, 1950.1238476953906, 1957.5385771543085, 1964.9533066132265, 1972.3680360721442, 1979.782765531062, 1987.19749498998, 1994.6122244488977, 2002.0269539078156, 2009.4416833667335, 2016.8564128256512, 2024.2711422845691, 2031.6858717434868, 2039.1006012024047, 2046.5153306613227, 2053.930060120241, 2061.3447895791587, 2068.759519038076, 2076.174248496994, 2083.588977955912, 2091.00370741483, 2098.418436873748, 2105.8331663326653, 2113.2478957915832, 2120.662625250501, 2128.077354709419, 2135.492084168337, 2142.906813627255, 2150.3215430861724, 2157.7362725450903, 2165.151002004008, 2172.565731462926, 2179.980460921844, 2187.3951903807615, 2194.8099198396794, 2202.2246492985973, 2209.6393787575153, 2217.054108216433, 2224.468837675351, 2231.8835671342686, 2239.2982965931865, 2246.7130260521044, 2254.1277555110223, 2261.5424849699402, 2268.9572144288577, 2276.3719438877756, 2283.7866733466935, 2291.2014028056115, 2298.6161322645294, 2306.0308617234473, 2313.4455911823648, 2320.8603206412827, 2328.2750501002006, 2335.6897795591185, 2343.1045090180364, 2350.519238476954, 2357.933967935872, 2365.3486973947897, 2372.7634268537076, 2380.1781563126256, 2387.5928857715435, 2395.007615230461, 2402.422344689379, 2409.837074148297, 2417.2518036072147, 2424.6665330661326, 2432.08126252505, 2439.495991983968, 2446.910721442886, 2454.325450901804, 2461.7401803607218, 2469.1549098196397, 2476.569639278557, 2483.984368737475, 2491.399098196393, 2498.813827655311, 2506.228557114229, 2513.6432865731463, 2521.058016032064, 2528.472745490982, 2535.8874749499, 2543.302204408818, 2550.716933867736, 2558.1316633266533, 2565.5463927855712, 2572.961122244489, 2580.375851703407, 2587.790581162325, 2595.2053106212425, 2602.6200400801604, 2610.0347695390783, 2617.449498997996, 2624.864228456914, 2632.278957915832, 2639.6936873747495, 2647.1084168336674, 2654.5231462925854, 2661.9378757515033, 2669.352605210421, 2676.7673346693387, 2684.1820641282566, 2691.5967935871745, 2699.0115230460924, 2706.4262525050103, 2713.8409819639282, 2721.2557114228457, 2728.6704408817636, 2736.0851703406815, 2743.4998997995995, 2750.9146292585174, 2758.329358717435, 2765.7440881763528, 2773.1588176352707, 2780.5735470941886, 2787.9882765531065, 2795.4030060120244, 2802.817735470942, 2810.23246492986, 2817.6471943887777, 2825.0619238476957, 2832.4766533066136, 2839.891382765531, 2847.306112224449, 2854.720841683367, 2862.135571142285, 2869.5503006012027, 2876.9650300601206, 2884.379759519038, 2891.794488977956, 2899.209218436874, 2906.623947895792, 2914.0386773547098, 2921.453406813627, 2928.868136272545, 2936.282865731463, 2943.697595190381, 2951.112324649299, 2958.527054108217, 2965.9417835671343, 2973.356513026052, 2980.77124248497, 2988.185971943888, 2995.600701402806, 3003.0154308617234, 3010.4301603206413, 3017.8448897795593, 3025.259619238477, 3032.674348697395, 3040.089078156313, 3047.5038076152305, 3054.9185370741484, 3062.3332665330663, 3069.747995991984, 3077.162725450902, 3084.5774549098196, 3091.9921843687375, 3099.4069138276554, 3106.8216432865734, 3114.2363727454913, 3121.651102204409, 3129.0658316633267, 3136.4805611222446, 3143.8952905811625, 3151.3100200400804, 3158.7247494989983, 3166.139478957916, 3173.5542084168337, 3180.9689378757516, 3188.3836673346696, 3195.7983967935875, 3203.2131262525054, 3210.627855711423, 3218.0425851703408, 3225.4573146292587, 3232.8720440881766, 3240.2867735470945, 3247.701503006012, 3255.11623246493, 3262.530961923848, 3269.9456913827657, 3277.3604208416837, 3284.7751503006016, 3292.189879759519, 3299.604609218437, 3307.019338677355, 3314.434068136273, 3321.8487975951907, 3329.263527054108, 3336.678256513026, 3344.092985971944, 3351.507715430862, 3358.92244488978, 3366.3371743486978, 3373.7519038076152, 3381.166633266533, 3388.581362725451, 3395.996092184369, 3403.410821643287, 3410.8255511022044, 3418.2402805611223, 3425.65501002004, 3433.069739478958, 3440.484468937876, 3447.899198396794, 3455.3139278557114, 3462.7286573146293, 3470.1433867735473, 3477.558116232465, 3484.972845691383, 3492.3875751503006, 3499.8023046092185, 3507.2170340681364, 3514.6317635270543, 3522.0464929859722, 3529.46122244489, 3536.8759519038076, 3544.2906813627255, 3551.7054108216435, 3559.1201402805614, 3566.5348697394793, 3573.9495991983968, 3581.3643286573147, 3588.7790581162326, 3596.1937875751505, 3603.6085170340684, 3611.0232464929863, 3618.437975951904, 3625.8527054108217, 3633.2674348697396, 3640.6821643286576, 3648.0968937875755, 3655.511623246493, 3662.926352705411, 3670.341082164329, 3677.7558116232467, 3685.1705410821646, 3692.5852705410825, 3700.0], \"y\": [0.9834993381850379, 0.9670907615465918, 0.9508168130809307, 0.9346763881983451, 0.9186683913720006, 0.9027917360635811, 0.8870453446495388, 0.8714281483479516, 0.8559390871459793, 0.8405771097279162, 0.8253411734038327, 0.8102302440388036, 0.7952432959827158, 0.7803793120006528, 0.7656372832038512, 0.7510162089812205, 0.7365150969314291, 0.722132962795544, 0.707868830390225, 0.6937217315414665, 0.679690706018883, 0.6657748014705329, 0.6519730733582796, 0.6382845848936793, 0.6247084069743987, 0.6112436181211502, 0.597889304415149, 0.5846445594360796, 0.5715084842005733, 0.5584801871011902, 0.5455587838459006, 0.5327433973980655, 0.5200331579169066, 0.5074272026984668, 0.49492467611705404, 0.4825247295671662, 0.4702265214058923, 0.458029216895786, 0.4459319881482082, 0.43393401406713417, 0.4220344802934217, 0.4102325791495376, 0.3985275095847354, 0.3869184771206857, 0.37540469379755037, 0.3639853781204998, 0.3526597550066699, 0.3414270557325527, 0.3302865178818206, 0.3192373852935759, 0.30827890801102864, 0.2974103422305918, 0.2866309502513966, 0.2759400004252208, 0.2653367671068294, 0.25482053060472043, 0.2443905771322763, 0.23404619875931632, 0.22378669336404577, 0.2136113645853992, 0.20351952177577637, 0.19351047995416293, 0.18358355975963914, 0.17373808740526742, 0.1639733946323596, 0.15428881866511945, 0.1446837021656564, 0.1351573931893686, 0.1257092451406936, 0.1163386167292193, 0.10704487192615808, 0.09782737992117552, 0.088685515079574, 0.07961865689982939, 0.07062618997147374, 0.06170750393332347, 0.05286199343205378, 0.04408905808110797, 0.03538810241994783, 0.02675853587363619, 0.01819977271275275, 0.009711232013636772, 0.0012923376189573066, 0.007057481901392881, 0.01533879328908272, 0.023552158635811504, 0.03169813542145983, 0.03977727655192809, 0.047790130396665575, 0.05573724082589049, 0.06361914724750528, 0.07143638464370794, 0.07918948360730516, 0.08687897037772485, 0.09450536687673572, 0.10206919074387111, 0.1095709553715648, 0.1170111699399975, 0.12439033945165578, 0.131708964765611, 0.13896754263151334, 0.14616656572330988, 0.1533065226726833, 0.16038789810221854, 0.16741117265829675, 0.17437682304371804, 0.18128532205005776, 0.188137138589758, 0.19493273772795416, 0.20167258071404048, 0.20835712501297876, 0.21498682433634753, 0.22156212867313785, 0.22808348432029624, 0.23455133391301708, 0.2409661164547865, 0.24732826734717872, 0.2536382184194098, 0.25989639795764785, 0.26610323073408204, 0.27225913803575463, 0.2783645376931555, 0.28441984410858245, 0.2904254682842685, 0.29638181785027773, 0.3022892970921749, 0.3081483069784644, 0.3139592451878074, 0.3197225061360123, 0.3254384810028077, 0.3311075577583923, 0.3367301211897684, 0.34230655292685963, 0.34783723146841383, 0.35332253220769316, 0.3587628274579543, 0.36415848647771876, 0.3695098754958368, 0.3748173577363443, 0.3800812934431167, 0.3853020399043209, 0.39047995147666614, 0.3956153796094546, 0.4007086728684379, 0.4057601769594742, 0.4107702347519936, 0.4157391863022706, 0.4206673688765048, 0.4255551169737125, 0.430402762348432, 0.4352106340332399, 0.43997905836108475, 0.444708358987437, 0.44939885691225656, 0.45405087050178117, 0.45866471551013444, 0.46324070510075843, 0.4677791498676698, 0.4722803578565401, 0.4767446345856051, 0.48117228306640203, 0.4855636038243357, 0.4899188949190765, 0.4942384519647922, 0.49852256815021145, 0.5027715342585247, 0.5069856386871207, 0.5111651674671609, 0.5153104042829952, 0.5194216304914152, 0.5234991251407521, 0.5275431649898176, 0.5315540245266874, 0.535531975987333, 0.5394772893740998, 0.5433902324740325, 0.5472710708770521, 0.5511200679939816, 0.5549374850744262, 0.5587235812245048, 0.5624786134244368, 0.5662028365459846, 0.5698965033697534, 0.5735598646023474, 0.577193168893388, 0.5807966628523901, 0.5843705910654999, 0.5879151961120979, 0.5914307185812618, 0.5949173970880981, 0.5983754682899374, 0.6018051669023972, 0.6052067257153134, 0.6085803756085413, 0.6119263455676257, 0.6152448626993434, 0.618536152247119, 0.6218004376063113, 0.6250379403393784, 0.6282488801909144, 0.6314334751025655, 0.6345919412278227, 0.6377244929466926, 0.6408313428802486, 0.643912701905063, 0.6469687791675194, 0.6499997820980088, 0.6530059164250096, 0.6559873861890498, 0.6589443937565578, 0.6618771398335966, 0.6647858234794877, 0.6676706421203217, 0.6705317915623586, 0.6733694660053183, 0.6761838580555616, 0.6789751587391634, 0.6817435575148781, 0.6844892422870005, 0.6872123994181176, 0.6899132137417601, 0.6925918685749461, 0.6952485457306247, 0.6978834255300166, 0.7004966868148523, 0.7030885069595125, 0.705659061883066, 0.7082085260612108, 0.7107370725381162, 0.7132448729381689, 0.7157320974776207, 0.7181989149761432, 0.7206454928682857, 0.7230719972148395, 0.7254785927141101, 0.7278654427130951, 0.730232709218572, 0.7325805529080942, 0.7349091331408968, 0.7372186079687131, 0.7395091341465025, 0.74178086714309, 0.7440339611517186, 0.7462685691005153, 0.748484842662871, 0.7506829322677349, 0.7528629871098257, 0.7550251551597571, 0.7571695831740821, 0.7592964167052538, 0.7614058001115042, 0.7634978765666434, 0.7655727880697767, 0.7676306754549433, 0.7696716784006754, 0.7716959354394779, 0.7737035839672324, 0.7756947602525224, 0.7776695994458824, 0.7796282355889717, 0.7815708016236715, 0.7834974294011094, 0.785408249690608, 0.7873033921885609, 0.7891829855272366, 0.7910471572835082, 0.7928960339875131, 0.7947297411312418, 0.7965484031770548, 0.7983521435661308, 0.8001410847268453, 0.8019153480830802, 0.8036750540624655, 0.8054203221045537, 0.8071512706689258, 0.8088680172432325, 0.8105706783511684, 0.812259369560381, 0.8139342054903146, 0.8155952998199906, 0.817242765295723, 0.8188767137387711, 0.8204972560529296, 0.8221045022320554, 0.8236985613675345, 0.825279541655686, 0.8268475504051053, 0.828402694043949, 0.8299450781271571, 0.831474807343619, 0.8329919855232781, 0.8344967156441803, 0.8359890998394621, 0.8374692394042845, 0.8389372348027072, 0.8403931856745082, 0.8418371908419464, 0.8432693483164697, 0.8446897553053669, 0.8460985082183659, 0.8474957026741774, 0.848881433506985, 0.8502557947728826, 0.8516188797562572, 0.8529707809761216, 0.8543115901923938, 0.855641398412125, 0.8569602958956772, 0.8582683721628489, 0.8595657159989516, 0.860852415460836, 0.862128557882869, 0.8633942298828612, 0.8646495173679465, 0.8658945055404126, 0.8671292789034841, 0.8683539212670583, 0.8695685157533939, 0.8707731448027527, 0.8719678901789951, 0.8731528329751302, 0.8743280536188194, 0.8754936318778359, 0.8766496468654786, 0.8777961770459424, 0.8789333002396431, 0.8800610936285, 0.8811796337611748, 0.8822889965582666, 0.883389257317466, 0.8844804907186644, 0.8855627708290246, 0.886636171108007, 0.8877007644123559, 0.8887566230010446, 0.8898038185401804, 0.8908424221078679, 0.8918725041990346, 0.8928941347302148, 0.8939073830442956, 0.8949123179152237, 0.8959090075526729, 0.8968975196066741, 0.897877921172207, 0.8988502787937543, 0.8998146584698181, 0.9007711256573998, 0.9017197452764429, 0.902660581714239, 0.903593698829799, 0.9045191599581864, 0.9054370279148173, 0.9063473649997228, 0.9072502330017784, 0.9081456932028981, 0.9090338063821928, 0.9099146328200967, 0.9107882323024584, 0.9116546641245992, 0.9125139870953368, 0.9133662595409783, 0.9142115393092778, 0.9150498837733638, 0.915881349835633, 0.9167059939316119, 0.9175238720337886, 0.918335039655411, 0.9191395518542549, 0.9199374632363613, 0.9207288279597425, 0.9215136997380584, 0.9222921318442616, 0.9230641771142143, 0.9238298879502735, 0.9245893163248486, 0.9253425137839286, 0.9260895314505807, 0.9268304200284205, 0.9275652298050535, 0.9282940106554882, 0.9290168120455214, 0.9297336830350957, 0.9304446722816295, 0.9311498280433192, 0.9318491981824156, 0.9325428301684716, 0.9332307710815646, 0.9339130676154921, 0.9345897660809408, 0.9352609124086303, 0.9359265521524303, 0.9365867304924524, 0.9372414922381174, 0.9378908818311958, 0.9385349433488253, 0.9391737205065013, 0.9398072566610454, 0.940435594813547, 0.9410587776122828, 0.9416768473556116, 0.9422898459948446, 0.9428978151370933, 0.9435007960480933, 0.9440988296550061, 0.9446919565491956, 0.9452802169889842, 0.945863650902385, 0.9464422978898122, 0.9470161972267684, 0.947585387866511, 0.9481499084426959, 0.9487097972719993, 0.9492650923567196, 0.9498158313873555, 0.950362051745165, 0.9509037905047024, 0.9514410844363348, 0.951973970008738, 0.9525024833913712, 0.9530266604569331, 0.9535465367837954, 0.9540621476584188, 0.9545735280777474, 0.9550807127515847, 0.9555837361049486, 0.9560826322804089, 0.9565774351404044, 0.9570681782695408, 0.9575548949768713, 0.9580376182981565, 0.958516380998107, 0.9589912155726075, 0.9594621542509221, 0.9599292289978824, 0.9603924715160561, 0.9608519132479003, 0.961307585377894, 0.9617595188346558, 0.962207744293043, 0.9626522921762337, 0.9630931926577911, 0.9635304756637124, 0.9639641708744597, 0.9643943077269742, 0.9648209154166749, 0.9652440228994394, 0.9656636588935703, 0.9660798518817434, 0.9664926301129416, 0.9669020216043722, 0.9673080541433684, 0.9677107552892754, 0.968110152375321, 0.9685062725104713, 0.9688991425812695, 0.9692887892536622, 0.9696752389748085, 0.9700585179748753, 0.9704386522688179, 0.9708156676581453, 0.9711895897326718, 0.9715604438722538, 0.9719282552485127, 0.9722930488265428, 0.9726548493666064, 0.9730136814258143, 0.9733695693597924, 0.9737225373243348, 0.9740726092770434, 0.9744198089789545, 0.9747641599961511, 0.9751056857013619, 0.9754444092755493, 0.9757803537094811, 0.9761135418052921, 0.9764439961780311, 0.9767717392571967, 0.9770967932882587, 0.9774191803341689, 0.9777389222768579, 0.9780560408187209, 0.9783705574840904, 0.9786824936206974, 0.9789918704011198, 0.9792987088242205, 0.9796030297165718, 0.9799048537338692, 0.9802042013623337, 0.9805010929201019, 0.9807955485586056, 0.9810875882639392, 0.9813772318582158, 0.9816644990009138, 0.9819494091902101, 0.9822319817643046, 0.9825122359027316, 0.9827901906276627, 0.9830658648051973, 0.983339277146643, 0.9836104462097864], \"type\": \"scatter\", \"uid\": \"170c9626-a2d2-4af3-9096-4ed1aa6031ba\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": true, \"x\": [0.05, 7.665130260521042, 15.280260521042084, 22.895390781563126, 30.510521042084168, 38.125651302605206, 45.74078156312625, 53.35591182364729, 60.97104208416833, 68.58617234468937, 76.20130260521042, 83.81643286573146, 91.4315631262525, 99.04669338677354, 106.66182364729458, 114.27695390781562, 121.89208416833667, 129.5072144288577, 137.12234468937876, 144.73747494989982, 152.35260521042085, 159.96773547094188, 167.58286573146293, 175.197995991984, 182.81312625250501, 190.42825651302604, 198.0433867735471, 205.65851703406815, 213.27364729458918, 220.8887775551102, 228.50390781563127, 236.11903807615232, 243.73416833667335, 251.34929859719438, 258.9644288577154, 266.5795591182365, 274.1946893787575, 281.80981963927854, 289.4249498997996, 297.04008016032066, 304.6552104208417, 312.2703406813627, 319.88547094188374, 327.5006012024048, 335.11573146292585, 342.7308617234469, 350.34599198396796, 357.961122244489, 365.57625250501, 373.19138276553105, 380.8065130260521, 388.42164328657316, 396.0367735470942, 403.6519038076152, 411.2670340681363, 418.8821643286573, 426.49729458917835, 434.1124248496994, 441.7275551102204, 449.3426853707415, 456.9578156312625, 464.57294589178355, 472.18807615230463, 479.80320641282566, 487.4183366733467, 495.0334669338677, 502.64859719438874, 510.2637274549098, 517.8788577154307, 525.4939879759519, 533.1091182364729, 540.7242484969939, 548.339378757515, 555.954509018036, 563.569639278557, 571.184769539078, 578.7998997995992, 586.4150300601202, 594.0301603206412, 601.6452905811623, 609.2604208416833, 616.8755511022043, 624.4906813627254, 632.1058116232464, 639.7209418837674, 647.3360721442886, 654.9512024048096, 662.5663326653306, 670.1814629258516, 677.7965931863727, 685.4117234468937, 693.0268537074147, 700.6419839679359, 708.2571142284569, 715.8722444889779, 723.4873747494989, 731.10250501002, 738.717635270541, 746.332765531062, 753.947895791583, 761.5630260521041, 769.1781563126252, 776.7932865731462, 784.4084168336673, 792.0235470941883, 799.6386773547093, 807.2538076152304, 814.8689378757514, 822.4840681362725, 830.0991983967936, 837.7143286573146, 845.3294589178356, 852.9445891783566, 860.5597194388777, 868.1748496993987, 875.7899799599197, 883.4051102204407, 891.0202404809619, 898.6353707414829, 906.250501002004, 913.865631262525, 921.480761523046, 929.095891783567, 936.711022044088, 944.3261523046092, 951.9412825651302, 959.5564128256513, 967.1715430861723, 974.7866733466933, 982.4018036072143, 990.0169338677354, 997.6320641282564, 1005.2471943887774, 1012.8623246492986, 1020.4774549098196, 1028.0925851703405, 1035.7077154308615, 1043.3228456913828, 1050.9379759519038, 1058.5531062124248, 1066.1682364729459, 1073.783366733467, 1081.398496993988, 1089.013627254509, 1096.62875751503, 1104.243887775551, 1111.859018036072, 1119.474148296593, 1127.089278557114, 1134.704408817635, 1142.3195390781561, 1149.9346693386772, 1157.5497995991984, 1165.1649298597195, 1172.7800601202405, 1180.3951903807615, 1188.0103206412825, 1195.6254509018036, 1203.2405811623246, 1210.8557114228456, 1218.4708416833666, 1226.0859719438877, 1233.7011022044087, 1241.3162324649297, 1248.9313627254508, 1256.5464929859718, 1264.1616232464928, 1271.7767535070138, 1279.3918837675349, 1287.0070140280561, 1294.6221442885771, 1302.2372745490982, 1309.8524048096192, 1317.4675350701402, 1325.0826653306613, 1332.6977955911823, 1340.3129258517033, 1347.9280561122243, 1355.5431863727454, 1363.1583166332664, 1370.7734468937874, 1378.3885771543085, 1386.0037074148295, 1393.6188376753505, 1401.2339679358718, 1408.8490981963928, 1416.4642284569138, 1424.0793587174348, 1431.6944889779559, 1439.309619238477, 1446.924749498998, 1454.539879759519, 1462.15501002004, 1469.770140280561, 1477.385270541082, 1485.000400801603, 1492.615531062124, 1500.2306613226451, 1507.8457915831661, 1515.4609218436872, 1523.0760521042082, 1530.6911823647295, 1538.3063126252505, 1545.9214428857715, 1553.5365731462925, 1561.1517034068136, 1568.7668336673346, 1576.3819639278556, 1583.9970941883766, 1591.6122244488977, 1599.2273547094187, 1606.8424849699397, 1614.4576152304608, 1622.0727454909818, 1629.6878757515028, 1637.3030060120238, 1644.918136272545, 1652.5332665330661, 1660.1483967935872, 1667.7635270541082, 1675.3786573146292, 1682.9937875751502, 1690.6089178356713, 1698.2240480961923, 1705.8391783567133, 1713.4543086172343, 1721.0694388777554, 1728.6845691382764, 1736.2996993987974, 1743.9148296593185, 1751.5299599198395, 1759.1450901803605, 1766.7602204408815, 1774.3753507014028, 1781.9904809619238, 1789.6056112224448, 1797.2207414829659, 1804.835871743487, 1812.451002004008, 1820.066132264529, 1827.68126252505, 1835.296392785571, 1842.911523046092, 1850.526653306613, 1858.141783567134, 1865.7569138276551, 1873.3720440881762, 1880.9871743486972, 1888.6023046092184, 1896.2174348697395, 1903.8325651302605, 1911.4476953907815, 1919.0628256513025, 1926.6779559118236, 1934.2930861723446, 1941.9082164328656, 1949.5233466933867, 1957.1384769539077, 1964.7536072144287, 1972.3687374749497, 1979.9838677354708, 1987.5989979959918, 1995.2141282565128, 2002.8292585170338, 2010.4443887775549, 2018.0595190380761, 2025.6746492985972, 2033.2897795591182, 2040.9049098196392, 2048.5200400801605, 2056.1351703406813, 2063.7503006012025, 2071.3654308617233, 2078.9805611222446, 2086.595691382766, 2094.2108216432866, 2101.825951903808, 2109.4410821643287, 2117.05621242485, 2124.6713426853707, 2132.286472945892, 2139.901603206413, 2147.516733466934, 2155.131863727455, 2162.746993987976, 2170.362124248497, 2177.977254509018, 2185.592384769539, 2193.20751503006, 2200.8226452905815, 2208.4377755511023, 2216.0529058116235, 2223.6680360721443, 2231.2831663326656, 2238.8982965931864, 2246.5134268537076, 2254.1285571142284, 2261.7436873747497, 2269.3588176352705, 2276.9739478957918, 2284.5890781563126, 2292.204208416834, 2299.8193386773546, 2307.434468937876, 2315.049599198397, 2322.664729458918, 2330.279859719439, 2337.89498997996, 2345.5101202404812, 2353.125250501002, 2360.7403807615233, 2368.355511022044, 2375.9706412825653, 2383.585771543086, 2391.2009018036074, 2398.816032064128, 2406.4311623246494, 2414.0462925851702, 2421.6614228456915, 2429.2765531062123, 2436.8916833667336, 2444.506813627255, 2452.1219438877756, 2459.737074148297, 2467.3522044088177, 2474.967334669339, 2482.5824649298597, 2490.197595190381, 2497.812725450902, 2505.427855711423, 2513.042985971944, 2520.658116232465, 2528.273246492986, 2535.888376753507, 2543.503507014028, 2551.118637274549, 2558.73376753507, 2566.3488977955913, 2573.9640280561125, 2581.5791583166333, 2589.1942885771546, 2596.8094188376754, 2604.4245490981966, 2612.0396793587174, 2619.6548096192387, 2627.2699398797595, 2634.8850701402807, 2642.5002004008015, 2650.115330661323, 2657.7304609218436, 2665.345591182365, 2672.9607214428856, 2680.575851703407, 2688.190981963928, 2695.806112224449, 2703.42124248497, 2711.036372745491, 2718.6515030060123, 2726.266633266533, 2733.8817635270543, 2741.496893787575, 2749.1120240480964, 2756.727154308617, 2764.3422845691384, 2771.9574148296592, 2779.5725450901805, 2787.1876753507013, 2794.8028056112225, 2802.417935871744, 2810.0330661322646, 2817.648196392786, 2825.2633266533066, 2832.878456913828, 2840.4935871743487, 2848.10871743487, 2855.7238476953908, 2863.338977955912, 2870.954108216433, 2878.569238476954, 2886.184368737475, 2893.799498997996, 2901.414629258517, 2909.029759519038, 2916.644889779559, 2924.2600200400802, 2931.8751503006015, 2939.4902805611223, 2947.1054108216435, 2954.7205410821643, 2962.3356713426856, 2969.9508016032064, 2977.5659318637277, 2985.1810621242485, 2992.7961923847697, 3000.4113226452905, 3008.0264529058118, 3015.6415831663326, 3023.256713426854, 3030.8718436873746, 3038.486973947896, 3046.1021042084167, 3053.717234468938, 3061.332364729459, 3068.94749498998, 3076.5626252505012, 3084.177755511022, 3091.7928857715433, 3099.408016032064, 3107.0231462925854, 3114.638276553106, 3122.2534068136274, 3129.868537074148, 3137.4836673346695, 3145.0987975951903, 3152.7139278557115, 3160.3290581162323, 3167.9441883767536, 3175.559318637275, 3183.1744488977956, 3190.789579158317, 3198.4047094188377, 3206.019839679359, 3213.6349699398797, 3221.250100200401, 3228.865230460922, 3236.480360721443, 3244.095490981964, 3251.710621242485, 3259.325751503006, 3266.940881763527, 3274.556012024048, 3282.171142284569, 3289.7862725450905, 3297.4014028056113, 3305.0165330661325, 3312.6316633266533, 3320.2467935871746, 3327.8619238476954, 3335.4770541082166, 3343.0921843687374, 3350.7073146292587, 3358.3224448897795, 3365.9375751503007, 3373.5527054108215, 3381.167835671343, 3388.7829659318636, 3396.398096192385, 3404.0132264529057, 3411.628356713427, 3419.243486973948, 3426.858617234469, 3434.47374749499, 3442.088877755511, 3449.7040080160323, 3457.319138276553, 3464.9342685370743, 3472.549398797595, 3480.1645290581164, 3487.779659318637, 3495.3947895791584, 3503.0099198396792, 3510.6250501002005, 3518.2401803607213, 3525.8553106212426, 3533.4704408817634, 3541.0855711422846, 3548.700701402806, 3556.3158316633267, 3563.930961923848, 3571.5460921843687, 3579.16122244489, 3586.7763527054108, 3594.391482965932, 3602.006613226453, 3609.621743486974, 3617.236873747495, 3624.852004008016, 3632.467134268537, 3640.082264529058, 3647.697394789579, 3655.3125250501002, 3662.9276553106215, 3670.5427855711423, 3678.1579158316636, 3685.7730460921844, 3693.3881763527056, 3701.0033066132264, 3708.6184368737477, 3716.2335671342685, 3723.8486973947897, 3731.4638276553105, 3739.078957915832, 3746.6940881763526, 3754.309218436874, 3761.9243486973946, 3769.539478957916, 3777.154609218437, 3784.769739478958, 3792.384869739479, 3800.0], \"y\": [0.9852228748587244, 0.9683726906710981, 0.9516644787241781, 0.935097042822308, 0.9186691968484499, 0.9023797646792668, 0.8862275801009194, 0.8702114867255732, 0.8543303379086091, 0.8385829966665312, 0.8229683355955664, 0.8074852367909497, 0.7921325917668907, 0.7769093013772119, 0.7618142757366584, 0.7468464341428691, 0.7320047049990057, 0.7172880257370335, 0.7026953427416487, 0.6882256112748466, 0.6738777954011255, 0.6596508679133202, 0.645543810259062, 0.6315556124678559, 0.6176852730787745, 0.6039317990687592, 0.590294205781527, 0.5767715168570764, 0.5633627641617847, 0.5500669877190985, 0.5368832356408033, 0.523810564058877, 0.5108480370579143, 0.4979947266081206, 0.48524971249887305, 0.4726120822728386, 0.46008093116064797, 0.447655362016121, 0.43533448525203644, 0.4231174187764437, 0.4110032879295116, 0.3989912254209069, 0.3870803712677042, 0.3752698727328154, 0.36355888426394034, 0.35194656743303065, 0.34043209087626347, 0.3290146302345227, 0.31769336809437854, 0.3064674939295684, 0.29533620404296634, 0.28429870150904546, 0.2733541961168231, 0.2625019043132861, 0.2517410491472951, 0.24107086021395863, 0.23049057359947867, 0.21999943182645798, 0.2095966837996719, 0.19928158475229218, 0.18905339619257022, 0.17891138585096233, 0.16885482762770687, 0.15888300154083956, 0.14899519367464675, 0.13919069612855517, 0.12946880696645002, 0.11982883016642187, 0.1102700755709356, 0.1007918588374197, 0.0913935013892726, 0.0820743303672804, 0.07283367858144518, 0.06367088446321811, 0.054585292018136666, 0.04557625077885841, 0.03664311575859314, 0.027785247404925384, 0.019002011554027032, 0.010292779385255635, 0.0016569273761350978, 0.006906162742285282, 0.015397104029693298, 0.023816504380405612, 0.03216496656688883, 0.040443088282913986, 0.04865146218634686, 0.05679067594157916, 0.06486131226160075, 0.07286394894971804, 0.08079915894092093, 0.08866751034290155, 0.09646956647672578, 0.10420588591716429, 0.11187702253268261, 0.11948352552509367, 0.12702593946887808, 0.1345048043501712, 0.14192065560542233, 0.14927402415972912, 0.1565654364648481, 0.1637954145368843, 0.17096447599366482, 0.17807313409179704, 0.18512189776341315, 0.19211127165260766, 0.19904175615156583, 0.20591384743638808, 0.2127280375026137, 0.21948481420044363, 0.22618466126966763, 0.232828058374297, 0.2394154811369048, 0.24594740117267755, 0.2524242861231797, 0.2588465996898335, 0.265214801667117, 0.2715293479754822, 0.27779069069399587, 0.2839992780927053, 0.2901555546647321, 0.2962599611580935, 0.30231293460725805, 0.30831490836443465, 0.3142663121305965, 0.3201675719862457, 0.326019110421917, 0.331821346368426, 0.3375746952268619, 0.34327956889832656, 0.3489363758134243, 0.35454552096150305, 0.3601074059196484, 0.3656224288814345, 0.3710909846854308, 0.37651346484347126, 0.3818902575686832, 0.3872217478032809, 0.39250831724612456, 0.39775034438004786, 0.40294820449895474, 0.40810226973468744, 0.4132129090836695, 0.41828048843332233, 0.423305370588261, 0.428287915296269, 0.4332284792740523, 0.4381274162327794, 0.44298507690340416, 0.44780180906177536, 0.45257795755353536, 0.4573138643188094, 0.462009868416685, 0.466666306049487, 0.4712835105868478, 0.4758618125895735, 0.48040153983331024, 0.4849030173320109, 0.48936656736120376, 0.4937925094810649, 0.4981811605592974, 0.5025328347938163, 0.5068478437352427, 0.51112649630921, 0.5153690988384796, 0.519575955064872, 0.523747366171013, 0.5278836308018959, 0.5319850450862627, 0.5360519026578049, 0.5400844946761854, 0.5440831098478839, 0.5480480344468668, 0.5519795523350814, 0.5558779449827791, 0.5597434914886674, 0.5635764685998901, 0.5673771507318415, 0.5711458099878126, 0.5748827161784719, 0.5785881368411814, 0.5822623372591514, 0.5859055804804325, 0.5895181273367478, 0.5931002364621676, 0.5966521643116245, 0.6001741651792751, 0.6036664912167056, 0.6071293924509831, 0.6105631168025571, 0.6139679101030084, 0.6173440161126489, 0.6206916765379733, 0.624011131048964, 0.6273026172962489, 0.6305663709281168, 0.6338026256073879, 0.6370116130281411, 0.6401935629323042, 0.6433487031260999, 0.6464772594963558, 0.649579456026677, 0.6526555148134803, 0.6557056560818968, 0.6587300982015369, 0.6617290577021249, 0.6647027492890007, 0.6676513858584919, 0.6705751785131548, 0.6734743365768885, 0.6763490676099212, 0.6791995774236697, 0.6820260700954744, 0.68482874798321, 0.6876078117397724, 0.6903634603274444, 0.6930958910321408, 0.6958052994775311, 0.6984918796390465, 0.7011558238577663, 0.7037973228541885, 0.7064165657418838, 0.7090137400410357, 0.7115890316918647, 0.7141426250679406, 0.7166747029893833, 0.71918544673595, 0.7216750360600148, 0.7241436491994375, 0.7265914628903238, 0.7290186523796786, 0.7314253914379529, 0.7338118523714845, 0.7361782060348331, 0.7385246218430137, 0.7408512677836244, 0.7431583104288741, 0.7454459149475074, 0.7477142451166293, 0.7499634633334318, 0.7521937306268186, 0.7544052066689355, 0.7565980497866006, 0.7587724169726399, 0.760928463897127, 0.763066344918528, 0.7651862130947522, 0.7672882201941106, 0.7693725167061808, 0.7714392518525817, 0.7734885735976562, 0.7755206286590651, 0.7775355625182905, 0.7795335194310514, 0.7815146424376318, 0.7834790733731212, 0.7854269528775687, 0.7873584204060524, 0.7892736142386633, 0.7911726714904052, 0.793055728121011, 0.7949229189446769, 0.7967743776397138, 0.798610236758118, 0.8004306277350611, 0.8022356808982998, 0.8040255254775059, 0.8058002896135195, 0.8075601003675219, 0.8093050837301333, 0.8110353646304316, 0.8127510669448978, 0.814452313506284, 0.8161392261124075, 0.8178119255348708, 0.819470531527708, 0.8211151628359584, 0.8227459372041678, 0.8243629713848184, 0.8259663811466869, 0.8275562812831336, 0.8291327856203204, 0.83069600702536, 0.8322460574143963, 0.8337830477606172, 0.835307088102199, 0.8368182875501853, 0.8383167542962974, 0.8398025956206812, 0.8412759178995871, 0.842736826612986, 0.8441854263521209, 0.845621820826995, 0.847046112873797, 0.8484584044622625, 0.8498587967029754, 0.851247389854606, 0.8526242833310894, 0.8539895757087425, 0.8553433647333215, 0.8566857473270197, 0.8580168195954071, 0.8593366768343098, 0.8606454135366337, 0.8619431233991288, 0.8632298993290974, 0.864505833451046, 0.8657710171132804, 0.8670255408944457, 0.8682694946100112, 0.8695029673187008, 0.8707260473288683, 0.8719388222048204, 0.8731413787730856, 0.8743338031286302, 0.8755161806410218, 0.8766885959605422, 0.8778511330242464, 0.8790038750619737, 0.8801469046023045, 0.8812803034784702, 0.8824041528342108, 0.8835185331295854, 0.884623524146732, 0.8857192049955789, 0.8868056541195095, 0.8878829493009777, 0.8889511676670762, 0.890010385695059, 0.8910606792178167, 0.8921021234293048, 0.8931347928899279, 0.8941587615318775, 0.8951741026644248, 0.896180888979169, 0.8971791925552428, 0.8981690848644709, 0.8991506367764882, 0.9001239185638134, 0.9010889999068794, 0.902045949899023, 0.9029948370514305, 0.9039357292980432, 0.904868694000421, 0.9057937979525648, 0.9067111073856986, 0.9076206879730113, 0.9085226048343584, 0.9094169225409242, 0.9103037051198444, 0.9111830160587905, 0.9120549183105146, 0.9129194742973565, 0.9137767459157133, 0.9146267945404697, 0.9154696810293929, 0.9163054657274892, 0.9171342084713248, 0.9179559685933087, 0.9187708049259417, 0.9195787758060274, 0.9203799390788494, 0.9211743521023121, 0.9219620717510479, 0.9227431544204883, 0.9235176560309013, 0.9242856320313961, 0.9250471374038916, 0.9258022266670531, 0.9265509538801961, 0.9272933726471557, 0.9280295361201248, 0.9287594970034594, 0.9294833075574515, 0.930201019602071, 0.9309126845206757, 0.9316183532636896, 0.9323180763522508, 0.933011903881829, 0.9336998855258106, 0.9343820705390569, 0.9350585077614286, 0.9357292456212838, 0.9363943321389441, 0.9370538149301334, 0.937707741209386, 0.9383561577934276, 0.9389991111045269, 0.9396366471738186, 0.9402688116445995, 0.9408956497755961, 0.9415172064442048, 0.9421335261497045, 0.9427446530164432, 0.9433506307969961, 0.9439515028752989, 0.944547312269753, 0.9451381016363057, 0.9457239132715043, 0.9463047891155236, 0.9468807707551694, 0.9474518994268549, 0.9480182160195538, 0.9485797610777271, 0.949136574804226, 0.94968869706317, 0.9502361673828017, 0.9507790249583153, 0.9513173086546641, 0.9518510570093421, 0.9523803082351435, 0.9529051002228982, 0.9534254705441846, 0.9539414564540196, 0.9544530948935258, 0.954960422492576, 0.9554634755724156, 0.9559622901482637, 0.9564569019318905, 0.9569473463341748, 0.957433658467639, 0.9579158731489623, 0.9583940249014745, 0.9588681479576269, 0.9593382762614427, 0.9598044434709484, 0.9602666829605822, 0.9607250278235844, 0.9611795108743657, 0.9616301646508578, 0.9620770214168413, 0.9625201131642567, 0.9629594716154946, 0.9633951282256663, 0.9638271141848568, 0.9642554604203566, 0.9646801975988767, 0.9651013561287438, 0.9655189661620776, 0.9659330575969487, 0.9663436600795207, 0.9667508030061708, 0.9671545155255956, 0.9675548265408976, 0.9679517647116546, 0.9683453584559709, 0.9687356359525131, 0.9691226251425261, 0.9695063537318345, 0.9698868491928256, 0.9702641387664168, 0.9706382494640051, 0.9710092080694015, 0.9713770411407486, 0.9717417750124214, 0.9721034357969133, 0.9724620493867053, 0.9728176414561196, 0.9731702374631579, 0.9735198626513242, 0.9738665420514314, 0.9742103004833943, 0.9745511625580056, 0.9748891526786984, 0.9752242950432932, 0.9755566136457305, 0.9758861322777883, 0.9762128745307853, 0.9765368637972704, 0.9768581232726972, 0.9771766759570844, 0.9774925446566626, 0.9778057519855077, 0.9781163203671586, 0.9784242720362237, 0.9787296290399725, 0.9790324132399137, 0.9793326463133605, 0.9796303497549828, 0.9799255448783455, 0.9802182528174352, 0.9805084945281726, 0.9807962907899131, 0.9810816622069343, 0.9813646292099113, 0.9816452120573793, 0.981923430837184, 0.9821993054679198, 0.9824728557003556, 0.9827441011188491, 0.983013061142749, 0.9832797550277849, 0.9835442018674461, 0.9838064205943486, 0.9840664299815907, 0.9843242486440963, 0.9845798950399487, 0.9848333874717112, 0.985084744087738, 0.985333982883473], \"type\": \"scatter\", \"uid\": \"9373ddb0-c420-4635-a20d-f3a7fb71ce31\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 7.865531062124248, 15.681062124248497, 23.496593186372746, 31.312124248496993, 39.127655310621236, 46.94318637274549, 54.75871743486973, 62.57424849699398, 70.38977955911822, 78.20531062124248, 86.02084168336673, 93.83637274549098, 101.65190380761523, 109.46743486973946, 117.28296593186371, 125.09849699398796, 132.91402805611222, 140.72955911823647, 148.54509018036072, 156.36062124248497, 164.17615230460922, 171.99168336673347, 179.80721442885772, 187.62274549098197, 195.43827655310622, 203.25380761523047, 211.0693386773547, 218.88486973947894, 226.7004008016032, 234.51593186372745, 242.3314629258517, 250.14699398797595, 257.96252505010017, 265.7780561122244, 273.59358717434867, 281.4091182364729, 289.22464929859717, 297.0401803607214, 304.8557114228457, 312.6712424849699, 320.4867735470942, 328.3023046092184, 336.1178356713427, 343.9333667334669, 351.7488977955912, 359.5644288577154, 367.3799599198397, 375.1954909819639, 383.0110220440882, 390.82655310621243, 398.6420841683367, 406.45761523046093, 414.2731462925852, 422.0886773547094, 429.9042084168336, 437.7197394789579, 445.5352705410821, 453.3508016032064, 461.16633266533063, 468.9818637274549, 476.79739478957913, 484.6129258517034, 492.42845691382763, 500.2439879759519, 508.05951903807613, 515.8750501002003, 523.6905811623245, 531.5061122244488, 539.321643286573, 547.1371743486973, 554.9527054108215, 562.7682364729458, 570.58376753507, 578.3992985971943, 586.2148296593185, 594.0303607214428, 601.845891783567, 609.6614228456913, 617.4769539078155, 625.2924849699398, 633.108016032064, 640.9235470941883, 648.7390781563125, 656.5546092184368, 664.370140280561, 672.1856713426853, 680.0012024048095, 687.8167334669338, 695.632264529058, 703.4477955911823, 711.2633266533065, 719.0788577154308, 726.894388777555, 734.7099198396793, 742.5254509018035, 750.3409819639278, 758.156513026052, 765.9720440881763, 773.7875751503005, 781.6031062124248, 789.418637274549, 797.2341683366733, 805.0496993987975, 812.8652304609218, 820.680761523046, 828.4962925851703, 836.3118236472944, 844.1273547094187, 851.9428857715429, 859.7584168336672, 867.5739478957914, 875.3894789579157, 883.2050100200399, 891.0205410821642, 898.8360721442884, 906.6516032064127, 914.4671342685369, 922.2826653306612, 930.0981963927854, 937.9137274549097, 945.7292585170339, 953.5447895791582, 961.3603206412824, 969.1758517034067, 976.991382765531, 984.8069138276552, 992.6224448897794, 1000.4379759519037, 1008.253507014028, 1016.0690380761522, 1023.8845691382764, 1031.7001002004006, 1039.515631262525, 1047.331162324649, 1055.1466933867734, 1062.9622244488976, 1070.777755511022, 1078.593286573146, 1086.4088176352705, 1094.2243486973946, 1102.039879759519, 1109.855410821643, 1117.6709418837675, 1125.4864729458916, 1133.302004008016, 1141.11753507014, 1148.9330661322645, 1156.7485971943886, 1164.564128256513, 1172.379659318637, 1180.1951903807615, 1188.0107214428856, 1195.82625250501, 1203.641783567134, 1211.4573146292585, 1219.2728456913826, 1227.088376753507, 1234.903907815631, 1242.7194388777555, 1250.5349699398796, 1258.350501002004, 1266.166032064128, 1273.9815631262525, 1281.7970941883766, 1289.612625250501, 1297.428156312625, 1305.2436873747495, 1313.0592184368736, 1320.874749498998, 1328.690280561122, 1336.5058116232462, 1344.3213426853706, 1352.1368737474947, 1359.952404809619, 1367.7679358717432, 1375.5834669338676, 1383.3989979959917, 1391.214529058116, 1399.0300601202403, 1406.8455911823646, 1414.6611222444888, 1422.4766533066131, 1430.2921843687373, 1438.1077154308616, 1445.9232464929858, 1453.7387775551101, 1461.5543086172343, 1469.3698396793586, 1477.1853707414828, 1485.0009018036071, 1492.8164328657313, 1500.6319639278556, 1508.4474949899798, 1516.2630260521041, 1524.0785571142283, 1531.8940881763526, 1539.7096192384768, 1547.5251503006011, 1555.3406813627253, 1563.1562124248496, 1570.9717434869738, 1578.7872745490981, 1586.6028056112223, 1594.4183366733466, 1602.2338677354708, 1610.0493987975951, 1617.8649298597193, 1625.6804609218436, 1633.4959919839678, 1641.3115230460921, 1649.1270541082163, 1656.9425851703406, 1664.7581162324648, 1672.573647294589, 1680.3891783567133, 1688.2047094188374, 1696.0202404809618, 1703.835771543086, 1711.6513026052103, 1719.4668336673344, 1727.2823647294588, 1735.097895791583, 1742.9134268537073, 1750.7289579158314, 1758.5444889779558, 1766.36002004008, 1774.1755511022043, 1781.9910821643284, 1789.8066132264528, 1797.622144288577, 1805.4376753507013, 1813.2532064128254, 1821.0687374749498, 1828.884268537074, 1836.6997995991983, 1844.5153306613224, 1852.3308617234468, 1860.146392785571, 1867.9619238476953, 1875.7774549098194, 1883.5929859719438, 1891.408517034068, 1899.2240480961923, 1907.0395791583164, 1914.8551102204408, 1922.670641282565, 1930.4861723446893, 1938.3017034068134, 1946.1172344689378, 1953.932765531062, 1961.7482965931863, 1969.5638276553104, 1977.3793587174348, 1985.194889779559, 1993.0104208416833, 2000.8259519038074, 2008.6414829659316, 2016.457014028056, 2024.27254509018, 2032.0880761523044, 2039.9036072144286, 2047.719138276553, 2055.5346693386773, 2063.3502004008014, 2071.165731462926, 2078.98126252505, 2086.7967935871743, 2094.6123246492984, 2102.427855711423, 2110.243386773547, 2118.0589178356713, 2125.8744488977954, 2133.68997995992, 2141.505511022044, 2149.3210420841683, 2157.1365731462924, 2164.952104208417, 2172.767635270541, 2180.5831663326653, 2188.3986973947895, 2196.214228456914, 2204.029759519038, 2211.8452905811623, 2219.6608216432865, 2227.476352705411, 2235.291883767535, 2243.1074148296593, 2250.9229458917835, 2258.738476953908, 2266.554008016032, 2274.3695390781563, 2282.1850701402805, 2290.000601202405, 2297.816132264529, 2305.6316633266533, 2313.4471943887775, 2321.262725450902, 2329.078256513026, 2336.8937875751503, 2344.7093186372745, 2352.5248496993986, 2360.340380761523, 2368.1559118236473, 2375.9714428857715, 2383.7869739478956, 2391.60250501002, 2399.4180360721443, 2407.2335671342685, 2415.0490981963926, 2422.864629258517, 2430.6801603206413, 2438.4956913827655, 2446.3112224448896, 2454.126753507014, 2461.9422845691383, 2469.7578156312625, 2477.5733466933866, 2485.388877755511, 2493.2044088176353, 2501.0199398797595, 2508.8354709418836, 2516.651002004008, 2524.4665330661323, 2532.2820641282565, 2540.0975951903806, 2547.913126252505, 2555.7286573146293, 2563.5441883767535, 2571.3597194388776, 2579.175250501002, 2586.9907815631263, 2594.8063126252505, 2602.6218436873746, 2610.437374749499, 2618.2529058116234, 2626.0684368737475, 2633.8839679358716, 2641.699498997996, 2649.5150300601204, 2657.3305611222445, 2665.1460921843686, 2672.9616232464928, 2680.7771543086174, 2688.5926853707415, 2696.4082164328656, 2704.2237474949898, 2712.0392785571144, 2719.8548096192385, 2727.6703406813626, 2735.4858717434868, 2743.3014028056114, 2751.1169338677355, 2758.9324649298596, 2766.7479959919838, 2774.5635270541084, 2782.3790581162325, 2790.1945891783566, 2798.010120240481, 2805.8256513026054, 2813.6411823647295, 2821.4567134268536, 2829.272244488978, 2837.0877755511024, 2844.9033066132265, 2852.7188376753506, 2860.534368737475, 2868.3498997995994, 2876.1654308617235, 2883.9809619238476, 2891.796492985972, 2899.6120240480964, 2907.4275551102205, 2915.2430861723446, 2923.058617234469, 2930.8741482965934, 2938.6896793587175, 2946.5052104208416, 2954.320741482966, 2962.1362725450904, 2969.9518036072145, 2977.7673346693387, 2985.582865731463, 2993.3983967935874, 3001.2139278557115, 3009.0294589178357, 3016.84498997996, 3024.660521042084, 3032.4760521042085, 3040.2915831663327, 3048.107114228457, 3055.922645290581, 3063.7381763527055, 3071.5537074148297, 3079.369238476954, 3087.184769539078, 3095.0003006012025, 3102.8158316633267, 3110.631362725451, 3118.446893787575, 3126.2624248496995, 3134.0779559118237, 3141.893486973948, 3149.709018036072, 3157.5245490981965, 3165.3400801603207, 3173.155611222445, 3180.971142284569, 3188.7866733466935, 3196.6022044088177, 3204.417735470942, 3212.233266533066, 3220.0487975951905, 3227.8643286573147, 3235.679859719439, 3243.495390781563, 3251.3109218436875, 3259.1264529058117, 3266.941983967936, 3274.75751503006, 3282.5730460921845, 3290.3885771543087, 3298.204108216433, 3306.019639278557, 3313.8351703406815, 3321.6507014028057, 3329.46623246493, 3337.281763527054, 3345.097294589178, 3352.9128256513027, 3360.728356713427, 3368.543887775551, 3376.359418837675, 3384.1749498997997, 3391.990480961924, 3399.806012024048, 3407.621543086172, 3415.4370741482967, 3423.252605210421, 3431.068136272545, 3438.883667334669, 3446.6991983967937, 3454.514729458918, 3462.330260521042, 3470.145791583166, 3477.9613226452907, 3485.776853707415, 3493.592384769539, 3501.407915831663, 3509.2234468937877, 3517.038977955912, 3524.854509018036, 3532.67004008016, 3540.4855711422847, 3548.301102204409, 3556.116633266533, 3563.932164328657, 3571.7476953907817, 3579.563226452906, 3587.37875751503, 3595.194288577154, 3603.0098196392787, 3610.825350701403, 3618.640881763527, 3626.456412825651, 3634.2719438877757, 3642.0874749499, 3649.903006012024, 3657.718537074148, 3665.5340681362727, 3673.349599198397, 3681.165130260521, 3688.980661322645, 3696.7961923847693, 3704.611723446894, 3712.427254509018, 3720.242785571142, 3728.0583166332663, 3735.873847695391, 3743.689378757515, 3751.504909819639, 3759.3204408817633, 3767.135971943888, 3774.951503006012, 3782.767034068136, 3790.5825651302603, 3798.398096192385, 3806.213627254509, 3814.029158316633, 3821.8446893787573, 3829.660220440882, 3837.475751503006, 3845.29128256513, 3853.1068136272543, 3860.922344689379, 3868.737875751503, 3876.553406813627, 3884.3689378757513, 3892.184468937876, 3900.0], \"y\": [0.9867651632383105, 0.9694734698222316, 0.9523312860426107, 0.9353373191902348, 0.9184902877330765, 0.9017889212196544, 0.8852319601832259, 0.8688181560468096, 0.8525462710290288, 0.83641507805077, 0.8204233606426465, 0.8045699128532642, 0.7888535391582785, 0.77327305437024, 0.7578272835492172, 0.7425150619141938, 0.7273352347552307, 0.7122866573463884, 0.6973681948594033, 0.682578722278107, 0.6679171243135895, 0.653382295320093, 0.6389731392116349, 0.6246885693793502, 0.6105275086095499, 0.5964888890024862, 0.5825716518918223, 0.5687747477647969, 0.5550971361830788, 0.5415377857043069, 0.5280956738043088, 0.5147697867999894, 0.5015591197728901, 0.4884626764934057, 0.47547946934565766, 0.4626085192530176, 0.4498488556042739, 0.4371995161804365, 0.4246595470821761, 0.4122280026578886, 0.3999039454323827, 0.38768644603618463, 0.37557458313545267, 0.36356744336249935, 0.3516641212469125, 0.3398637191472731, 0.3281653471834638, 0.31656812316956184, 0.3050711725473121, 0.2936736283201762, 0.2823746309879518, 0.27117332848195574, 0.2600688761007699, 0.24906043644654097, 0.23814717936183083, 0.22732828186701437, 0.21660292809821713, 0.2059703092457914, 0.19542962349332105, 0.18498007595715804, 0.17462087862647735, 0.16435125030385378, 0.15417041654635066, 0.1440776096071179, 0.13407206837749586, 0.12415303832961921, 0.11431977145951788, 0.10457152623070787, 0.09490756751827267, 0.08532716655342609, 0.07582960086855528, 0.06641415424273878, 0.057080116647735046, 0.04782678419443909, 0.038653459079801555, 0.02955944953420664, 0.020544069769303785, 0.011606639926294182, 0.0027464860246595446, 0.006037060088661672, 0.014744660789661967, 0.023376972727213507, 0.0319346468725884, 0.040418328568547324, 0.04882865757800725, 0.057166268132285314, 0.06543178897892721, 0.0736258434291217, 0.08174904940470573, 0.08980201948476096, 0.0977853609518109, 0.1056996758376153, 0.11354556096857038, 0.12132360801071629, 0.12903440351435513, 0.13667852895828303, 0.1442565607936407, 0.1517690704873833, 0.159216624565376, 0.16659978465511627, 0.17391910752808604, 0.1811751451417395, 0.1883684446811258, 0.19549954860015317, 0.20256899466249623, 0.2095773159821489, 0.2165250410636269, 0.22341269384182327, 0.23024079372151895, 0.23700985561655052, 0.24372038998864165, 0.2503729028858971, 0.2569678959809636, 0.2635058666088629, 0.26998730780449487, 0.2764127083398187, 0.2827825527607112, 0.2890973214235074, 0.29535749053122407, 0.3015635321694706, 0.3077159143420507, 0.31381510100625354, 0.31986155210784173, 0.3258557236157368, 0.3317980675564036, 0.3376890320479383, 0.34352906133386185, 0.34931859581661984, 0.35505807209079454, 0.36074792297602887, 0.3663885775496655, 0.37198046117910377, 0.3775239955538775, 0.38301959871745517, 0.3884676850987644, 0.3938686655434449, 0.39922294734483044, 0.404530934274664, 0.409793026613545, 0.41500962118111695, 0.42018111136599, 0.42530788715540857, 0.4303903351646592, 0.43542883866622684, 0.4404237776186962, 0.44537552869540686, 0.4502844653128567, 0.45515095765886326, 0.45997537272047817, 0.46475807431166405, 0.469499423100728, 0.47419977663752166, 0.47885948938040324, 0.4834789127229687, 0.4880583950205496, 0.4925982816164832, 0.4970989148681556, 0.5015606341728193, 0.5059837759931862, 0.5103686738828028, 0.5147156585112014, 0.5190250576888382, 0.5232971963918124, 0.5275323967863741, 0.531730978253218, 0.5358932574115698, 0.5400195481430606, 0.5441101616153994, 0.5481654063058367, 0.5521855880244281, 0.5561710099370953, 0.5601219725884887, 0.5640387739246508, 0.5679217093154854, 0.5717710715770317, 0.5755871509935451, 0.5793702353393895, 0.583120609900736, 0.5868385574970794, 0.5905243585025641, 0.5941782908671285, 0.5978006301374639, 0.6013916494777959, 0.6049516196904821, 0.6084808092364345, 0.6119794842553647, 0.6154479085858529, 0.6188863437852445, 0.6222950491493754, 0.6256742817321236, 0.6290242963647963, 0.6323453456753452, 0.6356376801074187, 0.638901547939247, 0.6421371953023658, 0.6453448662001767, 0.6485248025263487, 0.6516772440830585, 0.654802428599075, 0.6579005917476863, 0.6609719671644722, 0.6640167864649229, 0.6670352792619052, 0.6700276731829784, 0.672994193887559, 0.6759350650839382, 0.6788505085461529, 0.6817407441307086, 0.6846059897931597, 0.6874464616045455, 0.6902623737676845, 0.6930539386333276, 0.6958213667161719, 0.6985648667107349, 0.7012846455070936, 0.7039809082064858, 0.7066538581367766, 0.7093036968677919, 0.7119306242265192, 0.7145348383121763, 0.7171165355111506, 0.7196759105118082, 0.7222131563191763, 0.7247284642694973, 0.7272220240446579, 0.7296940236864933, 0.7321446496109671, 0.7345740866222303, 0.7369825179265557, 0.7393701251461557, 0.7417370883328772, 0.74408358598178, 0.7464097950445971, 0.7487158909430796, 0.7510020475822237, 0.7532684373633869, 0.7555152311972879, 0.7577425985168957, 0.7599507072902062, 0.7621397240329091, 0.764309813820945, 0.7664611403029538, 0.7685938657126161, 0.7707081508808867, 0.7728041552481234, 0.7748820368761108, 0.7769419524599794, 0.7789840573400222, 0.7810085055134096, 0.7830154496458018, 0.7850050410828617, 0.7869774298616687, 0.7889327647220318, 0.7908711931177074, 0.7927928612275184, 0.7946979139663776, 0.7965864949962163, 0.7984587467368178, 0.8003148103765574, 0.8021548258830492, 0.8039789320137017, 0.8057872663261817, 0.807579965188787, 0.8093571637907311, 0.8111189961523366, 0.8128655951351431, 0.8145970924519257, 0.8163136186766278, 0.8180153032542076, 0.8197022745104003, 0.8213746596613944, 0.8230325848234259, 0.8246761750222882, 0.8263055542027613, 0.8279208452379577, 0.8295221699385891, 0.8311096490621515, 0.8326834023220328, 0.8342435483965389, 0.8357902049378452, 0.8373234885808671, 0.8388435149520569, 0.8403503986781224, 0.8418442533946718, 0.8433251917547826, 0.8447933254374965, 0.846248765156242, 0.8476916206671834, 0.8491220007774966, 0.8505400133535758, 0.8519457653291665, 0.8533393627134304, 0.8547209105989393, 0.8560905131696, 0.8574482737085116, 0.8587942946057532, 0.8601286773661063, 0.8614515226167087, 0.8627629301146427, 0.8640629987544588, 0.8653518265756324, 0.866629510769958, 0.8678961476888778, 0.8691518328507477, 0.8703966609480411, 0.8716307258544889, 0.8728541206321594, 0.8740669375384755, 0.8752692680331725, 0.8764612027851947, 0.8776428316795332, 0.878814243824004, 0.8799755275559678, 0.8811267704489916, 0.8822680593194527, 0.8833994802330856, 0.8845211185114723, 0.8856330587384765, 0.8867353847666224, 0.8878281797234173, 0.8889115260176212, 0.8899855053454613, 0.8910501986967919, 0.8921056863612031, 0.8931520479340745, 0.8941893623225783, 0.8952177077516295, 0.8962371617697844, 0.8972478012550898, 0.8982497024208795, 0.899242940821522, 0.9002275913581176, 0.9012037282841474, 0.9021714252110731, 0.9031307551138869, 0.9040817903366157, 0.9050246025977765, 0.905959262995784, 0.9068858420143133, 0.9078044095276141, 0.9087150348057811, 0.9096177865199764, 0.9105127327476092, 0.9113999409774692, 0.9122794781148157, 0.9131514104864235, 0.9140158038455841, 0.914872723377065, 0.9157222337020243, 0.916564398882885, 0.9173992824281649, 0.918226947297267, 0.9190474559052261, 0.9198608701274166, 0.9206672513042179, 0.9214666602456408, 0.9222591572359125, 0.9230448020380231, 0.9238236538982325, 0.9245957715505381, 0.9253612132211035, 0.9261200366326506, 0.9268722990088112, 0.9276180570784429, 0.9283573670799071, 0.9290902847653102, 0.9298168654047074, 0.930537163790271, 0.931251234240422, 0.931959130603927, 0.9326609062639584, 0.93335661414212, 0.9340463067024385, 0.9347300359553191, 0.9354078534614683, 0.9360798103357817, 0.9367459572511988, 0.9374063444425244, 0.9380610217102165, 0.9387100384241427, 0.9393534435273018, 0.9399912855395156, 0.9406236125610882, 0.9412504722764321, 0.941871911957665, 0.9424879784681744, 0.9430987182661519, 0.9437041774080958, 0.9443044015522855, 0.9448994359622234, 0.9454893255100492, 0.9460741146799234, 0.9466538475713818, 0.9472285679026612, 0.9477983190139962, 0.9483631438708878, 0.9489230850673429, 0.9494781848290867, 0.9500284850167472, 0.9505740271290116, 0.951114852305756, 0.9516510013311473, 0.9521825146367197, 0.9527094323044226, 0.9532317940696442, 0.9537496393242073, 0.95426300711934, 0.9547719361686211, 0.9552764648508988, 0.9557766312131852, 0.9562724729735259, 0.9567640275238435, 0.957251331932758, 0.957734422948382, 0.9582133370010918, 0.9586881102062749, 0.9591587783670532, 0.9596253769769831, 0.9600879412227323, 0.9605465059867329, 0.961001105849812, 0.9614517750937999, 0.9618985477041145, 0.9623414573723251, 0.9627805374986924, 0.9632158211946876, 0.9636473412854895, 0.9640751303124591, 0.9644992205355949, 0.9649196439359643, 0.9653364322181163, 0.9657496168124717, 0.9661592288776939, 0.9665652993030381, 0.966967858710681, 0.9673669374580299, 0.9677625656400121, 0.9681547730913441, 0.9685435893887819, 0.9689290438533513, 0.9693111655525585, 0.9696899833025829, 0.9700655256704498, 0.9704378209761844, 0.9708068972949477, 0.9711727824591541, 0.9715355040605693, 0.9718950894523921, 0.972251565751316, 0.9726049598395753, 0.9729552983669713, 0.9733026077528826, 0.973646914188257, 0.9739882436375871, 0.9743266218408677, 0.9746620743155375, 0.9749946263584028, 0.9753243030475457, 0.9756511292442147, 0.9759751295947, 0.9762963285321921, 0.9766147502786235, 0.9769304188464968, 0.977243358040694, 0.9775535914602727, 0.9778611425002449, 0.9781660343533422, 0.9784682900117638, 0.9787679322689112, 0.9790649837211065, 0.9793594667692965, 0.9796514036207423, 0.9799408162906936, 0.9802277266040493, 0.9805121561970027, 0.9807941265186739, 0.9810736588327266, 0.981350774218972, 0.9816254935749583, 0.9818978376175469, 0.9821678268844742, 0.9824354817359007, 0.9827008223559462, 0.9829638687542122, 0.9832246407672904, 0.9834831580602591, 0.9837394401281657, 0.983993506297497, 0.984245375727637, 0.9844950674123111, 0.9847426001810187, 0.9849879927004533, 0.9852312634759104, 0.985472430852682, 0.9857115130174412, 0.985948527999613, 0.986183493672734, 0.9864164277558006, 0.9866473478146048, 0.9868762712630591], \"type\": \"scatter\", \"uid\": \"501a7f86-87a2-4946-a408-43a516f81a2d\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 8.065931863727455, 16.08186372745491, 24.097795591182365, 32.113727454909814, 40.129659318637266, 48.145591182364726, 56.16152304609218, 64.17745490981963, 72.19338677354709, 80.20931863727454, 88.225250501002, 96.24118236472945, 104.2571142284569, 112.27304609218436, 120.2889779559118, 128.30490981963928, 136.32084168336672, 144.3367735470942, 152.35270541082164, 160.3686372745491, 168.38456913827656, 176.400501002004, 184.41643286573145, 192.43236472945893, 200.44829659318637, 208.46422845691382, 216.48016032064126, 224.49609218436873, 232.51202404809618, 240.52795591182363, 248.5438877755511, 256.55981963927854, 264.575751503006, 272.59168336673343, 280.6076152304609, 288.6235470941884, 296.6394789579158, 304.6554108216433, 312.67134268537075, 320.68727454909816, 328.70320641282564, 336.7191382765531, 344.7350701402805, 352.751002004008, 360.7669338677355, 368.7828657314629, 376.79879759519036, 384.81472945891784, 392.83066132264526, 400.84659318637273, 408.86252505010015, 416.8784569138276, 424.8943887775551, 432.9103206412825, 440.92625250501, 448.94218436873746, 456.9581162324649, 464.97404809619235, 472.9899799599198, 481.00591182364724, 489.0218436873747, 497.0377755511022, 505.0537074148296, 513.069639278557, 521.0855711422845, 529.101503006012, 537.1174348697393, 545.1333667334668, 553.1492985971943, 561.1652304609217, 569.1811623246492, 577.1970941883767, 585.213026052104, 593.2289579158315, 601.244889779559, 609.2608216432865, 617.276753507014, 625.2926853707414, 633.3086172344688, 641.3245490981963, 649.3404809619237, 657.3564128256512, 665.3723446893787, 673.3882765531062, 681.4042084168335, 689.420140280561, 697.4360721442885, 705.4520040080159, 713.4679358717434, 721.4838677354709, 729.4997995991982, 737.5157314629257, 745.5316633266532, 753.5475951903807, 761.5635270541081, 769.5794589178356, 777.595390781563, 785.6113226452904, 793.6272545090179, 801.6431863727454, 809.6591182364729, 817.6750501002002, 825.6909819639277, 833.7069138276552, 841.7228456913826, 849.7387775551101, 857.7547094188376, 865.770641282565, 873.7865731462924, 881.8025050100199, 889.8184368737474, 897.8343687374748, 905.8503006012023, 913.8662324649297, 921.8821643286572, 929.8980961923846, 937.9140280561121, 945.9299599198396, 953.945891783567, 961.9618236472944, 969.9777555110219, 977.9936873747494, 986.0096192384768, 994.0255511022043, 1002.0414829659318, 1010.0574148296591, 1018.0733466933866, 1026.089278557114, 1034.1052104208416, 1042.121142284569, 1050.1370741482965, 1058.153006012024, 1066.1689378757515, 1074.1848697394787, 1082.2008016032062, 1090.2167334669336, 1098.2326653306611, 1106.2485971943886, 1114.264529058116, 1122.2804609218435, 1130.296392785571, 1138.3123246492985, 1146.328256513026, 1154.3441883767534, 1162.360120240481, 1170.3760521042082, 1178.3919839679356, 1186.407915831663, 1194.4238476953906, 1202.439779559118, 1210.4557114228455, 1218.471643286573, 1226.4875751503005, 1234.503507014028, 1242.5194388777554, 1250.535370741483, 1258.5513026052104, 1266.5672344689376, 1274.583166332665, 1282.5990981963926, 1290.61503006012, 1298.6309619238475, 1306.646893787575, 1314.6628256513025, 1322.67875751503, 1330.6946893787574, 1338.7106212424849, 1346.7265531062124, 1354.7424849699396, 1362.758416833667, 1370.7743486973945, 1378.790280561122, 1386.8062124248495, 1394.822144288577, 1402.8380761523044, 1410.854008016032, 1418.8699398797594, 1426.8858717434869, 1434.9018036072143, 1442.9177354709418, 1450.933667334669, 1458.9495991983965, 1466.965531062124, 1474.9814629258515, 1482.997394789579, 1491.0133266533064, 1499.029258517034, 1507.0451903807614, 1515.0611222444888, 1523.0770541082163, 1531.0929859719438, 1539.1089178356713, 1547.1248496993985, 1555.140781563126, 1563.1567134268535, 1571.172645290581, 1579.1885771543084, 1587.2045090180359, 1595.2204408817634, 1603.2363727454908, 1611.2523046092183, 1619.2682364729458, 1627.2841683366732, 1635.3001002004005, 1643.316032064128, 1651.3319639278554, 1659.347895791583, 1667.3638276553104, 1675.3797595190379, 1683.3956913827653, 1691.4116232464928, 1699.4275551102203, 1707.4434869739478, 1715.4594188376752, 1723.4753507014027, 1731.49128256513, 1739.5072144288574, 1747.523146292585, 1755.5390781563124, 1763.5550100200398, 1771.5709418837673, 1779.5868737474948, 1787.6028056112223, 1795.6187374749497, 1803.6346693386772, 1811.6506012024047, 1819.666533066132, 1827.6824649298594, 1835.6983967935869, 1843.7143286573144, 1851.7302605210418, 1859.7461923847693, 1867.7621242484968, 1875.7780561122242, 1883.7939879759517, 1891.8099198396792, 1899.8258517034067, 1907.8417835671341, 1915.8577154308614, 1923.8736472945889, 1931.8895791583163, 1939.9055110220438, 1947.9214428857713, 1955.9373747494988, 1963.9533066132262, 1971.9692384769537, 1979.9851703406812, 1988.0011022044087, 1996.0170340681361, 2004.0329659318636, 2012.0488977955908, 2020.0648296593183, 2028.0807615230458, 2036.0966933867733, 2044.1126252505007, 2052.1285571142284, 2060.144488977956, 2068.1604208416834, 2076.176352705411, 2084.1922845691383, 2092.208216432866, 2100.2241482965933, 2108.2400801603208, 2116.2560120240482, 2124.2719438877757, 2132.287875751503, 2140.3038076152307, 2148.3197394789577, 2156.335671342685, 2164.3516032064126, 2172.36753507014, 2180.3834669338676, 2188.399398797595, 2196.4153306613225, 2204.43126252505, 2212.4471943887775, 2220.463126252505, 2228.4790581162324, 2236.49498997996, 2244.5109218436874, 2252.526853707415, 2260.5427855711423, 2268.55871743487, 2276.5746492985973, 2284.5905811623247, 2292.606513026052, 2300.6224448897797, 2308.638376753507, 2316.6543086172346, 2324.670240480962, 2332.686172344689, 2340.7021042084166, 2348.718036072144, 2356.7339679358715, 2364.749899799599, 2372.7658316633265, 2380.781763527054, 2388.7976953907814, 2396.813627254509, 2404.8295591182364, 2412.845490981964, 2420.8614228456913, 2428.877354709419, 2436.8932865731463, 2444.9092184368737, 2452.925150300601, 2460.9410821643287, 2468.957014028056, 2476.9729458917836, 2484.988877755511, 2493.0048096192386, 2501.020741482966, 2509.0366733466935, 2517.052605210421, 2525.068537074148, 2533.0844689378755, 2541.100400801603, 2549.1163326653304, 2557.132264529058, 2565.1481963927854, 2573.164128256513, 2581.1800601202403, 2589.195991983968, 2597.2119238476953, 2605.2278557114228, 2613.2437875751502, 2621.2597194388777, 2629.275651302605, 2637.2915831663327, 2645.30751503006, 2653.3234468937876, 2661.339378757515, 2669.3553106212426, 2677.37124248497, 2685.3871743486975, 2693.403106212425, 2701.4190380761524, 2709.4349699398795, 2717.450901803607, 2725.4668336673344, 2733.482765531062, 2741.4986973947894, 2749.514629258517, 2757.5305611222443, 2765.546492985972, 2773.5624248496993, 2781.5783567134267, 2789.594288577154, 2797.6102204408817, 2805.626152304609, 2813.6420841683366, 2821.658016032064, 2829.6739478957916, 2837.689879759519, 2845.7058116232465, 2853.721743486974, 2861.7376753507015, 2869.753607214429, 2877.7695390781564, 2885.785470941884, 2893.801402805611, 2901.8173346693384, 2909.833266533066, 2917.8491983967933, 2925.865130260521, 2933.8810621242483, 2941.8969939879757, 2949.912925851703, 2957.9288577154307, 2965.944789579158, 2973.9607214428856, 2981.976653306613, 2989.9925851703406, 2998.008517034068, 3006.0244488977955, 3014.040380761523, 3022.0563126252505, 3030.072244488978, 3038.0881763527054, 3046.104108216433, 3054.1200400801604, 3062.135971943888, 3070.1519038076153, 3078.167835671343, 3086.18376753507, 3094.1996993987973, 3102.2156312625248, 3110.2315631262522, 3118.2474949899797, 3126.263426853707, 3134.2793587174347, 3142.295290581162, 3150.3112224448896, 3158.327154308617, 3166.3430861723446, 3174.359018036072, 3182.3749498997995, 3190.390881763527, 3198.4068136272545, 3206.422745490982, 3214.4386773547094, 3222.454609218437, 3230.4705410821643, 3238.486472945892, 3246.5024048096193, 3254.5183366733468, 3262.5342685370742, 3270.5502004008013, 3278.5661322645287, 3286.582064128256, 3294.5979959919837, 3302.613927855711, 3310.6298597194386, 3318.645791583166, 3326.6617234468936, 3334.677655310621, 3342.6935871743485, 3350.709519038076, 3358.7254509018035, 3366.741382765531, 3374.7573146292584, 3382.773246492986, 3390.7891783567134, 3398.805110220441, 3406.8210420841683, 3414.836973947896, 3422.8529058116233, 3430.8688376753507, 3438.884769539078, 3446.9007014028057, 3454.9166332665327, 3462.93256513026, 3470.9484969939876, 3478.964428857715, 3486.9803607214426, 3494.99629258517, 3503.0122244488975, 3511.028156312625, 3519.0440881763525, 3527.06002004008, 3535.0759519038074, 3543.091883767535, 3551.1078156312624, 3559.12374749499, 3567.1396793587173, 3575.155611222445, 3583.1715430861723, 3591.1874749498998, 3599.203406813627, 3607.2193386773547, 3615.235270541082, 3623.2512024048096, 3631.267134268537, 3639.283066132264, 3647.2989979959916, 3655.314929859719, 3663.3308617234466, 3671.346793587174, 3679.3627254509015, 3687.378657314629, 3695.3945891783565, 3703.410521042084, 3711.4264529058114, 3719.442384769539, 3727.4583166332663, 3735.474248496994, 3743.4901803607213, 3751.5061122244488, 3759.5220440881762, 3767.5379759519037, 3775.553907815631, 3783.5698396793587, 3791.585771543086, 3799.6017034068136, 3807.617635270541, 3815.6335671342686, 3823.649498997996, 3831.665430861723, 3839.6813627254505, 3847.697294589178, 3855.7132264529055, 3863.729158316633, 3871.7450901803604, 3879.761022044088, 3887.7769539078154, 3895.792885771543, 3903.8088176352703, 3911.824749498998, 3919.8406813627253, 3927.8566132264527, 3935.87254509018, 3943.8884769539077, 3951.904408817635, 3959.9203406813626, 3967.93627254509, 3975.9522044088176, 3983.968136272545, 3991.9840681362725, 4000.0], \"y\": [0.9881452635182302, 0.9704121591725356, 0.9528362950570346, 0.9354162769155656, 0.9181507228548995, 0.9010382632351157, 0.8840775405609527, 0.8672672093741198, 0.8506059361465657, 0.8340923991746911, 0.8177252884745032, 0.8015033056776946, 0.7854251639286483, 0.7694895877823533, 0.7536953131032276, 0.7380410869648348, 0.7225256675504941, 0.7071478240547686, 0.6919063365858282, 0.6767999960686786, 0.661827604149247, 0.6469879730993202, 0.6322799257223244, 0.6177022952599405, 0.6032539252995472, 0.5889336696824863, 0.5747403924131391, 0.5606729675688116, 0.5467302792104161, 0.5329112212939473, 0.519214697582741, 0.5056396215605135, 0.49218491634516837, 0.4788495146033722, 0.46563235846588324, 0.4525323994436341, 0.4395485983445564, 0.42667992519114506, 0.41392535913875106, 0.4012838883946006, 0.38875451013753226, 0.3763362304384441, 0.3640280641814486, 0.3518290349857245, 0.3397381751280628, 0.3277545254661005, 0.31587713536223183, 0.3041050626081976, 0.2924373733503418, 0.28087314201552993, 0.26941145123772636, 0.2580513917852214, 0.24679206248850294, 0.2356325701687696, 0.22457202956707678, 0.21360956327410996, 0.202744301660583, 0.19197538280825088, 0.18130195244153668, 0.17072316385976283, 0.1602381778699855, 0.14984616272042106, 0.13954629403446717, 0.12933775474530518, 0.11921973503108485, 0.10919143225068195, 0.09925205088002764, 0.08940080244900095, 0.07963690547887925, 0.06995958542034852, 0.06036807459205695, 0.05086161211971851, 0.0414394438757526, 0.03210082241946277, 0.022845006937741497, 0.013671263186305183, 0.004578863431446534, 0.0044329136076937115, 0.0133647828163459, 0.02221745274082032, 0.030991625644716136, 0.03968799756462915, 0.048307258365367645, 0.056850091794677926, 0.06531717553748417, 0.0737091812696482, 0.08202677471125197, 0.0902706156794073, 0.09844135814059862, 0.10653965026255974, 0.11456613446569253, 0.12252144747402827, 0.13040622036573768, 0.13822107862319344, 0.14596664218258737, 0.1536435254831099, 0.16125233751569157, 0.1687936818713126, 0.17626815678888563, 0.18367635520271164, 0.1910188647895168, 0.19829626801507128, 0.2055091421803953, 0.212658059467555, 0.21974358698505292, 0.2267662868128144, 0.23372671604677753, 0.2406254268430854, 0.24746296646188792, 0.25423987731075526, 0.2609566969877045, 0.2676139583238478, 0.2742121894256594, 0.28075191371687025, 0.28723364997998935, 0.2936579123974582, 0.3000252105924395, 0.3063360496692441, 0.31259093025340123, 0.31879034853137034, 0.3249347962899034, 0.33102476095505784, 0.33706072563086176, 0.34304316913763855, 0.3489725660499903, 0.35484938673444466, 0.36067409738676837, 0.3664471600689495, 0.3721690327458519, 0.3778401693215443, 0.3834610196753073, 0.38903202969732265, 0.39455364132404336, 0.40002629257325206, 0.40545041757880806, 0.41082644662508705, 0.416154806181113, 0.42143591893439014, 0.426670203824434, 0.43185807607600457, 0.43699994723204494, 0.4420962251863291, 0.4471473142158181, 0.45215361501273144, 0.45711552471633254, 0.46203343694443344, 0.46690774182461925, 0.47173882602519623, 0.4765270727858659, 0.4812728619481257, 0.4859765699854015, 0.4906385700329129, 0.4952592319172724, 0.4998389221858234, 0.5043780041357179, 0.5088768378427354, 0.5133357801898475, 0.5177551848955286, 0.5221354025418155, 0.5264767806021182, 0.5307796634687849, 0.5350443924804209, 0.5392713059489669, 0.5434607391865367, 0.5476130245320167, 0.551728491377429, 0.5558074661940621, 0.559850272558369, 0.5638572311776362, 0.5678286599154235, 0.5717648738167813, 0.5756661851332405, 0.5795329033475842, 0.5833653351983976, 0.5871637847044013, 0.5909285531885682, 0.5946599393020269, 0.5983582390477531, 0.6020237458040508, 0.6056567503478256, 0.609257540877651, 0.6128264030366313, 0.61636361993506, 0.6198694721728792, 0.6233442378619392, 0.6267881926480594, 0.6302016097328955, 0.6335847598956126, 0.6369379115143636, 0.6402613305875815, 0.6435552807550784, 0.6468200233189609, 0.650055817264358, 0.6532629192799655, 0.6564415837784101, 0.6595920629164294, 0.662714606614876, 0.6658094625785438, 0.6688768763158164, 0.671917091158144, 0.674930348279346, 0.6779168867147424, 0.6808769433801165, 0.6838107530905089, 0.6867185485788443, 0.6896005605143947, 0.6924570175210769, 0.6952881461955895, 0.6980941711253877, 0.7008753149064999, 0.7036317981611855, 0.7063638395554364, 0.7090716558163234, 0.7117554617491888, 0.714415470254686, 0.717051892345669, 0.7196649371639314, 0.7222548119967971, 0.7248217222935638, 0.7273658716818014, 0.729887461983505, 0.7323866932311048, 0.7348637636833346, 0.7373188698409593, 0.7397522064623624, 0.7421639665789963, 0.7445543415106949, 0.7469235208808502, 0.749271692631456, 0.7515990430380148, 0.7539057567243168, 0.7561920166770845, 0.7584580042604887, 0.7607038992305364, 0.7629298797493298, 0.7651361223991997, 0.7673228021967137, 0.7694900926065593, 0.7716381655553054, 0.7737671914450396, 0.7758773391668873, 0.7779687761144083, 0.780041668196876, 0.7820961798524395, 0.7841324740611669, 0.7861507123579752, 0.7881510548454433, 0.7901336602065144, 0.7920986857170821, 0.7940462872584679, 0.7959766193297868, 0.797889835060203, 0.7997860862210776, 0.8016655232380083, 0.8035282952027624, 0.8053745498851035, 0.8072044337445144, 0.809018091941815, 0.8108156683506775, 0.8125973055690403, 0.814363144930419, 0.8161133265151188, 0.8178479891613467, 0.8195672704762249, 0.8212713068467069, 0.8229602334503976, 0.8246341842662753, 0.8262932920853214, 0.827937688521053, 0.8295675040199649, 0.8311828678718765, 0.832783908220189, 0.83437075207205, 0.8359435253084292, 0.837502352694104, 0.839047357887557, 0.8405786634507856, 0.842096390859024, 0.843600660510381, 0.845091591735389, 0.8465693028064717, 0.8480339109473259, 0.8494855323422207, 0.8509242821452138, 0.8523502744892869, 0.8537636224953995, 0.8551644382814625, 0.8565528329712321, 0.8579289167031252, 0.8592927986389565, 0.8606445869725979, 0.8619843889385618, 0.8633123108205067, 0.8646284579596699, 0.8659329347632224, 0.8672258447125529, 0.8685072903714754, 0.8697773733943664, 0.8710361945342284, 0.8722838536506823, 0.8735204497178894, 0.8747460808324029, 0.875960844220949, 0.8771648362481406, 0.878358152424121, 0.8795408874121409, 0.8807131350360677, 0.8818749882878285, 0.8830265393347865, 0.884167879527053, 0.8852990994047336, 0.8864202887051111, 0.8875315363697635, 0.8886329305516196, 0.8897245586219529, 0.8908065071773111, 0.8918788620463873, 0.8929417082968271, 0.8939951302419776, 0.895039211447576, 0.8960740347383779, 0.8970996822047284, 0.8981162352090735, 0.8991237743924153, 0.9001223796807082, 0.9011121302911993, 0.9020931047387135, 0.9030653808418805, 0.9040290357293094, 0.9049841458457057, 0.9059307869579373, 0.9068690341610428, 0.9077989618841906, 0.9087206438965817, 0.9096341533133028, 0.9105395626011253, 0.9114369435842551, 0.9123263674500293, 0.9132079047545637, 0.9140816254283499, 0.9149475987818028, 0.9158058935107586, 0.9166565777019244, 0.9174997188382799, 0.9183353838044294, 0.919163638891909, 0.9199845498044448, 0.9207981816631645, 0.9216045990117646, 0.9224038658216289, 0.9231960454969049, 0.9239812008795322, 0.924759394254228, 0.9255306873534287, 0.9262951413621858, 0.9270528169230206, 0.927803774140734, 0.9285480725871756, 0.9292857713059685, 0.9300169288171929, 0.9307416031220294, 0.9314598517073591, 0.9321717315503248, 0.9328772991228501, 0.9335766103961196, 0.9342697208450189, 0.9349566854525354, 0.9356375587141198, 0.936312394642009, 0.9369812467695114, 0.937644168155253, 0.9383012113873862, 0.9389524285877626, 0.9395978714160664, 0.9402375910739134, 0.9408716383089122, 0.9415000634186902, 0.9421229162548835, 0.9427402462270915, 0.9433521023067963, 0.9439585330312479, 0.9445595865073142, 0.9451553104152974, 0.9457457520127163, 0.9463309581380551, 0.9469109752144793, 0.947485849253518, 0.9480556258587137, 0.9486203502292406, 0.9491800671634899, 0.9497348210626231, 0.9502846559340948, 0.9508296153951437, 0.951369742676252, 0.9519050806245757, 0.952435671707343, 0.9529615580152234, 0.9534827812656665, 0.9539993828062113, 0.9545114036177664, 0.955018884317861, 0.9555218651638663, 0.9560203860561903, 0.956514486541442, 0.9570042058155688, 0.9574895827269656, 0.9579706557795575, 0.9584474631358532, 0.9589200426199724, 0.9593884317206474, 0.9598526675941956, 0.9603127870674679, 0.9607688266407699, 0.9612208224907574, 0.9616688104733058, 0.9621128261263553, 0.9625529046727295, 0.9629890810229293, 0.9634213897779031, 0.9638498652317911, 0.9642745413746452, 0.9646954518951268, 0.9651126301831779, 0.9655261093326707, 0.9659359221440323, 0.9663421011268472, 0.9667446785024356, 0.9671436862064102, 0.967539155891209, 0.9679311189286064, 0.9683196064122019, 0.9687046491598867, 0.9690862777162884, 0.9694645223551939, 0.9698394130819512, 0.9702109796358493, 0.9705792514924781, 0.9709442578660656, 0.9713060277117961, 0.9716645897281071, 0.9720199723589656, 0.972372203796125, 0.9727213119813606, 0.9730673246086872, 0.9734102691265553, 0.973750172740029, 0.9740870624129434, 0.9744209648700447, 0.9747519065991093, 0.9750799138530449, 0.9754050126519741, 0.9757272287852977, 0.9760465878137405, 0.9763631150713796, 0.9766768356676534, 0.9769877744893539, 0.9772959562026008, 0.9776014052547982, 0.9779041458765739, 0.9782042020837018, 0.9785015976790069, 0.9787963562542531, 0.9790885011920154, 0.9793780556675344, 0.979665042650555, 0.9799494849071478, 0.9802314050015162, 0.9805108252977854, 0.9807877679617772, 0.981062254962768, 0.9813343080752314, 0.9816039488805659, 0.981871198768807, 0.9821360789403236, 0.9823986104075, 0.9826588139964026, 0.9829167103484324, 0.983172319921962, 0.9834256629939587, 0.9836767596615933, 0.9839256298438336, 0.9841722932830254, 0.9844167695464581, 0.984659078027917, 0.984899237949222, 0.9851372683617521, 0.9853731881479572, 0.985607016022855, 0.9858387705355172, 0.9860684700705391, 0.9862961328494999, 0.9865217769324064, 0.9867454202191271, 0.9869670804508114, 0.9871867752112969, 0.9874045219285049, 0.9876203378758223, 0.9878342401734722, 0.9880462457898718, 0.9882563715429786], \"type\": \"scatter\", \"uid\": \"c8c8de76-a373-4d0d-b718-0edcf403ffa2\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 8.266332665330662, 16.482665330661323, 24.698997995991984, 32.91533066132264, 41.1316633266533, 49.347995991983964, 57.564328657314626, 65.78066132264529, 73.99699398797596, 82.21332665330661, 90.42965931863726, 98.64599198396793, 106.8623246492986, 115.07865731462925, 123.29498997995991, 131.5113226452906, 139.72765531062126, 147.94398797595193, 156.16032064128257, 164.37665330661324, 172.5929859719439, 180.80931863727454, 189.0256513026052, 197.24198396793588, 205.45831663326655, 213.67464929859722, 221.89098196392786, 230.10731462925852, 238.3236472945892, 246.53997995991983, 254.7563126252505, 262.97264529058117, 271.1889779559118, 279.4053106212425, 287.62164328657315, 295.83797595190384, 304.0543086172345, 312.2706412825651, 320.4869739478958, 328.70330661322646, 336.9196392785571, 345.1359719438878, 353.35230460921844, 361.5686372745491, 369.7849699398798, 378.0013026052104, 386.2176352705411, 394.43396793587175, 402.6503006012024, 410.8666332665331, 419.0829659318637, 427.2992985971944, 435.51563126252506, 443.7319639278557, 451.9482965931864, 460.16462925851704, 468.3809619238477, 476.5972945891784, 484.813627254509, 493.02995991983965, 501.24629258517035, 509.462625250501, 517.6789579158316, 525.8952905811623, 534.111623246493, 542.3279559118236, 550.5442885771542, 558.760621242485, 566.9769539078155, 575.1932865731462, 583.4096192384769, 591.6259519038076, 599.8422845691382, 608.0586172344689, 616.2749498997996, 624.4912825651302, 632.7076152304609, 640.9239478957916, 649.1402805611222, 657.3566132264529, 665.5729458917835, 673.7892785571141, 682.0056112224448, 690.2219438877755, 698.4382765531061, 706.6546092184368, 714.8709418837675, 723.0872745490981, 731.3036072144288, 739.5199398797595, 747.7362725450902, 755.9526052104208, 764.1689378757515, 772.3852705410821, 780.6016032064127, 788.8179358717434, 797.0342685370741, 805.2506012024047, 813.4669338677354, 821.6832665330661, 829.8995991983967, 838.1159318637274, 846.3322645290581, 854.5485971943888, 862.7649298597194, 870.98126252505, 879.1975951903808, 887.4139278557113, 895.630260521042, 903.8465931863727, 912.0629258517033, 920.279258517034, 928.4955911823647, 936.7119238476953, 944.928256513026, 953.1445891783567, 961.3609218436873, 969.577254509018, 977.7935871743487, 986.0099198396792, 994.2262525050099, 1002.4425851703406, 1010.6589178356713, 1018.8752505010019, 1027.0915831663326, 1035.3079158316632, 1043.524248496994, 1051.7405811623246, 1059.9569138276552, 1068.173246492986, 1076.3895791583166, 1084.6059118236471, 1092.822244488978, 1101.0385771543085, 1109.2549098196391, 1117.47124248497, 1125.6875751503005, 1133.903907815631, 1142.120240480962, 1150.3365731462925, 1158.552905811623, 1166.769238476954, 1174.9855711422845, 1183.2019038076153, 1191.4182364729459, 1199.6345691382764, 1207.8509018036073, 1216.0672344689378, 1224.2835671342684, 1232.4998997995992, 1240.7162324649298, 1248.9325651302604, 1257.1488977955912, 1265.3652304609218, 1273.5815631262524, 1281.7978957915832, 1290.0142284569138, 1298.2305611222444, 1306.4468937875752, 1314.6632264529057, 1322.8795591182363, 1331.0958917835671, 1339.3122244488977, 1347.5285571142283, 1355.7448897795591, 1363.9612224448897, 1372.1775551102203, 1380.393887775551, 1388.6102204408817, 1396.8265531062123, 1405.042885771543, 1413.2592184368737, 1421.4755511022042, 1429.691883767535, 1437.9082164328656, 1446.1245490981962, 1454.340881763527, 1462.5572144288576, 1470.7735470941884, 1478.989879759519, 1487.2062124248496, 1495.4225450901804, 1503.638877755511, 1511.8552104208416, 1520.0715430861724, 1528.287875751503, 1536.5042084168335, 1544.7205410821643, 1552.936873747495, 1561.1532064128255, 1569.3695390781563, 1577.585871743487, 1585.8022044088175, 1594.0185370741483, 1602.2348697394789, 1610.4512024048095, 1618.6675350701403, 1626.8838677354709, 1635.1002004008014, 1643.3165330661323, 1651.5328657314628, 1659.7491983967934, 1667.9655310621242, 1676.1818637274548, 1684.3981963927854, 1692.6145290581162, 1700.8308617234468, 1709.0471943887776, 1717.2635270541082, 1725.4798597194388, 1733.6961923847696, 1741.9125250501002, 1750.1288577154307, 1758.3451903807616, 1766.5615230460921, 1774.7778557114227, 1782.9941883767535, 1791.210521042084, 1799.4268537074147, 1807.6431863727455, 1815.859519038076, 1824.0758517034067, 1832.2921843687375, 1840.508517034068, 1848.7248496993986, 1856.9411823647295, 1865.15751503006, 1873.3738476953906, 1881.5901803607214, 1889.806513026052, 1898.0228456913826, 1906.2391783567134, 1914.455511022044, 1922.6718436873746, 1930.8881763527054, 1939.104509018036, 1947.3208416833666, 1955.5371743486974, 1963.753507014028, 1971.9698396793585, 1980.1861723446893, 1988.40250501002, 1996.6188376753507, 2004.8351703406813, 2013.051503006012, 2021.2678356713427, 2029.4841683366733, 2037.7005010020039, 2045.9168336673347, 2054.1331663326655, 2062.3494989979963, 2070.5658316633267, 2078.7821643286575, 2086.9984969939883, 2095.2148296593186, 2103.4311623246494, 2111.6474949899803, 2119.8638276553106, 2128.0801603206414, 2136.2964929859722, 2144.5128256513026, 2152.7291583166334, 2160.945490981964, 2169.1618236472946, 2177.3781563126254, 2185.594488977956, 2193.8108216432865, 2202.0271543086174, 2210.243486973948, 2218.4598196392785, 2226.6761523046093, 2234.89248496994, 2243.1088176352705, 2251.3251503006013, 2259.541482965932, 2267.7578156312625, 2275.9741482965933, 2284.190480961924, 2292.4068136272545, 2300.6231462925853, 2308.839478957916, 2317.0558116232464, 2325.2721442885772, 2333.488476953908, 2341.7048096192384, 2349.921142284569, 2358.1374749499, 2366.353807615231, 2374.570140280561, 2382.786472945892, 2391.002805611223, 2399.219138276553, 2407.435470941884, 2415.651803607215, 2423.868136272545, 2432.084468937876, 2440.3008016032068, 2448.517134268537, 2456.733466933868, 2464.9497995991987, 2473.166132264529, 2481.38246492986, 2489.5987975951907, 2497.815130260521, 2506.031462925852, 2514.2477955911827, 2522.464128256513, 2530.680460921844, 2538.8967935871747, 2547.113126252505, 2555.329458917836, 2563.5457915831666, 2571.762124248497, 2579.978456913828, 2588.1947895791586, 2596.411122244489, 2604.62745490982, 2612.8437875751506, 2621.060120240481, 2629.2764529058118, 2637.4927855711426, 2645.709118236473, 2653.9254509018037, 2662.1417835671346, 2670.358116232465, 2678.5744488977957, 2686.7907815631265, 2695.007114228457, 2703.2234468937877, 2711.4397795591185, 2719.656112224449, 2727.8724448897797, 2736.0887775551105, 2744.305110220441, 2752.5214428857716, 2760.7377755511025, 2768.954108216433, 2777.1704408817636, 2785.3867735470944, 2793.603106212425, 2801.8194388777556, 2810.0357715430864, 2818.2521042084168, 2826.4684368737476, 2834.6847695390784, 2842.9011022044087, 2851.1174348697396, 2859.3337675350704, 2867.5501002004007, 2875.7664328657315, 2883.9827655310623, 2892.1990981963927, 2900.4154308617235, 2908.6317635270543, 2916.848096192385, 2925.0644288577155, 2933.2807615230463, 2941.497094188377, 2949.7134268537075, 2957.9297595190383, 2966.146092184369, 2974.3624248496994, 2982.5787575150302, 2990.795090180361, 2999.0114228456914, 3007.227755511022, 3015.444088176353, 3023.6604208416834, 3031.876753507014, 3040.093086172345, 3048.3094188376754, 3056.525751503006, 3064.742084168337, 3072.9584168336673, 3081.174749498998, 3089.391082164329, 3097.6074148296593, 3105.82374749499, 3114.040080160321, 3122.2564128256513, 3130.472745490982, 3138.689078156313, 3146.9054108216433, 3155.121743486974, 3163.338076152305, 3171.5544088176352, 3179.770741482966, 3187.987074148297, 3196.203406813627, 3204.419739478958, 3212.636072144289, 3220.852404809619, 3229.06873747495, 3237.285070140281, 3245.501402805611, 3253.717735470942, 3261.934068136273, 3270.150400801603, 3278.366733466934, 3286.583066132265, 3294.799398797595, 3303.015731462926, 3311.2320641282568, 3319.448396793587, 3327.664729458918, 3335.8810621242487, 3344.097394789579, 3352.31372745491, 3360.5300601202407, 3368.746392785571, 3376.962725450902, 3385.1790581162327, 3393.395390781563, 3401.611723446894, 3409.8280561122247, 3418.0443887775555, 3426.260721442886, 3434.4770541082166, 3442.6933867735474, 3450.909719438878, 3459.1260521042086, 3467.3423847695394, 3475.55871743487, 3483.7750501002006, 3491.9913827655314, 3500.2077154308618, 3508.4240480961926, 3516.6403807615234, 3524.8567134268537, 3533.0730460921845, 3541.2893787575154, 3549.5057114228457, 3557.7220440881765, 3565.9383767535073, 3574.1547094188377, 3582.3710420841685, 3590.5873747494993, 3598.8037074148297, 3607.0200400801605, 3615.2363727454913, 3623.4527054108216, 3631.6690380761524, 3639.8853707414833, 3648.1017034068136, 3656.3180360721444, 3664.5343687374752, 3672.7507014028056, 3680.9670340681364, 3689.183366733467, 3697.3996993987976, 3705.6160320641284, 3713.832364729459, 3722.0486973947895, 3730.2650300601204, 3738.481362725451, 3746.6976953907815, 3754.9140280561123, 3763.130360721443, 3771.3466933867735, 3779.5630260521043, 3787.779358717435, 3795.9956913827655, 3804.2120240480963, 3812.428356713427, 3820.6446893787574, 3828.8610220440883, 3837.077354709419, 3845.2936873747494, 3853.5100200400802, 3861.726352705411, 3869.9426853707414, 3878.159018036072, 3886.375350701403, 3894.5916833667334, 3902.808016032064, 3911.024348697395, 3919.2406813627254, 3927.457014028056, 3935.673346693387, 3943.8896793587173, 3952.106012024048, 3960.322344689379, 3968.5386773547098, 3976.75501002004, 3984.971342685371, 3993.1876753507017, 4001.404008016032, 4009.620340681363, 4017.8366733466937, 4026.053006012024, 4034.269338677355, 4042.4856713426857, 4050.702004008016, 4058.918336673347, 4067.1346693386777, 4075.351002004008, 4083.567334669339, 4091.7836673346696, 4100.0], \"y\": [0.9893802315098488, 0.9712058145114901, 0.9531965614052638, 0.9353509712290604, 0.917667556661085, 0.9001448438958961, 0.8827813725215738, 0.8655756953980034, 0.8485263785362642, 0.8316320009791163, 0.8148911546825717, 0.7983024443985425, 0.7818644875585552, 0.765575914158523, 0.749435366644563, 0.7334414997998531, 0.7175929806325156, 0.7018884882645215, 0.6863267138216027, 0.6709063603241647, 0.6556261425791925, 0.640484787073136, 0.6254810318657722, 0.6106136264850281, 0.5958813318227634, 0.5812829200314966, 0.5668171744220725, 0.5524828893622584, 0.5382788701762615, 0.5242039330451602, 0.5102569049082399, 0.49643662336522554, 0.48274193657940256, 0.4691717031816185, 0.45572479217515593, 0.4424000828414727, 0.42919646464679406, 0.4161128371495586, 0.40314810990870265, 0.39030120239277744, 0.3775710438898956, 0.3649565734184912, 0.35245673963889534, 0.34007050076571277, 0.3277968244809948, 0.3156346878482026, 0.30358307722695166, 0.29164098818853024, 0.2798074254321872, 0.26808140270217895, 0.2564619427055719, 0.24494807703079013, 0.23353884606690478, 0.22223329892365573, 0.21103049335220136, 0.1999294956665869, 0.18892938066592868, 0.17802923155730266, 0.1672281398793365, 0.1565252054264945, 0.14591953617405085, 0.13541024820374425, 0.12499646563010969, 0.11467732052747848, 0.10445195285764042, 0.09431951039816733, 0.08427914867138386, 0.07433003087398471, 0.06447132780729481, 0.05470221780815798, 0.04502188668045681, 0.03542952762725626, 0.02592434118355902, 0.016505535149677897, 0.007172324525207996, 0.002076068556395416, 0.01124041489264993, 0.020321478276286276, 0.029320015558905066, 0.03823677671405712, 0.047072504899748346, 0.055827936520377874, 0.06450380128811228, 0.07310082228370374, 0.08161971601675366, 0.09006119248542921, 0.09842595523563824, 0.10671470141966466, 0.11492812185427226, 0.12306690107828067, 0.13113171740961627, 0.13912324300184675, 0.14704214390020087, 0.15488908009707947, 0.16266470558706136, 0.17036966842141021, 0.17800461076208562, 0.18557016893526312, 0.19306697348436852, 0.20049564922262997, 0.20785681528515165, 0.2151510851805155, 0.22237906684191355, 0.22954136267781522, 0.236638569622174, 0.2436712791841793, 0.2506400774975541, 0.25754554536940644, 0.26438825832863566, 0.27116878667389954, 0.277887695521145, 0.2845455448507075, 0.29114288955398115, 0.297680279479667, 0.30415825947959774, 0.3105773694541497, 0.31693814439723855, 0.3232411144409091, 0.329486804899518, 0.33567573631351544, 0.34180842449282955, 0.3478853805598551, 0.35390711099205385, 0.3598741176641649, 0.3657868978900337, 0.3716459444640604, 0.37745174570227025, 0.3832047854830132, 0.38890554328729077, 0.394554494238719, 0.40015210914312693, 0.4056988545277941, 0.4111951926803349, 0.4166415816872263, 0.42203847547198625, 0.427386323833006, 0.4326855724810382, 0.4379366630763436, 0.44314003326550133, 0.44829611671788405, 0.4534053431618007, 0.4584681384203133, 0.46348492444672584, 0.4684561193597512, 0.4733821374783599, 0.4782633893563095, 0.48310028181636355, 0.4878932179841967, 0.49264259732199267, 0.49734881566173783, 0.5020122652382107, 0.5066333347216725, 0.5112124092502606, 0.5157498704620878, 0.5202460965270479, 0.5247014621783364, 0.5291163387436804, 0.5334910941762872, 0.5378260930855104, 0.542121696767239, 0.5463782632340078, 0.5505961472448369, 0.5547757003347978, 0.5589172708443122, 0.5630212039481834, 0.5670878416843661, 0.5711175229824708, 0.5751105836920136, 0.579067356610407, 0.5829881715106945, 0.5868733551690379, 0.5907232313919508, 0.5945381210432856, 0.5983183420709762, 0.6020642095335369, 0.6057760356263202, 0.6094541297075371, 0.6130987983240399, 0.6167103452368703, 0.6202890714465776, 0.623835275218304, 0.6273492521066433, 0.6308312949802746, 0.6342816940463694, 0.6377007368747803, 0.6410887084220077, 0.6444458910549484, 0.6477725645744301, 0.6510690062385306, 0.654335490785686, 0.6575722904575881, 0.6607796750218745, 0.6639579117946113, 0.6671072656625732, 0.6702279991053197, 0.6733203722170715, 0.6763846427283873, 0.6794210660276446, 0.6824298951823243, 0.6854113809601027, 0.6883657718497515, 0.6912933140818471, 0.6941942516492936, 0.6970688263276577, 0.699917277695318, 0.7027398431534344, 0.7055367579457332, 0.7083082551781124, 0.7110545658380708, 0.7137759188139592, 0.7164725409140564, 0.7191446568854729, 0.7217924894328814, 0.7244162592370789, 0.727016184973378, 0.7295924833298333, 0.7321453690253, 0.7346750548273304, 0.7371817515699057, 0.739665668171009, 0.7421270116500358, 0.7445659871450494, 0.7469827979298769, 0.749377645431051, 0.7517507292445978, 0.7541022471526726, 0.7564323951400422, 0.7587413674104206, 0.761029356402654, 0.7632965528067595, 0.7655431455798178, 0.7677693219617222, 0.7699752674907833, 0.7721611660191925, 0.7743271997283456, 0.776473549144026, 0.7786003931514504, 0.7807079090101776, 0.7827962723688833, 0.7848656572799974, 0.7869162362142115, 0.7889481800748535, 0.79096165821213, 0.7929568384372422, 0.7949338870363708, 0.7968929687845354, 0.7988342469593277, 0.8007578833545188, 0.8026640382935455, 0.80455287064287, 0.8064245378252223, 0.8082791958327196, 0.8101169992398674, 0.8119381012164424, 0.8137426535402585, 0.815530806609816, 0.8173027094568369, 0.8190585097586858, 0.8207983538506771, 0.8225223867382727, 0.8242307521091659, 0.8259235923452575, 0.8276010485345223, 0.8292632604827684, 0.8309103667252883, 0.8325425045384058, 0.8341598099509168, 0.8357624177554263, 0.8373504615195829, 0.8389240735972108, 0.8404833851393403, 0.8420285261051389, 0.8435596252727424, 0.8450768102499879, 0.8465802074850491, 0.8480699422769745, 0.8495461387861313, 0.8510089200445526, 0.8524584079661919, 0.853894723357083, 0.8553179859254101, 0.8567283142914828, 0.8581258259976237, 0.8595106375179647, 0.8608828642681539, 0.8622426206149748, 0.863590019885879, 0.8649251743784303, 0.8662481953696646, 0.8675591931253637, 0.8688582769092458, 0.8701455549920719, 0.8714211346606691, 0.8726851222268726, 0.8739376230363861, 0.875178741477562, 0.876408580990101, 0.8776272440736737, 0.8788348322964625, 0.8800314463036283, 0.8812171858256964, 0.8823921496868706, 0.8835564358132685, 0.8847101412410827, 0.8858533621246691, 0.8869861937445607, 0.8881087305154075, 0.889221065993847, 0.8903232928863003, 0.8914155030566995, 0.8924977875341431, 0.893570236520484, 0.8946329393978456, 0.895685984736073, 0.8967294603001135, 0.8977634530573317, 0.898788049184758, 0.8998033340762704, 0.9008093923497119, 0.9018063078539428, 0.9027941636758291, 0.9037730421471668, 0.9047430248515446, 0.9057041926311427, 0.9066566255934707, 0.9076004031180442, 0.9085356038630006, 0.9094623057716545, 0.9103805860789942, 0.9112905213181184, 0.912192187326615, 0.9130856592528815, 0.9139710115623887, 0.914848318043886, 0.9157176518155523, 0.9165790853310892, 0.9174326903857598, 0.9182785381223725, 0.9191166990372103, 0.919947242985906, 0.9207702391892647, 0.9215857562390324, 0.9223938621036132, 0.9231946241337337, 0.9239881090680563, 0.9247743830387418, 0.9255535115769609, 0.9263255596183554, 0.9270905915084511, 0.9278486710080196, 0.9285998612983936, 0.9293442249867311, 0.9300818241112349, 0.9308127201463219, 0.9315369740077475, 0.932254646057682, 0.9329657961097415, 0.9336704834339733, 0.9343687667617955, 0.9350607042908915, 0.9357463536900614, 0.9364257721040276, 0.9370990161581972, 0.9377661419633827, 0.9384272051204767, 0.9390822607250875, 0.93973136337213, 0.9403745671603762, 0.9410119256969638, 0.9416434921018647, 0.9422693190123111, 0.9428894585871836, 0.9435039625113578, 0.9441128820000115, 0.9447162678028942, 0.9453141702085559, 0.9459066390485389, 0.9464937237015304, 0.9470754730974786, 0.9476519357216703, 0.9482231596187716, 0.9487891923968326, 0.9493500812312554, 0.9499058728687252, 0.9504566136311068, 0.9510023494193053, 0.9515431257170912, 0.9520789875948922, 0.9526099797135481, 0.9531361463280342, 0.9536575312911493, 0.9541741780571703, 0.9546861296854744, 0.9551934288441272, 0.9556961178134393, 0.95619423848949, 0.9566878323876191, 0.9571769406458867, 0.957661604028502, 0.9581418629292209, 0.9586177573747124, 0.9590893270278945, 0.9595566111912401, 0.9600196488100525, 0.9604784784757111, 0.9609331384288881, 0.961383666562735, 0.9618301004260419, 0.9622724772263656, 0.9627108338331317, 0.9631452067807068, 0.9635756322714439, 0.9640021461786992, 0.964424784049822, 0.9648435811091178, 0.9652585722607836, 0.9656697920918168, 0.9660772748748984, 0.966481054571249, 0.9668811648334593, 0.967277639008295, 0.9676705101394759, 0.9680598109704299, 0.9684455739470222, 0.9688278312202591, 0.9692066146489677, 0.9695819558024513, 0.9699538859631207, 0.9703224361291006, 0.970687637016814, 0.9710495190635418, 0.9714081124299594, 0.9717634470026508, 0.9721155523965995, 0.9724644579576561, 0.9728101927649847, 0.9731527856334865, 0.9734922651162007, 0.9738286595066851, 0.9741619968413735, 0.9744923049019126, 0.9748196112174777, 0.9751439430670668, 0.9754653274817737, 0.9757837912470421, 0.9760993609048967, 0.9764120627561562, 0.976721922862625, 0.9770289670492651, 0.9773332209063487, 0.977634709791591, 0.9779334588322636, 0.9782294929272884, 0.9785228367493135, 0.9788135147467687, 0.9791015511459035, 0.9793869699528062, 0.9796697949554048, 0.9799500497254493, 0.9802277576204763, 0.9805029417857561, 0.9807756251562211, 0.9810458304583778, 0.9813135802122006, 0.981578896733009, 0.9818418021333272, 0.9821023183247268, 0.982360467019654, 0.9826162697332379, 0.9828697477850845, 0.9831209223010533, 0.9833698142150181, 0.9836164442706117, 0.9838608330229546, 0.9841030008403682, 0.9843429679060726, 0.9845807542198685, 0.9848163795998041, 0.9850498636838269, 0.9852812259314205, 0.985510485625226, 0.9857376618726497, 0.985962773607455, 0.9861858395913409, 0.9864068784155052, 0.9866259085021946, 0.9868429481062393, 0.9870580153165751, 0.9872711280577506, 0.9874823040914213, 0.9876915610178301, 0.9878989162772733, 0.9881043871515555, 0.9883079907654286, 0.9885097440880203, 0.9887096639342472, 0.988907766966217, 0.9891040696946168, 0.9892985884800896, 0.9894913395345972], \"type\": \"scatter\", \"uid\": \"c14e278d-03e3-4dd6-86a1-b9f06af98c12\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 8.466733466933869, 16.883466933867737, 25.300200400801604, 33.71693386773547, 42.13366733466934, 50.5504008016032, 58.96713426853707, 67.38386773547094, 75.8006012024048, 84.21733466933868, 92.63406813627255, 101.05080160320641, 109.46753507014029, 117.88426853707415, 126.30100200400803, 134.7177354709419, 143.13446893787577, 151.55120240480963, 159.96793587174352, 168.38466933867738, 176.80140280561125, 185.2181362725451, 193.63486973947897, 202.05160320641284, 210.46833667334673, 218.8850701402806, 227.30180360721445, 235.71853707414832, 244.13527054108218, 252.55200400801607, 260.96873747494993, 269.3854709418838, 277.80220440881766, 286.2189378757515, 294.6356713426854, 303.05240480961925, 311.4691382765531, 319.88587174348703, 328.3026052104209, 336.71933867735476, 345.1360721442886, 353.5528056112225, 361.96953907815634, 370.3862725450902, 378.80300601202407, 387.21973947895793, 395.6364729458918, 404.05320641282566, 412.4699398797596, 420.88667334669344, 429.3034068136273, 437.72014028056117, 446.13687374749503, 454.5536072144289, 462.97034068136276, 471.3870741482966, 479.8038076152305, 488.22054108216435, 496.63727454909827, 505.0540080160321, 513.4707414829659, 521.8874749498998, 530.3042084168336, 538.7209418837675, 547.1376753507014, 555.5544088176352, 563.9711422845692, 572.387875751503, 580.8046092184369, 589.2213426853707, 597.6380761523046, 606.0548096192384, 614.4715430861723, 622.8882765531062, 631.3050100200401, 639.721743486974, 648.1384769539078, 656.5552104208417, 664.9719438877755, 673.3886773547094, 681.8054108216432, 690.2221442885772, 698.638877755511, 707.0556112224449, 715.4723446893787, 723.8890781563126, 732.3058116232465, 740.7225450901803, 749.1392785571143, 757.5560120240481, 765.972745490982, 774.3894789579158, 782.8062124248497, 791.2229458917835, 799.6396793587174, 808.0564128256513, 816.4731462925852, 824.8898797595191, 833.3066132264529, 841.7233466933868, 850.1400801603206, 858.5568136272545, 866.9735470941883, 875.3902805611223, 883.8070140280561, 892.22374749499, 900.6404809619239, 909.0572144288577, 917.4739478957916, 925.8906813627254, 934.3074148296594, 942.7241482965932, 951.1408817635271, 959.5576152304609, 967.9743486973948, 976.3910821643286, 984.8078156312625, 993.2245490981965, 1001.6412825651303, 1010.0580160320642, 1018.474749498998, 1026.8914829659318, 1035.3082164328657, 1043.7249498997996, 1052.1416833667336, 1060.5584168336673, 1068.9751503006012, 1077.391883767535, 1085.808617234469, 1094.225350701403, 1102.6420841683366, 1111.0588176352705, 1119.4755511022045, 1127.8922845691384, 1136.309018036072, 1144.725751503006, 1153.14248496994, 1161.5592184368738, 1169.9759519038078, 1178.3926853707414, 1186.8094188376754, 1195.2261523046093, 1203.6428857715432, 1212.059619238477, 1220.4763527054108, 1228.8930861723447, 1237.3098196392787, 1245.7265531062124, 1254.1432865731463, 1262.5600200400802, 1270.976753507014, 1279.393486973948, 1287.8102204408817, 1296.2269539078156, 1304.6436873747496, 1313.0604208416835, 1321.4771543086172, 1329.893887775551, 1338.310621242485, 1346.727354709419, 1355.1440881763529, 1363.5608216432865, 1371.9775551102205, 1380.3942885771544, 1388.8110220440883, 1397.227755511022, 1405.644488977956, 1414.0612224448898, 1422.4779559118238, 1430.8946893787574, 1439.3114228456914, 1447.7281563126253, 1456.1448897795592, 1464.5616232464931, 1472.9783567134268, 1481.3950901803607, 1489.8118236472947, 1498.2285571142286, 1506.6452905811623, 1515.0620240480962, 1523.47875751503, 1531.895490981964, 1540.312224448898, 1548.7289579158316, 1557.1456913827656, 1565.5624248496995, 1573.9791583166334, 1582.395891783567, 1590.812625250501, 1599.229358717435, 1607.6460921843689, 1616.0628256513025, 1624.4795591182365, 1632.8962925851704, 1641.3130260521043, 1649.7297595190382, 1658.146492985972, 1666.5632264529058, 1674.9799599198398, 1683.3966933867737, 1691.8134268537074, 1700.2301603206413, 1708.6468937875752, 1717.0636272545091, 1725.480360721443, 1733.8970941883767, 1742.3138276553107, 1750.7305611222446, 1759.1472945891785, 1767.5640280561122, 1775.980761523046, 1784.39749498998, 1792.814228456914, 1801.2309619238479, 1809.6476953907816, 1818.0644288577155, 1826.4811623246494, 1834.8978957915833, 1843.314629258517, 1851.731362725451, 1860.1480961923849, 1868.5648296593188, 1876.9815631262525, 1885.3982965931864, 1893.8150300601203, 1902.2317635270542, 1910.6484969939881, 1919.0652304609218, 1927.4819639278558, 1935.8986973947897, 1944.3154308617236, 1952.7321643286573, 1961.1488977955912, 1969.5656312625251, 1977.982364729459, 1986.399098196393, 1994.8158316633267, 2003.2325651302606, 2011.6492985971945, 2020.0660320641284, 2028.4827655310621, 2036.899498997996, 2045.31623246493, 2053.732965931864, 2062.149699398798, 2070.5664328657317, 2078.983166332666, 2087.3998997995996, 2095.8166332665332, 2104.2333667334674, 2112.650100200401, 2121.066833667335, 2129.483567134269, 2137.9003006012026, 2146.3170340681368, 2154.7337675350705, 2163.150501002004, 2171.5672344689383, 2179.983967935872, 2188.400701402806, 2196.81743486974, 2205.2341683366735, 2213.6509018036077, 2222.0676352705414, 2230.484368737475, 2238.901102204409, 2247.317835671343, 2255.734569138277, 2264.1513026052107, 2272.5680360721444, 2280.9847695390786, 2289.4015030060123, 2297.8182364729464, 2306.23496993988, 2314.651703406814, 2323.068436873748, 2331.4851703406816, 2339.901903807616, 2348.3186372745495, 2356.735370741483, 2365.1521042084173, 2373.568837675351, 2381.9855711422847, 2390.402304609219, 2398.8190380761525, 2407.2357715430867, 2415.6525050100204, 2424.069238476954, 2432.485971943888, 2440.902705410822, 2449.319438877756, 2457.7361723446897, 2466.1529058116234, 2474.5696392785576, 2482.9863727454913, 2491.403106212425, 2499.819839679359, 2508.236573146293, 2516.653306613227, 2525.0700400801607, 2533.4867735470943, 2541.9035070140285, 2550.320240480962, 2558.7369739478963, 2567.15370741483, 2575.5704408817637, 2583.987174348698, 2592.4039078156316, 2600.8206412825652, 2609.2373747494994, 2617.654108216433, 2626.0708416833672, 2634.487575150301, 2642.9043086172346, 2651.3210420841688, 2659.7377755511025, 2668.1545090180366, 2676.5712424849703, 2684.987975951904, 2693.404709418838, 2701.821442885772, 2710.238176352706, 2718.6549098196397, 2727.0716432865734, 2735.4883767535075, 2743.905110220441, 2752.321843687375, 2760.738577154309, 2769.1553106212427, 2777.572044088177, 2785.9887775551106, 2794.4055110220443, 2802.8222444889784, 2811.238977955912, 2819.6557114228463, 2828.07244488978, 2836.4891783567136, 2844.905911823648, 2853.3226452905815, 2861.739378757515, 2870.1561122244493, 2878.572845691383, 2886.989579158317, 2895.406312625251, 2903.8230460921845, 2912.2397795591187, 2920.6565130260524, 2929.0732464929865, 2937.48997995992, 2945.906713426854, 2954.323446893788, 2962.7401803607218, 2971.156913827656, 2979.5736472945896, 2987.9903807615233, 2996.4071142284574, 3004.823847695391, 3013.240581162325, 3021.657314629259, 3030.0740480961927, 3038.490781563127, 3046.9075150300605, 3055.324248496994, 3063.7409819639283, 3072.157715430862, 3080.574448897796, 3088.99118236473, 3097.4079158316636, 3105.8246492985977, 3114.2413827655314, 3122.658116232465, 3131.0748496993992, 3139.491583166333, 3147.908316633267, 3156.3250501002008, 3164.7417835671345, 3173.1585170340686, 3181.5752505010023, 3189.9919839679364, 3198.40871743487, 3206.825450901804, 3215.242184368738, 3223.6589178356717, 3232.0756513026054, 3240.4923847695395, 3248.909118236473, 3257.3258517034074, 3265.742585170341, 3274.1593186372747, 3282.576052104209, 3290.9927855711426, 3299.4095190380767, 3307.8262525050104, 3316.242985971944, 3324.6597194388783, 3333.076452905812, 3341.493186372746, 3349.90991983968, 3358.3266533066135, 3366.7433867735476, 3375.1601202404813, 3383.576853707415, 3391.993587174349, 3400.410320641283, 3408.827054108217, 3417.2437875751507, 3425.6605210420844, 3434.0772545090185, 3442.493987975952, 3450.9107214428864, 3459.32745490982, 3467.7441883767538, 3476.160921843688, 3484.5776553106216, 3492.9943887775553, 3501.4111222444894, 3509.827855711423, 3518.2445891783573, 3526.661322645291, 3535.0780561122247, 3543.494789579159, 3551.9115230460925, 3560.3282565130266, 3568.7449899799603, 3577.161723446894, 3585.578456913828, 3593.995190380762, 3602.411923847696, 3610.8286573146297, 3619.2453907815634, 3627.6621242484975, 3636.0788577154312, 3644.495591182365, 3652.912324649299, 3661.3290581162328, 3669.745791583167, 3678.1625250501006, 3686.5792585170343, 3694.9959919839685, 3703.412725450902, 3711.8294589178363, 3720.24619238477, 3728.6629258517037, 3737.079659318638, 3745.4963927855715, 3753.913126252505, 3762.3298597194394, 3770.746593186373, 3779.163326653307, 3787.580060120241, 3795.9967935871746, 3804.4135270541087, 3812.8302605210424, 3821.2469939879766, 3829.6637274549103, 3838.080460921844, 3846.497194388778, 3854.913927855712, 3863.330661322646, 3871.7473947895796, 3880.1641282565133, 3888.5808617234475, 3896.997595190381, 3905.414328657315, 3913.831062124249, 3922.2477955911827, 3930.664529058117, 3939.0812625250505, 3947.497995991984, 3955.9147294589184, 3964.331462925852, 3972.748196392786, 3981.16492985972, 3989.5816633266536, 3997.9983967935877, 4006.4151302605214, 4014.831863727455, 4023.2485971943893, 4031.665330661323, 4040.082064128257, 4048.498797595191, 4056.9155310621245, 4065.3322645290586, 4073.7489979959923, 4082.1657314629265, 4090.58246492986, 4098.999198396794, 4107.415931863728, 4115.832665330662, 4124.249398797596, 4132.66613226453, 4141.082865731463, 4149.499599198397, 4157.9163326653315, 4166.333066132265, 4174.749799599199, 4183.166533066133, 4191.583266533066, 4200.0], \"y\": [0.9904853294237563, 0.9718696980278045, 0.9534273471244143, 0.9351566637610911, 0.9170560499992384, 0.8991239227744043, 0.881358713757828, 0.8637588692192744, 0.8463228498911461, 0.8290491308338619, 0.8119362013024847, 0.7949825646145947, 0.7781867380193899, 0.761547252568006, 0.7450626529850444, 0.7287314975412935, 0.7125523579276372, 0.6965238191301364, 0.6806444793062723, 0.6649129496623425, 0.6493278543319996, 0.633887830255917, 0.6185915270625788, 0.6034376069501759, 0.588424744569604, 0.5735516269085494, 0.558816953176654, 0.5442194346917493, 0.5297577947671488, 0.5154307685999917, 0.5012371031606218, 0.487175557083001, 0.4732449005561392, 0.4594439152165357, 0.4457713940416237, 0.43222614124420344, 0.41880697216786067, 0.40551271318335713, 0.3923422015859863, 0.37929428549388433, 0.3663678237472865, 0.35356168580872316, 0.34087475166414394, 0.3283059117249618, 0.31585406673100946, 0.30351812765439923, 0.2912970156042778, 0.2791896617324665, 0.2671950071399811, 0.25531200278442223, 0.24353960938822583, 0.23187679734776934, 0.22032254664332318, 0.20887584674984128, 0.19753569654858105, 0.1863011042395457, 0.17517108725474384, 0.16414467217225304, 0.1532208946310869, 0.14239879924685117, 0.13167743952818833, 0.12105587779399718, 0.11053318509142374, 0.10010844111461714, 0.08978073412423893, 0.07954916086772479, 0.06941282650028513, 0.059370844506643206, 0.049422336623502705, 0.03956643276273297, 0.029802270935274766, 0.020128997175748342, 0.010545765467768975, 0.0010517376699534786, 0.008353916557381824, 0.017672019824843455, 0.026903387085903452, 0.03604882570817636, 0.04510913554403062, 0.05408510900054164, 0.06297753110879722, 0.07178717959255332, 0.0805148249362555, 0.08916123045242252, 0.09772715234840723, 0.106213339792532, 0.11462053497961178, 0.12294947319586447, 0.13120088288321952, 0.1393754857030266, 0.14747399659917093, 0.15549712386060277, 0.16344556918328224, 0.17132002773155086, 0.17912118819892808, 0.18684973286834583, 0.19450633767181869, 0.20209167224956182, 0.20960640000855557, 0.21705117818056807, 0.22442665787963478, 0.23173348415900552, 0.23897229606755965, 0.24614372670569662, 0.2532484032807071, 0.2602869471616269, 0.2672599739335829, 0.27416809345163007, 0.28101190989408964, 0.28779202181539054, 0.2945090221984169, 0.3011634985063718, 0.3077560327341544, 0.3142872014592625, 0.32075757589221787, 0.3271677219265253, 0.333518200188164, 0.33980956608462043, 0.34604236985346304, 0.3522171566104656, 0.3583344663972835, 0.364394834228684, 0.3703987901393394, 0.37634685923018274, 0.3822395617143325, 0.38807741296259046, 0.39386092354851554, 0.39959059929307816, 0.4052669413088986, 0.4108904460440742, 0.41646160532559817, 0.4219809064023742, 0.42744883198783123, 0.43286586030214114, 0.4382324651140428, 0.44354911578227796, 0.448816277296642, 0.45403441031864933, 0.4592039712218242, 0.46432541213161416, 0.46939918096493227, 0.47442572146933293, 0.4794054732618195, 0.4843388718672942, 0.48922634875664905, 0.4940683313845009, 0.498865243226577, 0.5036175038167512, 0.508325528783737, 0.5129897298874373, 0.5176105150549566, 0.5221882884162783, 0.5267234503396092, 0.531216397466396, 0.5356675227460146, 0.5400772154701371, 0.5444458613067795, 0.5487738423340313, 0.5530615370734723, 0.5573093205232771, 0.5615175641910126, 0.5656866361261299, 0.5698169009521526, 0.5739087198985682, 0.5779624508324192, 0.5819784482896025, 0.5859570635058774, 0.5898986444475836, 0.5938035358420741, 0.5976720792078652, 0.6015046128845052, 0.6053014720621652, 0.6090629888109547, 0.6127894921099639, 0.6164813078760366, 0.6201387589922733, 0.6237621653362723, 0.6273518438081037, 0.630908108358027, 0.6344312700139476, 0.6379216369086202, 0.6413795143065971, 0.6448052046309263, 0.6481990074896016, 0.6515612197017658, 0.6548921353236707, 0.6581920456743942, 0.6614612393613193, 0.6647000023053756, 0.6679086177660456, 0.6710873663661382, 0.6742365261163314, 0.6773563724394879, 0.6804471781947424, 0.6835092137013661, 0.6865427467624081, 0.6895480426881181, 0.6925253643191494, 0.695474972049547, 0.6983971238495218, 0.7012920752880116, 0.7041600795550339, 0.707001387483829, 0.709816247572798, 0.7126049060072365, 0.7153676066808647, 0.7181045912171594, 0.7208160989904857, 0.7235023671470324, 0.7261636306255523, 0.7288001221779106, 0.7314120723894402, 0.7339997096991094, 0.7365632604195003, 0.7391029487566023, 0.7416189968294207, 0.7441116246894033, 0.7465810503396856, 0.7490274897541577, 0.7514511568963523, 0.7538522637381592, 0.7562310202783623, 0.7585876345610076, 0.7609223126935978, 0.763235258865118, 0.7655266753638947, 0.7677967625952871, 0.7700457190992147, 0.7722737415675212, 0.7744810248611774, 0.7766677620273233, 0.7788341443161517, 0.7809803611976349, 0.783106600378096, 0.7852130478166249, 0.7872998877413424, 0.7893673026655128, 0.7914154734035059, 0.7934445790866116, 0.7954547971787057, 0.7974463034917716, 0.7994192722012756, 0.8013738758614016, 0.8033102854201413, 0.8052286702342455, 0.8071291980840363, 0.8090120351880803, 0.810877346217727, 0.8127252943115093, 0.8145560410894133, 0.816369746667012, 0.818166569669469, 0.8199466672454128, 0.8217101950806798, 0.8234573074119306, 0.8251881570401401, 0.8269028953439607, 0.8286016722929616, 0.8302846364607459, 0.8319519350379437, 0.833603713845086, 0.8352401173453576, 0.836861288657232, 0.8384673695669883, 0.8400585005411115, 0.8416348207385782, 0.8431964680230267, 0.8447435789748147, 0.8462762889029645, 0.8477947318569969, 0.8492990406386554, 0.8507893468135203, 0.852265780722516, 0.8537284714933101, 0.8551775470516068, 0.8566131341323353, 0.8580353582907342, 0.8594443439133316, 0.860840214228825, 0.8622230913188574, 0.8635930961286962, 0.8649503484778094, 0.8662949670703454, 0.8676270695055153, 0.8689467722878773, 0.8702541908375265, 0.8715494395001896, 0.8728326315572246, 0.8741038792355296, 0.8753632937173568, 0.8766109851500373, 0.8778470626556144, 0.8790716343403866, 0.8802848073043632, 0.8814866876506312, 0.8826773804946344, 0.8838569899733674, 0.8850256192544828, 0.8861833705453142, 0.8873303451018156, 0.8884666432374169, 0.8895923643317968, 0.8907076068395756, 0.8918124682989244, 0.8929070453400971, 0.8939914336938809, 0.8950657281999689, 0.8961300228152549, 0.8971844106220503, 0.8982289838362261, 0.8992638338152764, 0.9002890510663101, 0.9013047252539652, 0.902310945208252, 0.9033077989323207, 0.90429537361016, 0.9052737556142199, 0.9062430305129676, 0.9072032830783703, 0.9081545972933094, 0.9090970563589259, 0.9100307427018969, 0.9109557379816443, 0.9118721230974772, 0.9127799781956668, 0.9136793826764564, 0.914570415201005, 0.9154531536982677, 0.9163276753718109, 0.9171940567065644, 0.9180523734755109, 0.9189027007463129, 0.919745112887878, 0.9205796835768636, 0.9214064858041199, 0.9222255918810743, 0.923037073446055, 0.923841001470557, 0.9246374462654493, 0.9254264774871233, 0.9262081641435858, 0.9269825746004944, 0.9277497765871361, 0.9285098372023511, 0.9292628229204015, 0.9300087995967847, 0.9307478324739933, 0.9314799861872208, 0.9322053247700153, 0.9329239116598788, 0.9336358097038162, 0.9343410811638316, 0.9350397877223735, 0.9357319904877297, 0.9364177499993718, 0.9370971262332497, 0.9377701786070373, 0.9384369659853289, 0.9390975466847877, 0.939751978479246, 0.9404003186047579, 0.9410426237646055, 0.9416789501342574, 0.9423093533662829, 0.9429338885952181, 0.9435526104423888, 0.9441655730206873, 0.9447728299393049, 0.9453744343084209, 0.9459704387438472, 0.9465608953716306, 0.9471458558326107, 0.9477253712869373, 0.9482994924185448, 0.9488682694395842, 0.9494317520948152, 0.9499899896659568, 0.9505430309759975, 0.9510909243934648, 0.9516337178366562, 0.9521714587778295, 0.9527041942473551, 0.9532319708378288, 0.9537548347081476, 0.9542728315875453, 0.9547860067795935, 0.9552944051661625, 0.9557980712113476, 0.9562970489653575, 0.9567913820683666, 0.9572811137543323, 0.9577662868547759, 0.9582469438025286, 0.9587231266354426, 0.9591948770000679, 0.9596622361552944, 0.960125244975961, 0.9605839439564292, 0.9610383732141261, 0.9614885724930524, 0.9619345811672582, 0.9623764382442868, 0.9628141823685865, 0.9632478518248904, 0.9636774845415639, 0.9641031180939232, 0.9645247897075208, 0.964942536261401, 0.9653563942913262, 0.9657663999929714, 0.9661725892250904, 0.9665749975126516, 0.9669736600499456, 0.9673686117036621, 0.9677598870159407, 0.9681475202073911, 0.968531545180086, 0.9689119955205264, 0.9692889045025792, 0.9696623050903868, 0.9700322299412503, 0.9703987114084861, 0.9707617815442551, 0.9711214721023657, 0.9714778145410516, 0.9718308400257228, 0.9721805794316912, 0.972527063346871, 0.9728703220744538, 0.9732103856355592, 0.9735472837718602, 0.9738810459481844, 0.9742117013550908, 0.9745392789114233, 0.9748638072668393, 0.9751853148043158, 0.9755038296426315, 0.9758193796388263, 0.9761319923906371, 0.9764416952389126, 0.976748515270003, 0.9770524793181303, 0.9773536139677343, 0.9776519455557984, 0.977947500174152, 0.9782403036717534, 0.9785303816569504, 0.9788177594997193, 0.9791024623338845, 0.9793845150593166, 0.9796639423441094, 0.9799407686267383, 0.980215018118197, 0.9804867148041154, 0.980755882446857, 0.9810225445875974, 0.9812867245483831, 0.9815484454341712, 0.9818077301348503, 0.982064601327242, 0.9823190814770849, 0.9825711928409987, 0.9828209574684311, 0.9830683972035864, 0.9833135336873358, 0.9835563883591096, 0.9837969824587735, 0.9840353370284847, 0.9842714729145335, 0.9845054107691658, 0.9847371710523896, 0.9849667740337643, 0.9851942397941734, 0.985419588227581, 0.9856428390427715, 0.9858640117650734, 0.986083125738067, 0.9863002001252759, 0.9865152539118434, 0.9867283059061928, 0.9869393747416723, 0.9871484788781846, 0.9873556366038017, 0.9875608660363638, 0.9877641851250646, 0.9879656116520206, 0.9881651632338262, 0.9883628573230949, 0.9885587112099856, 0.9887527420237143, 0.9889449667340527, 0.9891354021528125, 0.989324064935315, 0.9895109715818485, 0.9896961384391111, 0.9898795817016404, 0.9900613174132296, 0.9902413614683312, 0.990419729613447, 0.9905964374485048], \"type\": \"scatter\", \"uid\": \"b3d0ade2-a60e-41a2-83e0-ee8087faa9ef\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 8.667134268537074, 17.284268537074148, 25.901402805611223, 34.51853707414829, 43.13567134268536, 51.75280561122244, 60.369939879759514, 68.98707414829659, 77.60420841683366, 86.22134268537073, 94.8384769539078, 103.45561122244489, 112.07274549098196, 120.68987975951903, 129.3070140280561, 137.9241482965932, 146.54128256513027, 155.15841683366733, 163.77555110220442, 172.39268537074148, 181.00981963927856, 189.62695390781562, 198.2440881763527, 206.8612224448898, 215.47835671342685, 224.09549098196393, 232.712625250501, 241.32975951903808, 249.94689378757514, 258.5640280561122, 267.1811623246493, 275.79829659318636, 284.41543086172345, 293.03256513026054, 301.64969939879757, 310.26683366733465, 318.88396793587174, 327.5011022044088, 336.11823647294585, 344.73537074148294, 353.35250501002, 361.9696392785571, 370.5867735470942, 379.2039078156312, 387.8210420841683, 396.4381763527054, 405.0553106212425, 413.67244488977957, 422.2895791583166, 430.9067134268537, 439.52384769539077, 448.14098196392786, 456.7581162324649, 465.375250501002, 473.99238476953906, 482.60951903807614, 491.22665330661323, 499.84378757515026, 508.46092184368734, 517.0780561122243, 525.6951903807615, 534.3123246492985, 542.9294589178356, 551.5465931863727, 560.1637274549097, 568.7808617234468, 577.3979959919839, 586.015130260521, 594.632264529058, 603.2493987975951, 611.8665330661322, 620.4836673346692, 629.1008016032064, 637.7179358717434, 646.3350701402804, 654.9522044088176, 663.5693386773546, 672.1864729458916, 680.8036072144288, 689.4207414829658, 698.037875751503, 706.65501002004, 715.272144288577, 723.8892785571142, 732.5064128256512, 741.1235470941883, 749.7406813627254, 758.3578156312624, 766.9749498997995, 775.5920841683366, 784.2092184368737, 792.8263527054107, 801.4434869739478, 810.0606212424849, 818.6777555110219, 827.2948897795591, 835.9120240480961, 844.5291583166331, 853.1462925851703, 861.7634268537073, 870.3805611222443, 878.9976953907815, 887.6148296593185, 896.2319639278556, 904.8490981963927, 913.4662324649297, 922.0833667334668, 930.7005010020039, 939.317635270541, 947.934769539078, 956.5519038076151, 965.1690380761522, 973.7861723446892, 982.4033066132264, 991.0204408817634, 999.6375751503004, 1008.2547094188376, 1016.8718436873746, 1025.4889779559117, 1034.1061122244487, 1042.723246492986, 1051.340380761523, 1059.95751503006, 1068.574649298597, 1077.191783567134, 1085.8089178356713, 1094.4260521042083, 1103.0431863727454, 1111.6603206412824, 1120.2774549098194, 1128.8945891783567, 1137.5117234468937, 1146.1288577154307, 1154.7459919839678, 1163.3631262525048, 1171.980260521042, 1180.597394789579, 1189.214529058116, 1197.8316633266531, 1206.4487975951902, 1215.0659318637274, 1223.6830661322645, 1232.3002004008015, 1240.9173346693385, 1249.5344689378755, 1258.1516032064128, 1266.7687374749498, 1275.3858717434869, 1284.003006012024, 1292.620140280561, 1301.237274549098, 1309.8544088176352, 1318.4715430861722, 1327.0886773547093, 1335.7058116232463, 1344.3229458917833, 1352.9400801603206, 1361.5572144288576, 1370.1743486973946, 1378.7914829659317, 1387.4086172344687, 1396.025751503006, 1404.642885771543, 1413.26002004008, 1421.877154308617, 1430.494288577154, 1439.1114228456913, 1447.7285571142284, 1456.3456913827654, 1464.9628256513024, 1473.5799599198394, 1482.1970941883767, 1490.8142284569137, 1499.4313627254508, 1508.0484969939878, 1516.6656312625248, 1525.282765531062, 1533.899899799599, 1542.5170340681361, 1551.1341683366732, 1559.7513026052102, 1568.3684368737474, 1576.9855711422845, 1585.6027054108215, 1594.2198396793585, 1602.8369739478956, 1611.4541082164328, 1620.0712424849698, 1628.6883767535069, 1637.305511022044, 1645.922645290581, 1654.5397795591182, 1663.1569138276552, 1671.7740480961922, 1680.3911823647293, 1689.0083166332663, 1697.6254509018033, 1706.2425851703406, 1714.8597194388776, 1723.4768537074146, 1732.0939879759517, 1740.7111222444887, 1749.328256513026, 1757.945390781563, 1766.5625250501, 1775.179659318637, 1783.796793587174, 1792.4139278557113, 1801.0310621242484, 1809.6481963927854, 1818.2653306613224, 1826.8824649298595, 1835.4995991983967, 1844.1167334669337, 1852.7338677354708, 1861.3510020040078, 1869.9681362725448, 1878.585270541082, 1887.202404809619, 1895.8195390781561, 1904.4366733466932, 1913.0538076152302, 1921.6709418837675, 1930.2880761523045, 1938.9052104208415, 1947.5223446893785, 1956.1394789579156, 1964.7566132264528, 1973.3737474949899, 1981.9908817635269, 1990.608016032064, 1999.225150300601, 2007.8422845691382, 2016.4594188376752, 2025.0765531062123, 2033.6936873747493, 2042.3108216432863, 2050.9279559118236, 2059.5450901803606, 2068.1622244488976, 2076.779358717435, 2085.396492985972, 2094.013627254509, 2102.630761523046, 2111.2478957915832, 2119.8650300601203, 2128.4821643286573, 2137.0992985971943, 2145.7164328657313, 2154.3335671342684, 2162.950701402806, 2171.567835671343, 2180.18496993988, 2188.802104208417, 2197.419238476954, 2206.036372745491, 2214.653507014028, 2223.270641282565, 2231.887775551102, 2240.504909819639, 2249.122044088176, 2257.7391783567136, 2266.3563126252507, 2274.9734468937877, 2283.5905811623247, 2292.2077154308618, 2300.824849699399, 2309.441983967936, 2318.059118236473, 2326.67625250501, 2335.293386773547, 2343.9105210420844, 2352.5276553106214, 2361.1447895791584, 2369.7619238476955, 2378.3790581162325, 2386.9961923847695, 2395.6133266533066, 2404.2304609218436, 2412.8475951903806, 2421.4647294589176, 2430.081863727455, 2438.698997995992, 2447.316132264529, 2455.933266533066, 2464.5504008016032, 2473.1675350701403, 2481.7846693386773, 2490.4018036072143, 2499.0189378757514, 2507.6360721442884, 2516.253206412826, 2524.870340681363, 2533.4874749499, 2542.104609218437, 2550.721743486974, 2559.338877755511, 2567.956012024048, 2576.573146292585, 2585.190280561122, 2593.807414829659, 2602.424549098196, 2611.0416833667337, 2619.6588176352707, 2628.2759519038077, 2636.8930861723447, 2645.5102204408818, 2654.127354709419, 2662.744488977956, 2671.361623246493, 2679.97875751503, 2688.595891783567, 2697.2130260521044, 2705.8301603206414, 2714.4472945891785, 2723.0644288577155, 2731.6815631262525, 2740.2986973947895, 2748.9158316633266, 2757.5329659318636, 2766.1501002004006, 2774.7672344689377, 2783.384368737475, 2792.001503006012, 2800.618637274549, 2809.2357715430862, 2817.8529058116233, 2826.4700400801603, 2835.0871743486973, 2843.7043086172343, 2852.3214428857714, 2860.9385771543084, 2869.555711422846, 2878.172845691383, 2886.78997995992, 2895.407114228457, 2904.024248496994, 2912.641382765531, 2921.258517034068, 2929.875651302605, 2938.492785571142, 2947.109919839679, 2955.727054108216, 2964.3441883767537, 2972.9613226452907, 2981.5784569138277, 2990.1955911823648, 2998.812725450902, 3007.429859719439, 3016.046993987976, 3024.664128256513, 3033.28126252505, 3041.898396793587, 3050.5155310621244, 3059.1326653306614, 3067.7497995991985, 3076.3669338677355, 3084.9840681362725, 3093.6012024048096, 3102.2183366733466, 3110.8354709418836, 3119.4526052104206, 3128.0697394789577, 3136.686873747495, 3145.304008016032, 3153.921142284569, 3162.5382765531062, 3171.1554108216433, 3179.7725450901803, 3188.3896793587173, 3197.0068136272544, 3205.6239478957914, 3214.2410821643284, 3222.858216432866, 3231.475350701403, 3240.09248496994, 3248.709619238477, 3257.326753507014, 3265.943887775551, 3274.561022044088, 3283.178156312625, 3291.795290581162, 3300.412424849699, 3309.0295591182366, 3317.6466933867737, 3326.2638276553107, 3334.8809619238477, 3343.4980961923848, 3352.115230460922, 3360.732364729459, 3369.349498997996, 3377.966633266533, 3386.58376753507, 3395.200901803607, 3403.8180360721444, 3412.4351703406815, 3421.0523046092185, 3429.6694388777555, 3438.2865731462925, 3446.9037074148296, 3455.5208416833666, 3464.1379759519036, 3472.7551102204407, 3481.3722444889777, 3489.989378757515, 3498.606513026052, 3507.2236472945892, 3515.8407815631263, 3524.4579158316633, 3533.0750501002003, 3541.6921843687373, 3550.3093186372744, 3558.9264529058114, 3567.5435871743484, 3576.160721442886, 3584.777855711423, 3593.39498997996, 3602.012124248497, 3610.629258517034, 3619.246392785571, 3627.863527054108, 3636.480661322645, 3645.097795591182, 3653.714929859719, 3662.3320641282567, 3670.9491983967937, 3679.5663326653307, 3688.1834669338677, 3696.800601202405, 3705.417735470942, 3714.034869739479, 3722.652004008016, 3731.269138276553, 3739.88627254509, 3748.503406813627, 3757.1205410821644, 3765.7376753507015, 3774.3548096192385, 3782.9719438877755, 3791.5890781563126, 3800.2062124248496, 3808.8233466933866, 3817.4404809619236, 3826.0576152304607, 3834.6747494989977, 3843.291883767535, 3851.909018036072, 3860.5261523046092, 3869.1432865731463, 3877.7604208416833, 3886.3775551102203, 3894.9946893787574, 3903.6118236472944, 3912.2289579158314, 3920.8460921843684, 3929.463226452906, 3938.080360721443, 3946.69749498998, 3955.314629258517, 3963.931763527054, 3972.548897795591, 3981.166032064128, 3989.783166332665, 3998.400300601202, 4007.017434869739, 4015.6345691382767, 4024.2517034068137, 4032.8688376753507, 4041.4859719438878, 4050.103106212425, 4058.720240480962, 4067.337374749499, 4075.954509018036, 4084.571643286573, 4093.18877755511, 4101.805911823647, 4110.423046092184, 4119.040180360721, 4127.6573146292585, 4136.274448897795, 4144.891583166333, 4153.50871743487, 4162.125851703407, 4170.742985971944, 4179.360120240481, 4187.977254509018, 4196.594388777555, 4205.211523046092, 4213.828657314629, 4222.445791583166, 4231.062925851703, 4239.68006012024, 4248.297194388778, 4256.914328657314, 4265.531462925852, 4274.1485971943885, 4282.765731462926, 4291.3828657314625, 4300.0], \"y\": [0.9914742144860504, 0.9724174669257006, 0.9535423092671877, 0.9348470111579248, 0.9163298587336861, 0.8979891544614931, 0.8798232169839937, 0.8618303809653276, 0.844008996938459, 0.8263574311539632, 0.8088740654302558, 0.7915572970052476, 0.7744055383894146, 0.7574172172202667, 0.7405907761182031, 0.7239246725437432, 0.7074173786561151, 0.691067381173194, 0.6748731812327737, 0.6588332942551607, 0.6429462498070782, 0.6272105914668649, 0.6116248766909607, 0.5961876766816638, 0.580897576256147, 0.5657531737167232, 0.5507530807223464, 0.5358959221613389, 0.5211803360253282, 0.506604973284388, 0.49216849776336735, 0.47786958601939933, 0.46370692722057516, 0.4496792230257771, 0.43578518746565376, 0.4220235468247313, 0.40839303952464734, 0.3948924160084972, 0.38152043862628315, 0.36827588152145485, 0.3551575305185293, 0.3421641830117852, 0.3292946478550136, 0.3165477452523233, 0.30392230664998365, 0.29141717462929906, 0.27903120280050464, 0.2667632556976729, 0.25461220867462075, 0.24257694780181005, 0.23065636976422899, 0.2188493817602477, 0.20715490140143777, 0.19557185661334442, 0.18409918553720717, 0.17273583643261436, 0.16148076758108743, 0.15033294719058166, 0.13929135330089926, 0.12835497369000204, 0.11752280578121765, 0.10679385655132934, 0.09616714243954294, 0.08564168925731974, 0.07521653209906898, 0.06489071525369217, 0.05466329211696874, 0.04453332510477903, 0.03449988556715078, 0.024562053703127695, 0.014718918476447795, 0.0049695775320250934, 0.004686862886771559, 0.014251288020054043, 0.0237245746725655, 0.03310759129406282, 0.042401198058928724, 0.051606246945027245, 0.06072358181180859, 0.06975403847766781, 0.07869844479656674, 0.08755762073392803, 0.0963323784418022, 0.10502352233332235, 0.11363184915644642, 0.1221581480669982, 0.13060320070101206, 0.13896778124638842, 0.147252656513866, 0.15545858600731854, 0.1635863219933804, 0.17163660957041083, 0.17961018673679818, 0.18750778445861616, 0.1953301267366333, 0.2030779306726852, 0.2107519065354131, 0.21835275782537744, 0.22588118133954982, 0.23333786723519145, 0.24072349909312085, 0.24803875398038222, 0.2552843025123127, 0.26246080891402124, 0.2695689310812799, 0.27660932064083554, 0.28358262301014725, 0.2904894774565532, 0.2973305171558752, 0.3041063692504641, 0.3108176549066919, 0.31746498937189616, 0.3240489820307829, 0.33057023646128936, 0.3370293504899178, 0.343426916246539, 0.3497635202186762, 0.35603974330526966, 0.3622561608699294, 0.3684133427936819, 0.3745118535272124, 0.38055225214261024, 0.38653509238462047, 0.39246092272140887, 0.3983302863948407, 0.4041437214702823, 0.4099017608859272, 0.4156049325016523, 0.42125375914740926, 0.42684875867115346, 0.4323904439863171, 0.4378793231188307, 0.44331589925369397, 0.4487006707811062, 0.4540341313421542, 0.4593167698740671, 0.4645490706550385, 0.4697315133486216, 0.47486457304770235, 0.4799487203180526, 0.48498442124146857, 0.4899721374584983, 0.4949123262107612, 0.499805440382866, 0.504651928543928, 0.5094522349886907, 0.5142067997782558, 0.5189160587804256, 0.5235804437096601, 0.5282003821666545, 0.5327762976775379, 0.5373086097327002, 0.541797733825248, 0.5462440814890941, 0.5506480603366848, 0.5550100740963665, 0.5593305226493976, 0.5636098020666072, 0.5678483046447025, 0.5720464189422343, 0.5762045298152166, 0.5803230184524076, 0.5844022624102548, 0.5884426356475065, 0.5924445085594947, 0.59640824801209, 0.6003342173753339, 0.6042227765567494, 0.6080742820343361, 0.6118890868892493, 0.6156675408381677, 0.6194099902653539, 0.6231167782544086, 0.6267882446197217, 0.6304247259376252, 0.6340265555772471, 0.637594063731074, 0.6411275774452201, 0.6446274206494083, 0.6480939141866671, 0.6515273758427429, 0.6549281203752322, 0.6582964595424371, 0.6616327021319446, 0.6649371539889353, 0.6682101180442203, 0.6714518943420125, 0.6746627800674322, 0.677843069573752, 0.6809930544093803, 0.6841130233445892, 0.6872032623979867, 0.6902640548627372, 0.6932956813325319, 0.6962984197273121, 0.6992725453187467, 0.7022183307554677, 0.7051360460880643, 0.7080259587938406, 0.7108883338013343, 0.7137234335146057, 0.7165315178372915, 0.7193128441964323, 0.7220676675660713, 0.7247962404906283, 0.7274988131080523, 0.7301756331727518, 0.7328269460783076, 0.7354529948799686, 0.7380540203169342, 0.7406302608344228, 0.7431819526055319, 0.7457093295528879, 0.7482126233700919, 0.750692063542958, 0.7531478773705533, 0.7555802899860335, 0.7579895243772825, 0.7603758014073541, 0.7627393398347194, 0.7650803563333215, 0.7673990655124383, 0.7696956799363567, 0.7719704101438589, 0.7742234646675238, 0.7764550500528433, 0.7786653708771576, 0.7808546297684086, 0.7830230274237169, 0.7851707626277793, 0.7872980322710926, 0.789405031368003, 0.7914919530745839, 0.7935589887063433, 0.7956063277557622, 0.7976341579096661, 0.7996426650664308, 0.8016320333530247, 0.8036024451418879, 0.8055540810676516, 0.8074871200436965, 0.8094017392785556, 0.8112981142921585, 0.8131764189319225, 0.81503682538869, 0.8168795042125132, 0.8187046243282896, 0.8205123530512474, 0.8223028561022846, 0.8240762976231605, 0.8258328401915436, 0.8275726448359155, 0.8292958710503331, 0.8310026768090496, 0.8326932185809973, 0.8343676513441307, 0.8360261285996348, 0.8376688023859964, 0.8392958232929424, 0.8409073404752447, 0.842503501666394, 0.8440844531921426, 0.8456503399839193, 0.8472013055921147, 0.8487374921992423, 0.8502590406329718, 0.8517660903790397, 0.8532587795940367, 0.8547372451180726, 0.8562016224873207, 0.8576520459464437, 0.8590886484608997, 0.860511561729132, 0.861920916194642, 0.8633168410579473, 0.864699464288427, 0.8660689126360519, 0.8674253116430048, 0.8687687856551891, 0.8700994578336281, 0.8714174501657558, 0.8727228834765994, 0.8740158774398566, 0.8752965505888658, 0.8765650203274724, 0.8778214029407926, 0.8790658136058723, 0.8802983664022469, 0.8815191743223989, 0.8827283492821162, 0.8839260021307522, 0.8851122426613875, 0.886287179620895, 0.8874509207199092, 0.8886035726427003, 0.8897452410569546, 0.8908760306234614, 0.891996045005707, 0.8931053868793787, 0.8942041579417771, 0.895292458921139, 0.8963703895858717, 0.8974380487536987, 0.8984955343007195, 0.8995429431703812, 0.9005803713823666, 0.9016079140413958, 0.9026256653459458, 0.903633718596885, 0.9046321662060269, 0.9056210997046021, 0.9066006097516485, 0.9075707861423231, 0.9085317178161336, 0.9094834928650917, 0.9104261985417885, 0.9113599212673941, 0.9122847466395794, 0.9132007594403634, 0.9141080436438855, 0.9150066824241038, 0.9158967581624192, 0.9167783524552292, 0.9176515461214062, 0.918516419209708, 0.9193730510061151, 0.9202215200410999, 0.9210619040968254, 0.921894280214276, 0.9227187247003199, 0.9235353131347046, 0.9243441203769854, 0.9251452205733883, 0.9259386871636073, 0.926724592887536, 0.927503009791937, 0.9282740092370465, 0.9290376619031158, 0.9297940377968905, 0.9305432062580292, 0.9312852359654595, 0.932020194943674, 0.9327481505689666, 0.9334691695756092, 0.9341833180619689, 0.9348906614965679, 0.9355912647240856, 0.9362851919713024, 0.9369725068529882, 0.9376532723777334, 0.9383275509537262, 0.9389954043944729, 0.9396568939244652, 0.9403120801847918, 0.9409610232386995, 0.9416037825770972, 0.9422404171240112, 0.9428709852419864, 0.9434955447374365, 0.9441141528659438, 0.9447268663375072, 0.9453337413217422, 0.9459348334530288, 0.9465301978356128, 0.9471198890486567, 0.9477039611512438, 0.9482824676873333, 0.9488554616906694, 0.9494229956896426, 0.949985121712106, 0.9505418912901438, 0.9510933554647961, 0.9516395647907381, 0.952180569340914, 0.9527164187111282, 0.9532471620245913, 0.9537728479364233, 0.9542935246381147, 0.9548092398619438, 0.9553200408853525, 0.9558259745352807, 0.9563270871924591, 0.9568234247956604, 0.9573150328459116, 0.9578019564106647, 0.9582842401279283, 0.9587619282103599, 0.9592350644493184, 0.9597036922188796, 0.9601678544798119, 0.9606275937835143, 0.9610829522759179, 0.9615339717013494, 0.9619806934063575, 0.9624231583435041, 0.9628614070751179, 0.9632954797770129, 0.9637254162421719, 0.9641512558843942, 0.9645730377419088, 0.9649908004809532, 0.9654045823993179, 0.9658144214298577, 0.966220355143969, 0.9666224207550335, 0.9670206551218306, 0.9674150947519159, 0.967805775804968, 0.9681927340961034, 0.96857600509916, 0.9689556239499485, 0.9693316254494744, 0.9697040440671274, 0.970072913943842, 0.9704382688952268, 0.9708001424146648, 0.9711585676763839, 0.9715135775384979, 0.9718652045460189, 0.9722134809338407, 0.9725584386296939, 0.9729001092570728, 0.9732385241381345, 0.9735737142965704, 0.9739057104604502, 0.9742345430650384, 0.9745602422555852, 0.9748828378900898, 0.9752023595420368, 0.9755188365031084, 0.9758322977858691, 0.9761427721264253, 0.9764502879870602, 0.9767548735588424, 0.9770565567642104, 0.9773553652595328, 0.9776513264376432, 0.9779444674303515, 0.9782348151109314, 0.9785223960965833, 0.9788072367508756, 0.9790893631861602, 0.9793688012659673, 0.9796455766073756, 0.9799197145833617, 0.9801912403251252, 0.980460178724393, 0.9807265544357011, 0.9809903918786549, 0.9812517152401677, 0.9815105484766781, 0.9817669153163461, 0.9820208392612282, 0.9822723435894323, 0.9825214513572514, 0.9827681854012774, 0.9830125683404943, 0.983254622578352, 0.9834943703048206, 0.9837318334984233, 0.9839670339282528, 0.9841999931559657, 0.9844307325377603, 0.984659273226333, 0.9848856361728187, 0.9851098421287108, 0.9853319116477638, 0.9855518650878774, 0.9857697226129629, 0.9859855041947916, 0.9861992296148256, 0.9864109184660317, 0.986620590154677, 0.986828263902108, 0.9870339587465132, 0.9872376935446678, 0.9874394869736628, 0.9876393575326167, 0.987837323544372, 0.9880334031571746, 0.9882276143463372, 0.9884199749158878, 0.9886105025002015, 0.9887992145656171, 0.9889861284120384, 0.9891712611745198, 0.9893546298248379, 0.9895362511730466, 0.9897161418690184, 0.9898943184039708, 0.9900707971119782, 0.9902455941714692, 0.9904187256067096, 0.9905902072892715, 0.9907600549394885, 0.9909282841278965, 0.9910949102766613, 0.9912599486609924, 0.9914234144105434, 0.9915853225107988], \"type\": \"scatter\", \"uid\": \"4dc68cb8-5569-46c6-83bf-520701e01dfc\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 8.867535070140281, 17.685070140280562, 26.502605210420842, 35.32014028056112, 44.1376753507014, 52.95521042084168, 61.77274549098196, 70.59028056112224, 79.40781563126252, 88.2253507014028, 97.04288577154308, 105.86042084168336, 114.67795591182364, 123.49549098196393, 132.31302605210422, 141.1305611222445, 149.94809619238478, 158.76563126252506, 167.58316633266534, 176.40070140280562, 185.2182364729459, 194.03577154308618, 202.85330661322647, 211.67084168336675, 220.48837675350703, 229.3059118236473, 238.1234468937876, 246.94098196392787, 255.75851703406815, 264.57605210420843, 273.39358717434874, 282.211122244489, 291.02865731462924, 299.84619238476955, 308.66372745490986, 317.4812625250501, 326.29879759519036, 335.1163326653307, 343.933867735471, 352.75140280561124, 361.5689378757515, 370.3864729458918, 379.2040080160321, 388.02154308617236, 396.8390781563126, 405.6566132264529, 414.4741482965932, 423.2916833667335, 432.10921843687373, 440.92675350701404, 449.74428857715435, 458.5618236472946, 467.37935871743485, 476.19689378757516, 485.0144288577155, 493.8319639278557, 502.649498997996, 511.4670340681363, 520.2845691382765, 529.1021042084168, 537.919639278557, 546.7371743486974, 555.5547094188377, 564.3722444889779, 573.1897795591182, 582.0073146292584, 590.8248496993988, 599.642384769539, 608.4599198396793, 617.2774549098197, 626.0949899799599, 634.9125250501002, 643.7300601202404, 652.5475951903807, 661.365130260521, 670.1826653306613, 679.0002004008015, 687.8177354709419, 696.6352705410821, 705.4528056112224, 714.2703406813627, 723.0878757515029, 731.9054108216433, 740.7229458917835, 749.5404809619238, 758.3580160320641, 767.1755511022044, 775.9930861723446, 784.8106212424849, 793.6281563126252, 802.4456913827655, 811.2632264529058, 820.080761523046, 828.8982965931864, 837.7158316633266, 846.5333667334669, 855.3509018036071, 864.1684368737474, 872.9859719438878, 881.803507014028, 890.6210420841683, 899.4385771543086, 908.2561122244489, 917.0736472945891, 925.8911823647294, 934.7087174348696, 943.52625250501, 952.3437875751503, 961.1613226452905, 969.9788577154309, 978.7963927855711, 987.6139278557114, 996.4314629258516, 1005.2489979959919, 1014.0665330661323, 1022.8840681362725, 1031.7016032064128, 1040.5191382765531, 1049.3366733466933, 1058.1542084168336, 1066.971743486974, 1075.7892785571141, 1084.6068136272545, 1093.4243486973949, 1102.241883767535, 1111.0594188376754, 1119.8769539078155, 1128.6944889779559, 1137.5120240480962, 1146.3295591182364, 1155.1470941883767, 1163.9646292585169, 1172.7821643286572, 1181.5996993987976, 1190.4172344689377, 1199.2347695390781, 1208.0523046092185, 1216.8698396793586, 1225.687374749499, 1234.5049098196394, 1243.3224448897795, 1252.1399799599199, 1260.95751503006, 1269.7750501002004, 1278.5925851703407, 1287.4101202404809, 1296.2276553106212, 1305.0451903807614, 1313.8627254509017, 1322.680260521042, 1331.4977955911822, 1340.3153306613226, 1349.132865731463, 1357.950400801603, 1366.7679358717435, 1375.5854709418838, 1384.403006012024, 1393.2205410821643, 1402.0380761523045, 1410.8556112224448, 1419.6731462925852, 1428.4906813627254, 1437.3082164328657, 1446.1257515030059, 1454.9432865731462, 1463.7608216432866, 1472.5783567134267, 1481.395891783567, 1490.2134268537075, 1499.0309619238476, 1507.848496993988, 1516.6660320641283, 1525.4835671342685, 1534.3011022044088, 1543.118637274549, 1551.9361723446893, 1560.7537074148297, 1569.5712424849698, 1578.3887775551102, 1587.2063126252503, 1596.0238476953907, 1604.841382765531, 1613.6589178356712, 1622.4764529058116, 1631.293987975952, 1640.111523046092, 1648.9290581162325, 1657.7465931863728, 1666.564128256513, 1675.3816633266533, 1684.1991983967935, 1693.0167334669338, 1701.8342685370742, 1710.6518036072143, 1719.4693386773547, 1728.2868737474948, 1737.1044088176352, 1745.9219438877756, 1754.7394789579157, 1763.557014028056, 1772.3745490981964, 1781.1920841683366, 1790.009619238477, 1798.8271543086173, 1807.6446893787574, 1816.4622244488978, 1825.279759519038, 1834.0972945891783, 1842.9148296593187, 1851.7323647294588, 1860.5498997995992, 1869.3674348697393, 1878.1849699398797, 1887.00250501002, 1895.8200400801602, 1904.6375751503006, 1913.455110220441, 1922.272645290581, 1931.0901803607214, 1939.9077154308618, 1948.725250501002, 1957.5427855711423, 1966.3603206412824, 1975.1778557114228, 1983.9953907815632, 1992.8129258517033, 2001.6304609218437, 2010.4479959919838, 2019.2655310621242, 2028.0830661322645, 2036.9006012024047, 2045.718136272545, 2054.5356713426854, 2063.353206412826, 2072.170741482966, 2080.9882765531065, 2089.805811623247, 2098.623346693387, 2107.440881763527, 2116.2584168336675, 2125.075951903808, 2133.8934869739483, 2142.711022044088, 2151.5285571142285, 2160.346092184369, 2169.1636272545093, 2177.9811623246496, 2186.79869739479, 2195.61623246493, 2204.4337675350703, 2213.2513026052106, 2222.068837675351, 2230.8863727454914, 2239.7039078156313, 2248.5214428857716, 2257.338977955912, 2266.1565130260524, 2274.9740480961927, 2283.7915831663327, 2292.609118236473, 2301.4266533066134, 2310.2441883767538, 2319.061723446894, 2327.879258517034, 2336.6967935871744, 2345.5143286573148, 2354.331863727455, 2363.1493987975955, 2371.966933867736, 2380.7844689378758, 2389.602004008016, 2398.4195390781565, 2407.237074148297, 2416.0546092184372, 2424.872144288577, 2433.6896793587175, 2442.507214428858, 2451.3247494989982, 2460.1422845691386, 2468.959819639279, 2477.777354709419, 2486.5948897795593, 2495.4124248496996, 2504.22995991984, 2513.0474949899804, 2521.8650300601203, 2530.6825651302606, 2539.500100200401, 2548.3176352705414, 2557.1351703406817, 2565.9527054108216, 2574.770240480962, 2583.5877755511024, 2592.4053106212427, 2601.222845691383, 2610.040380761523, 2618.8579158316634, 2627.6754509018037, 2636.492985971944, 2645.3105210420845, 2654.128056112225, 2662.9455911823648, 2671.763126252505, 2680.5806613226455, 2689.398196392786, 2698.215731462926, 2707.033266533066, 2715.8508016032065, 2724.668336673347, 2733.485871743487, 2742.3034068136276, 2751.120941883768, 2759.938476953908, 2768.7560120240482, 2777.5735470941886, 2786.391082164329, 2795.2086172344693, 2804.0261523046092, 2812.8436873747496, 2821.66122244489, 2830.4787575150303, 2839.2962925851707, 2848.1138276553106, 2856.931362725451, 2865.7488977955913, 2874.5664328657317, 2883.383967935872, 2892.201503006012, 2901.0190380761524, 2909.8365731462927, 2918.654108216433, 2927.4716432865735, 2936.289178356714, 2945.1067134268537, 2953.924248496994, 2962.7417835671345, 2971.559318637275, 2980.376853707415, 2989.194388777555, 2998.0119238476955, 3006.829458917836, 3015.646993987976, 3024.4645290581166, 3033.282064128257, 3042.099599198397, 3050.917134268537, 3059.7346693386776, 3068.552204408818, 3077.3697394789583, 3086.187274549098, 3095.0048096192386, 3103.822344689379, 3112.6398797595193, 3121.4574148296597, 3130.2749498997996, 3139.09248496994, 3147.9100200400803, 3156.7275551102207, 3165.545090180361, 3174.362625250501, 3183.1801603206413, 3191.9976953907817, 3200.815230460922, 3209.6327655310624, 3218.450300601203, 3227.2678356713427, 3236.085370741483, 3244.9029058116234, 3253.720440881764, 3262.537975951904, 3271.355511022044, 3280.1730460921844, 3288.990581162325, 3297.808116232465, 3306.6256513026055, 3315.443186372746, 3324.260721442886, 3333.078256513026, 3341.8957915831666, 3350.713326653307, 3359.5308617234473, 3368.348396793587, 3377.1659318637276, 3385.983466933868, 3394.8010020040083, 3403.6185370741487, 3412.4360721442886, 3421.253607214429, 3430.0711422845693, 3438.8886773547097, 3447.70621242485, 3456.52374749499, 3465.3412825651303, 3474.1588176352707, 3482.976352705411, 3491.7938877755514, 3500.611422845692, 3509.4289579158317, 3518.246492985972, 3527.0640280561124, 3535.881563126253, 3544.699098196393, 3553.516633266533, 3562.3341683366734, 3571.151703406814, 3579.969238476954, 3588.7867735470945, 3597.604308617235, 3606.421843687375, 3615.239378757515, 3624.0569138276555, 3632.874448897796, 3641.6919839679363, 3650.509519038076, 3659.3270541082165, 3668.144589178357, 3676.9621242484973, 3685.7796593186376, 3694.5971943887776, 3703.414729458918, 3712.2322645290583, 3721.0497995991986, 3729.867334669339, 3738.684869739479, 3747.5024048096193, 3756.3199398797597, 3765.1374749499, 3773.9550100200404, 3782.7725450901808, 3791.5900801603207, 3800.407615230461, 3809.2251503006014, 3818.0426853707418, 3826.860220440882, 3835.677755511022, 3844.4952905811624, 3853.312825651303, 3862.130360721443, 3870.9478957915835, 3879.765430861724, 3888.582965931864, 3897.400501002004, 3906.2180360721445, 3915.035571142285, 3923.8531062124252, 3932.670641282565, 3941.4881763527055, 3950.305711422846, 3959.1232464929863, 3967.9407815631266, 3976.7583166332665, 3985.575851703407, 3994.3933867735473, 4003.2109218436876, 4012.028456913828, 4020.845991983968, 4029.6635270541083, 4038.4810621242486, 4047.298597194389, 4056.1161322645294, 4064.9336673346697, 4073.7512024048096, 4082.56873747495, 4091.3862725450904, 4100.20380761523, 4109.021342685371, 4117.838877755511, 4126.656412825651, 4135.473947895792, 4144.291482965932, 4153.1090180360725, 4161.926553106213, 4170.744088176353, 4179.561623246494, 4188.379158316633, 4197.196693386773, 4206.014228456914, 4214.831763527054, 4223.6492985971945, 4232.466833667335, 4241.284368737475, 4250.101903807616, 4258.919438877756, 4267.736973947896, 4276.554509018037, 4285.372044088176, 4294.1895791583165, 4303.007114228457, 4311.824649298597, 4320.642184368738, 4329.459719438878, 4338.277254509018, 4347.094789579159, 4355.912324649299, 4364.729859719439, 4373.54739478958, 4382.364929859719, 4391.18246492986, 4400.0], \"y\": [0.9923591077196015, 0.9728613422061776, 0.953553668683135, 0.9344342338629883, 0.9155012025267395, 0.8967527573477185, 0.8781870987171447, 0.859802444571387, 0.8415970302209086, 0.8235691081808802, 0.8057169480034443, 0.7880388361116126, 0.770533075634787, 0.7531979862458811, 0.7360319040000294, 0.7190331811748718, 0.702200186112393, 0.6855313030623031, 0.6690249320269486, 0.6526794886077312, 0.6364934038530274, 0.6204651241075889, 0.6045931108634117, 0.5888758406120591, 0.5733118046984247, 0.5578995091759211, 0.5426374746630802, 0.5275242362015515, 0.5125583431154854, 0.49773835887228635, 0.4830628609447254, 0.4685304406743942, 0.4541397031364942, 0.43988926700594, 0.42577776442477067, 0.4118038408708531, 0.3979661550278655, 0.3842633786565477, 0.37069419646720814, 0.3572573059934725, 0.3439514174672642, 0.33077525369500216, 0.3177275499350083, 0.3048070537761074, 0.2920125250174128, 0.27934273554928235, 0.26679646923543565, 0.2543725217962214, 0.24206970069302147, 0.2298868250137831, 0.21782272535966607, 0.20587624373279545, 0.19404623342510963, 0.18233155890829011, 0.17073109572476586, 0.15924373037978, 0.14786836023450878, 0.13660389340022183, 0.12544924863347573, 0.11440335523232825, 0.1034651529335644, 0.09263359181092579, 0.08190763217432995, 0.07128624447007503, 0.06076840918201465, 0.050353116733698355, 0.0400393673914643, 0.029826171168479076, 0.01971254772971065, 0.009697526297829606, 0.00021985443997385445, 0.010040546424262553, 0.019765492314727018, 0.029395625580668105, 0.03893187059059888, 0.048375142700970986, 0.05772634834403745, 0.06698638511485933, 0.07615614185746167, 0.08523649875015249, 0.09422832739000764, 0.10313249087653353, 0.11194984389451268, 0.12068123279604359, 0.12932749568177837, 0.13788946248137057, 0.14636795503313738, 0.15476378716294525, 0.16307776476232694, 0.17131068586583675, 0.17946334072765135, 0.18753651189742437, 0.19553097429540023, 0.2034474952867974, 0.21128683475546517, 0.21904974517682252, 0.22673697169008644, 0.2343492521697953, 0.2418873172966357, 0.24935189062757812, 0.2567436886653286, 0.26406342092710466, 0.27131179001273964, 0.2784894916721221, 0.2855972148719803, 0.29263564186201374, 0.29960544824037905, 0.3065073030185409, 0.3133418686854863, 0.3201098012713166, 0.32681175041021726, 0.3334483594028138, 0.34002026527792173, 0.34652809885369174, 0.3529724847981609, 0.3593540416892125, 0.36567338207395117, 0.37193111252750044, 0.3781278337112254, 0.38426414043038815, 0.3903406216912424, 0.3963578607575695, 0.40231643520666505, 0.40821691698477824, 0.4140598724620118, 0.41984586248668543, 0.42557544243917134, 0.43124916228520205, 0.43686756662866144, 0.4424311947638584, 0.44794058072729304, 0.4533962533489172, 0.4587987363028946, 0.46414854815786755, 0.46944620242673296, 0.4746922076159318, 0.47988706727426067, 0.4850312800412049, 0.49012533969480176, 0.4951697351990374, 0.5001649507507802, 0.5051114658262574, 0.5100097552270799, 0.5148602891258154, 0.5196635331111206, 0.5244199482324297, 0.5291299910442109, 0.5337941136497893, 0.5384127637447427, 0.5429863846598745, 0.547515415403768, 0.5520002907049257, 0.5564414410534976, 0.560839292742602, 0.5651942679092449, 0.5695067845748398, 0.5737772566853319, 0.5780060941509312, 0.5821937028854598, 0.5863404848453133, 0.5904468380680441, 0.5945131567105673, 0.5985398310869948, 0.6025272477061013, 0.6064757893084228, 0.6103858349029956, 0.6142577598037361, 0.6180919356654657, 0.6218887305195859, 0.6256485088094033, 0.6293716314251121, 0.6330584557384353, 0.6367093356369269, 0.6403246215579409, 0.6439046605222691, 0.6474497961674501, 0.6509603687807546, 0.654436715331848, 0.6578791695051355, 0.6612880617317913, 0.6646637192214764, 0.6680064659937452, 0.6713166229091486, 0.6745945077000313, 0.677840435001031, 0.6810547163792784, 0.6842376603643041, 0.6873895724776539, 0.6905107552622134, 0.6936015083112502, 0.6966621282971694, 0.6996929089999913, 0.7026941413355494, 0.7056661133834163, 0.7086091104145539, 0.7115234149186966, 0.7144093066314663, 0.7172670625612242, 0.7200969570156588, 0.7228992616281168, 0.7256742453836762, 0.7284221746449651, 0.7311433131777294, 0.7338379221761511, 0.7365062602879189, 0.7391485836390552, 0.741765145858502, 0.744356198102464, 0.7469219890785185, 0.7494627650694864, 0.751978769957073, 0.7544702452452776, 0.7569374300835744, 0.7593805612898676, 0.7617998733732236, 0.7641955985563801, 0.766567966798037, 0.7689172058149288, 0.7712435411036835, 0.7735471959624665, 0.7758283915124146, 0.7780873467188607, 0.7803242784123521, 0.7825394013094625, 0.7847329280334034, 0.7869050691344317, 0.7890560331100608, 0.7911860264250732, 0.7932952535313387, 0.7953839168874391, 0.7974522169781016, 0.7995003523334425, 0.8015285195480241, 0.8035369132997244, 0.8055257263684247, 0.8074951496545129, 0.8094453721972084, 0.8113765811927067, 0.8132889620121484, 0.8151826982194124, 0.8170579715887348, 0.8189149621221581, 0.8207538480668082, 0.8225748059320039, 0.8243780105062006, 0.826163634873766, 0.8279318504315952, 0.8296828269055624, 0.8314167323668118, 0.833133733247891, 0.834833994358726, 0.8365176789024408, 0.8381849484910231, 0.8398359631608365, 0.8414708813879821, 0.8430898601035108, 0.8446930547084857, 0.8462806190888985, 0.8478527056304421, 0.8494094652331357, 0.8509510473258107, 0.8524775998804534, 0.8539892694264077, 0.8554862010644421, 0.8569685384806746, 0.8584364239603675, 0.8598899984015829, 0.8613294013287083, 0.8627547709058485, 0.8641662439500881, 0.8655639559446235, 0.8669480410517684, 0.8683186321258307, 0.8696758607258656, 0.871019857128303, 0.8723507503394526, 0.8736686681078872, 0.8749737369367043, 0.8762660820956688, 0.8775458276332377, 0.8788130963884674, 0.8800680100028032, 0.8813106889317572, 0.8825412524564695, 0.8837598186951572, 0.8849665046144531, 0.886161426040633, 0.8873446976707325, 0.8885164330835578, 0.8896767447505867, 0.8908257440467647, 0.8919635412611963, 0.8930902456077301, 0.8942059652354428, 0.89531080723902, 0.8964048776690355, 0.8974882815421311, 0.898561122851097, 0.8996235045748532, 0.9006755286883349, 0.9017172961722801, 0.9027489070229229, 0.9037704602615914, 0.9047820539442131, 0.9057837851707264, 0.9067757500944016, 0.9077580439310693, 0.908730760968261, 0.909693994574259, 0.9106478372070588, 0.911592380423243, 0.9125277148867708, 0.9134539303776799, 0.914371115800704, 0.9152793591938073, 0.9161787477366343, 0.9170693677588782, 0.9179513047485669, 0.91882464336027, 0.9196894674232233, 0.9205458599493761, 0.9213939031413586, 0.9222336784003731, 0.9230652663340067, 0.9238887467639689, 0.9247041987337539, 0.9255117005162269, 0.9263113296211379, 0.9271031628025614, 0.927887276066264, 0.9286637446769995, 0.9294326431657342, 0.9301940453367998, 0.9309480242749786, 0.9316946523525182, 0.9324340012360788, 0.9331661418936111, 0.9338911446011702, 0.9346090789496591, 0.9353200138515102, 0.9360240175472994, 0.9367211576122956, 0.9374115009629486, 0.9380951138633105, 0.9387720619313977, 0.9394424101454883, 0.9401062228503599, 0.9407635637634653, 0.9414144959810489, 0.942059081984203, 0.9426973836448652, 0.9433294622317576, 0.9439553784162671, 0.9445751922782699, 0.9451889633118976, 0.9457967504312484, 0.9463986119760425, 0.9469946057172204, 0.9475847888624899, 0.9481692180618164, 0.9487479494128608, 0.949321038466364, 0.949888540231479, 0.9504505091810516, 0.9510069992568485, 0.9515580638747353, 0.9521037559298035, 0.952644127801448, 0.9531792313583948, 0.9537091179636796, 0.9542338384795782, 0.9547534432724882, 0.9552679822177643, 0.9557775047045047, 0.9562820596402926, 0.9567816954558902, 0.957276460109888, 0.9577664010933075, 0.9582515654341603, 0.9587319997019619, 0.9592077500122016, 0.9596788620307698, 0.96014538097834, 0.9606073516347109, 0.9610648183431033, 0.9615178250144175, 0.9619664151314479, 0.9624106317530562, 0.9628505175183054, 0.9632861146505521, 0.9637174649614995, 0.9641446098552104, 0.9645675903320825, 0.9649864469927826, 0.9654012200421446, 0.9658119492930286, 0.9662186741701418, 0.9666214337138238, 0.9670202665837927, 0.9674152110628571, 0.96780630506059, 0.9681935861169679, 0.9685770914059743, 0.9689568577391675, 0.9693329215692146, 0.9697053189933901, 0.9700740857570405, 0.9704392572570162, 0.9708008685450685, 0.9711589543312142, 0.9715135489870679, 0.9718646865491398, 0.9722124007221048, 0.9725567248820358, 0.9728976920796086, 0.9732353350432739, 0.9735696861823986, 0.9739007775903774, 0.9742286410477123, 0.9745533080250643, 0.974874809686273, 0.975193176891349, 0.9755084401994351, 0.9758206298717403, 0.9761297758744445, 0.9764359078815739, 0.9767390552778507, 0.9770392471615126, 0.9773365123471063, 0.9776308793682533, 0.9779223764803888, 0.9782110316634736, 0.9784968726246801, 0.9787799268010515, 0.9790602213621361, 0.9793377832125943, 0.9796126389947817, 0.9798848150913062, 0.9801543376275607, 0.9804212324742301, 0.9806855252497756, 0.9809472413228926, 0.9812064058149468, 0.9814630436023846, 0.9817171793191216, 0.9819688373589069, 0.9822180418776648, 0.9824648167958127, 0.9827091858005582, 0.982951172348172, 0.9831907996662397, 0.9834280907558913, 0.9836630683940093, 0.9838957551354144, 0.9841261733150306, 0.9843543450500298, 0.9845802922419539, 0.9848040365788171, 0.9850255995371885, 0.9852450023842526, 0.9854622661798513, 0.9856774117785052, 0.9858904598314151, 0.9861014307884446, 0.9863103449000828, 0.9865172222193886, 0.9867220826039146, 0.9869249457176139, 0.9871258310327274, 0.9873247578316531, 0.9875217452087961, 0.9877168120724025, 0.9879099771463739, 0.9881012589720645, 0.9882906759100608, 0.9884782461419447, 0.9886639876720374, 0.9888479183291291, 0.9890300557681888, 0.9892104174720605, 0.9893890207531397, 0.9895658827550369, 0.9897410204542213, 0.9899144506616522, 0.9900861900243911, 0.9902562550272006, 0.9904246619941262, 0.9905914270900631, 0.9907565663223087, 0.9909200955420979, 0.9910820304461255, 0.9912423865780523, 0.9914011793299977, 0.9915584239440164, 0.9917141355135622, 0.9918683289849362, 0.9920210191587217, 0.9921722206912048, 0.9923219480957814, 0.99247021574435], \"type\": \"scatter\", \"uid\": \"7f9001e1-d254-4e47-ad26-5d11e424d80f\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 9.067935871743487, 18.085871743486972, 27.10380761523046, 36.12174348697394, 45.13967935871743, 54.15761523046091, 63.175551102204395, 72.19348697394788, 81.21142284569137, 90.22935871743486, 99.24729458917834, 108.26523046092183, 117.28316633266532, 126.30110220440879, 135.3190380761523, 144.33697394789579, 153.35490981963926, 162.37284569138276, 171.39078156312624, 180.40871743486974, 189.42665330661322, 198.4445891783567, 207.4625250501002, 216.48046092184367, 225.49839679358715, 234.51633266533065, 243.53426853707413, 252.5522044088176, 261.5701402805611, 270.5880761523046, 279.6060120240481, 288.62394789579156, 297.64188376753503, 306.6598196392785, 315.67775551102204, 324.6956913827655, 333.713627254509, 342.73156312625247, 351.74949899799594, 360.7674348697395, 369.78537074148295, 378.8033066132264, 387.8212424849699, 396.8391783567134, 405.85711422845685, 414.8750501002004, 423.89298597194386, 432.91092184368733, 441.9288577154308, 450.9467935871743, 459.9647294589178, 468.9826653306613, 478.00060120240477, 487.01853707414824, 496.0364729458917, 505.0544088176352, 514.0723446893786, 523.0902805611221, 532.1082164328657, 541.1261523046091, 550.1440881763526, 559.1620240480961, 568.1799599198396, 577.197895791583, 586.2158316633265, 595.23376753507, 604.2517034068135, 613.269639278557, 622.2875751503004, 631.305511022044, 640.3234468937875, 649.341382765531, 658.3593186372744, 667.3772545090179, 676.3951903807614, 685.4131262525049, 694.4310621242483, 703.4489979959918, 712.4669338677353, 721.4848697394789, 730.5028056112224, 739.5207414829658, 748.5386773547093, 757.5566132264528, 766.5745490981963, 775.5924849699397, 784.6104208416832, 793.6283567134267, 802.6462925851702, 811.6642284569136, 820.6821643286572, 829.7001002004007, 838.7180360721442, 847.7359719438876, 856.7539078156311, 865.7718436873746, 874.7897795591181, 883.8077154308615, 892.825651302605, 901.8435871743485, 910.861523046092, 919.8794589178356, 928.897394789579, 937.9153306613225, 946.933266533066, 955.9512024048095, 964.9691382765529, 973.9870741482964, 983.0050100200399, 992.0229458917834, 1001.0408817635268, 1010.0588176352703, 1019.0767535070139, 1028.0946893787573, 1037.1126252505007, 1046.1305611222442, 1055.1484969939877, 1064.1664328657314, 1073.1843687374749, 1082.2023046092183, 1091.2202404809618, 1100.2381763527053, 1109.2561122244488, 1118.2740480961922, 1127.2919839679357, 1136.3099198396792, 1145.3278557114227, 1154.3457915831661, 1163.3637274549096, 1172.381663326653, 1181.3995991983966, 1190.41753507014, 1199.4354709418835, 1208.453406813627, 1217.4713426853705, 1226.489278557114, 1235.5072144288574, 1244.525150300601, 1253.5430861723446, 1262.561022044088, 1271.5789579158316, 1280.596893787575, 1289.6148296593185, 1298.632765531062, 1307.6507014028055, 1316.668637274549, 1325.6865731462924, 1334.7045090180359, 1343.7224448897794, 1352.7403807615228, 1361.7583166332663, 1370.7762525050098, 1379.7941883767533, 1388.8121242484967, 1397.8300601202402, 1406.8479959919837, 1415.8659318637272, 1424.8838677354706, 1433.901803607214, 1442.9197394789578, 1451.9376753507013, 1460.9556112224448, 1469.9735470941882, 1478.9914829659317, 1488.0094188376752, 1497.0273547094187, 1506.0452905811621, 1515.0632264529056, 1524.081162324649, 1533.0990981963926, 1542.117034068136, 1551.1349699398795, 1560.152905811623, 1569.1708416833665, 1578.18877755511, 1587.2067134268534, 1596.224649298597, 1605.2425851703404, 1614.2605210420838, 1623.2784569138273, 1632.2963927855708, 1641.3143286573145, 1650.332264529058, 1659.3502004008014, 1668.368136272545, 1677.3860721442884, 1686.4040080160319, 1695.4219438877753, 1704.4398797595188, 1713.4578156312623, 1722.4757515030058, 1731.4936873747492, 1740.5116232464927, 1749.5295591182362, 1758.5474949899797, 1767.5654308617231, 1776.5833667334666, 1785.60130260521, 1794.6192384769536, 1803.637174348697, 1812.6551102204405, 1821.673046092184, 1830.6909819639277, 1839.7089178356712, 1848.7268537074146, 1857.7447895791581, 1866.7627254509016, 1875.780661322645, 1884.7985971943885, 1893.816533066132, 1902.8344689378755, 1911.852404809619, 1920.8703406813624, 1929.888276553106, 1938.9062124248494, 1947.9241482965929, 1956.9420841683364, 1965.9600200400798, 1974.9779559118233, 1983.9958917835668, 1993.0138276553103, 2002.0317635270537, 2011.0496993987972, 2020.0676352705407, 2029.0855711422844, 2038.1035070140279, 2047.1214428857713, 2056.139378757515, 2065.1573146292585, 2074.1752505010018, 2083.1931863727455, 2092.2111222444887, 2101.2290581162324, 2110.2469939879757, 2119.2649298597194, 2128.282865731463, 2137.3008016032063, 2146.31873747495, 2155.3366733466933, 2164.354609218437, 2173.37254509018, 2182.390480961924, 2191.408416833667, 2200.426352705411, 2209.444288577154, 2218.462224448898, 2227.480160320641, 2236.4980961923848, 2245.516032064128, 2254.5339679358717, 2263.551903807615, 2272.5698396793587, 2281.587775551102, 2290.6057114228456, 2299.623647294589, 2308.6415831663326, 2317.6595190380763, 2326.6774549098195, 2335.695390781563, 2344.7133266533065, 2353.73126252505, 2362.7491983967934, 2371.767134268537, 2380.7850701402804, 2389.803006012024, 2398.8209418837673, 2407.838877755511, 2416.8568136272543, 2425.874749498998, 2434.892685370741, 2443.910621242485, 2452.928557114228, 2461.946492985972, 2470.964428857715, 2479.982364729459, 2489.000300601202, 2498.018236472946, 2507.0361723446895, 2516.0541082164327, 2525.0720440881764, 2534.0899799599197, 2543.1079158316634, 2552.1258517034066, 2561.1437875751503, 2570.1617234468936, 2579.1796593186373, 2588.1975951903805, 2597.2155310621242, 2606.2334669338675, 2615.251402805611, 2624.2693386773544, 2633.287274549098, 2642.3052104208414, 2651.323146292585, 2660.3410821643283, 2669.359018036072, 2678.3769539078153, 2687.394889779559, 2696.4128256513027, 2705.430761523046, 2714.4486973947896, 2723.466633266533, 2732.4845691382766, 2741.50250501002, 2750.5204408817635, 2759.538376753507, 2768.5563126252505, 2777.5742484969937, 2786.5921843687374, 2795.6101202404807, 2804.6280561122244, 2813.6459919839676, 2822.6639278557113, 2831.6818637274546, 2840.6997995991983, 2849.7177354709415, 2858.7356713426852, 2867.7536072144285, 2876.771543086172, 2885.789478957916, 2894.807414829659, 2903.825350701403, 2912.843286573146, 2921.86122244489, 2930.879158316633, 2939.8970941883767, 2948.91503006012, 2957.9329659318637, 2966.950901803607, 2975.9688376753506, 2984.986773547094, 2994.0047094188376, 3003.022645290581, 3012.0405811623245, 3021.058517034068, 3030.0764529058115, 3039.0943887775547, 3048.1123246492984, 3057.1302605210417, 3066.1481963927854, 3075.1661322645286, 3084.1840681362723, 3093.202004008016, 3102.2199398797593, 3111.237875751503, 3120.2558116232462, 3129.27374749499, 3138.291683366733, 3147.309619238477, 3156.32755511022, 3165.345490981964, 3174.363426853707, 3183.381362725451, 3192.399298597194, 3201.4172344689377, 3210.435170340681, 3219.4531062124247, 3228.471042084168, 3237.4889779559117, 3246.506913827655, 3255.5248496993986, 3264.542785571142, 3273.5607214428856, 3282.5786573146293, 3291.5965931863725, 3300.614529058116, 3309.6324649298595, 3318.650400801603, 3327.6683366733464, 3336.68627254509, 3345.7042084168334, 3354.722144288577, 3363.7400801603203, 3372.758016032064, 3381.7759519038073, 3390.793887775551, 3399.811823647294, 3408.829759519038, 3417.847695390781, 3426.865631262525, 3435.883567134268, 3444.901503006012, 3453.919438877755, 3462.9373747494988, 3471.9553106212425, 3480.9732464929857, 3489.9911823647294, 3499.0091182364727, 3508.0270541082164, 3517.0449899799596, 3526.0629258517033, 3535.0808617234466, 3544.0987975951903, 3553.1167334669335, 3562.134669338677, 3571.1526052104205, 3580.170541082164, 3589.1884769539074, 3598.206412825651, 3607.2243486973944, 3616.242284569138, 3625.2602204408813, 3634.278156312625, 3643.2960921843683, 3652.314028056112, 3661.3319639278557, 3670.349899799599, 3679.3678356713426, 3688.385771543086, 3697.4037074148296, 3706.421643286573, 3715.4395791583165, 3724.4575150300598, 3733.4754509018035, 3742.4933867735467, 3751.5113226452904, 3760.5292585170337, 3769.5471943887774, 3778.5651302605206, 3787.5830661322643, 3796.6010020040076, 3805.6189378757513, 3814.6368737474945, 3823.654809619238, 3832.6727454909815, 3841.690681362725, 3850.708617234469, 3859.726553106212, 3868.744488977956, 3877.762424849699, 3886.780360721443, 3895.798296593186, 3904.8162324649297, 3913.834168336673, 3922.8521042084167, 3931.87004008016, 3940.8879759519036, 3949.905911823647, 3958.9238476953906, 3967.941783567134, 3976.9597194388775, 3985.977655310621, 3994.9955911823645, 4004.0135270541077, 4013.0314629258514, 4022.0493987975947, 4031.0673346693384, 4040.0852705410816, 4049.1032064128253, 4058.121142284569, 4067.1390781563123, 4076.157014028056, 4085.1749498997992, 4094.192885771543, 4103.210821643286, 4112.228757515029, 4121.246693386774, 4130.264629258517, 4139.28256513026, 4148.300501002003, 4157.3184368737475, 4166.336372745491, 4175.354308617234, 4184.372244488977, 4193.390180360721, 4202.408116232465, 4211.426052104208, 4220.443987975951, 4229.461923847695, 4238.4798597194385, 4247.497795591182, 4256.515731462926, 4265.533667334669, 4274.551603206412, 4283.569539078156, 4292.5874749499, 4301.605410821643, 4310.623346693386, 4319.64128256513, 4328.659218436874, 4337.677154308617, 4346.69509018036, 4355.7130260521035, 4364.730961923848, 4373.748897795591, 4382.766833667334, 4391.784769539077, 4400.8027054108215, 4409.820641282565, 4418.838577154308, 4427.856513026052, 4436.874448897795, 4445.892384769539, 4454.910320641282, 4463.928256513026, 4472.946192384769, 4481.964128256513, 4490.982064128256, 4500.0], \"y\": [0.9931509449761662, 0.9732122596991266, 0.9534723610507703, 0.9339292671489825, 0.9145810158708079, 0.8954256646554539, 0.8764612903092586, 0.8576859888126009, 0.839097875128739, 0.8206950830145521, 0.80247576483317, 0.7844380913684712, 0.7665802516414295, 0.7489004527282919, 0.7313969195805701, 0.7140678948468251, 0.6969116386962302, 0.679926428643892, 0.6631105593779127, 0.6464623425881786, 0.6299801067968518, 0.6136621971905567, 0.5975069754542353, 0.5815128196066606, 0.5656781238375914, 0.5500012983465483, 0.5344807691831979, 0.5191149780893285, 0.5039023823424023, 0.4888414546006643, 0.4739306827498002, 0.45916856975111786, 0.4445536334912461, 0.43008440663333136, 0.4157594364697157, 0.40157728477608656, 0.38753652766707924, 0.3736357554533185, 0.3598735724998863, 0.34624859708620015, 0.33275946126728906, 0.31940481073645155, 0.3061833046892839, 0.29309361568906356, 0.2801344295334749, 0.2673044451226627, 0.25460237432860366, 0.24202694186577656, 0.2295768851631257, 0.21725095423729734, 0.20504791156714308, 0.19296653196947178, 0.18100560247604225, 0.16916392221178111, 0.15744030227421502, 0.14583356561410543, 0.13434254691727254, 0.12296609248759904, 0.11170306013119768, 0.10055231904173612, 0.08951274968690481, 0.07858324369601521, 0.06776270374871918, 0.057050043464839995, 0.04644418729529787, 0.035944070414126505, 0.0255486386115642, 0.01525684818821138, 0.005067665850243763, 0.005019931394330879, 0.015006956338380117, 0.02489441167733164, 0.03468329010984328, 0.04437457443747039, 0.053969237663338165, 0.06346824308983146, 0.0728725444153101, 0.08218308582985989, 0.09140080211008927, 0.10052661871298052, 0.10956145186880595, 0.11850620867311612, 0.12736178717781355, 0.1361290764813159, 0.1448089568178219, 0.15340229964568597, 0.1619099677349135, 0.17033281525378163, 0.17867168785459842, 0.18692742275860608, 0.19510084884003753, 0.20319278670933572, 0.21120404879554144, 0.2191354394278633, 0.22698775491642997, 0.23476178363224098, 0.2424583060863187, 0.2500780950080709, 0.2576219154228737, 0.26509052472887884, 0.27248467277305743, 0.27980510192648356, 0.2870525471588684, 0.29422773611235165, 0.3013313891745556, 0.30836421955091287, 0.3153269333362718, 0.3222202295857878, 0.32904480038510897, 0.3358013309198612, 0.34249049954444055, 0.34911297785011974, 0.35566943073247637, 0.3621605164581476, 0.36858688673092055, 0.37494918675716293, 0.3812480553106018, 0.38748412479645633, 0.393658021314931, 0.3997703647240759, 0.4058217687020209, 0.41181284080858815, 0.4177441825462913, 0.4236163894207261, 0.42943005100035947, 0.4351857509757213, 0.44088406721800766, 0.4465255718370984, 0.4521108312389972, 0.4576404061826983, 0.46311485183648704, 0.4685347178336783, 0.4739005483277997, 0.47921288204722445, 0.48447225234925984, 0.48967918727369575, 0.49483420959582003, 0.49993783687890525, 0.5049905815261715, 0.5099929508322321, 0.5149454470340249, 0.5198485673612381, 0.5247028040862313, 0.5295086445734591, 0.5342665713284038, 0.5389770620460173, 0.5436405896586824, 0.548257622383695, 0.5528286237702731, 0.5573540527460971, 0.5618343636633857, 0.5662700063445129, 0.5706614261271704, 0.5750090639090794, 0.5793133561922558, 0.5835747351268362, 0.5877936285544648, 0.5919704600512492, 0.5961056489702863, 0.6001996104837666, 0.6042527556246572, 0.6082654913279679, 0.6122382204716097, 0.6161713419168418, 0.6200652505483185, 0.6239203373137343, 0.6277369892630764, 0.631515589587483, 0.6352565176577167, 0.6389601490622527, 0.6426268556449881, 0.6462570055425749, 0.6498509632213804, 0.6534090895140803, 0.6569317416558855, 0.6604192733204097, 0.663872034655176, 0.6672903723167738, 0.670674629505662, 0.6740251460006266, 0.6773422581928936, 0.6806262991199039, 0.68387759849875, 0.6870964827592776, 0.6902832750768623, 0.6934382954048537, 0.6965618605066997, 0.6996542839877498, 0.7027158763267403, 0.7057469449069665, 0.7087477940471445, 0.711718725031964, 0.7146600361423376, 0.7175720226853479, 0.7204549770238968, 0.7233091886060581, 0.7261349439941382, 0.7289325268934472, 0.7317022181807823, 0.7344442959326283, 0.7371590354530762, 0.7398467093014639, 0.7425075873197404, 0.7451419366595591, 0.7477500218090982, 0.750332104619617, 0.7528884443317442, 0.7554192976015065, 0.7579249185260969, 0.7604055586693852, 0.7628614670871754, 0.7652928903522115, 0.7677000725789321, 0.7700832554479807, 0.7724426782304694, 0.774778577812002, 0.7770911887164578, 0.7793807431295369, 0.781647470922072, 0.7838915996731076, 0.7861133546927488, 0.7883129590447817, 0.7904906335690702, 0.7926465969037271, 0.7947810655070663, 0.7968942536793342, 0.7989863735842264, 0.8010576352701881, 0.8031082466915033, 0.8051384137291734, 0.8071483402115875, 0.8091382279349868, 0.8111082766837245, 0.8130586842503251, 0.8149896464553416, 0.8169013571670166, 0.8187940083207463, 0.8206677899383508, 0.8225228901471524, 0.8243594951988634, 0.8261777894882861, 0.8279779555718252, 0.8297601741858174, 0.8315246242646764, 0.8332714829588589, 0.8350009256526492, 0.8367131259817688, 0.8384082558508091, 0.8400864854504905, 0.8417479832747492, 0.8433929161376547, 0.8450214491901572, 0.8466337459366693, 0.8482299682514811, 0.8498102763950135, 0.8513748290299066, 0.8529237832369513, 0.8544572945308588, 0.8559755168758748, 0.8574786027012377, 0.8589667029164814, 0.8604399669265883, 0.861898542646988, 0.8633425765184086, 0.8647722135215797, 0.8661875971917877, 0.8675888696332871, 0.8689761715335675, 0.8703496421774792, 0.8717094194612167, 0.8730556399061637, 0.8743884386726002, 0.8757079495732714, 0.8770143050868241, 0.8783076363711062, 0.8795880732763358, 0.8808557443581373, 0.8821107768904494, 0.8833532968783022, 0.8845834290704692, 0.8858012969719913, 0.8870070228565768, 0.8882007277788782, 0.889382531586645, 0.8905525529327578, 0.8917109092871397, 0.8928577169485511, 0.8939930910562656, 0.8951171456016302, 0.8962299934395102, 0.8973317462996192, 0.8984225147977375, 0.8995024084468173, 0.9005715356679779, 0.9016300038013915, 0.9026779191170597, 0.9037153868254836, 0.9047425110882257, 0.9057593950283692, 0.9067661407408707, 0.9077628493028103, 0.9087496207835405, 0.9097265542547325, 0.9106937478003231, 0.9116512985263627, 0.9125993025707642, 0.9135378551129554, 0.9144670503834353, 0.9153869816732344, 0.9162977413432813, 0.9171994208336758, 0.9180921106728692, 0.9189759004867537, 0.9198508790076604, 0.9207171340832685, 0.9215747526854247, 0.9224238209188755, 0.9232644240299122, 0.9240966464149288, 0.9249205716288967, 0.9257362823937525, 0.9265438606067036, 0.9273433873484508, 0.9281349428913287, 0.9289186067073654, 0.9296944574762602, 0.930462573093285, 0.9312230306771031, 0.9319759065775132, 0.9327212763831141, 0.9334592149288943, 0.9341897963037451, 0.9349130938578992, 0.9356291802102951, 0.9363381272558681, 0.9370400061727683, 0.9377348874295071, 0.938422840792032, 0.9391039353307314, 0.9397782394273689, 0.9404458207819494, 0.941106746419515, 0.9417610826968759, 0.9424088953092711, 0.9430502492969652, 0.9436852090517782, 0.9443138383235501, 0.9449362002265416, 0.9455523572457707, 0.9461623712432866, 0.9467663034643798, 0.947364214543732, 0.947956164511503, 0.9485422127993586, 0.9491224182464364, 0.9496968391052545, 0.9502655330475592, 0.9508285571701154, 0.9513859680004391, 0.9519378215024731, 0.9524841730822051, 0.9530250775932312, 0.9535605893422625, 0.9540907620945781, 0.9546156490794228, 0.9551353029953509, 0.9556497760155183, 0.9561591197929192, 0.9566633854655734, 0.9571626236616595, 0.9576568845045987, 0.9581462176180867, 0.9586306721310761, 0.959110296682709, 0.9595851394272003, 0.9600552480386723, 0.9605206697159411, 0.9609814511872558, 0.9614376387149894, 0.9618892781002841, 0.9623364146876494, 0.9627790933695143, 0.9632173585907357, 0.963651254353059, 0.9640808242195374, 0.964506111318905, 0.9649271583499064, 0.9653440075855844, 0.9657567008775239, 0.966165279660054, 0.9665697849544076, 0.9669702573728403, 0.9673667371227075, 0.9677592640105018, 0.9681478774458488, 0.9685326164454645, 0.9689135196370721, 0.9692906252632805, 0.9696639711854236, 0.9700335948873618, 0.9703995334792456, 0.9707618237012405, 0.971120501927217, 0.9714756041684014, 0.971827166076992, 0.9721752229497385, 0.9725198097314854, 0.9728609610186808, 0.9731987110628499, 0.9735330937740337, 0.9738641427241935, 0.9741918911505816, 0.9745163719590786, 0.9748376177274967, 0.9751556607088504, 0.9754705328345956, 0.9757822657178343, 0.9760908906564896, 0.9763964386364472, 0.976698940334667, 0.9769984261222625, 0.9772949260675505, 0.97758846993907, 0.9778790872085703, 0.9781668070539709, 0.9784516583622899, 0.9787336697325454, 0.9790128694786258, 0.9792892856321331, 0.9795629459451974, 0.9798338778932625, 0.9801021086778452, 0.9803676652292659, 0.9806305742093522, 0.9808908620141166, 0.9811485547764056, 0.981403678368524, 0.981656258404833, 0.9819063202443202, 0.9821538889931476, 0.9823989895071711, 0.9826416463944361, 0.9828818840176484, 0.9831197264966205, 0.9833551977106925, 0.9835883213011298, 0.9838191206734974, 0.9840476190000088, 0.9842738392218531, 0.9844978040514978, 0.98471953597497, 0.984939057254113, 0.985156389928822, 0.9853715558192568, 0.9855845765280323, 0.9857954734423875, 0.9860042677363332, 0.9862109803727771, 0.9864156321056291, 0.9866182434818848, 0.9868188348436882, 0.9870174263303744, 0.9872140378804912, 0.9874086892338015, 0.9876013999332645, 0.9877921893269982, 0.9879810765702218, 0.9881680806271792, 0.9883532202730424, 0.9885365140957971, 0.9887179804981088, 0.98889763769917, 0.9890755037365302, 0.9892515964679057, 0.989425933572974, 0.9895985325551476, 0.9897694107433318, 0.9899385852936646, 0.9901060731912391, 0.9902718912518087, 0.9904360561234756, 0.990598584288362, 0.9907594920642652, 0.9909187956062955, 0.9910765109084987, 0.9912326538054614, 0.9913872399739012, 0.9915402849342405, 0.9916918040521643, 0.9918418125401637, 0.9919903254590627, 0.9921373577195304, 0.9922829240835782, 0.9924270391660416, 0.9925697174360478, 0.9927109732184685, 0.9928508206953575, 0.9929892739073751, 0.9931263467551981, 0.9932620530009144], \"type\": \"scatter\", \"uid\": \"e49b90e3-2ed0-4a1d-a823-57882d36e0b5\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 9.268336673346694, 18.486673346693387, 27.70501002004008, 36.92334669338677, 46.14168336673346, 55.36002004008016, 64.57835671342684, 73.79669338677354, 83.01503006012024, 92.23336673346692, 101.45170340681362, 110.67004008016032, 119.888376753507, 129.1067134268537, 138.3250501002004, 147.5433867735471, 156.7617234468938, 165.9800601202405, 175.19839679358716, 184.41673346693386, 193.63507014028056, 202.85340681362726, 212.07174348697396, 221.29008016032066, 230.50841683366733, 239.72675350701402, 248.94509018036072, 258.1634268537074, 267.3817635270541, 276.6001002004008, 285.8184368737475, 295.0367735470942, 304.2551102204409, 313.4734468937876, 322.6917835671343, 331.910120240481, 341.1284569138277, 350.3467935871743, 359.565130260521, 368.7834669338677, 378.0018036072144, 387.2201402805611, 396.4384769539078, 405.6568136272545, 414.8751503006012, 424.0934869739479, 433.3118236472946, 442.5301603206413, 451.74849699398794, 460.96683366733464, 470.18517034068134, 479.40350701402804, 488.62184368737474, 497.84018036072143, 507.05851703406813, 516.2768537074147, 525.4951903807614, 534.7135270541081, 543.9318637274548, 553.1502004008015, 562.3685370741482, 571.5868737474949, 580.8052104208416, 590.0235470941883, 599.241883767535, 608.4602204408817, 617.6785571142284, 626.8968937875751, 636.1152304609218, 645.3335671342685, 654.5519038076152, 663.7702404809619, 672.9885771543086, 682.2069138276553, 691.4252505010019, 700.6435871743486, 709.8619238476953, 719.080260521042, 728.2985971943887, 737.5169338677354, 746.7352705410821, 755.9536072144288, 765.1719438877755, 774.3902805611222, 783.6086172344689, 792.8269539078156, 802.0452905811622, 811.263627254509, 820.4819639278556, 829.7003006012023, 838.918637274549, 848.1369739478957, 857.3553106212424, 866.5736472945891, 875.7919839679358, 885.0103206412825, 894.2286573146291, 903.4469939879758, 912.6653306613225, 921.8836673346692, 931.1020040080159, 940.3203406813626, 949.5386773547093, 958.757014028056, 967.9753507014027, 977.1936873747494, 986.4120240480961, 995.6303607214428, 1004.8486973947895, 1014.0670340681362, 1023.2853707414829, 1032.5037074148295, 1041.7220440881763, 1050.9403807615229, 1060.1587174348697, 1069.3770541082163, 1078.595390781563, 1087.8137274549097, 1097.0320641282565, 1106.250400801603, 1115.4687374749499, 1124.6870741482965, 1133.9054108216433, 1143.1237474949899, 1152.3420841683367, 1161.5604208416833, 1170.77875751503, 1179.9970941883766, 1189.2154308617232, 1198.43376753507, 1207.6521042084166, 1216.8704408817634, 1226.08877755511, 1235.3071142284568, 1244.5254509018034, 1253.7437875751502, 1262.9621242484968, 1272.1804609218436, 1281.3987975951902, 1290.617134268537, 1299.8354709418836, 1309.0538076152304, 1318.272144288577, 1327.4904809619238, 1336.7088176352704, 1345.9271543086172, 1355.1454909819638, 1364.3638276553106, 1373.5821643286572, 1382.8005010020038, 1392.0188376753506, 1401.2371743486972, 1410.455511022044, 1419.6738476953906, 1428.8921843687374, 1438.110521042084, 1447.3288577154308, 1456.5471943887774, 1465.7655310621242, 1474.9838677354708, 1484.2022044088176, 1493.4205410821642, 1502.638877755511, 1511.8572144288576, 1521.0755511022044, 1530.293887775551, 1539.5122244488978, 1548.7305611222444, 1557.9488977955912, 1567.1672344689377, 1576.3855711422843, 1585.6039078156311, 1594.8222444889777, 1604.0405811623245, 1613.2589178356711, 1622.477254509018, 1631.6955911823645, 1640.9139278557113, 1650.132264529058, 1659.3506012024047, 1668.5689378757513, 1677.7872745490981, 1687.0056112224447, 1696.2239478957915, 1705.442284569138, 1714.660621242485, 1723.8789579158315, 1733.0972945891783, 1742.315631262525, 1751.5339679358717, 1760.7523046092183, 1769.970641282565, 1779.1889779559117, 1788.4073146292583, 1797.625651302605, 1806.8439879759517, 1816.0623246492985, 1825.280661322645, 1834.4989979959919, 1843.7173346693385, 1852.9356713426853, 1862.1540080160319, 1871.3723446893787, 1880.5906813627253, 1889.809018036072, 1899.0273547094187, 1908.2456913827655, 1917.464028056112, 1926.6823647294589, 1935.9007014028055, 1945.1190380761523, 1954.3373747494988, 1963.5557114228457, 1972.7740480961922, 1981.9923847695388, 1991.2107214428856, 2000.4290581162322, 2009.647394789579, 2018.8657314629256, 2028.0840681362724, 2037.302404809619, 2046.5207414829658, 2055.7390781563126, 2064.9574148296592, 2074.1757515030063, 2083.394088176353, 2092.6124248496994, 2101.830761523046, 2111.049098196393, 2120.2674348697396, 2129.4857715430862, 2138.704108216433, 2147.92244488978, 2157.1407815631264, 2166.359118236473, 2175.5774549098196, 2184.795791583166, 2194.0141282565132, 2203.23246492986, 2212.4508016032064, 2221.669138276553, 2230.8874749499, 2240.1058116232466, 2249.324148296593, 2258.54248496994, 2267.760821643287, 2276.9791583166334, 2286.19749498998, 2295.4158316633266, 2304.6341683366736, 2313.85250501002, 2323.070841683367, 2332.2891783567134, 2341.5075150300604, 2350.725851703407, 2359.9441883767536, 2369.1625250501, 2378.3808617234467, 2387.599198396794, 2396.8175350701404, 2406.035871743487, 2415.2542084168335, 2424.4725450901806, 2433.690881763527, 2442.9092184368737, 2452.1275551102203, 2461.3458917835674, 2470.564228456914, 2479.7825651302605, 2489.000901803607, 2498.219238476954, 2507.4375751503007, 2516.6559118236473, 2525.874248496994, 2535.092585170341, 2544.3109218436875, 2553.529258517034, 2562.7475951903807, 2571.9659318637273, 2581.1842685370743, 2590.402605210421, 2599.6209418837675, 2608.839278557114, 2618.057615230461, 2627.2759519038077, 2636.4942885771543, 2645.712625250501, 2654.930961923848, 2664.1492985971945, 2673.367635270541, 2682.5859719438877, 2691.8043086172347, 2701.0226452905813, 2710.240981963928, 2719.4593186372745, 2728.6776553106215, 2737.895991983968, 2747.1143286573147, 2756.3326653306613, 2765.551002004008, 2774.769338677355, 2783.9876753507015, 2793.206012024048, 2802.4243486973946, 2811.6426853707417, 2820.8610220440883, 2830.079358717435, 2839.2976953907814, 2848.5160320641285, 2857.734368737475, 2866.9527054108216, 2876.171042084168, 2885.3893787575153, 2894.607715430862, 2903.8260521042084, 2913.044388777555, 2922.262725450902, 2931.4810621242486, 2940.699398797595, 2949.917735470942, 2959.1360721442884, 2968.3544088176354, 2977.572745490982, 2986.7910821643286, 2996.009418837675, 3005.227755511022, 3014.446092184369, 3023.6644288577154, 3032.882765531062, 3042.101102204409, 3051.3194388777556, 3060.537775551102, 3069.7561122244488, 3078.974448897796, 3088.1927855711424, 3097.411122244489, 3106.6294589178356, 3115.8477955911826, 3125.066132264529, 3134.2844689378758, 3143.5028056112224, 3152.721142284569, 3161.939478957916, 3171.1578156312626, 3180.376152304609, 3189.5944889779557, 3198.812825651303, 3208.0311623246494, 3217.249498997996, 3226.4678356713425, 3235.6861723446896, 3244.904509018036, 3254.1228456913827, 3263.3411823647293, 3272.5595190380764, 3281.777855711423, 3290.9961923847695, 3300.214529058116, 3309.432865731463, 3318.6512024048097, 3327.8695390781563, 3337.087875751503, 3346.3062124248495, 3355.5245490981965, 3364.742885771543, 3373.9612224448897, 3383.1795591182363, 3392.3978957915833, 3401.61623246493, 3410.8345691382765, 3420.052905811623, 3429.27124248497, 3438.4895791583167, 3447.7079158316633, 3456.92625250501, 3466.144589178357, 3475.3629258517035, 3484.58126252505, 3493.7995991983967, 3503.0179358717437, 3512.2362725450903, 3521.454609218437, 3530.6729458917835, 3539.8912825651305, 3549.109619238477, 3558.3279559118237, 3567.5462925851702, 3576.764629258517, 3585.982965931864, 3595.2013026052105, 3604.419639278557, 3613.6379759519036, 3622.8563126252507, 3632.0746492985973, 3641.292985971944, 3650.5113226452904, 3659.7296593186375, 3668.947995991984, 3678.1663326653306, 3687.384669338677, 3696.6030060120243, 3705.821342685371, 3715.0396793587174, 3724.258016032064, 3733.476352705411, 3742.6946893787576, 3751.913026052104, 3761.131362725451, 3770.3496993987974, 3779.5680360721444, 3788.786372745491, 3798.0047094188376, 3807.223046092184, 3816.441382765531, 3825.659719438878, 3834.8780561122244, 3844.096392785571, 3853.314729458918, 3862.5330661322646, 3871.751402805611, 3880.9697394789578, 3890.188076152305, 3899.4064128256514, 3908.624749498998, 3917.8430861723446, 3927.0614228456916, 3936.279759519038, 3945.4980961923848, 3954.7164328657313, 3963.934769539078, 3973.153106212425, 3982.3714428857716, 3991.589779559118, 4000.8081162324647, 4010.0264529058118, 4019.2447895791584, 4028.463126252505, 4037.6814629258515, 4046.8997995991986, 4056.118136272545, 4065.3364729458917, 4074.5548096192383, 4083.7731462925854, 4092.991482965932, 4102.209819639279, 4111.428156312625, 4120.646492985972, 4129.864829659318, 4139.083166332665, 4148.301503006012, 4157.5198396793585, 4166.7381763527055, 4175.956513026052, 4185.174849699399, 4194.393186372746, 4203.611523046092, 4212.829859719439, 4222.048196392786, 4231.266533066132, 4240.484869739479, 4249.703206412825, 4258.921543086172, 4268.139879759519, 4277.358216432865, 4286.5765531062125, 4295.7948897795595, 4305.013226452906, 4314.231563126253, 4323.449899799599, 4332.668236472946, 4341.886573146293, 4351.104909819639, 4360.323246492986, 4369.541583166332, 4378.759919839679, 4387.978256513026, 4397.196593186372, 4406.414929859719, 4415.6332665330665, 4424.851603206413, 4434.06993987976, 4443.288276553106, 4452.506613226453, 4461.7249498998, 4470.943286573146, 4480.161623246493, 4489.37995991984, 4498.598296593186, 4507.816633266533, 4517.034969939879, 4526.253306613226, 4535.471643286573, 4544.68997995992, 4553.908316633267, 4563.126653306613, 4572.34498997996, 4581.563326653307, 4590.781663326653, 4600.0], \"y\": [0.9938595120858584, 0.9734800052128001, 0.9533081720270429, 0.933341896267351, 0.9135790832378672, 0.8940176595883542, 0.8746555730966763, 0.8554907924534967, 0.8365213070491706, 0.8177451267628071, 0.799160281753484, 0.7807648222535868, 0.7625568183642566, 0.7445343598529204, 0.7266955559528852, 0.7090385351649751, 0.6915614450611889, 0.6742624520903588, 0.6571397413857889, 0.6401915165748551, 0.6234159995905442, 0.6068114304849144, 0.5903760672444553, 0.5741081856073316, 0.5580060788824863, 0.5420680577705899, 0.5262924501868131, 0.5106776010854053, 0.4952218722860606, 0.4799236423020543, 0.46478130617012914, 0.449793275282117, 0.4349579772182737, 0.4202738555823158, 0.4057393698381342, 0.39135299514817623, 0.3771132222134701, 0.3630185571152831, 0.34906752115839246, 0.3352586507159512, 0.3215904970759387, 0.30806162628917155, 0.29467061901886793, 0.28141607039174055, 0.26829658985061, 0.25531080100851944, 0.2424573415043343, 0.22973486285981548, 0.21714203033814816, 0.20467752280391216, 0.19234003258447907, 0.1801282653328229, 0.1680409398917273, 0.15607678815937742, 0.14423455495632087, 0.1325129978937849, 0.12091088724333621, 0.1094270058078659, 0.09806014879389369, 0.08680912368516913, 0.0756727501175638, 0.06464985975523696, 0.053739296168063166, 0.04293991471030956, 0.03225058240054923, 0.021670177802797896, 0.011197590908862631, 0.0008317230218879423, 0.009428513358908597, 0.019584194652329856, 0.029636386308126594, 0.039586142918776046, 0.04943450833012175, 0.059182515750883846, 0.06883118786105602, 0.07838153691919525, 0.0878345648686214, 0.09719126344253104, 0.10645261426804242, 0.11561958896918045, 0.12469314926880992, 0.13367424708953324, 0.14256382465355655, 0.15136281458154077, 0.16007213999044456, 0.1686927145903696, 0.17722544278041974, 0.1856712197435827, 0.19403093154064588, 0.2023054552031538, 0.21049565882541943, 0.21860240165559752, 0.226626534185829, 0.23456889824146854, 0.24243032706940126, 0.2502116454254605, 0.25791366966095375, 0.2655372078083078, 0.27308305966584145, 0.28055201688167253, 0.28794486303677136, 0.2952623737271681, 0.30250531664532176, 0.3096744516606593, 0.31677053089929597, 0.3237942988229412, 0.3307464923070016, 0.3376278407178883, 0.34443906598953555, 0.35118088269914005, 0.35785399814212826, 0.36445911240636064, 0.37099691844557836, 0.3774681021521028, 0.3838733424287931, 0.3902133112602717, 0.39648867378342223, 0.4027000883571722, 0.40884820663155996, 0.4149336736161028, 0.42095712774746386, 0.4269192009564339, 0.4328205187342258, 0.438661700198098, 0.44444335815630576, 0.4501660991723926, 0.45583052362882515, 0.46143722578998203, 0.4669867938644968, 0.4724798100669696, 0.47791685067904777, 0.48329848610988424, 0.4886252809559808, 0.4938977940604201, 0.4991165785714954, 0.5042821820007417, 0.5093951462803774, 0.5144560078201575, 0.5194652975636507, 0.5244235410439407, 0.5293312584387615, 0.5341889646250697, 0.5389971692330611, 0.5437563766996367, 0.5484670863213248, 0.5531297923066621, 0.5577449838280428, 0.5623131450730378, 0.5668347552951918, 0.5713102888643029, 0.5757402153161895, 0.58012499940195, 0.5844651011367201, 0.5887609758479351, 0.5930130742230972, 0.5972218423570601, 0.6013877217988272, 0.6055111495978774, 0.6095925583500152, 0.613632376242756, 0.6176310271002473, 0.6215889304277333, 0.6255065014555654, 0.6293841511827654, 0.6332222864201434, 0.637021309832978, 0.6407816199832589, 0.6445036113715027, 0.6481876744781392, 0.6518341958044778, 0.6554435579132564, 0.659016139468776, 0.6625523152766277, 0.6660524563230137, 0.669516929813668, 0.672946099212381, 0.6763403242791315, 0.6796999611078282, 0.6830253621636697, 0.6863168763201211, 0.6895748488955162, 0.692799621689284, 0.6959915330178084, 0.6991509177499207, 0.7022781073420323, 0.7053734298729082, 0.708437210078085, 0.7114697693839411, 0.7144714259414173, 0.7174424946593945, 0.7203832872377314, 0.7232941121999658, 0.7261752749256818, 0.7290270776825482, 0.7318498196580294, 0.7346437969907744, 0.7374093028016842, 0.7401466272246642, 0.7428560574370631, 0.7455378776898001, 0.7481923693371868, 0.7508198108664448, 0.7534204779269215, 0.7559946433590097, 0.7585425772227713, 0.7610645468262698, 0.7635608167536139, 0.7660316488927162, 0.7684773024627675, 0.7708980340414322, 0.7732940975917661, 0.7756657444888612, 0.7780132235462157, 0.7803367810418397, 0.7826366607440911, 0.7849131039372508, 0.7871663494468356, 0.789396633664654, 0.7916041905736061, 0.7937892517722318, 0.7959520464990082, 0.7980928016563982, 0.8002117418346568, 0.8023090893353925, 0.8043850641948889, 0.8064398842071899, 0.8084737649469486, 0.8104869197920431, 0.8124795599459632, 0.8144518944599675, 0.8164041302550151, 0.8183364721434748, 0.820249122850612, 0.8221422830358566, 0.8240161513138549, 0.8258709242753062, 0.8277067965075883, 0.8295239606151711, 0.8313226072398235, 0.8331029250806138, 0.8348651009137064, 0.836609319611957, 0.8383357641643081, 0.8400446156949858, 0.841736053482503, 0.843410254978467, 0.8450673958261967, 0.8467076498791493, 0.8483311892191594, 0.8499381841744935, 0.8515288033377181, 0.8531032135833875, 0.8546615800855513, 0.8562040663350825, 0.8577308341568302, 0.8592420437265958, 0.8607378535879392, 0.8622184206688099, 0.8636839002980119, 0.8651344462214988, 0.8665702106185038, 0.8679913441175053, 0.8693979958120294, 0.8707903132762911, 0.8721684425806774, 0.8735325283070712, 0.8748827135640198, 0.8762191400017492, 0.8775419478270232, 0.8788512758178548, 0.8801472613380648, 0.8814300403516919, 0.8826997474372587, 0.8839565158018889, 0.8852004772952837, 0.8864317624235534, 0.8876505003629092, 0.8888568189732157, 0.8900508448114044, 0.8912327031447513, 0.8924025179640191, 0.8935604119964646, 0.894706506718715, 0.8958409223695112, 0.8969637779623238, 0.8980751912978375, 0.8991752789763104, 0.9002641564098073, 0.9013419378343063, 0.9024087363216848, 0.903464663791582, 0.9045098310231396, 0.9055443476666248, 0.9065683222549334, 0.9075818622149765, 0.9085850738789504, 0.9095780624954923, 0.9105609322407227, 0.9115337862291732, 0.9124967265246064, 0.9134498541507219, 0.9143932691017557, 0.9153270703529705, 0.9162513558710395, 0.9171662226243241, 0.9180717665930476, 0.9189680827793635, 0.9198552652173232, 0.9207334069827413, 0.9216026002029598, 0.922462936066514, 0.9233145048326985, 0.924157395841037, 0.924991697520655, 0.9258174973995569, 0.9266348821138087, 0.9274439374166273, 0.9282447481873768, 0.9290373984404736, 0.9298219713342001, 0.9305985491794296, 0.931367213448261, 0.9321280447825666, 0.9328811230024523, 0.9336265271146313, 0.9343643353207137, 0.9350946250254097, 0.935817472844651, 0.9365329546136285, 0.9372411453947481, 0.937942119485506, 0.9386359504262831, 0.9393227110080602, 0.9400024732800548, 0.94067530855728, 0.941341287428026, 0.9420004797612658, 0.9426529547139851, 0.9432987807384381, 0.9439380255893285, 0.9445707563309178, 0.9451970393440613, 0.9458169403331724, 0.9464305243331154, 0.9470378557160284, 0.9476389981980768, 0.9482340148461385, 0.9488229680844189, 0.9494059197010014, 0.949982930854329, 0.9505540620796205, 0.9511193732952214, 0.9516789238088904, 0.9522327723240209, 0.9527809769458001, 0.9533235951873048, 0.953860683975535, 0.9543922996573867, 0.9549184980055626, 0.9554393342244242, 0.9559548629557825, 0.9564651382846312, 0.9569702137448206, 0.9574701423246741, 0.9579649764725469, 0.9584547681023287, 0.9589395685988902, 0.9594194288234739, 0.9598943991190301, 0.9603645293154978, 0.9608298687350336, 0.9612904661971853, 0.9617463700240139, 0.9621976280451632, 0.9626442876028776, 0.9630863955569691, 0.9635239982897328, 0.9639571417108139, 0.9643858712620234, 0.9648102319221056, 0.9652302682114573, 0.965646024196798, 0.9660575434957934, 0.9664648692816312, 0.9668680442875506, 0.9672671108113251, 0.9676621107197008, 0.968053085452788, 0.9684400760284093, 0.9688231230464023, 0.9692022666928793, 0.9695775467444436, 0.9699490025723618, 0.970316673146695, 0.9706805970403867, 0.9710408124333098, 0.9713973571162724, 0.9717502684949818, 0.9720995835939695, 0.972445339060475, 0.9727875711682908, 0.9731263158215678, 0.9734616085585821, 0.9737934845554636, 0.9741219786298859, 0.9744471252447198, 0.974768958511648, 0.9750875121947444, 0.9754028197140164, 0.9757149141489107, 0.9760238282417836, 0.9763295944013368, 0.9766322447060167, 0.9769318109073801, 0.9772283244334253, 0.9775218163918893, 0.9778123175735113, 0.978099858455263, 0.978384469203546, 0.9786661796773569, 0.9789450194314191, 0.9792210177192842, 0.9794942034964008, 0.9797646054231522, 0.9800322518678631, 0.9802971709097762, 0.9805593903419972, 0.980818937674412, 0.981075840136571, 0.9813301246805476, 0.9815818179837645, 0.9818309464517931, 0.9820775362211237, 0.982321613161907, 0.9825632028806691, 0.982802330722997, 0.9830390217761984, 0.9832733008719332, 0.9835051925888186, 0.983734721255008, 0.9839619109507431, 0.9841867855108803, 0.9844093685273911, 0.9846296833518374, 0.984847753097821, 0.9850636006434089, 0.9852772486335333, 0.9854887194823672, 0.985698035375676, 0.9859052182731451, 0.9861102899106838, 0.9863132718027054, 0.9865141852443846, 0.9867130513138912, 0.9869098908746019, 0.987104724577289, 0.9872975728622867, 0.9874884559616356, 0.9876773939012056, 0.9878644065027962, 0.9880495133862168, 0.9882327339713445, 0.9884140874801618, 0.9885935929387727, 0.9887712691793994, 0.9889471348423577, 0.9891212083780128, 0.9892935080487143, 0.9894640519307132, 0.9896328579160572, 0.9897999437144686, 0.989965326855202, 0.9901290246888832, 0.9902910543893296, 0.9904514329553519, 0.9906101772125375, 0.9907673038150158, 0.9909228292472051, 0.9910767698255422, 0.9912291417001944, 0.9913799608567535, 0.9915292431179131, 0.9916770041451284, 0.9918232594402593, 0.9919680243471971, 0.9921113140534735, 0.9922531435918549, 0.9923935278419185, 0.9925324815316142, 0.9926700192388094, 0.9928061553928181, 0.9929409042759152, 0.9930742800248346, 0.9932062966322522, 0.9933369679482545, 0.9934663076817908, 0.9935943294021118, 0.9937210465401934, 0.9938464723901456, 0.993970620110607], \"type\": \"scatter\", \"uid\": \"5f5c0960-2aff-46d7-a9a9-c3e5900eea5e\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 9.4687374749499, 18.8874749498998, 28.3062124248497, 37.7249498997996, 47.1436873747495, 56.5624248496994, 65.9811623246493, 75.3998997995992, 84.81863727454909, 94.237374749499, 103.6561122244489, 113.0748496993988, 122.49358717434869, 131.91232464929863, 141.33106212424852, 150.7497995991984, 160.1685370741483, 169.5872745490982, 179.00601202404812, 188.424749498998, 197.8434869739479, 207.26222444889783, 216.68096192384772, 226.0996993987976, 235.5184368737475, 244.9371743486974, 254.35591182364732, 263.77464929859724, 273.1933867735471, 282.612124248497, 292.0308617234469, 301.4495991983968, 310.86833667334673, 320.2870741482966, 329.7058116232465, 339.1245490981964, 348.5432865731463, 357.9620240480962, 367.3807615230461, 376.799498997996, 386.21823647294593, 395.6369739478958, 405.0557114228457, 414.47444889779564, 423.8931863727455, 433.3119238476954, 442.7306613226453, 452.1493987975952, 461.56813627254513, 470.986873747495, 480.4056112224449, 489.8243486973948, 499.2430861723447, 508.6618236472946, 518.0805611222445, 527.4992985971944, 536.9180360721442, 546.3367735470941, 555.7555110220441, 565.174248496994, 574.5929859719439, 584.0117234468937, 593.4304609218436, 602.8491983967936, 612.2679358717435, 621.6866733466934, 631.1054108216432, 640.5241482965931, 649.942885771543, 659.361623246493, 668.7803607214429, 678.1990981963927, 687.6178356713426, 697.0365731462925, 706.4553106212425, 715.8740480961924, 725.2927855711423, 734.7115230460921, 744.130260521042, 753.548997995992, 762.9677354709419, 772.3864729458918, 781.8052104208416, 791.2239478957915, 800.6426853707414, 810.0614228456914, 819.4801603206413, 828.8988977955912, 838.317635270541, 847.7363727454909, 857.1551102204409, 866.5738476953908, 875.9925851703407, 885.4113226452905, 894.8300601202404, 904.2487975951904, 913.6675350701403, 923.0862725450902, 932.50501002004, 941.9237474949899, 951.3424849699398, 960.7612224448898, 970.1799599198397, 979.5986973947895, 989.0174348697394, 998.4361723446893, 1007.8549098196393, 1017.2736472945892, 1026.692384769539, 1036.111122244489, 1045.529859719439, 1054.9485971943889, 1064.3673346693386, 1073.7860721442885, 1083.2048096192384, 1092.6235470941883, 1102.0422845691382, 1111.4610220440882, 1120.879759519038, 1130.298496993988, 1139.717234468938, 1149.1359719438879, 1158.5547094188375, 1167.9734468937875, 1177.3921843687374, 1186.8109218436873, 1196.2296593186372, 1205.6483967935872, 1215.067134268537, 1224.485871743487, 1233.904609218437, 1243.3233466933868, 1252.7420841683368, 1262.1608216432865, 1271.5795591182364, 1280.9982965931863, 1290.4170340681362, 1299.8357715430861, 1309.254509018036, 1318.673246492986, 1328.091983967936, 1337.5107214428858, 1346.9294589178357, 1356.3481963927854, 1365.7669338677354, 1375.1856713426853, 1384.6044088176352, 1394.0231462925851, 1403.441883767535, 1412.860621242485, 1422.279358717435, 1431.6980961923848, 1441.1168336673347, 1450.5355711422847, 1459.9543086172343, 1469.3730460921843, 1478.7917835671342, 1488.210521042084, 1497.629258517034, 1507.047995991984, 1516.4667334669339, 1525.8854709418838, 1535.3042084168337, 1544.7229458917836, 1554.1416833667336, 1563.5604208416833, 1572.9791583166332, 1582.397895791583, 1591.816633266533, 1601.235370741483, 1610.6541082164329, 1620.0728456913828, 1629.4915831663327, 1638.9103206412826, 1648.3290581162325, 1657.7477955911825, 1667.1665330661322, 1676.585270541082, 1686.004008016032, 1695.422745490982, 1704.8414829659318, 1714.2602204408818, 1723.6789579158317, 1733.0976953907816, 1742.5164328657315, 1751.9351703406815, 1761.3539078156311, 1770.772645290581, 1780.191382765531, 1789.610120240481, 1799.0288577154308, 1808.4475951903808, 1817.8663326653307, 1827.2850701402806, 1836.7038076152305, 1846.1225450901804, 1855.5412825651304, 1864.96002004008, 1874.37875751503, 1883.79749498998, 1893.2162324649298, 1902.6349699398797, 1912.0537074148297, 1921.4724448897796, 1930.8911823647295, 1940.3099198396794, 1949.7286573146293, 1959.147394789579, 1968.566132264529, 1977.9848697394789, 1987.4036072144288, 1996.8223446893787, 2006.2410821643286, 2015.6598196392786, 2025.0785571142285, 2034.4972945891784, 2043.9160320641283, 2053.3347695390785, 2062.7535070140284, 2072.1722444889783, 2081.5909819639282, 2091.009719438878, 2100.428456913828, 2109.847194388778, 2119.2659318637275, 2128.6846693386774, 2138.1034068136273, 2147.5221442885772, 2156.940881763527, 2166.359619238477, 2175.778356713427, 2185.197094188377, 2194.615831663327, 2204.0345691382768, 2213.4533066132267, 2222.8720440881766, 2232.2907815631265, 2241.7095190380765, 2251.1282565130264, 2260.5469939879763, 2269.965731462926, 2279.384468937876, 2288.803206412826, 2298.221943887776, 2307.640681362726, 2317.0594188376754, 2326.4781563126253, 2335.896893787575, 2345.315631262525, 2354.734368737475, 2364.153106212425, 2373.571843687375, 2382.990581162325, 2392.4093186372747, 2401.8280561122247, 2411.2467935871746, 2420.6655310621245, 2430.0842685370744, 2439.5030060120243, 2448.9217434869743, 2458.340480961924, 2467.759218436874, 2477.177955911824, 2486.596693386774, 2496.015430861724, 2505.434168336674, 2514.8529058116233, 2524.271643286573, 2533.690380761523, 2543.109118236473, 2552.527855711423, 2561.946593186373, 2571.365330661323, 2580.7840681362727, 2590.2028056112226, 2599.6215430861726, 2609.0402805611225, 2618.4590180360724, 2627.8777555110223, 2637.2964929859722, 2646.715230460922, 2656.133967935872, 2665.552705410822, 2674.971442885772, 2684.390180360722, 2693.8089178356718, 2703.2276553106217, 2712.646392785571, 2722.065130260521, 2731.483867735471, 2740.902605210421, 2750.321342685371, 2759.7400801603208, 2769.1588176352707, 2778.5775551102206, 2787.9962925851705, 2797.4150300601204, 2806.8337675350704, 2816.2525050100203, 2825.67124248497, 2835.08997995992, 2844.50871743487, 2853.92745490982, 2863.34619238477, 2872.76492985972, 2882.1836673346697, 2891.6024048096197, 2901.0211422845696, 2910.4398797595195, 2919.858617234469, 2929.277354709419, 2938.696092184369, 2948.1148296593187, 2957.5335671342687, 2966.9523046092186, 2976.3710420841685, 2985.7897795591184, 2995.2085170340683, 3004.6272545090183, 3014.045991983968, 3023.464729458918, 3032.883466933868, 3042.302204408818, 3051.720941883768, 3061.139679358718, 3070.5584168336677, 3079.9771543086176, 3089.3958917835675, 3098.8146292585175, 3108.2333667334674, 3117.652104208417, 3127.070841683367, 3136.4895791583167, 3145.9083166332666, 3155.3270541082165, 3164.7457915831665, 3174.1645290581164, 3183.5832665330663, 3193.0020040080162, 3202.420741482966, 3211.839478957916, 3221.258216432866, 3230.676953907816, 3240.095691382766, 3249.5144288577158, 3258.9331663326657, 3268.3519038076156, 3277.7706412825655, 3287.1893787575154, 3296.6081162324654, 3306.0268537074153, 3315.445591182365, 3324.8643286573147, 3334.2830661322646, 3343.7018036072145, 3353.1205410821644, 3362.5392785571144, 3371.9580160320643, 3381.376753507014, 3390.795490981964, 3400.214228456914, 3409.632965931864, 3419.051703406814, 3428.470440881764, 3437.8891783567137, 3447.3079158316636, 3456.7266533066136, 3466.1453907815635, 3475.5641282565134, 3484.9828657314633, 3494.4016032064133, 3503.820340681363, 3513.239078156313, 3522.6578156312626, 3532.0765531062125, 3541.4952905811624, 3550.9140280561123, 3560.3327655310623, 3569.751503006012, 3579.170240480962, 3588.588977955912, 3598.007715430862, 3607.426452905812, 3616.845190380762, 3626.2639278557117, 3635.6826653306616, 3645.1014028056115, 3654.5201402805615, 3663.9388777555114, 3673.3576152304613, 3682.776352705411, 3692.195090180361, 3701.613827655311, 3711.032565130261, 3720.4513026052105, 3729.8700400801604, 3739.2887775551103, 3748.70751503006, 3758.12625250501, 3767.54498997996, 3776.96372745491, 3786.38246492986, 3795.80120240481, 3805.2199398797597, 3814.6386773547097, 3824.0574148296596, 3833.4761523046095, 3842.8948897795594, 3852.3136272545094, 3861.7323647294593, 3871.151102204409, 3880.569839679359, 3889.988577154309, 3899.407314629259, 3908.826052104209, 3918.2447895791584, 3927.6635270541083, 3937.082264529058, 3946.501002004008, 3955.919739478958, 3965.338476953908, 3974.757214428858, 3984.175951903808, 3993.5946893787577, 4003.0134268537076, 4012.4321643286576, 4021.8509018036075, 4031.2696392785574, 4040.6883767535073, 4050.1071142284572, 4059.525851703407, 4068.944589178357, 4078.363326653307, 4087.782064128257, 4097.200801603207, 4106.619539078157, 4116.038276553107, 4125.457014028057, 4134.8757515030065, 4144.2944889779565, 4153.713226452906, 4163.131963927856, 4172.550701402806, 4181.969438877756, 4191.388176352706, 4200.806913827656, 4210.225651302606, 4219.644388777556, 4229.063126252505, 4238.481863727455, 4247.900601202405, 4257.319338677355, 4266.7380761523045, 4276.156813627254, 4285.575551102204, 4294.994288577154, 4304.413026052104, 4313.831763527054, 4323.250501002004, 4332.669238476954, 4342.087975951904, 4351.506713426854, 4360.925450901804, 4370.344188376754, 4379.762925851704, 4389.1816633266535, 4398.600400801603, 4408.019138276553, 4417.437875751503, 4426.856613226453, 4436.275350701403, 4445.694088176353, 4455.112825651303, 4464.531563126253, 4473.950300601203, 4483.369038076153, 4492.787775551103, 4502.206513026053, 4511.6252505010025, 4521.043987975952, 4530.462725450902, 4539.881462925852, 4549.300200400802, 4558.718937875752, 4568.137675350702, 4577.556412825652, 4586.975150300602, 4596.393887775552, 4605.812625250502, 4615.231362725452, 4624.650100200401, 4634.068837675351, 4643.4875751503005, 4652.90631262525, 4662.3250501002, 4671.74378757515, 4681.1625250501, 4690.58126252505, 4700.0], \"y\": [0.9944935657942127, 0.9736733354708762, 0.9530698581843988, 0.9326808773853452, 0.912504160016524, 0.892537496268418, 0.87277869933716, 0.8532256051850269, 0.83387607230343, 0.8147279814783694, 0.7957792355583331, 0.7770277592246106, 0.7584714987639987, 0.7401084218438723, 0.7219365172895988, 0.7039537948642685, 0.6861582850507182, 0.6685480388358236, 0.6511211274970394, 0.6338756423911593, 0.6168096947452766, 0.5999214154499204, 0.5832089548543453, 0.5666704825639535, 0.550304187239824, 0.5341082764003304, 0.5180809762248229, 0.5022205313593551, 0.48652520472443217, 0.47099327732476204, 0.4556230480609853, 0.440412833543367, 0.4253609679074266, 0.4104658026314878, 0.395725706356129, 0.38113906470551084, 0.36670428011056644, 0.35241977163403027, 0.3382839747972912, 0.3242953414090446, 0.310452339395731, 0.29675345263373987, 0.2831971807833584, 0.26978203912445053, 0.2565065583938466, 0.24336928462442642, 0.2303687789858746, 0.2175036176270979, 0.20477239152027993, 0.19217370630656183, 0.17970618214332656, 0.1673684535530764, 0.15515916927388118, 0.14307699211138392, 0.13112059879234939, 0.11928867981973346, 0.1075799393292649, 0.09599309494751829, 0.0845268776514645, 0.07318003162948461, 0.06195131414382926, 0.05083949539451149, 0.03984335838461428, 0.028961698787003387, 0.018193324812424416, 0.007537057078976117, 0.003008271517058958, 0.01344381592903976, 0.02377071908645967, 0.03399011202012303, 0.044103113986019626, 0.05411083258790761, 0.06401436389862225, 0.07381479258012058, 0.08351319200227592, 0.09311062436043738, 0.1026081407917635, 0.11200678149034582, 0.12130757582113438, 0.13051154243267626, 0.1396196893686804, 0.14863301417842179, 0.15755250402599552, 0.166379135798434, 0.17511387621269814, 0.18375768192155473, 0.19231149961835203, 0.20077626614070365, 0.2091529085730941, 0.21744234434841558, 0.22564548134844742, 0.23376321800329025, 0.24179644338976403, 0.24974603732878242, 0.25761287048171344, 0.26539780444573624, 0.273101691848206, 0.2807253764400355, 0.2882696931881058, 0.29573546836671294, 0.3031235196480656, 0.31043465619183663, 0.31766967873378615, 0.3248293796734596, 0.33191454316097313, 0.3389259451828973, 0.34586435364724344, 0.35273052846756814, 0.3595252216462014, 0.36624917735660645, 0.37290313202488545, 0.3794878144104341, 0.3860039456857568, 0.3924522395154524, 0.3988334021343768, 0.40514813242499026, 0.41139712199390266, 0.41758105524761957, 0.4237006094674993, 0.42975645488393244, 0.435749254749746, 0.441679665412845, 0.44754833638809777, 0.45335591042847223, 0.45910302359543254, 0.46479030532860144, 0.4704183785146987, 0.47598785955576184, 0.48149935843665503, 0.48695347879187745, 0.49235081797167424, 0.49769196710746033, 0.5029775111765628, 0.5082080290662887, 0.513384093637327, 0.5185062717864896, 0.5235751245087994, 0.5285912069589322, 0.5335550685120183, 0.538467252823812, 0.5433282978902345, 0.5481387361062957, 0.5528990943244049, 0.557609893912072, 0.5622716508090095, 0.5668848755836403, 0.5714500734890153, 0.5759677445181507, 0.5804383834587891, 0.5848624799475893, 0.5892405185237528, 0.5935729786820924, 0.5978603349255468, 0.6021030568171504, 0.6063016090314606, 0.6104564514054506, 0.6145680389888717, 0.6186368220940914, 0.6226632463454138, 0.6266477527278844, 0.6305907776355886, 0.6344927529194471, 0.6383541059345126, 0.6421752595867753, 0.6459566323794814, 0.6496986384589674, 0.653401687660019, 0.6570661855507587, 0.6606925334770624, 0.6642811286065178, 0.6678323639719219, 0.6713466285143286, 0.674824307125645, 0.6782657806907867, 0.6816714261293932, 0.6850416164371094, 0.6883767207264362, 0.6916771042671581, 0.6949431285263475, 0.6981751512079539, 0.7013735262919806, 0.7045386040732536, 0.7076707311997869, 0.710770250710748, 0.7138375020740291, 0.7168728212234261, 0.719876540595431, 0.7228489891656413, 0.7257904924847911, 0.7287013727144044, 0.7315819486620811, 0.734432535816413, 0.7372534463815361, 0.7400449893113257, 0.7428074703432321, 0.7455411920317678, 0.7482464537816421, 0.7509235518805538, 0.7535727795316416, 0.7561944268855959, 0.7587887810724374, 0.7613561262329638, 0.7638967435498706, 0.7664109112785459, 0.7688989047775463, 0.7713609965387553, 0.7737974562172265, 0.7762085506607173, 0.7785945439389153, 0.7809556973723594, 0.7832922695610601, 0.7856045164128227, 0.7878926911712751, 0.7901570444436028, 0.7923978242279969, 0.7946152759408156, 0.7968096424434625, 0.7989811640689851, 0.8011300786483981, 0.8032566215367295, 0.8053610256387987, 0.8074435214347244, 0.8095043370051673, 0.8115436980563103, 0.8135618279445784, 0.8155589477011013, 0.8175352760559214, 0.8194910294619495, 0.8214264221186718, 0.823341665995609, 0.825236970855532, 0.8271125442774365, 0.828968591679276, 0.8308053163404608, 0.8326229194241224, 0.8344215999991433, 0.8362015550619619, 0.8379629795581468, 0.8397060664037477, 0.8414310065064246, 0.8431379887863566, 0.8448272001969326, 0.8464988257452267, 0.8481530485122617, 0.8497900496730595, 0.8514100085164844, 0.8530131024648795, 0.8545995070934982, 0.8561693961497335, 0.8577229415721481, 0.8592603135093045, 0.8607816803384007, 0.8622872086837117, 0.8637770634348376, 0.8652514077647642, 0.8667104031477326, 0.8681542093769256, 0.8695829845819677, 0.8709968852462449, 0.8723960662240421, 0.873780680757504, 0.8751508804934183, 0.8765068154998241, 0.8778486342824487, 0.8791764838009715, 0.8804905094851195, 0.8817908552505959, 0.8830776635148411, 0.8843510752126315, 0.8856112298115146, 0.8868582653270842, 0.8880923183380958, 0.8893135240014255, 0.8905220160668724, 0.8917179268918076, 0.8929013874556704, 0.8940725273743126, 0.8952314749141959, 0.8963783570064385, 0.8975132992607182, 0.8986364259790285, 0.8997478601692932, 0.9008477235588384, 0.9019361366077238, 0.9030132185219368, 0.9040790872664478, 0.9051338595781299, 0.9061776509785443, 0.9072105757865927, 0.9082327471310381, 0.9092442769628941, 0.9102452760676869, 0.9112358540775884, 0.9122161194834237, 0.913186179646553, 0.9141461408106306, 0.9150961081132403, 0.9160361855974108, 0.916966476223011, 0.9178870818780259, 0.918798103389716, 0.9196996405356601, 0.9205917920546831, 0.9214746556576705, 0.9223483280382694, 0.9232129048834793, 0.9240684808841313, 0.9249151497452597, 0.9257530041963641, 0.9265821360015658, 0.9274026359696579, 0.9282145939640511, 0.9290180989126158, 0.9298132388174211, 0.9306001007643739, 0.9313787709327566, 0.9321493346046649, 0.9329118761743493, 0.9336664791574574, 0.9344132262001811, 0.9351521990883078, 0.9358834787561785, 0.9366071452955516, 0.9373232779643743, 0.9380319551954641, 0.9387332546050982, 0.9394272530015145, 0.9401140263933243, 0.940793649997836, 0.9414661982492938, 0.94213174480703, 0.9427903625635319, 0.9434421236524259, 0.9440870994563766, 0.9447253606149063, 0.9453569770321305, 0.9459820178844143, 0.9466005516279491, 0.9472126460062498, 0.9478183680575741, 0.9484177841222655, 0.9490109598500178, 0.9495979602070665, 0.9501788494833033, 0.9507536912993177, 0.9513225486133645, 0.9518854837282597, 0.9524425582982033, 0.952993833335533, 0.9535393692174052, 0.9540792256924084, 0.9546134618871069, 0.9551421363125167, 0.9556653068705128, 0.9561830308601722, 0.9566953649840487, 0.957202365354383, 0.9577040874992485, 0.9582005863686329, 0.9586919163404564, 0.9591781312265272, 0.9596592842784355, 0.9601354281933855, 0.9606066151199667, 0.9610728966638657, 0.9615343238935184, 0.9619909473457027, 0.9624428170310733, 0.9628899824396396, 0.9633324925461859, 0.9637703958156344, 0.9642037402083545, 0.9646325731854144, 0.96505694171378, 0.9654768922714583, 0.965892470852588, 0.9663037229724774, 0.966710693672588, 0.9671134275254692, 0.967511968639639, 0.967906360664415, 0.9682966467946954, 0.9686828697756893, 0.9690650719075987, 0.9694432950502511, 0.9698175806276841, 0.9701879696326824, 0.9705545026312674, 0.9709172197671402, 0.9712761607660778, 0.9716313649402847, 0.9719828711926977, 0.9723307180212474, 0.972674943523074, 0.9730155853987003, 0.9733526809561601, 0.9736862671150852, 0.974016380410748, 0.9743430569980637, 0.9746663326555495, 0.9749862427892435, 0.9753028224365825, 0.9756161062702392, 0.9759261286019197, 0.9762329233861216, 0.9765365242238523, 0.9768369643663097, 0.9771342767185238, 0.9774284938429599, 0.977719647963086, 0.9780077709669011, 0.9782928944104281, 0.9785750495211699, 0.9788542672015295, 0.979130578032194, 0.9794040122754851, 0.979674599878672, 0.9799423704772525, 0.9802073533981983, 0.9804695776631667, 0.9807290719916797, 0.980985864804269, 0.9812399842255889, 0.9814914580874967, 0.9817403139321005, 0.981986579014776, 0.9822302803071518, 0.9824714445000629, 0.9827100980064741, 0.9829462669643733, 0.9831799772396334, 0.9834112544288459, 0.983640123862124, 0.9838666106058765, 0.9840907394655543, 0.9843125349883655, 0.9845320214659651, 0.9847492229371152, 0.9849641631903175, 0.9851768657664194, 0.9853873539611909, 0.9855956508278777, 0.9858017791797248, 0.9860057615924755, 0.9862076204068442, 0.9864073777309625, 0.9866050554428017, 0.9868006751925678, 0.9869942584050729, 0.9871858262820826, 0.987375399804637, 0.9875629997353489, 0.9877486466206784, 0.9879323607931823, 0.9881141623737413, 0.9882940712737641, 0.9884721071973678, 0.9886482896435358, 0.9888226379082535, 0.9889951710866219, 0.9891659080749489, 0.9893348675728181, 0.9895020680851382, 0.9896675279241686, 0.9898312652115254, 0.9899932978801661, 0.9901536436763538, 0.9903123201616006, 0.990469344714591, 0.9906247345330856, 0.9907785066358041, 0.9909306778642897, 0.9910812648847532, 0.991230284189899, 0.9913777521007309, 0.9915236847683393, 0.991668098175671, 0.9918110081392792, 0.9919524303110558, 0.9920923801799454, 0.9922308730736422, 0.9923679241602683, 0.9925035484500354, 0.9926377607968881, 0.9927705759001315, 0.9929020083060406, 0.9930320724094535, 0.9931607824553481, 0.9932881525404023, 0.9934141966145377, 0.9935389284824475, 0.9936623618051087, 0.9937845101012779, 0.9939053867489719, 0.9940250049869334, 0.9941433779160804, 0.9942605185009412, 0.9943764395710746, 0.9944911538224747, 0.9946046738189613], \"type\": \"scatter\", \"uid\": \"e8520d65-911d-4431-810c-6c26def5d86a\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 9.669138276553106, 19.28827655310621, 28.907414829659317, 38.52655310621242, 48.14569138276552, 57.76482965931863, 67.38396793587174, 77.00310621242484, 86.62224448897794, 96.24138276553104, 105.86052104208416, 115.47965931863726, 125.09879759519036, 134.7179358717435, 144.33707414829658, 153.9562124248497, 163.5753507014028, 173.1944889779559, 182.81362725450902, 192.4327655310621, 202.05190380761522, 211.67104208416833, 221.29018036072142, 230.90931863727454, 240.52845691382765, 250.14759519038074, 259.76673346693383, 269.385871743487, 279.00501002004006, 288.62414829659315, 298.2432865731463, 307.8624248496994, 317.48156312625247, 327.1007014028056, 336.7198396793587, 346.3389779559118, 355.95811623246493, 365.577254509018, 375.1963927855711, 384.8155310621242, 394.43466933867734, 404.0538076152304, 413.6729458917835, 423.29208416833666, 432.91122244488975, 442.53036072144283, 452.149498997996, 461.76863727454906, 471.38777555110215, 481.0069138276553, 490.6260521042084, 500.24519038076147, 509.8643286573146, 519.4834669338676, 529.1026052104207, 538.7217434869739, 548.3408817635269, 557.96002004008, 567.5791583166332, 577.1982965931862, 586.8174348697394, 596.4365731462925, 606.0557114228455, 615.6748496993987, 625.2939879759518, 634.9131262525049, 644.532264529058, 654.1514028056112, 663.7705410821642, 673.3896793587173, 683.0088176352705, 692.6279559118235, 702.2470941883766, 711.8662324649298, 721.4853707414828, 731.104509018036, 740.7236472945891, 750.3427855711421, 759.9619238476953, 769.5810621242483, 779.2002004008015, 788.8193386773546, 798.4384769539076, 808.0576152304608, 817.6767535070139, 827.295891783567, 836.9150300601201, 846.5341683366732, 856.1533066132263, 865.7724448897794, 875.3915831663326, 885.0107214428856, 894.6298597194387, 904.2489979959919, 913.8681362725449, 923.4872745490981, 933.1064128256512, 942.7255511022042, 952.3446893787574, 961.9638276553105, 971.5829659318636, 981.2021042084167, 990.8212424849698, 1000.4403807615229, 1010.059519038076, 1019.6786573146292, 1029.2977955911822, 1038.9169338677352, 1048.5360721442885, 1058.1552104208415, 1067.7743486973945, 1077.3934869739478, 1087.0126252505008, 1096.6317635270539, 1106.2509018036071, 1115.8700400801602, 1125.4891783567132, 1135.1083166332664, 1144.7274549098195, 1154.3465931863725, 1163.9657314629258, 1173.5848697394788, 1183.2040080160318, 1192.823146292585, 1202.442284569138, 1212.0614228456911, 1221.6805611222444, 1231.2996993987974, 1240.9188376753505, 1250.5379759519037, 1260.1571142284567, 1269.7762525050098, 1279.395390781563, 1289.014529058116, 1298.633667334669, 1308.2528056112224, 1317.8719438877754, 1327.4910821643284, 1337.1102204408817, 1346.7293587174347, 1356.3484969939877, 1365.967635270541, 1375.586773547094, 1385.205911823647, 1394.8250501002003, 1404.4441883767533, 1414.0633266533064, 1423.6824649298596, 1433.3016032064127, 1442.9207414829657, 1452.539879759519, 1462.159018036072, 1471.778156312625, 1481.3972945891783, 1491.0164328657313, 1500.6355711422843, 1510.2547094188376, 1519.8738476953906, 1529.4929859719437, 1539.1121242484967, 1548.73126252505, 1558.350400801603, 1567.969539078156, 1577.5886773547093, 1587.2078156312623, 1596.8269539078153, 1606.4460921843686, 1616.0652304609216, 1625.6843687374746, 1635.303507014028, 1644.922645290581, 1654.541783567134, 1664.1609218436872, 1673.7800601202403, 1683.3991983967933, 1693.0183366733465, 1702.6374749498996, 1712.2566132264526, 1721.8757515030059, 1731.494889779559, 1741.114028056112, 1750.7331663326652, 1760.3523046092182, 1769.9714428857712, 1779.5905811623245, 1789.2097194388775, 1798.8288577154306, 1808.4479959919838, 1818.0671342685368, 1827.6862725450899, 1837.3054108216431, 1846.9245490981962, 1856.5436873747492, 1866.1628256513025, 1875.7819639278555, 1885.4011022044085, 1895.0202404809618, 1904.6393787575148, 1914.2585170340678, 1923.877655310621, 1933.4967935871741, 1943.1159318637272, 1952.7350701402804, 1962.3542084168334, 1971.9733466933865, 1981.5924849699397, 1991.2116232464928, 2000.8307615230458, 2010.449899799599, 2020.069038076152, 2029.688176352705, 2039.3073146292584, 2048.9264529058114, 2058.5455911823647, 2068.164729458918, 2077.7838677354707, 2087.403006012024, 2097.0221442885772, 2106.64128256513, 2116.2604208416833, 2125.8795591182366, 2135.4986973947894, 2145.1178356713426, 2154.736973947896, 2164.3561122244487, 2173.975250501002, 2183.594388777555, 2193.213527054108, 2202.8326653306613, 2212.4518036072145, 2222.0709418837673, 2231.6900801603206, 2241.309218436874, 2250.9283567134266, 2260.54749498998, 2270.166633266533, 2279.785771543086, 2289.404909819639, 2299.0240480961925, 2308.6431863727453, 2318.2623246492985, 2327.881462925852, 2337.5006012024046, 2347.119739478958, 2356.738877755511, 2366.358016032064, 2375.977154308617, 2385.5962925851704, 2395.2154308617232, 2404.8345691382765, 2414.4537074148298, 2424.0728456913826, 2433.691983967936, 2443.311122244489, 2452.930260521042, 2462.549398797595, 2472.1685370741484, 2481.787675350701, 2491.4068136272545, 2501.0259519038077, 2510.6450901803605, 2520.2642284569138, 2529.883366733467, 2539.50250501002, 2549.121643286573, 2558.7407815631263, 2568.359919839679, 2577.9790581162324, 2587.5981963927857, 2597.2173346693385, 2606.8364729458917, 2616.455611222445, 2626.074749498998, 2635.693887775551, 2645.3130260521043, 2654.932164328657, 2664.5513026052104, 2674.1704408817636, 2683.7895791583164, 2693.4087174348697, 2703.027855711423, 2712.6469939879757, 2722.266132264529, 2731.8852705410823, 2741.504408817635, 2751.1235470941883, 2760.7426853707416, 2770.3618236472944, 2779.9809619238476, 2789.600100200401, 2799.2192384769537, 2808.838376753507, 2818.45751503006, 2828.076653306613, 2837.6957915831663, 2847.3149298597195, 2856.9340681362723, 2866.5532064128256, 2876.172344689379, 2885.7914829659317, 2895.410621242485, 2905.029759519038, 2914.648897795591, 2924.2680360721442, 2933.8871743486975, 2943.5063126252503, 2953.1254509018036, 2962.744589178357, 2972.3637274549096, 2981.982865731463, 2991.602004008016, 3001.221142284569, 3010.840280561122, 3020.4594188376755, 3030.0785571142283, 3039.6976953907815, 3049.316833667335, 3058.9359719438876, 3068.555110220441, 3078.1742484969936, 3087.793386773547, 3097.4125250501, 3107.031663326653, 3116.650801603206, 3126.2699398797595, 3135.8890781563123, 3145.5082164328655, 3155.127354709419, 3164.7464929859716, 3174.365631262525, 3183.984769539078, 3193.603907815631, 3203.223046092184, 3212.8421843687374, 3222.4613226452902, 3232.0804609218435, 3241.6995991983968, 3251.3187374749496, 3260.937875751503, 3270.557014028056, 3280.176152304609, 3289.795290581162, 3299.4144288577154, 3309.033567134268, 3318.6527054108215, 3328.2718436873747, 3337.8909819639275, 3347.510120240481, 3357.129258517034, 3366.748396793587, 3376.36753507014, 3385.9866733466934, 3395.605811623246, 3405.2249498997994, 3414.8440881763527, 3424.4632264529055, 3434.0823647294587, 3443.701503006012, 3453.320641282565, 3462.939779559118, 3472.5589178356713, 3482.178056112224, 3491.7971943887774, 3501.4163326653306, 3511.0354709418834, 3520.6546092184367, 3530.27374749499, 3539.8928857715428, 3549.512024048096, 3559.1311623246493, 3568.750300601202, 3578.3694388777553, 3587.9885771543086, 3597.6077154308614, 3607.2268537074146, 3616.845991983968, 3626.4651302605207, 3636.084268537074, 3645.703406813627, 3655.32254509018, 3664.9416833667333, 3674.5608216432865, 3684.1799599198393, 3693.7990981963926, 3703.418236472946, 3713.0373747494987, 3722.656513026052, 3732.275651302605, 3741.894789579158, 3751.5139278557112, 3761.1330661322645, 3770.7522044088173, 3780.3713426853706, 3789.990480961924, 3799.6096192384766, 3809.22875751503, 3818.847895791583, 3828.467034068136, 3838.086172344689, 3847.7053106212425, 3857.3244488977953, 3866.9435871743485, 3876.562725450902, 3886.1818637274546, 3895.801002004008, 3905.420140280561, 3915.039278557114, 3924.658416833667, 3934.2775551102204, 3943.896693386773, 3953.5158316633265, 3963.1349699398797, 3972.7541082164325, 3982.373246492986, 3991.992384769539, 4001.611523046092, 4011.230661322645, 4020.8497995991984, 4030.468937875751, 4040.0880761523044, 4049.7072144288577, 4059.3263527054105, 4068.9454909819638, 4078.564629258517, 4088.18376753507, 4097.802905811623, 4107.422044088176, 4117.041182364729, 4126.660320641282, 4136.279458917836, 4145.8985971943885, 4155.517735470941, 4165.136873747495, 4174.756012024048, 4184.375150300601, 4193.994288577154, 4203.613426853707, 4213.23256513026, 4222.851703406814, 4232.470841683366, 4242.089979959919, 4251.709118236473, 4261.328256513026, 4270.9473947895785, 4280.566533066132, 4290.185671342685, 4299.804809619238, 4309.423947895792, 4319.043086172344, 4328.662224448897, 4338.281362725451, 4347.900501002004, 4357.5196392785565, 4367.13877755511, 4376.757915831663, 4386.377054108216, 4395.9961923847695, 4405.615330661322, 4415.234468937875, 4424.853607214429, 4434.472745490982, 4444.0918837675345, 4453.711022044088, 4463.330160320641, 4472.949298597194, 4482.5684368737475, 4492.1875751503, 4501.806713426853, 4511.425851703407, 4521.04498997996, 4530.664128256512, 4540.283266533066, 4549.902404809619, 4559.521543086172, 4569.140681362725, 4578.759819639278, 4588.378957915831, 4597.998096192385, 4607.617234468938, 4617.23637274549, 4626.855511022044, 4636.474649298597, 4646.09378757515, 4655.712925851703, 4665.332064128256, 4674.951202404809, 4684.570340681363, 4694.1894789579155, 4703.808617234468, 4713.427755511022, 4723.046893787575, 4732.666032064128, 4742.285170340681, 4751.904308617234, 4761.523446893787, 4771.142585170341, 4780.7617234468935, 4790.380861723446, 4800.0], \"y\": [0.99506094198142, 0.9738000863316945, 0.952765255230019, 0.9319540458052593, 0.9113640807312489, 0.8909930079552197, 0.8708385004291199, 0.8508982558437879, 0.8311699963659536, 0.8116514683780343, 0.7923404422206974, 0.7732347119381597, 0.7543320950261947, 0.735630432182818, 0.7171275870616249, 0.6988214460277489, 0.6807099179164136, 0.6627909337940552, 0.6450624467219797, 0.6275224315225367, 0.6101688845477764, 0.5929998234505676, 0.5760132869581474, 0.5592073346480799, 0.5425800467265967, 0.5261295238092911, 0.5098538867041476, 0.49375127619687587, 0.4778198528385267, 0.46205779673536607, 0.4464633073409847, 0.4310346032506147, 0.4157699219976354, 0.4006675198522409, 0.38572567162224924, 0.37094267045602836, 0.35631682764751726, 0.3418464724433199, 0.3275299518518511, 0.3133656304545087, 0.299351890218857, 0.2854871303137916, 0.2717697669266741, 0.2581982330824071, 0.24477097846443407, 0.23148646923764282, 0.21834318787314988, 0.20533963297494995, 0.19247431910840618, 0.17974577663056412, 0.16715255152227138, 0.15469320522207952, 0.1423663144619136, 0.13017047110448732, 0.11810428198244893, 0.10616636873923313, 0.09435536767160912, 0.08266992957390107, 0.07110871958386222, 0.0596704170301916, 0.04835371528166954, 0.03715732159789642, 0.026079956981619468, 0.015120356032630067, 0.00427726680321161, 0.00645054934487288, 0.017064317881874236, 0.02756525125004694, 0.03795454900214923, 0.0482333979384717, 0.05840297224240987, 0.06846443361459331, 0.07841893140559086, 0.08826760274720469, 0.09801157268236749, 0.10765195429365959, 0.1171898488304608, 0.12662634583474763, 0.1359625232655558, 0.14519944762211934, 0.1543381740656986, 0.16337974654011533, 0.17232519789100553, 0.18117554998380392, 0.18993181382047497, 0.19859498965500288, 0.20716606710765306, 0.21564602527801968, 0.22403583285687145, 0.2323364482368071, 0.24054881962173658, 0.24867388513519606, 0.25671257292751337, 0.26466580128183326, 0.27253447871901526, 0.2803195041014167, 0.2880217667355732, 0.2956421464737856, 0.3031815138146293, 0.310640730002393, 0.3180206471254612, 0.3253221082136516, 0.33254594733451626, 0.3396929896886197, 0.34676405170380387, 0.35375994112845155, 0.3606814571237572, 0.3675293903550184, 0.37430452308195505, 0.38100762924806986, 0.38763947456905734, 0.39420081662027495, 0.4006924049232824, 0.4071149810314615, 0.4134692786147268, 0.41975602354333474, 0.425975933970801, 0.43212972041593833, 0.4382180858440212, 0.44424172574708676, 0.45020132822338366, 0.45609757405597595, 0.46193113679050934, 0.4677026828121543, 0.47341287142172805, 0.47906235491100824, 0.48465177863724684, 0.4901817810968916, 0.4956529939985218, 0.5010660423350118, 0.5064215444549253, 0.5117201121331503, 0.516962350640785, 0.5221488588142804, 0.5272802291238445, 0.5323570477411249, 0.537379894606167, 0.5423493434936629, 0.5472659620784956, 0.5521303120005863, 0.5569429489290507, 0.5617044226256771, 0.5664152770077255, 0.5710760502100616, 0.5756872746466293, 0.5802494770712707, 0.5847631786378971, 0.5892288949600235, 0.5936471361696685, 0.5980184069756269, 0.6023432067211258, 0.6066220294408652, 0.6108553639174523, 0.6150436937372386, 0.619187497345559, 0.623287248101388, 0.6273434143314119, 0.6313564593835277, 0.6353268416797716, 0.6392550147686873, 0.6431414273771355, 0.6469865234615534, 0.6507907422586687, 0.6545545183356761, 0.6582782816398779, 0.6619624575477987, 0.6656074669137775, 0.6692137261180436, 0.6727816471142797, 0.6763116374766815, 0.6798041004465163, 0.6832594349781853, 0.6866780357847988, 0.6900602933832648, 0.6934065941388982, 0.6967173203095576, 0.6999928500893112, 0.7032335576516391, 0.7064398131921759, 0.7096119829710004, 0.7127504293544729, 0.7158555108566306, 0.7189275821801415, 0.7219669942568228, 0.724974094287729, 0.7279492257828142, 0.7308927286001714, 0.7338049389848562, 0.7366861896072969, 0.739536809601296, 0.7423571246016287, 0.7451474567812413, 0.7479081248880525, 0.7506394442813671, 0.753341726967899, 0.7560152816374128, 0.7586604136979864, 0.7612774253108991, 0.7638666154251481, 0.7664282798115982, 0.7689627110967685, 0.7714701987962603, 0.7739510293478296, 0.7764054861441068, 0.77883384956497, 0.7812363970095743, 0.7836134029280386, 0.785965138852798, 0.7882918734296207, 0.7905938724482975, 0.7928713988730024, 0.7951247128723331, 0.7973540718490294, 0.7995597304693783, 0.8017419406923049, 0.8039009517981539, 0.8060370104171662, 0.8081503605576525, 0.8102412436338662, 0.8123098984935812, 0.8143565614453767, 0.816381466285631, 0.8183848443252285, 0.8203669244159838, 0.8223279329767831, 0.8242680940194496, 0.8261876291743326, 0.8280867577156252, 0.8299656965864121, 0.8318246604234525, 0.8336638615816983, 0.8354835101585513, 0.837283814017865, 0.8390649788136876, 0.8408272080137555, 0.8425707029227365, 0.8442956627052238, 0.8460022844084887, 0.8476907629849892, 0.8493612913146402, 0.8510140602268464, 0.8526492585223021, 0.8542670729945575, 0.8558676884513572, 0.8574512877357514, 0.8590180517469824, 0.8605681594611492, 0.8621017879516528, 0.8636191124094236, 0.8651203061629337, 0.8666055406979974, 0.86807498567736, 0.8695288089600789, 0.870967176620699, 0.8723902529682234, 0.8737982005648833, 0.875191180244708, 0.8765693511318969, 0.8779328706589974, 0.8792818945848885, 0.8806165770125736, 0.8819370704067843, 0.8832435256113969, 0.8845360918666636, 0.8858149168262607, 0.8870801465741556, 0.8883319256412944, 0.8895703970221119, 0.8907957021908666, 0.8920079811178013, 0.8932073722851329, 0.8943940127028712, 0.8955680379244699, 0.8967295820623115, 0.8978787778030274, 0.8990157564226549, 0.9001406478016332, 0.9012535804396405, 0.9023546814702723, 0.9034440766755645, 0.9045218905003618, 0.9055882460665339, 0.9066432651870391, 0.90768706837984, 0.9087197748816709, 0.9097415026616578, 0.9107523684347947, 0.9117524876752767, 0.9127419746296903, 0.9137209423300646, 0.9146895026067832, 0.9156477661013583, 0.916595842279071, 0.9175338394414743, 0.9184618647387655, 0.9193800241820265, 0.9202884226553332, 0.9211871639277368, 0.9220763506651183, 0.9229560844419152, 0.9238264657527259, 0.9246875940237883, 0.9255395676243386, 0.9263824838778475, 0.9272164390731384, 0.9280415284753863, 0.9288578463370002, 0.9296654859083903, 0.9304645394486196, 0.9312550982359438, 0.9320372525782373, 0.9328110918233102, 0.9335767043691142, 0.9343341776738406, 0.9350835982659115, 0.9358250517538632, 0.9365586228361265, 0.9372843953107015, 0.9380024520847301, 0.938712875183967, 0.9394157457621494, 0.9401111441102679, 0.940799149665738, 0.9414798410214742, 0.9421532959348691, 0.942819591336674, 0.943478803339789, 0.9441310072479556, 0.9447762775643607, 0.9454146880001457, 0.946046311482828, 0.946671220164631, 0.9472894854307267, 0.9479011779073896, 0.9485063674700653, 0.9491051232513523, 0.9496975136488991, 0.9502836063332174, 0.9508634682554123, 0.9514371656548312, 0.9520047640666289, 0.9525663283292554, 0.9531219225918615, 0.9536716103216274, 0.9542154543110126, 0.9547535166849288, 0.9552858589078365, 0.9558125417907664, 0.956333625498266, 0.9568491695552724, 0.9573592328539122, 0.9578638736602286, 0.9583631496208372, 0.9588571177695115, 0.9593458345336983, 0.9598293557409624, 0.9603077366253654, 0.9607810318337743, 0.9612492954321041, 0.9617125809114944, 0.9621709411944194, 0.9626244286407333, 0.9630730950536518, 0.9635169916856701, 0.9639561692444164, 0.9643906778984458, 0.9648205672829703, 0.9652458865055291, 0.9656666841515983, 0.9660830082901408, 0.9664949064790975, 0.96690242577082, 0.9673056127174454, 0.9677045133762143, 0.9680991733147318, 0.9684896376161731, 0.9688759508844332, 0.9692581572492224, 0.9696363003711069, 0.9700104234464971, 0.9703805692125812, 0.9707467799522078, 0.9711090974987157, 0.9714675632407125, 0.9718222181268029, 0.9721731026702665, 0.9725202569536848, 0.9728637206335214, 0.9732035329446509, 0.9735397327048412, 0.973872358319188, 0.9742014477845015, 0.9745270386936471, 0.97484916823984, 0.9751678732208936, 0.9754831900434229, 0.9757951547270035, 0.9761038029082865, 0.9764091698450686, 0.9767112904203209, 0.9770101991461724, 0.9773059301678533, 0.9775985172675952, 0.97788799386849, 0.9781743930383084, 0.978457747493277, 0.9787380896018151, 0.9790154513882332, 0.9792898645363909, 0.9795613603933155, 0.9798299699727842, 0.9800957239588655, 0.9803586527094255, 0.9806187862595949, 0.9808761543252007, 0.9811307863061601, 0.9813827112898396, 0.9816319580543769, 0.9818785550719691, 0.9821225305121248, 0.9823639122448822, 0.982602727843992, 0.9828390045900688, 0.9830727694737056, 0.9833040491985583, 0.9835328701843958, 0.9837592585701179, 0.9839832402167412, 0.9842048407103533, 0.9844240853650358, 0.9846409992257559, 0.9848556070712268, 0.9850679334167394, 0.9852780025169616, 0.9854858383687098, 0.9856914647136896, 0.9858949050412082, 0.9860961825908574, 0.9862953203551688, 0.9864923410822394, 0.9866872672783312, 0.9868801212104418, 0.9870709249088476, 0.9872597001696211, 0.9874464685571198, 0.9876312514064507, 0.9878140698259065, 0.9879949446993773, 0.9881738966887367, 0.9883509462362006, 0.9885261135666641, 0.9886994186900109, 0.9888708814033988, 0.9890405212935224, 0.9892083577388492, 0.989374409911834, 0.9895386967811091, 0.9897012371136505, 0.9898620494769228, 0.9900211522409987, 0.9901785635806591, 0.9903343014774679, 0.990488383721827, 0.990640827915008, 0.9907916514711631, 0.9909408716193145, 0.9910885054053222, 0.9912345696938314, 0.9913790811701988, 0.9915220563423989, 0.9916635115429098, 0.9918034629305782, 0.9919419264924664, 0.9920789180456776, 0.9922144532391631, 0.99234854755551, 0.9924812163127099, 0.992612474665908, 0.9927423376091354, 0.9928708199770213, 0.9929979364464874, 0.9931237015384251, 0.9932481296193537, 0.9933712349030619, 0.9934930314522313, 0.993613533180043, 0.9937327538517665, 0.9938507070863329, 0.9939674063578898, 0.9940828649973412, 0.9941970961938698, 0.9943101129964437, 0.9944219283153077, 0.9945325549234572, 0.9946420054580976, 0.9947502924220881, 0.9948574281853697, 0.9949634249863784, 0.9950682949334431, 0.9951720500061686], \"type\": \"scatter\", \"uid\": \"b8e50322-5dde-40e2-b3bb-5ca95c39b21e\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 9.869539078156313, 19.689078156312625, 29.50861723446894, 39.32815631262525, 49.14769539078156, 58.967234468937875, 68.78677354709419, 78.6063126252505, 88.4258517034068, 98.24539078156312, 108.06492985971943, 117.88446893787575, 127.70400801603206, 137.5235470941884, 147.3430861723447, 157.162625250501, 166.98216432865732, 176.80170340681363, 186.62124248496994, 196.44078156312625, 206.26032064128256, 216.07985971943887, 225.89939879759518, 235.71893787575152, 245.53847695390783, 255.35801603206414, 265.17755511022045, 274.99709418837676, 284.8166332665331, 294.6361723446894, 304.4557114228457, 314.275250501002, 324.0947895791583, 333.9143286573146, 343.73386773547094, 353.55340681362725, 363.37294589178356, 373.19248496993987, 383.0120240480962, 392.8315631262525, 402.6511022044088, 412.4706412825651, 422.2901803607214, 432.10971943887773, 441.92925851703404, 451.74879759519035, 461.56833667334666, 471.38787575150303, 481.20741482965934, 491.02695390781565, 500.84649298597196, 510.6660320641283, 520.4855711422845, 530.3051102204408, 540.1246492985971, 549.9441883767535, 559.7637274549097, 569.5832665330661, 579.4028056112223, 589.2223446893787, 599.041883767535, 608.8614228456913, 618.6809619238476, 628.500501002004, 638.3200400801603, 648.1395791583166, 657.9591182364729, 667.7786573146292, 677.5981963927856, 687.4177354709418, 697.2372745490982, 707.0568136272544, 716.8763527054108, 726.695891783567, 736.5154308617234, 746.3349699398797, 756.154509018036, 765.9740480961923, 775.7935871743487, 785.6131262525049, 795.4326653306613, 805.2522044088175, 815.0717434869739, 824.8912825651302, 834.7108216432865, 844.5303607214428, 854.3498997995991, 864.1694388777554, 873.9889779559118, 883.808517034068, 893.6280561122244, 903.4475951903806, 913.267134268537, 923.0866733466933, 932.9062124248496, 942.725751503006, 952.5452905811622, 962.3648296593186, 972.1843687374749, 982.0039078156312, 991.8234468937875, 1001.6429859719439, 1011.4625250501001, 1021.2820641282565, 1031.1016032064128, 1040.921142284569, 1050.7406813627254, 1060.5602204408817, 1070.379759519038, 1080.1992985971942, 1090.0188376753506, 1099.838376753507, 1109.6579158316633, 1119.4774549098195, 1129.2969939879758, 1139.1165330661322, 1148.9360721442886, 1158.7556112224447, 1168.575150300601, 1178.3946893787574, 1188.2142284569138, 1198.03376753507, 1207.8533066132263, 1217.6728456913827, 1227.492384769539, 1237.3119238476952, 1247.1314629258516, 1256.951002004008, 1266.7705410821643, 1276.5900801603207, 1286.4096192384768, 1296.2291583166332, 1306.0486973947895, 1315.868236472946, 1325.687775551102, 1335.5073146292584, 1345.3268537074148, 1355.1463927855712, 1364.9659318637273, 1374.7854709418837, 1384.60501002004, 1394.4245490981964, 1404.2440881763525, 1414.063627254509, 1423.8831663326653, 1433.7027054108216, 1443.5222444889778, 1453.3417835671341, 1463.1613226452905, 1472.9808617234469, 1482.800400801603, 1492.6199398797594, 1502.4394789579158, 1512.2590180360721, 1522.0785571142283, 1531.8980961923846, 1541.717635270541, 1551.5371743486974, 1561.3567134268535, 1571.1762525050099, 1580.9957915831662, 1590.8153306613226, 1600.634869739479, 1610.454408817635, 1620.2739478957915, 1630.0934869739478, 1639.9130260521042, 1649.7325651302604, 1659.5521042084167, 1669.371643286573, 1679.1911823647295, 1689.0107214428856, 1698.830260521042, 1708.6497995991983, 1718.4693386773547, 1728.2888777555108, 1738.1084168336672, 1747.9279559118236, 1757.74749498998, 1767.567034068136, 1777.3865731462924, 1787.2061122244488, 1797.0256513026052, 1806.8451903807613, 1816.6647294589177, 1826.484268537074, 1836.3038076152304, 1846.1233466933866, 1855.942885771543, 1865.7624248496993, 1875.5819639278557, 1885.401503006012, 1895.2210420841682, 1905.0405811623245, 1914.860120240481, 1924.6796593186373, 1934.4991983967934, 1944.3187374749498, 1954.1382765531062, 1963.9578156312625, 1973.7773547094187, 1983.596893787575, 1993.4164328657314, 2003.2359719438878, 2013.055511022044, 2022.8750501002003, 2032.6945891783566, 2042.514128256513, 2052.3336673346694, 2062.153206412826, 2071.972745490982, 2081.7922845691382, 2091.611823647295, 2101.431362725451, 2111.250901803607, 2121.0704408817637, 2130.88997995992, 2140.7095190380765, 2150.5290581162326, 2160.3485971943887, 2170.1681362725453, 2179.9876753507015, 2189.8072144288576, 2199.626753507014, 2209.4462925851703, 2219.265831663327, 2229.085370741483, 2238.904909819639, 2248.724448897796, 2258.543987975952, 2268.3635270541085, 2278.1830661322647, 2288.002605210421, 2297.8221442885774, 2307.6416833667336, 2317.4612224448897, 2327.2807615230463, 2337.1003006012024, 2346.919839679359, 2356.739378757515, 2366.5589178356713, 2376.378456913828, 2386.197995991984, 2396.01753507014, 2405.837074148297, 2415.656613226453, 2425.4761523046095, 2435.2956913827657, 2445.115230460922, 2454.9347695390784, 2464.7543086172345, 2474.5738476953907, 2484.3933867735473, 2494.2129258517034, 2504.03246492986, 2513.852004008016, 2523.6715430861723, 2533.491082164329, 2543.310621242485, 2553.1301603206416, 2562.9496993987977, 2572.769238476954, 2582.5887775551105, 2592.4083166332666, 2602.2278557114228, 2612.0473947895794, 2621.8669338677355, 2631.686472945892, 2641.5060120240482, 2651.3255511022044, 2661.145090180361, 2670.964629258517, 2680.7841683366732, 2690.60370741483, 2700.423246492986, 2710.2427855711426, 2720.0623246492987, 2729.881863727455, 2739.7014028056115, 2749.5209418837676, 2759.3404809619237, 2769.1600200400803, 2778.9795591182365, 2788.799098196393, 2798.618637274549, 2808.4381763527053, 2818.257715430862, 2828.077254509018, 2837.8967935871747, 2847.716332665331, 2857.535871743487, 2867.3554108216435, 2877.1749498997997, 2886.994488977956, 2896.8140280561124, 2906.6335671342686, 2916.453106212425, 2926.2726452905813, 2936.0921843687374, 2945.911723446894, 2955.73126252505, 2965.5508016032063, 2975.370340681363, 2985.189879759519, 2995.0094188376756, 3004.828957915832, 3014.648496993988, 3024.4680360721445, 3034.2875751503007, 3044.107114228457, 3053.9266533066134, 3063.7461923847695, 3073.565731462926, 3083.3852705410823, 3093.2048096192384, 3103.024348697395, 3112.843887775551, 3122.6634268537073, 3132.482965931864, 3142.30250501002, 3152.1220440881766, 3161.9415831663327, 3171.761122244489, 3181.5806613226455, 3191.4002004008016, 3201.219739478958, 3211.0392785571144, 3220.8588176352705, 3230.678356713427, 3240.4978957915832, 3250.3174348697394, 3260.136973947896, 3269.956513026052, 3279.7760521042087, 3289.595591182365, 3299.415130260521, 3309.2346693386776, 3319.0542084168337, 3328.87374749499, 3338.6932865731465, 3348.5128256513026, 3358.332364729459, 3368.1519038076153, 3377.9714428857715, 3387.790981963928, 3397.610521042084, 3407.4300601202403, 3417.249599198397, 3427.069138276553, 3436.8886773547097, 3446.708216432866, 3456.527755511022, 3466.3472945891785, 3476.1668336673347, 3485.9863727454913, 3495.8059118236474, 3505.6254509018036, 3515.44498997996, 3525.2645290581163, 3535.0840681362724, 3544.903607214429, 3554.723146292585, 3564.5426853707418, 3574.362224448898, 3584.181763527054, 3594.0013026052106, 3603.820841683367, 3613.640380761523, 3623.4599198396795, 3633.2794589178357, 3643.0989979959922, 3652.9185370741484, 3662.7380761523045, 3672.557615230461, 3682.3771543086173, 3692.1966933867734, 3702.01623246493, 3711.835771543086, 3721.6553106212427, 3731.474849699399, 3741.294388777555, 3751.1139278557116, 3760.9334669338677, 3770.7530060120243, 3780.5725450901805, 3790.3920841683366, 3800.211623246493, 3810.0311623246494, 3819.8507014028055, 3829.670240480962, 3839.4897795591182, 3849.309318637275, 3859.128857715431, 3868.948396793587, 3878.7679358717437, 3888.5874749499, 3898.407014028056, 3908.2265531062126, 3918.0460921843687, 3927.8656312625253, 3937.6851703406815, 3947.5047094188376, 3957.324248496994, 3967.1437875751503, 3976.9633266533065, 3986.782865731463, 3996.602404809619, 4006.421943887776, 4016.241482965932, 4026.061022044088, 4035.8805611222447, 4045.700100200401, 4055.519639278557, 4065.3391783567135, 4075.1587174348697, 4084.9782565130263, 4094.7977955911824, 4104.617334669339, 4114.436873747495, 4124.256412825652, 4134.075951903807, 4143.895490981964, 4153.715030060121, 4163.534569138276, 4173.354108216433, 4183.1736472945895, 4192.993186372745, 4202.812725450902, 4212.632264529058, 4222.451803607214, 4232.271342685371, 4242.090881763527, 4251.910420841684, 4261.7299599198395, 4271.549498997996, 4281.369038076153, 4291.188577154308, 4301.008116232465, 4310.827655310622, 4320.647194388777, 4330.466733466934, 4340.2862725450905, 4350.105811623246, 4359.925350701403, 4369.744889779559, 4379.564428857715, 4389.383967935872, 4399.203507014028, 4409.023046092185, 4418.8425851703405, 4428.662124248497, 4438.481663326654, 4448.301202404809, 4458.120741482966, 4467.940280561123, 4477.759819639278, 4487.579358717435, 4497.398897795591, 4507.218436873747, 4517.037975951904, 4526.85751503006, 4536.677054108217, 4546.496593186373, 4556.316132264529, 4566.135671342686, 4575.9552104208415, 4585.774749498998, 4595.594288577155, 4605.41382765531, 4615.233366733467, 4625.0529058116235, 4634.872444889779, 4644.691983967936, 4654.511523046092, 4664.331062124248, 4674.150601202405, 4683.970140280561, 4693.789679358718, 4703.609218436874, 4713.42875751503, 4723.248296593187, 4733.067835671342, 4742.887374749499, 4752.706913827656, 4762.526452905811, 4772.345991983968, 4782.1655310621245, 4791.98507014028, 4801.804609218437, 4811.624148296593, 4821.44368737475, 4831.263226452906, 4841.082765531062, 4850.902304609219, 4860.7218436873745, 4870.541382765531, 4880.360921843688, 4890.180460921843, 4900.0], \"y\": [0.9955686525011576, 0.9738672696270858, 0.952401374844646, 0.9311684128032587, 0.9101658558812056, 0.8893912038847356, 0.8688419837504355, 0.8485157492508313, 0.8284100807031827, 0.808522584681439, 0.7888508937313201, 0.7693926660884891, 0.7501455853997825, 0.7311073604474669, 0.7122757248764868, 0.6936484369246723, 0.6752232791558743, 0.6569980581959964, 0.6389706044718892, 0.6211387719530808, 0.6035004378963069, 0.5860535025928149, 0.5687958891184104, 0.551725543086214, 0.5348404324021032, 0.5181385470228068, 0.5016178987166244, 0.4852765208267431, 0.4691124680371219, 0.4531238161409161, 0.43730866181141614, 0.4216651223754708, 0.4061913355893687, 0.39088545941715336, 0.37574567181134233, 0.3607701704960271, 0.34595717275232474, 0.33130491520615957, 0.3168116536183472, 0.302475662676956, 0.2882952357919213, 0.27426868489189005, 0.260394340223268, 0.2466705501514479, 0.23309568096419642, 0.21966811667717234, 0.2063862588415557, 0.19324852635376533, 0.18025335526723985, 0.16739919860626307, 0.15468452618180706, 0.14210782440937497, 0.12966759612882095, 0.11736236042612536, 0.10519065245710069, 0.09315102327301639, 0.0812420396481095, 0.06946228390897313, 0.05781035376579036, 0.046284862145404615, 0.03488443702619737, 0.02360772127476185, 0.012453372484343639, 0.0014200628150404793, 0.009493521164269603, 0.02028867863228012, 0.03096669466991442, 0.04152884041330496, 0.051976373205111615, 0.062310536744199285, 0.07253256123369001, 0.0826436635274107, 0.09264504727474832, 0.10253790306393684, 0.1123234085637862, 0.12200272866387651, 0.13157701561322732, 0.1410474091574656, 0.15041503667450296, 0.15968101330874152, 0.16884644210382305, 0.17791241413393888, 0.18688000863371246, 0.19575029312667525, 0.20452432355234662, 0.21320314439193533, 0.22178778879267713, 0.23027927869082354, 0.23867862493329473, 0.24698682739801348, 0.2552048751129329, 0.26333374637377316, 0.27137440886047925, 0.2793278197524167, 0.28719492584231554, 0.29497666364898, 0.3026739595287725, 0.31028772978589036, 0.31781888078144427, 0.32526830904135373, 0.3326369013630721, 0.33992553492115174, 0.34713507737166693, 0.3542663869554996, 0.3613203126005078, 0.3682976940225836, 0.37519936182561453, 0.3820261376003612, 0.388778834022261, 0.3954582549481711, 0.4020651955120609, 0.40860044221966785, 0.41506477304212375, 0.42145895750856666, 0.4277837567977476, 0.4340399238286433, 0.4402282033500846, 0.44634933202941385, 0.4524040385401794, 0.45839304364887834, 0.46431706030075837, 0.4701767937046887, 0.4759729414171092, 0.48170619342507015, 0.48737723222836893, 0.49298673292079653, 0.49853536327050285, 0.5040237837994895, 0.5094526478622387, 0.5148226017234914, 0.5201342846351793, 0.5253883289125236, 0.5305853600093071, 0.5357259965923293, 0.540810850615054, 0.5458405273904583, 0.5508156256630898, 0.555736737680343, 0.5606044492629616, 0.5654193398747758, 0.5701819826916834, 0.5748929446698821, 0.5795527866133605, 0.5841620632406588, 0.5887213232509025, 0.5932311093891218, 0.5976919585108607, 0.6021044016460855, 0.6064689640624006, 0.6107861653275766, 0.6150565193714015, 0.6192805345468597, 0.6234587136906482, 0.627591554183035, 0.631679548007068, 0.6357231818071425, 0.6397229369469324, 0.6436792895666926, 0.6475927106399402, 0.6514636660295194, 0.6552926165430605, 0.659080017987834, 0.6628263212250117, 0.6665319722233383, 0.6701974121122201, 0.6738230772342388, 0.6774093991970942, 0.6809568049249838, 0.684465716709425, 0.6879365522595258, 0.6913697247517099, 0.6947656428789017, 0.6981247108991786, 0.7014473286838947, 0.7047338917652821, 0.7079847913835365, 0.7112004145333912, 0.7143811440101854, 0.7175273584554338, 0.7206394324019003, 0.7237177363181838, 0.7267626366528194, 0.7297744958779011, 0.7327536725322317, 0.7357005212640038, 0.7386153928730185, 0.7414986343524446, 0.7443505889301258, 0.7471715961094402, 0.7499619917097142, 0.7527221079062, 0.7554522732696183, 0.7581528128052725, 0.7608240479917376, 0.7634662968191301, 0.7660798738269622, 0.7686650901415848, 0.771222253513226, 0.7737516683526253, 0.7762536357672714, 0.7787284535972472, 0.7811764164506854, 0.7835978157388388, 0.7859929397107716, 0.7883620734876718, 0.7907054990967939, 0.7930234955050317, 0.7953163386521268, 0.7975843014835181, 0.7998276539828326, 0.8020466632040257, 0.8042415933031718, 0.80641270556991, 0.8085602584585488, 0.8106845076188326, 0.8127857059263754, 0.8148641035127636, 0.8169199477953317, 0.8189534835066166, 0.8209649527234898, 0.8229545948959757, 0.824922646875756, 0.8268693429443651, 0.8287949148410796, 0.8306995917905048, 0.8325836005298625, 0.8344471653359824, 0.8362905080519998, 0.8381138481137652, 0.8399174025759664, 0.8417013861379661, 0.8434660111693618, 0.8452114877352658, 0.8469380236213117, 0.8486458243583905, 0.8503350932471168, 0.8520060313820303, 0.8536588376755351, 0.8552937088815777, 0.8569108396190701, 0.8585104223950569, 0.8600926476276323, 0.8616577036686077, 0.8632057768259335, 0.8647370513858776, 0.8662517096349638, 0.8677499318816705, 0.8692318964778966, 0.8706977798401911, 0.872147756470756, 0.8735819989782182, 0.8750006780981773, 0.876403962713531, 0.8777920198745791, 0.8791650148189091, 0.880523110991067, 0.8818664700620138, 0.8831952519483716, 0.88450961483146, 0.8858097151761263, 0.8870957077493722, 0.8883677456387769, 0.8896259802707209, 0.8908705614284133, 0.8921016372697205, 0.893319354344805, 0.8945238576135703, 0.8957152904629171, 0.8968937947238127, 0.8980595106881748, 0.8992125771255726, 0.9003531312997453, 0.901481308984943, 0.90259724448209, 0.9037010706347712, 0.9047929188450466, 0.9058729190890943, 0.9069411999326822, 0.9079978885464732, 0.9090431107211644, 0.9100769908824604, 0.9110996521058863, 0.9121112161314384, 0.9131118033780763, 0.9141015329580582, 0.9150805226911198, 0.9160488891185008, 0.9170067475168172, 0.9179542119117844, 0.9188913950917916, 0.9198184086213276, 0.9207353628542624, 0.9216423669469834, 0.9225395288713903, 0.9234269554277477, 0.924304752257399, 0.9251730238553426, 0.9260318735826706, 0.9268814036788736, 0.9277217152740116, 0.9285529084007523, 0.9293750820062795, 0.9301883339640722, 0.9309927610855552, 0.9317884591316242, 0.9325755228240453, 0.9333540458567308, 0.9341241209068926, 0.9348858396460752, 0.9356392927510678, 0.9363845699146996, 0.9371217598565162, 0.9378509503333413, 0.9385722281497235, 0.9392856791682697, 0.9399913883198664, 0.9406894396137901, 0.941379916147708, 0.9420629001175698, 0.942738472827393, 0.943406714698941, 0.9440677052812975, 0.944721523260335, 0.945368246468083, 0.9460079518919926, 0.9466407156841012, 0.9472666131700983, 0.947885718858292, 0.9484981064484789, 0.9491038488407173, 0.9497030181440058, 0.9502956856848668, 0.9508819220158377, 0.9514617969238693, 0.9520353794386343, 0.9526027378407433, 0.9531639396698746, 0.9537190517328131, 0.9542681401114038, 0.9548112701704182, 0.9553485065653354, 0.9558799132500388, 0.9564055534844296, 0.9569254898419567, 0.9574397842170667, 0.9579484978325709, 0.9584516912469342, 0.9589494243614834, 0.9594417564275389, 0.959928746053467, 0.9604104512116578, 0.9608869292454256, 0.9613582368758359, 0.9618244302084569, 0.9622855647400389, 0.9627416953651208, 0.9631928763825642, 0.9636391615020183, 0.964080603850313, 0.9645172559777832, 0.9649491698645245, 0.9653763969265814, 0.965798988022068, 0.9662169934572215, 0.9666304629923916, 0.9670394458479641, 0.9674439907102194, 0.9678441457371288, 0.9682399585640877, 0.9686314763095855, 0.9690187455808149, 0.9694018124792205, 0.9697807226059864, 0.9701555210674648, 0.9705262524805459, 0.9708929609779685, 0.9712556902135743, 0.9716144833675042, 0.9719693831513387, 0.9723204318131825, 0.9726676711426936, 0.973011142476058, 0.9733508867009107, 0.9736869442612032, 0.9740193551620172, 0.9743481589743279, 0.9746733948397142, 0.974995101475018, 0.9753133171769535, 0.9756280798266659, 0.9759394268942412, 0.9762473954431661, 0.9765520221347407, 0.9768533432324426, 0.9771513946062436, 0.9774462117368798, 0.9777378297200757, 0.9780262832707215, 0.9783116067270061, 0.9785938340545044, 0.9788729988502209, 0.9791491343465893, 0.9794222734154283, 0.9796924485718547, 0.9799596919781542, 0.9802240354476103, 0.9804855104482909, 0.980744148106795, 0.9809999792119573, 0.9812530342185141, 0.9815033432507282, 0.9817509361059754, 0.9819958422582911, 0.9822380908618795, 0.9824777107545839, 0.9827147304613196, 0.9829491781974697, 0.983181081872244, 0.983410469092001, 0.9836373671635347, 0.9838618030973247, 0.9840838036107525, 0.9843033951312812, 0.9845206037996013, 0.9847354554727433, 0.9849479757271559, 0.9851581898617494, 0.9853661229009087, 0.9855717995974718, 0.9857752444356759, 0.9859764816340729, 0.986175535148412, 0.9863724286744917, 0.9865671856509799, 0.9867598292622052, 0.9869503824409158, 0.9871388678710102, 0.987325307990237, 0.9875097249928664, 0.9876921408323318, 0.9878725772238437, 0.9880510556469743, 0.9882275973482145, 0.9884022233435038, 0.9885749544207311, 0.9887458111422096, 0.9889148138471255, 0.989081982653958, 0.9892473374628746, 0.9894108979581009, 0.9895726836102624, 0.9897327136787036, 0.9898910072137803, 0.9900475830591267, 0.9902024598538997, 0.9903556560349971, 0.9905071898392522, 0.9906570793056056, 0.9908053422772517, 0.9909519964037631, 0.9910970591431917, 0.9912405477641473, 0.9913824793478524, 0.9915228707901765, 0.991661738803647, 0.9917990999194387, 0.9919349704893416, 0.992069366687708, 0.992202304513377, 0.9923337997915802, 0.9924638681758244, 0.9925925251497559, 0.9927197860290035, 0.9928456659630013, 0.9929701799367926, 0.9930933427728136, 0.9932151691326577, 0.9933356735188213, 0.99345487027643, 0.9935727735949457, 0.9936893975098569, 0.9938047559043484, 0.9939188625109547, 0.9940317309131946, 0.994143374547188, 0.9942538067032557, 0.9943630405275009, 0.9944710890233751, 0.994577965053225, 0.9946836813398248, 0.9947882504678894, 0.9948916848855739, 0.9949939969059544, 0.9950951987084944, 0.9951953023404944, 0.9952943197185261, 0.9953922626298509, 0.9954891427338233, 0.9955849715632785, 0.9956797605259059], \"type\": \"scatter\", \"uid\": \"08d70988-fe0b-4ed9-a147-dea0dfa4b0d7\"}, {\"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(247, 152, 19)\"}, \"name\": \"Noiseless signal\", \"text\": \"Noiseless signal\", \"visible\": false, \"x\": [0.05, 10.06993987975952, 20.08987975951904, 30.10981963927856, 40.129759519038075, 50.149699398797594, 60.16963927855711, 70.18957915831663, 80.20951903807615, 90.22945891783567, 100.24939879759519, 110.26933867735471, 120.28927855711423, 130.30921843687378, 140.32915831663328, 150.3490981963928, 160.36903807615232, 170.38897795591186, 180.40891783567136, 190.42885771543087, 200.4487975951904, 210.46873747494993, 220.48867735470944, 230.50861723446894, 240.52855711422848, 250.548496993988, 260.56843687374754, 270.588376753507, 280.60831663326655, 290.6282565130261, 300.64819639278556, 310.6681362725451, 320.68807615230463, 330.70801603206417, 340.7279559118237, 350.7478957915832, 360.7678356713427, 370.78777555110224, 380.8077154308617, 390.82765531062125, 400.8475951903808, 410.8675350701403, 420.88747494989985, 430.90741482965933, 440.92735470941886, 450.9472945891784, 460.9672344689379, 470.9871743486974, 481.00711422845694, 491.0270541082165, 501.046993987976, 511.0669338677355, 521.086873747495, 531.1068136272545, 541.126753507014, 551.1466933867736, 561.166633266533, 571.1865731462925, 581.2065130260521, 591.2264529058116, 601.2463927855711, 611.2663326653307, 621.2862725450901, 631.3062124248497, 641.3261523046092, 651.3460921843687, 661.3660320641283, 671.3859719438877, 681.4059118236473, 691.4258517034068, 701.4457915831663, 711.4657314629259, 721.4856713426854, 731.5056112224448, 741.5255511022044, 751.5454909819639, 761.5654308617234, 771.585370741483, 781.6053106212424, 791.625250501002, 801.6451903807615, 811.665130260521, 821.6850701402806, 831.70501002004, 841.7249498997996, 851.7448897795591, 861.7648296593186, 871.7847695390782, 881.8047094188377, 891.8246492985971, 901.8445891783567, 911.8645290581162, 921.8844689378757, 931.9044088176353, 941.9243486973947, 951.9442885771543, 961.9642284569138, 971.9841683366733, 982.0041082164329, 992.0240480961924, 1002.043987975952, 1012.0639278557114, 1022.0838677354709, 1032.1038076152304, 1042.12374749499, 1052.1436873747496, 1062.163627254509, 1072.1835671342685, 1082.203507014028, 1092.2234468937875, 1102.2433867735472, 1112.2633266533066, 1122.2832665330661, 1132.3032064128256, 1142.323146292585, 1152.3430861723448, 1162.3630260521043, 1172.3829659318637, 1182.4029058116232, 1192.4228456913827, 1202.4427855711422, 1212.4627254509019, 1222.4826653306613, 1232.5026052104208, 1242.5225450901803, 1252.5424849699398, 1262.5624248496995, 1272.582364729459, 1282.6023046092184, 1292.622244488978, 1302.6421843687374, 1312.662124248497, 1322.6820641282566, 1332.702004008016, 1342.7219438877755, 1352.741883767535, 1362.7618236472947, 1372.7817635270542, 1382.8017034068137, 1392.8216432865731, 1402.8415831663326, 1412.861523046092, 1422.8814629258518, 1432.9014028056113, 1442.9213426853707, 1452.9412825651302, 1462.9612224448897, 1472.9811623246494, 1483.0011022044089, 1493.0210420841684, 1503.0409819639278, 1513.0609218436873, 1523.0808617234468, 1533.1008016032065, 1543.120741482966, 1553.1406813627254, 1563.160621242485, 1573.1805611222444, 1583.200501002004, 1593.2204408817636, 1603.240380761523, 1613.2603206412825, 1623.280260521042, 1633.3002004008017, 1643.3201402805612, 1653.3400801603207, 1663.3600200400801, 1673.3799599198396, 1683.3998997995993, 1693.4198396793588, 1703.4397795591183, 1713.4597194388778, 1723.4796593186372, 1733.4995991983967, 1743.5195390781564, 1753.539478957916, 1763.5594188376754, 1773.5793587174348, 1783.5992985971943, 1793.619238476954, 1803.6391783567135, 1813.659118236473, 1823.6790581162325, 1833.698997995992, 1843.7189378757514, 1853.738877755511, 1863.7588176352706, 1873.77875751503, 1883.7986973947895, 1893.818637274549, 1903.8385771543087, 1913.8585170340682, 1923.8784569138277, 1933.8983967935872, 1943.9183366733466, 1953.9382765531063, 1963.9582164328658, 1973.9781563126253, 1983.9980961923848, 1994.0180360721442, 2004.037975951904, 2014.0579158316634, 2024.077855711423, 2034.0977955911824, 2044.1177354709419, 2054.1376753507016, 2064.157615230461, 2074.1775551102205, 2084.1974949899804, 2094.21743486974, 2104.2373747494994, 2114.257314629259, 2124.2772545090183, 2134.297194388778, 2144.3171342685373, 2154.337074148297, 2164.3570140280563, 2174.3769539078157, 2184.396893787575, 2194.416833667335, 2204.4367735470946, 2214.456713426854, 2224.4766533066136, 2234.496593186373, 2244.5165330661325, 2254.536472945892, 2264.5564128256515, 2274.576352705411, 2284.5962925851704, 2294.61623246493, 2304.63617234469, 2314.6561122244493, 2324.676052104209, 2334.6959919839683, 2344.7159318637277, 2354.735871743487, 2364.7558116232467, 2374.775751503006, 2384.7956913827657, 2394.815631262525, 2404.8355711422846, 2414.8555110220445, 2424.875450901804, 2434.8953907815635, 2444.915330661323, 2454.9352705410824, 2464.955210420842, 2474.9751503006014, 2484.995090180361, 2495.0150300601204, 2505.03496993988, 2515.0549098196398, 2525.0748496993992, 2535.0947895791587, 2545.114729458918, 2555.1346693386777, 2565.154609218437, 2575.1745490981966, 2585.194488977956, 2595.2144288577156, 2605.234368737475, 2615.2543086172345, 2625.2742484969945, 2635.294188376754, 2645.3141282565134, 2655.334068136273, 2665.3540080160324, 2675.373947895792, 2685.3938877755513, 2695.413827655311, 2705.4337675350703, 2715.4537074148298, 2725.4736472945897, 2735.493587174349, 2745.5135270541086, 2755.533466933868, 2765.5534068136276, 2775.573346693387, 2785.5932865731465, 2795.613226452906, 2805.6331663326655, 2815.653106212425, 2825.6730460921844, 2835.6929859719444, 2845.712925851704, 2855.7328657314633, 2865.752805611223, 2875.7727454909823, 2885.7926853707418, 2895.8126252505012, 2905.8325651302607, 2915.85250501002, 2925.8724448897797, 2935.892384769539, 2945.912324649299, 2955.9322645290586, 2965.952204408818, 2975.9721442885775, 2985.992084168337, 2996.0120240480965, 3006.031963927856, 3016.0519038076154, 3026.071843687375, 3036.0917835671344, 3046.111723446894, 3056.131663326654, 3066.1516032064133, 3076.1715430861727, 3086.191482965932, 3096.2114228456917, 3106.231362725451, 3116.2513026052106, 3126.27124248497, 3136.2911823647296, 3146.311122244489, 3156.331062124249, 3166.3510020040085, 3176.370941883768, 3186.3908817635274, 3196.410821643287, 3206.4307615230464, 3216.450701402806, 3226.4706412825653, 3236.490581162325, 3246.5105210420843, 3256.5304609218438, 3266.5504008016037, 3276.570340681363, 3286.5902805611227, 3296.610220440882, 3306.6301603206416, 3316.650100200401, 3326.6700400801606, 3336.68997995992, 3346.7099198396795, 3356.729859719439, 3366.749799599199, 3376.7697394789584, 3386.789679358718, 3396.8096192384774, 3406.829559118237, 3416.8494989979963, 3426.869438877756, 3436.8893787575153, 3446.9093186372747, 3456.929258517034, 3466.9491983967937, 3476.9691382765536, 3486.989078156313, 3497.0090180360726, 3507.028957915832, 3517.0488977955915, 3527.068837675351, 3537.0887775551105, 3547.10871743487, 3557.1286573146294, 3567.148597194389, 3577.1685370741484, 3587.1884769539083, 3597.208416833668, 3607.2283567134273, 3617.2482965931868, 3627.2682364729462, 3637.2881763527057, 3647.308116232465, 3657.3280561122247, 3667.347995991984, 3677.3679358717436, 3687.387875751503, 3697.407815631263, 3707.4277555110225, 3717.447695390782, 3727.4676352705415, 3737.487575150301, 3747.5075150300604, 3757.52745490982, 3767.5473947895794, 3777.567334669339, 3787.5872745490983, 3797.6072144288582, 3807.6271543086177, 3817.647094188377, 3827.6670340681367, 3837.686973947896, 3847.7069138276556, 3857.726853707415, 3867.7467935871746, 3877.766733466934, 3887.7866733466935, 3897.806613226453, 3907.826553106213, 3917.8464929859724, 3927.866432865732, 3937.8863727454914, 3947.906312625251, 3957.9262525050103, 3967.94619238477, 3977.9661322645293, 3987.9860721442888, 3998.0060120240482, 4008.025951903808, 4018.0458917835676, 4028.065831663327, 4038.0857715430866, 4048.105711422846, 4058.1256513026055, 4068.145591182365, 4078.1655310621245, 4088.185470941884, 4098.205410821643, 4108.225350701403, 4118.245290581162, 4128.265230460922, 4138.285170340681, 4148.305110220441, 4158.3250501002, 4168.344989979961, 4178.36492985972, 4188.38486973948, 4198.404809619239, 4208.424749498999, 4218.444689378758, 4228.464629258518, 4238.484569138277, 4248.5045090180365, 4258.524448897796, 4268.5443887775555, 4278.564328657315, 4288.584268537074, 4298.604208416834, 4308.624148296593, 4318.644088176353, 4328.664028056112, 4338.683967935872, 4348.703907815631, 4358.723847695391, 4368.74378757515, 4378.76372745491, 4388.78366733467, 4398.80360721443, 4408.823547094189, 4418.8434869739485, 4428.863426853708, 4438.8833667334675, 4448.903306613227, 4458.923246492986, 4468.943186372746, 4478.963126252505, 4488.983066132265, 4499.003006012024, 4509.022945891784, 4519.042885771543, 4529.062825651303, 4539.082765531062, 4549.102705410822, 4559.122645290581, 4569.142585170341, 4579.1625250501, 4589.18246492986, 4599.20240480962, 4609.2223446893795, 4619.242284569139, 4629.262224448898, 4639.282164328658, 4649.302104208417, 4659.322044088177, 4669.341983967936, 4679.361923847696, 4689.381863727455, 4699.401803607215, 4709.421743486974, 4719.441683366734, 4729.461623246493, 4739.481563126253, 4749.501503006012, 4759.521442885772, 4769.541382765531, 4779.561322645291, 4789.58126252505, 4799.60120240481, 4809.621142284569, 4819.641082164329, 4829.661022044089, 4839.680961923848, 4849.700901803608, 4859.720841683367, 4869.740781563127, 4879.760721442886, 4889.780661322646, 4899.800601202405, 4909.820541082165, 4919.840480961924, 4929.860420841684, 4939.880360721443, 4949.900300601203, 4959.920240480962, 4969.940180360722, 4979.960120240481, 4989.9800601202405, 5000.0], \"y\": [0.9960229718357787, 0.9738811598175616, 0.9519844913377769, 0.9303302522845718, 0.9089157585954402, 0.8877383559245313, 0.8667954193136393, 0.8460843528668391, 0.8256025894287222, 0.8053475902661946, 0.7853168447538004, 0.7655078700625249, 0.7459182108520483, 0.7265454389664023, 0.7073871531329994, 0.688440978664991, 0.6697045671669246, 0.6511755962436574, 0.632851769212494, 0.6147308148185084, 0.5968104869530226, 0.579088564375198, 0.5615628504367103, 0.5442311728094735, 0.5270913832163786, 0.5101413571650106, 0.49337899368431826, 0.4768022150641946, 0.4604089665979447, 0.44419721632760156, 0.4281649547920643, 0.41231019477802167, 0.396630971073638, 0.3811253402249608, 0.3657913802950299, 0.35062719062564973, 0.3356308916018025, 0.32080062441866763, 0.30613455085122143, 0.29163085302638714, 0.27728773319770816, 0.26310341352251543, 0.24907613584156296, 0.23520416146110135, 0.2214857709373661, 0.2079192638634504, 0.19450295865853828, 0.18123519235947172, 0.16811432041462337, 0.15513871648005506, 0.14230677221792898, 0.12961689709715407, 0.11706751819623706, 0.10465708000831886, 0.09238404424836744, 0.08024688966250482, 0.068244111839449, 0.05637422302403805, 0.044635751932822654, 0.03302724357170006, 0.021547259055564538, 0.010194375429957825, 0.0010328145053086768, 0.012135702370576928, 0.023115664378834277, 0.03397406150629767, 0.04471223966110738, 0.05533152985015233, 0.06583324834405169, 0.07621869684030591, 0.08648916262464479, 0.09664591873058659, 0.10669022409723228, 0.11662332372531203, 0.12644644883150435, 0.136160817001046, 0.14576763233865342, 0.1552680856177724, 0.1646633544281748, 0.17395460332192336, 0.18314298395771744, 0.19222963524364323, 0.20121568347834184, 0.21010224249061515, 0.21889041377748641, 0.22758128664073096, 0.23617593832189654, 0.24467543413582882, 0.2530808276027172, 0.26139316057868045, 0.2696134633849053, 0.2777427549353555, 0.2857820428630675, 0.29373232364504787, 0.3015945827257861, 0.30936979463940284, 0.3170589231304435, 0.3246629212733354, 0.3321827315905225, 0.33961928616929127, 0.34697350677730454, 0.3542463049768547, 0.3614385822378532, 0.36855123004956836, 0.37558513003112637, 0.38254115404078826, 0.38942016428401816, 0.3962230134203546, 0.40295054466909763, 0.4096035919138272, 0.4161829798057639, 0.42268952386598413, 0.4291240305865063, 0.43548729753025495, 0.4417801134299205, 0.4480032582857224, 0.45415750346209083, 0.4602436117832789, 0.466262337627915, 0.4722144270225084, 0.47810061773392, 0.4839216393608099, 0.4896782134240708, 0.49537105345626165, 0.5010008650900508, 0.5065683461456796, 0.5120741867174579, 0.5175190692593017, 0.522903668669324, 0.5282286523734899, 0.5334946804083429, 0.5387024055028184, 0.5438524731591499, 0.5489455217328785, 0.5539821825119793, 0.5589630797951088, 0.5638888309689885, 0.5687600465849287, 0.5735773304345086, 0.5783412796244165, 0.5830524846504606, 0.5877115294707631, 0.5923189915781413, 0.5968754420716881, 0.6013814457275615, 0.605837561068988, 0.6102443404354925, 0.6146023300513612, 0.6189120700933464, 0.6231740947576224, 0.6273889323259992, 0.6315571052314037, 0.6356791301226352, 0.6397555179284058, 0.6437867739206684, 0.647773397777248, 0.6517158836437751, 0.6556147201949369, 0.659470390695049, 0.6632833730579547, 0.667054139906265, 0.6707831586299398, 0.6744708914442206, 0.6781177954469234, 0.6817243226750962, 0.6852909201610493, 0.6888180299877651, 0.6923060893436952, 0.69575553057695, 0.6991667812488885, 0.7025402641871155, 0.7058763975378903, 0.7091755948179581, 0.7124382649658039, 0.7156648123923421, 0.718855637031043, 0.7220111343875051, 0.7251316955884781, 0.728217707430344, 0.7312695524270603, 0.734287608857573, 0.7372722508127052, 0.7402238482415252, 0.7431427669972028, 0.746029368882356, 0.7488840116938984, 0.7517070492673867, 0.7544988315208804, 0.7572597044983135, 0.7599900104123871, 0.762690087686988, 0.7653602709991346, 0.7680008913204628, 0.7706122759582481, 0.7731947485959774, 0.7757486293334686, 0.7782742347265474, 0.780771877826286, 0.7832418682178042, 0.7856845120586438, 0.788100112116717, 0.7904889678078351, 0.7928513752328199, 0.7951876272142078, 0.7974980133325436, 0.7997828199622754, 0.8020423303072503, 0.8042768244358182, 0.8064865793155462, 0.8086718688475495, 0.8108329639004408, 0.8129701323439056, 0.8150836390819045, 0.8171737460855082, 0.8192407124253694, 0.8212847943038344, 0.8233062450866998, 0.8253053153346175, 0.8272822528341518, 0.8292373026284934, 0.8311707070478309, 0.8330827057393905, 0.8349735356971381, 0.8368434312911563, 0.8386926242966946, 0.8405213439228973, 0.8423298168412156, 0.8441182672135024, 0.845886916719798, 0.8476359845858077, 0.8493656876100747, 0.8510762401908523, 0.8527678543526793, 0.8544407397726603, 0.8560951038064554, 0.857731151513982, 0.8593490856848326, 0.8609491068634102, 0.8625314133737862, 0.8640962013442831, 0.8656436647317843, 0.8671739953457758, 0.8686873828721203, 0.8701840148965699, 0.8716640769280171, 0.8731277524214884, 0.8745752228008847, 0.8760066674814678, 0.8774222638920999, 0.878822187497236, 0.8802066118186721, 0.8815757084570547, 0.8829296471131496, 0.8842685956088772, 0.885592719908114, 0.8869021841372637, 0.8881971506056016, 0.8894777798253918, 0.890744230531784, 0.8919966597024879, 0.8932352225772315, 0.8944600726770028, 0.8956713618230789, 0.8968692401558445, 0.8980538561534016, 0.8992253566499743, 0.9003838868541079, 0.9015295903666688, 0.9026626091986428, 0.9037830837887385, 0.9048911530207944, 0.9059869542409932, 0.907070623274887, 0.9081422944442319, 0.9092021005836384, 0.9102501730570354, 0.9112866417739535, 0.912311635205627, 0.9133252804009184, 0.9143277030020661, 0.9153190272602576, 0.9162993760510308, 0.9172688708895047, 0.9182276319454409, 0.9191757780581388, 0.9201134267511664, 0.9210406942469267, 0.9219576954810642, 0.9228645441167107, 0.9237613525585744, 0.9246482319668725, 0.9255252922711092, 0.9263926421837021, 0.9272503892134571, 0.9280986396788938, 0.9289374987214244, 0.9297670703183851, 0.9305874572959258, 0.9313987613417537, 0.9322010830177386, 0.9329945217723778, 0.9337791759531221, 0.9345551428185664, 0.9353225185505054, 0.9360813982658545, 0.9368318760284406, 0.9375740448606608, 0.9383079967550126, 0.9390338226854971, 0.9397516126188943, 0.9404614555259153, 0.9411634393922302, 0.9418576512293739, 0.942544177085531, 0.9432231020562021, 0.9438945102947511, 0.944558485022836, 0.9452151085407247, 0.9458644622374957, 0.9465066266011266, 0.9471416812284712, 0.9477697048351243, 0.9483907752651798, 0.949004969500879, 0.9496123636721525, 0.950213033066057, 0.9508070521361068, 0.9513944945115028, 0.9519754330062583, 0.952549939628225, 0.9531180855880179, 0.9536799413078425, 0.954235576430223, 0.9547850598266353, 0.955328459606043, 0.95586584312334, 0.956397276987699, 0.9569228270708281, 0.9574425585151349, 0.9579565357418021, 0.9584648224587713, 0.9589674816686407, 0.9594645756764736, 0.9599561660975219, 0.9604423138648625, 0.9609230792369506, 0.9613985218050889, 0.9618687005008133, 0.9623336736031982, 0.9627934987460801, 0.9632482329252011, 0.9636979325052737, 0.9641426532269675, 0.9645824502138177, 0.9650173779790587, 0.9654474904323802, 0.9658728408866093, 0.9662934820643195, 0.9667094661043651, 0.9671208445683439, 0.9675276684469882, 0.9679299881664858, 0.9683278535947293, 0.9687213140474985, 0.969110418294572, 0.9694952145657731, 0.9698757505569474, 0.9702520734358752, 0.9706242298481171, 0.9709922659227973, 0.9713562272783197, 0.9717161590280234, 0.9720721057857741, 0.9724241116714943, 0.9727722203166317, 0.9731164748695674, 0.9734569180009648, 0.9737935919090573, 0.9741265383248807, 0.9744557985174439, 0.9747814132988454, 0.9751034230293318, 0.9754218676223003, 0.975736786549246, 0.9760482188446546, 0.9763562031108408, 0.9766607775227326, 0.9769619798326038, 0.9772598473747529, 0.9775544170701311, 0.9778457254309184, 0.9781338085650496, 0.9784187021806894, 0.978700441590659, 0.978979061716813, 0.9792545970943681, 0.9795270818761832, 0.9797965498369934, 0.980063034377596, 0.9803265685289908, 0.9805871849564741, 0.9808449159636876, 0.9810997934966226, 0.9813518491475798, 0.981601114159085, 0.9818476194277617, 0.9820913955081607, 0.9823324726165475, 0.9825708806346479, 0.9828066491133511, 0.9830398072763731, 0.9832703840238791, 0.9834984079360652, 0.9837239072767017, 0.9839469099966356, 0.9841674437372555, 0.9843855358339182, 0.984601213319336, 0.9848145029269283, 0.9850254310941347, 0.9852340239656922, 0.9854403073968759, 0.9856443069567035, 0.9858460479311049, 0.9860455553260561, 0.9862428538706792, 0.9864379680203073, 0.9866309219595153, 0.9868217396051187, 0.9870104446091369, 0.9871970603617258, 0.9873816099940769, 0.9875641163812836, 0.9877446021451778, 0.987923089657133, 0.9880996010408378, 0.9882741581750376, 0.9884467826962471, 0.9886174960014316, 0.9887863192506597, 0.9889532733697258, 0.9891183790527439, 0.9892816567647126, 0.9894431267440519, 0.9896028090051117, 0.9897607233406526, 0.9899168893242993, 0.9900713263129667, 0.9902240534492589, 0.9903750896638428, 0.9905244536777936, 0.9906721640049159, 0.9908182389540382, 0.9909626966312826, 0.9911055549423086, 0.9912468315945332, 0.991386544099325, 0.9915247097741755, 0.9916613457448447, 0.9917964689474849, 0.9919300961307391, 0.9920622438578175, 0.9921929285085503, 0.9923221662814182, 0.9924499731955599, 0.992576365092758, 0.9927013576394024, 0.9928249663284321, 0.992947206481256, 0.9930680932496515, 0.9931876416176428, 0.9933058664033583, 0.993422782260867, 0.993538403681995, 0.9936527449981222, 0.9937658203819579, 0.9938776438492982, 0.9939882292607631, 0.9940975903235142, 0.994205740592954, 0.9943126934744063, 0.9944184622247775, 0.9945230599541997, 0.9946264996276559, 0.9947287940665874, 0.9948299559504823, 0.9949299978184474, 0.9950289320707628, 0.9951267709704186, 0.9952235266446346, 0.9953192110863645, 0.9954138361557808, 0.9955074135817469, 0.995599954963269, 0.9956914717709352, 0.9957819753483365, 0.995871476913473, 0.9959599875601448, 0.9960475182593265, 0.9961340798605273], \"type\": \"scatter\", \"uid\": \"26dfc07b-460f-456c-83ff-66bf25d5ec1f\"}, {\"error_y\": {\"array\": [0.026788247650785673, 0.02707439844158668, 0.02326015428359844, 0.02761980095456066, 0.02821861971982314, 0.02610704969745625], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 200.04000000000002, 400.03000000000003, 600.02, 800.01, 1000.0], \"y\": [0.6723602543605839, 0.27353701785263096, 0.05449847048997948, 0.30474522252512076, 0.5069864832126586, 0.6714192723827761], \"type\": \"scatter\", \"uid\": \"64160060-b296-437c-972f-5f1506cfad80\"}, {\"error_y\": {\"array\": [0.028343041003026596, 0.026783085373027527, 0.02745538603462091, 0.028317557047228208, 0.02779974074578399, 0.027848743969944894], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 220.04000000000002, 440.03000000000003, 660.02, 880.01, 1100.0], \"y\": [0.7071847496674085, 0.27327623539669416, 0.07411348584739623, 0.335960330610422, 0.5434114100123756, 0.7065204472520923], \"type\": \"scatter\", \"uid\": \"4996ff39-8b45-4c6a-ae31-b0f21de66c16\"}, {\"error_y\": {\"array\": [0.029342986666192592, 0.0290853625667043, 0.028304833133466812, 0.029376107795081468, 0.02875776452899197, 0.030118091241582712], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 240.04000000000002, 480.03000000000003, 720.02, 960.01, 1200.0], \"y\": [0.7354637900417587, 0.2698784140732949, 0.09628737044827092, 0.36550316487913925, 0.5740005146179972, 0.7353780367564976], \"type\": \"scatter\", \"uid\": \"ba36e6fe-f918-41f2-8d59-8a788cadd31c\"}, {\"error_y\": {\"array\": [0.030160894680667884, 0.031864728833852066, 0.02960742240977264, 0.030220720812414562, 0.030989155731397267, 0.031399283783408234], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 260.04, 520.03, 780.02, 1040.01, 1300.0], \"y\": [0.7637731645183854, 0.26519553659262135, 0.11726864515428279, 0.3985860229333988, 0.6057261716804685, 0.7654112968945394], \"type\": \"scatter\", \"uid\": \"f6d3dc51-a77f-49de-8bd2-9b6e1f9b1f88\"}, {\"error_y\": {\"array\": [0.0305009389292768, 0.0304094032225992, 0.03141051508672468, 0.03233843178288214, 0.03086123104133228, 0.03244146206879517], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 280.04, 560.03, 840.02, 1120.01, 1400.0], \"y\": [0.7894013340112835, 0.25663694139799437, 0.14141871060144148, 0.42432975992608657, 0.636622770206382, 0.7896213681107531], \"type\": \"scatter\", \"uid\": \"c6a64554-88a1-4572-a545-075cba6a61e6\"}, {\"error_y\": {\"array\": [0.0327703083231657, 0.03375169338485282, 0.03371766574655919, 0.03247335034183764, 0.0306156446437443, 0.03189759075070313], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 300.04, 600.03, 900.02, 1200.01, 1500.0], \"y\": [0.8104310283476045, 0.24734236838710252, 0.16489524400479824, 0.4556485580216419, 0.6624572273062064, 0.8113227440185651], \"type\": \"scatter\", \"uid\": \"4e341815-59f6-4eae-b561-3bf2da7efc05\"}, {\"error_y\": {\"array\": [0.033032632496104004, 0.03337497863395932, 0.03184206768554881, 0.03317288303604391, 0.0344867848799851, 0.032943550279896656], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 320.04, 640.03, 960.02, 1280.01, 1600.0], \"y\": [0.834325408222712, 0.2353710322845355, 0.1893932449814319, 0.47939235252411266, 0.6868464833864644, 0.8330922175205747], \"type\": \"scatter\", \"uid\": \"455b0682-bec4-4984-b768-1eaa8d508ede\"}, {\"error_y\": {\"array\": [0.03485854318228573, 0.03371864076353571, 0.03428334385303077, 0.03406117867508085, 0.034203649740431524, 0.033554336605405216], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 340.04, 680.03, 1020.02, 1360.01, 1700.0], \"y\": [0.8487488621049771, 0.2231636720449162, 0.21609560850551499, 0.508745059024266, 0.7102475965098282, 0.8495712628273114], \"type\": \"scatter\", \"uid\": \"dd29873e-78a2-4f8d-b6d9-4ca25fe14947\"}, {\"error_y\": {\"array\": [0.03452965473414759, 0.03466890427479763, 0.0337703445446918, 0.03534822491775978, 0.035583726356257846, 0.0352032627382223], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 360.04, 720.03, 1080.02, 1440.01, 1800.0], \"y\": [0.8654586783553914, 0.20924530468269267, 0.24002186885139687, 0.5334633225486481, 0.7345451941422585, 0.8652084242592796], \"type\": \"scatter\", \"uid\": \"0e1553c2-41a7-4bc5-ab91-dcd955378bea\"}, {\"error_y\": {\"array\": [0.035860632201497135, 0.03493154719988982, 0.03535742197173981, 0.03452709438232208, 0.03632067497108898, 0.035115545535823016], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 380.04, 760.03, 1140.02, 1520.01, 1900.0], \"y\": [0.8795751842225361, 0.1931622670590435, 0.26310325586270006, 0.558051393452357, 0.7520014740276612, 0.8800960612100318], \"type\": \"scatter\", \"uid\": \"23082f86-e67b-4d5f-b37c-3468343dea20\"}, {\"error_y\": {\"array\": [0.03518864460271337, 0.0358778375182449, 0.036021147333644886, 0.03420586108903546, 0.03385120105043522, 0.03568657966700837], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 400.04, 800.03, 1200.02, 1600.01, 2000.0], \"y\": [0.8940651426371855, 0.180133798644943, 0.28745357189729587, 0.5834547361967451, 0.772074885702386, 0.8938742021610011], \"type\": \"scatter\", \"uid\": \"7440f8c2-2394-4b19-a7da-d14b18223b5e\"}, {\"error_y\": {\"array\": [0.03689849272893368, 0.03480878593195907, 0.03498621469428275, 0.03665041013291051, 0.03709680051602306, 0.03660922559929139], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 420.03999999999996, 840.0299999999999, 1260.0199999999998, 1680.0099999999998, 2100.0], \"y\": [0.9034086484475412, 0.1610618470202902, 0.311504574615455, 0.6065878467475353, 0.7887279012185581, 0.9023659451111381], \"type\": \"scatter\", \"uid\": \"518b117b-2895-4446-9501-f5faf1bb01b4\"}, {\"error_y\": {\"array\": [0.03709569365653302, 0.03638877073928111, 0.037265376571112424, 0.0355129105302743, 0.03623533304363724, 0.037263189280334105], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 440.03999999999996, 880.0299999999999, 1320.0199999999998, 1760.0099999999998, 2200.0], \"y\": [0.9142600249053335, 0.144392961731949, 0.33864353533885344, 0.6252421192409697, 0.8049034578040523, 0.911890366201413], \"type\": \"scatter\", \"uid\": \"009155cf-d285-442e-bfa1-20d33ab81eb2\"}, {\"error_y\": {\"array\": [0.036147211178974334, 0.036727949973158557, 0.038364357816825796, 0.0366757242067322, 0.038217596810609857, 0.03726316256563837], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 460.03999999999996, 920.0299999999999, 1380.0199999999998, 1840.0099999999998, 2300.0], \"y\": [0.9223601450265972, 0.13131015254385064, 0.3610467160451477, 0.6490186640747241, 0.8203730751658643, 0.9235982532097307], \"type\": \"scatter\", \"uid\": \"be2321d8-8e09-4a59-97dd-c27b192cbc20\"}, {\"error_y\": {\"array\": [0.036929460609702466, 0.03560376705472317, 0.036602928582708, 0.03700363074038319, 0.037033421308230174, 0.03646127229231121], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 480.03999999999996, 960.0299999999999, 1440.0199999999998, 1920.0099999999998, 2400.0], \"y\": [0.9297146942198582, 0.11044276388320758, 0.38189872418325, 0.6665139919402532, 0.8329374638882314, 0.9315072989205515], \"type\": \"scatter\", \"uid\": \"a9b596b2-7df5-4bc9-b1ff-49cb5fab5f61\"}, {\"error_y\": {\"array\": [0.038089128180691566, 0.03695422077448899, 0.03868501142513978, 0.0381099401841163, 0.03809582240757446, 0.03701036158663884], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 500.03999999999996, 1000.0299999999999, 1500.0199999999998, 2000.0099999999998, 2500.0], \"y\": [0.9407316953282906, 0.09439606120704278, 0.4050201344968876, 0.6862317903553551, 0.8486768511519728, 0.9367468950139405], \"type\": \"scatter\", \"uid\": \"75d878d1-2a2f-4146-9b81-37e1093342d1\"}, {\"error_y\": {\"array\": [0.03723470693116256, 0.0331722477662342, 0.03844335950351771, 0.03781982272582219, 0.03723004984462546, 0.039055914507373383], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 520.04, 1040.03, 1560.02, 2080.01, 2600.0], \"y\": [0.9442117924627363, 0.07836633443049315, 0.427901101497056, 0.703339515956292, 0.8566625980851498, 0.9458350697478678], \"type\": \"scatter\", \"uid\": \"98cb07b9-7001-4512-9078-9287cf30fd1a\"}, {\"error_y\": {\"array\": [0.03601363440719608, 0.03144040608645307, 0.037360206423026045, 0.0367838806516187, 0.03847465917636426, 0.03834324472495902], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 540.04, 1080.03, 1620.02, 2160.01, 2700.0], \"y\": [0.951032711472254, 0.06556153125168246, 0.4497889609933063, 0.7201207159407845, 0.8696826707807894, 0.9509261516391493], \"type\": \"scatter\", \"uid\": \"2f706484-23c7-45e5-b94c-4e07d9c2fb34\"}, {\"error_y\": {\"array\": [0.03788105901113864, 0.026829321721417287, 0.037250723735764206, 0.038352438716443754, 0.03762089695492099, 0.03831985498201476], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 560.04, 1120.03, 1680.02, 2240.01, 2800.0], \"y\": [0.9575382506420475, 0.055641065998796854, 0.46883931150437147, 0.7349321853658757, 0.8776779439881688, 0.9559476668519667], \"type\": \"scatter\", \"uid\": \"59576a93-5b1a-4cd9-9329-7f2f91d37198\"}, {\"error_y\": {\"array\": [0.03844624513168259, 0.026127272787309863, 0.037672588256838425, 0.03858363275764844, 0.03831866023622625, 0.03776167291502007], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 580.04, 1160.03, 1740.02, 2320.01, 2900.0], \"y\": [0.9598670142893028, 0.050200132046673146, 0.4889848482460848, 0.7515558906381583, 0.8897792727348783, 0.9609262692679684], \"type\": \"scatter\", \"uid\": \"81e32f85-1a49-4841-b7f4-cbe40e0a706c\"}, {\"error_y\": {\"array\": [0.039115389127088396, 0.02700217817646775, 0.03914186502082126, 0.03758168336535997, 0.03804511395316291, 0.03806059119841811], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 600.04, 1200.03, 1800.02, 2400.01, 3000.0], \"y\": [0.9616479870085717, 0.05044132262964698, 0.510718887772379, 0.7664382717149358, 0.8970259534023115, 0.9653708114147207], \"type\": \"scatter\", \"uid\": \"0177ef1f-cafd-4ad4-ae8f-77f2047fb70f\"}, {\"error_y\": {\"array\": [0.0382765915437049, 0.028188661726600638, 0.03850588027817297, 0.03924430748305257, 0.03841967291327, 0.03886669433964447], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 620.04, 1240.03, 1860.02, 2480.01, 3100.0], \"y\": [0.96890747203288, 0.0544753223644361, 0.5294287626438323, 0.7783971881142299, 0.9053769960625413, 0.9699758800902516], \"type\": \"scatter\", \"uid\": \"77fb2b8e-4554-46f8-89c9-aeb8d6762d3b\"}, {\"error_y\": {\"array\": [0.03912225171164681, 0.03076336007617408, 0.0379533579583563, 0.03868011560735312, 0.03872374545077188, 0.03873817768058526], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 640.04, 1280.03, 1920.02, 2560.01, 3200.0], \"y\": [0.9720694491137973, 0.06324945370979608, 0.5470434500930385, 0.7921822209584156, 0.9131390535264916, 0.9731121465802117], \"type\": \"scatter\", \"uid\": \"de138a4c-36b0-4331-8cc9-eee077ab44be\"}, {\"error_y\": {\"array\": [0.038045006368949266, 0.03423651294979022, 0.03983835092020261, 0.03984750380183101, 0.03934367605762726, 0.03898845300723244], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 660.04, 1320.03, 1980.02, 2640.01, 3300.0], \"y\": [0.976127152285883, 0.07871310618706742, 0.5634297171382301, 0.8048300535566731, 0.9201798126553404, 0.9734412188606351], \"type\": \"scatter\", \"uid\": \"35c5b7e2-95b7-43fb-9978-1a5b34292b8e\"}, {\"error_y\": {\"array\": [0.03778188119803858, 0.03638530395273067, 0.038346838282382834, 0.03975240126209628, 0.03943904965681556, 0.03817660668651912], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 680.04, 1360.03, 2040.02, 2720.01, 3400.0], \"y\": [0.9781552426864087, 0.09358851054817127, 0.5834767451950118, 0.8153362373861575, 0.9242616939770086, 0.978539318895624], \"type\": \"scatter\", \"uid\": \"94fb090b-eaac-4616-a964-6b8e65efb2c8\"}, {\"error_y\": {\"array\": [0.03929870160421287, 0.037461763896110035, 0.03947509509412511, 0.038937180716415574, 0.03856163545281899, 0.04115667819540127], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 700.04, 1400.03, 2100.0200000000004, 2800.01, 3500.0], \"y\": [0.9774143174872129, 0.10973177291032098, 0.6003892687944491, 0.8272212548013496, 0.9339544925409161, 0.9811557432704662], \"type\": \"scatter\", \"uid\": \"17f4f468-864f-4e62-9005-eed656d70b63\"}, {\"error_y\": {\"array\": [0.04007418761095731, 0.03692773133181271, 0.039169731598775945, 0.03947743719587329, 0.039459025676689914, 0.040061351265615136], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 720.04, 1440.03, 2160.0200000000004, 2880.01, 3600.0], \"y\": [0.9839543689324538, 0.12639940759397977, 0.6138808359894159, 0.8385792813334134, 0.9383836199384353, 0.9819075836572709], \"type\": \"scatter\", \"uid\": \"ef6cbbcf-0a23-43ec-a02e-b5e25a209563\"}, {\"error_y\": {\"array\": [0.03952092494304416, 0.03827019159268912, 0.03812393509653767, 0.03790947272399367, 0.0396255716863552, 0.03901220280908563], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 740.04, 1480.03, 2220.0200000000004, 2960.01, 3700.0], \"y\": [0.984632904070673, 0.1409847644302439, 0.63168593889734, 0.8470367231508946, 0.9416083757060871, 0.9853346744641981], \"type\": \"scatter\", \"uid\": \"988759b8-9b16-4c8b-8115-9a73886808b7\"}, {\"error_y\": {\"array\": [0.03932446468166358, 0.036967114641573, 0.040738279968418466, 0.040250948257791526, 0.03718477171088201, 0.03822767576669643], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": true, \"x\": [0.05, 760.04, 1520.03, 2280.0200000000004, 3040.01, 3800.0], \"y\": [0.9869235352288104, 0.16228849824687883, 0.6493034495243664, 0.8569891964483497, 0.9475025116703446, 0.9838590362404479], \"type\": \"scatter\", \"uid\": \"7c491b05-1224-463a-9c6e-a8c826f08e32\"}, {\"error_y\": {\"array\": [0.03815824347065695, 0.039592822467674274, 0.040318396569101245, 0.040116165708758124, 0.039033059564821046, 0.0385518285506957], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 780.04, 1560.03, 2340.0200000000004, 3120.01, 3900.0], \"y\": [0.9880970626801551, 0.1769126979030466, 0.6626309446427007, 0.8629942101225223, 0.9508103405910905, 0.9875442994888105], \"type\": \"scatter\", \"uid\": \"5ded0c8a-e6d5-498d-94ff-9cce421a1613\"}, {\"error_y\": {\"array\": [0.03901086656035505, 0.03956886760907867, 0.04032843417047044, 0.03671123067541903, 0.04001819295321333, 0.03917410090107943], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 800.04, 1600.03, 2400.0200000000004, 3200.01, 4000.0], \"y\": [0.9876969863409386, 0.19319840486289186, 0.673067157119879, 0.8720708274801227, 0.9566741640446264, 0.9888235204794666], \"type\": \"scatter\", \"uid\": \"aff0ef94-cfd7-4034-a9ce-ffe272b7f67c\"}, {\"error_y\": {\"array\": [0.039916747570130286, 0.038736393162916105, 0.03984905993828498, 0.03880216955697487, 0.04021034551837949, 0.040176200591530896], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 820.04, 1640.03, 2460.0200000000004, 3280.01, 4100.0], \"y\": [0.9907375485500518, 0.2084729841958536, 0.6887696422718782, 0.8813134823724255, 0.9601240690158486, 0.990182562439359], \"type\": \"scatter\", \"uid\": \"6dd6c624-05bd-4045-88ff-a69ec8451d11\"}, {\"error_y\": {\"array\": [0.03898669162889692, 0.03852391452731423, 0.04007012473550594, 0.03835456202048813, 0.03848902747563602, 0.038909227476217945], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 840.04, 1680.03, 2520.0200000000004, 3360.01, 4200.0], \"y\": [0.9907803339856392, 0.22656082906412656, 0.6990314514765469, 0.8869583350150774, 0.9627769793620199, 0.9932437148262163], \"type\": \"scatter\", \"uid\": \"3785d403-5aac-4276-b68a-55efa18663c2\"}, {\"error_y\": {\"array\": [0.0417402901249937, 0.0392771777268249, 0.03917715903662836, 0.03879237863390961, 0.03912791952764471, 0.03916517949998663], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 860.04, 1720.03, 2580.0200000000004, 3440.01, 4300.0], \"y\": [0.9893061512284349, 0.24576337205028367, 0.7159323200663007, 0.8973754193448474, 0.9649945173076948, 0.9918460451852558], \"type\": \"scatter\", \"uid\": \"b1ba576c-f1ae-41d8-ba51-92988975292d\"}, {\"error_y\": {\"array\": [0.03984208892853192, 0.038803962145963294, 0.04037389252040756, 0.04048870626085143, 0.041380672176735404, 0.03751910408453364], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 880.04, 1760.03, 2640.0200000000004, 3520.01, 4400.0], \"y\": [0.9918369153711902, 0.25736170379624057, 0.7263103148566948, 0.9000613450729141, 0.9669710618232942, 0.9911097479651423], \"type\": \"scatter\", \"uid\": \"776a0832-abae-45ac-ab13-3fae1d2f8678\"}, {\"error_y\": {\"array\": [0.03900386687070472, 0.04065225381741424, 0.038630125849999454, 0.04050357255916619, 0.03906587784873647, 0.040755669836257793], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 900.04, 1800.03, 2700.0200000000004, 3600.01, 4500.0], \"y\": [0.9932860228184096, 0.27449376149264315, 0.7373259804961289, 0.9083403229448004, 0.9706302605098317, 0.9950805030644664], \"type\": \"scatter\", \"uid\": \"04d20906-ecd9-4167-81cb-3d846c3a533e\"}, {\"error_y\": {\"array\": [0.03855593772282857, 0.03796489354738052, 0.04081865188748599, 0.03926532140039036, 0.03897736242249482, 0.04019097723064729], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 920.04, 1840.03, 2760.0200000000004, 3680.01, 4600.0], \"y\": [0.9928080871850222, 0.28930544224765603, 0.749356274585442, 0.9159745834431371, 0.9724360348242972, 0.9952052335969094], \"type\": \"scatter\", \"uid\": \"29a5a895-dbf3-4cbf-9372-d097acfff2fc\"}, {\"error_y\": {\"array\": [0.04016378137216791, 0.03913403947004618, 0.037804951943364036, 0.03996893083506422, 0.039449559428300605, 0.039853674021317884], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 940.04, 1880.03, 2820.0200000000004, 3760.01, 4700.0], \"y\": [0.9960193948940164, 0.3056469849419268, 0.7583025054407239, 0.9182639455507544, 0.9761780861466917, 0.9947379272526168], \"type\": \"scatter\", \"uid\": \"38fe5f17-0f9e-4447-9681-146cf8c0610a\"}, {\"error_y\": {\"array\": [0.04102592463415911, 0.0406414188700333, 0.04039160649622046, 0.03886131925172895, 0.04022701876273069, 0.0411916487199522], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 960.04, 1920.03, 2880.0200000000004, 3840.01, 4800.0], \"y\": [0.9954340637597223, 0.31767789774309824, 0.7675073479024153, 0.9227488921298985, 0.9787104829309325, 0.9972098663311694], \"type\": \"scatter\", \"uid\": \"1abb80b1-da13-462e-9787-571dc6879d15\"}, {\"error_y\": {\"array\": [0.0387654056669004, 0.04031434357695905, 0.038917772654017, 0.03995394530461534, 0.041852993270600776, 0.04008916396373085], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 980.04, 1960.03, 2940.0200000000004, 3920.01, 4900.0], \"y\": [0.9975085742365739, 0.33301596215678714, 0.7779436011727957, 0.9285045503944925, 0.978501951352725, 0.9958586437621932], \"type\": \"scatter\", \"uid\": \"2c6ee605-e45b-4259-9338-880976d58b71\"}, {\"error_y\": {\"array\": [0.03933201140041071, 0.03826365839813522, 0.039652688807524025, 0.04178687253347006, 0.04021659968401741, 0.04036496697752771], \"color\": \"rgb(22, 96, 167)\", \"type\": \"data\", \"visible\": true}, \"hoverinfo\": \"x+y+text\", \"line\": {\"color\": \"rgb(22, 96, 167)\", \"dash\": \"dot\"}, \"mode\": \"markers\", \"name\": \"Monte Carlo simulated signal\", \"text\": \"Monte Carlo simulated signal\", \"visible\": false, \"x\": [0.05, 1000.04, 2000.03, 3000.0200000000004, 4000.01, 5000.0], \"y\": [0.9972631670432708, 0.3486537984280405, 0.7894948926270845, 0.9324087108607116, 0.9801214905817804, 0.9971892822149645], \"type\": \"scatter\", \"uid\": \"859775d4-4367-4f78-b936-56f9cb84fd19\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"25700517-2c56-48d7-a52d-01c7ef8f1182\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"c5a1050a-b91b-4cae-8eaa-9398ede5b4f9\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"bd16c086-4123-48d0-a259-00336853206d\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"ad81e32f-9ca7-4481-9647-b2d276f74798\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"366b477e-060d-4466-94cf-9a04cefd819f\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"10c8075e-df47-422d-830f-5dfd0f9f8cf1\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"f7f360ef-c802-4133-96f5-92295a5fea0f\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"138b96a4-403b-4b3b-be93-cfbcdbc23936\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"35e8d007-8f30-4fa1-9148-2067823873fe\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"8703aef1-a0c2-43e0-a66a-356d899ee010\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"7621087b-696f-4c7e-bcc5-1e931f1eabb4\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"36e59d92-b8a6-4e96-b431-cc3027e262c6\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"87c3fc89-5e43-4b82-9895-04a6f3fda6c7\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"55198797-a758-4a67-af0a-a68f44ba9751\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"18a5fcee-db08-4431-ba1a-adce3a94bd58\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": true, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"0e68aa9f-39f7-4cb0-820e-f9184a5d555f\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"99ddda14-7d3d-44ba-8b44-accecbc79e33\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"c494eeef-94b1-4413-80ea-cbe9f3d0f758\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"5174f9ec-be51-4af9-8bbc-236af26870eb\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"728abc1a-6cba-4348-bd85-9fa9f7de5d7b\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"f42a58a6-92ea-4077-bfe4-40d0d16d5360\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"63decf9c-2d2f-4303-8604-7f88140f1a4e\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"4ed872b5-de73-42ef-a76f-a8fef073eade\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"35a87db2-964d-4e98-a1c0-832f4323765e\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"106029fa-d835-45d5-8ae5-61540111c357\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"9bbc03de-5c59-4f8d-a303-334322bd5103\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"8ddc4b8d-44d3-458b-8a03-34e3beafed84\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"0ae1f557-d887-4485-890a-29c35da2f108\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"18abb352-e51d-4c43-ad53-c369736b3e4f\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"e91aa622-8f6b-4411-a2c4-1709e624804c\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"be021c57-200a-48e9-a2c8-4503cab36565\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"877d6e2b-3420-431c-9c21-de0f68124d43\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"8a88f986-c208-4fe2-bf06-523431d4f8cc\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"2a1bcae6-bbf4-4579-bfec-fab07fa2347f\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"aaa40d1b-8a04-4dcf-8c05-055278b16171\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"b33c1a27-4a84-46d7-98dd-b8e11d2ed627\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"063d9857-3c17-499c-9842-baae220ca678\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"6730ac55-3ef9-45c9-9e77-337e5f8964b4\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"45bce2d7-8bfc-42a8-9c77-270b9e410752\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"c21ef0d6-7c3b-47e8-9c89-d42f64c7e923\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"Mean T<sub>1</sub> (s)\", \"text\": \"Mean T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [909.2008, 902.451, 903.1208, 908.9028, 909.8795, 908.1413, 907.6135, 905.4125, 906.9026, 907.7208, 910.0622, 905.8549, 902.8861, 910.6911, 909.9642, 905.6332, 906.8378, 903.029, 902.5331, 903.0018, 901.5148, 904.3386, 903.8425, 898.0372, 893.8083, 898.1634, 896.3233, 898.4433, 891.4562, 895.9053, 900.3434, 899.8702, 900.8606, 894.9097, 897.8791, 899.0944, 899.1769, 897.2644, 902.7244, 898.9015, 897.1464], \"yaxis\": \"y2\", \"type\": \"scatter\", \"uid\": \"41782f49-bc40-4f4d-bf86-0500e3b358c6\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"9e517df5-a298-4592-b666-c22f4eba73c8\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"c87d5e85-78da-49be-aab4-4d4fd8118f94\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"f8a2efc3-d4c6-4064-acfd-a34b099c3159\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"ce314df0-19f8-4bc8-ba8b-f7aee2692d50\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"a0bfcb6e-6f33-4521-9503-d7368c7f9d2e\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"b55cbc72-cf50-4ef6-bb83-b05488a6f531\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"fa818f78-f76f-48f3-a004-b6f8d06b9cf6\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"f14ba27f-ecd2-4751-80a9-07ae77ee7e39\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"e4defe1c-144d-4658-855a-9b02c171417b\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"77d37794-d3ec-425d-a580-e11cfab35edb\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"94face9a-82d2-447e-bf78-7470d656d7c2\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"fee30f45-0dc3-42d5-a6ef-9670538d36ae\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"ca609e69-e8f4-49c3-b9e1-c3ab28c138d6\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"92cf9012-b95a-483e-8eba-0229aca124e8\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"fb937253-7969-4f01-abed-173325fa22f4\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"29234eee-dd9d-42b2-be43-1cf8269b6ad5\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"ceb19682-0665-48b6-bb2f-ac9d28f396fa\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"c2f1ad94-2d32-4f81-a6c1-2d91948f26b3\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"bc56a026-655e-4abb-b5ac-6ad557508c75\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"d7b67f86-8414-494d-8175-46d1cddb49da\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"1278b20b-cc6f-41ef-af96-bfb310657c93\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"a91a8043-1d9c-48e9-b776-a88ceef067eb\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"3c880132-fcd6-406f-a99e-c6d9a9ee6f80\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"db62a1da-48f6-478e-923f-aab99b62821e\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"88b92493-aaba-4513-88a1-6346e4037c92\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"3da1e754-b9a1-4c15-8f63-a17e6d2e417a\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"51bfad53-24e5-4eb3-929b-3577b441e3e6\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"5ea77736-187a-4faf-aaf2-a77cfc3694d5\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": true, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"b832eb9d-b7dd-4654-b3bf-2bc16f1305fd\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"22d1ebd2-1e29-4d3a-90fa-399251e1ece7\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"0845b9e4-b3c1-4ad0-b0b8-da47c4a57286\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"d26208dd-37c1-47eb-b091-f1979866cc5c\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"d1d35339-3bca-4c87-9e52-3b21ceb87636\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"df27b9a6-db66-430b-aba8-96bc9a9cf6d0\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"6524bc23-75b2-4e0e-9a55-ba8613720629\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"0e670d95-eb13-4ddf-86f2-0f3c8994f7ff\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"64fedc87-a722-4bb4-8036-2ff74d6a9e6d\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"3ac41775-6b1e-4f0f-b0f3-82566ca26618\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"ff22e2c5-5a10-4e57-b37a-9addf8ffdbbd\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"856836b8-b5ba-46ca-a3ed-cd6e012539a5\"}, {\"hoverinfo\": \"x+y+text\", \"name\": \"STD T<sub>1</sub> (s)\", \"text\": \"STD T<sub>1</sub> (s)\", \"visible\": false, \"x\": [1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2100, 2200, 2300, 2400, 2500, 2600, 2700, 2800, 2900, 3000, 3100, 3200, 3300, 3400, 3500, 3600, 3700, 3800, 3900, 4000, 4100, 4200, 4300, 4400, 4500, 4600, 4700, 4800, 4900, 5000], \"xaxis\": \"x2\", \"y\": [206.5163, 136.9669, 122.3092, 116.0951, 112.2524, 100.0484, 95.6991, 87.6726, 84.4738, 80.2784, 82.2373, 76.3397, 72.341, 71.4536, 71.5179, 76.8641, 82.0482, 85.6382, 84.5298, 88.8028, 86.8165, 86.5043, 81.8715, 76.6442, 62.9648, 62.3803, 58.2923, 56.7317, 56.8412, 55.753, 58.2878, 58.9989, 55.8049, 55.4229, 55.5909, 58.3058, 55.1797, 55.6067, 59.0726, 58.3801, 55.2589], \"yaxis\": \"y3\", \"type\": \"scatter\", \"uid\": \"43c85807-4a61-4336-8904-db3cbf0fef91\"}], {\"annotations\": [{\"font\": {\"family\": \"Times New Roman\", \"size\": 26}, \"showarrow\": false, \"text\": \"Inversion Time \\u2013\\u00a0TI (ms)\", \"x\": 0.5004254919715793, \"xref\": \"paper\", \"y\": -0.17, \"yref\": \"paper\"}, {\"font\": {\"family\": \"Times New Roman\", \"size\": 26}, \"showarrow\": false, \"text\": \"Signal (magnitude)\", \"textangle\": -90, \"x\": -0.15, \"xref\": \"paper\", \"y\": 0.5, \"yref\": \"paper\"}, {\"font\": {\"family\": \"Times New Roman\", \"size\": 14}, \"showarrow\": false, \"text\": \"<b>TR (ms)<b>\", \"x\": 0.76, \"xref\": \"paper\", \"y\": 0.77, \"yref\": \"paper\"}, {\"font\": {\"family\": \"Times New Roman\", \"size\": 14}, \"showarrow\": false, \"text\": \"<b>Mean T<sub>1</sub> (ms)<b>\", \"textangle\": -90, \"x\": 0.4, \"xref\": \"paper\", \"y\": 0.35, \"yref\": \"paper\"}, {\"font\": {\"family\": \"Times New Roman\", \"size\": 14}, \"showarrow\": false, \"text\": \"<b>STD T<sub>1</sub> (ms)<b>\", \"textangle\": -90, \"x\": 1.0, \"xref\": \"paper\", \"y\": 0.35, \"yref\": \"paper\"}], \"height\": 540, \"legend\": {\"bordercolor\": \"#000000\", \"borderwidth\": 2, \"font\": {\"color\": \"#000\", \"family\": \"Times New Roman\", \"size\": 12}, \"traceorder\": \"normal\", \"x\": 0.3, \"y\": 1.35}, \"margin\": {\"b\": 100, \"l\": 75, \"r\": 25, \"t\": 0}, \"sliders\": [{\"active\": 28, \"currentvalue\": {\"prefix\": \"TR value (ms): <b>\"}, \"pad\": {\"b\": 10, \"t\": 50}, \"steps\": [{\"args\": [\"visible\", [true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1000\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1100\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1200\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1300\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1400\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1500\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1600\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1700\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1800\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1900\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2000\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2100\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2200\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2300\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2400\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2500\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2600\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2700\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2800\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2900\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3000\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3100\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3200\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3300\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3400\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3500\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3600\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3700\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3800\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3900\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false]], \"label\": \"4000\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false]], \"label\": \"4100\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false]], \"label\": \"4200\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false]], \"label\": \"4300\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false]], \"label\": \"4400\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false]], \"label\": \"4500\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false]], \"label\": \"4600\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false]], \"label\": \"4700\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false]], \"label\": \"4800\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false]], \"label\": \"4900\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]], \"label\": \"5000\", \"method\": \"restyle\"}], \"x\": 0, \"y\": -0.02}], \"width\": 540, \"xaxis\": {\"autorange\": false, \"linecolor\": \"black\", \"linewidth\": 2, \"range\": [0, 5000], \"showgrid\": false}, \"yaxis\": {\"autorange\": false, \"linecolor\": \"black\", \"linewidth\": 2, \"range\": [0, 1], \"showgrid\": false}, \"xaxis2\": {\"anchor\": \"y2\", \"domain\": [0.5, 0.9], \"mirror\": true, \"showline\": true, \"side\": \"top\", \"ticks\": \"inside\"}, \"yaxis2\": {\"anchor\": \"x2\", \"autorange\": false, \"domain\": [0.05, 0.65], \"mirror\": true, \"range\": [500, 1300], \"showline\": true, \"ticks\": \"inside\"}, \"yaxis3\": {\"anchor\": \"x2\", \"autorange\": false, \"domain\": [0.05, 0.65], \"overlaying\": \"y2\", \"range\": [0, 190], \"side\": \"right\", \"ticks\": \"inside\"}}, {\"showLink\": false, \"displayModeBar\": false, \"linkText\": \"Export to plot.ly\", \"plotlyServerURL\": \"https://plot.ly\"})</script></body></html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%use sos\n",
    "%get TR_range --from Octave\n",
    "%get TI_lowres --from Octave\n",
    "%get TI_highres --from Octave\n",
    "%get T1_mean --from Octave\n",
    "%get T1_std --from Octave\n",
    "%get data_mean --from Octave\n",
    "%get data_std --from Octave\n",
    "%get data_noiseless --from Octave\n",
    "\n",
    "\n",
    "import matplotlib.pyplot as plt\n",
    "import plotly.plotly as py\n",
    "import plotly.graph_objs as go\n",
    "import numpy as np\n",
    "from plotly import __version__\n",
    "from plotly.offline import download_plotlyjs, init_notebook_mode, plot, iplot\n",
    "config={'showLink': False, 'displayModeBar': False}\n",
    "\n",
    "init_notebook_mode(connected=True)\n",
    "\n",
    "from IPython.core.display import display, HTML\n",
    "\n",
    "data1 = [dict(\n",
    "        visible = False,\n",
    "        x = np.squeeze(np.asarray(TI_lowres[ii,:])),\n",
    "        y = np.squeeze(np.asarray(data_mean[ii,:])),\n",
    "        error_y=dict(\n",
    "            type='data',\n",
    "            color = ('rgb(22, 96, 167)'),\n",
    "            array=np.squeeze(np.asarray(data_std[ii,:])),\n",
    "            visible=True\n",
    "        ),\n",
    "        line = dict(\n",
    "            color = ('rgb(22, 96, 167)'),\n",
    "            dash = 'dot'),\n",
    "        mode = 'markers',\n",
    "        name = 'Monte Carlo simulated signal',\n",
    "        text = 'Monte Carlo simulated signal',\n",
    "        hoverinfo = 'x+y+text') for ii in range(len(TR_range))]\n",
    "\n",
    "data1[28]['visible'] = True\n",
    "\n",
    "data2 = [dict(\n",
    "        visible = False,\n",
    "        x = np.squeeze(np.asarray(TI_highres[ii,:])),\n",
    "        y = np.squeeze(np.asarray(data_noiseless[ii,:])),\n",
    "        line = dict(\n",
    "            color = ('rgb(247, 152, 19)'),\n",
    "            ),\n",
    "        name = 'Noiseless signal',\n",
    "        text = 'Noiseless signal',\n",
    "        hoverinfo = 'x+y+text') for ii in range(len(TR_range))]\n",
    "\n",
    "data2[28]['visible'] = True\n",
    "\n",
    "data_meanT1 = [dict(\n",
    "    visible = False,\n",
    "    x = TR_range,\n",
    "    y = T1_mean,\n",
    "    name = 'Mean T<sub>1</sub> (s)',\n",
    "    text = 'Mean T<sub>1</sub> (s)',\n",
    "    hoverinfo = 'x+y+text',\n",
    "    xaxis='x2',\n",
    "    yaxis='y2') for ii in range(len(TR_range))]\n",
    "\n",
    "data_meanT1[15]['visible'] = True\n",
    "\n",
    "data_stdT1 = [dict(\n",
    "    visible = False,\n",
    "    x = TR_range,\n",
    "    y = T1_std,\n",
    "    name = 'STD T<sub>1</sub> (s)',\n",
    "    text = 'STD T<sub>1</sub> (s)',\n",
    "    hoverinfo = 'x+y+text',\n",
    "    xaxis='x2',\n",
    "    yaxis='y3') for ii in range(len(TR_range))]\n",
    "\n",
    "data_stdT1[28]['visible'] = True\n",
    "\n",
    "data = data2 + data1 + data_meanT1 + data_stdT1\n",
    "\n",
    "steps = []\n",
    "for i in range(len(TR_range)):\n",
    "    step = dict(\n",
    "        method = 'restyle',  \n",
    "        args = ['visible', [False] * len(data1)],\n",
    "        label = str(TR_range[i])\n",
    "    )\n",
    "    step['args'][1][i] = True # Toggle i'th trace to \"visible\"\n",
    "    steps.append(step)\n",
    "\n",
    "sliders = [dict(\n",
    "    x = 0,\n",
    "    y = -0.02,\n",
    "    active = 28,\n",
    "    currentvalue = {\"prefix\": \"TR value (ms): <b>\"},\n",
    "    pad = {\"t\": 50, \"b\": 10},\n",
    "    steps = steps\n",
    ")]\n",
    "\n",
    "layout = go.Layout(\n",
    "    width=540,\n",
    "    height=540,\n",
    "    margin = dict(\n",
    "                t=0,\n",
    "                r=25,\n",
    "                b=100,\n",
    "                l=75),\n",
    "    annotations=[\n",
    "        dict(\n",
    "            x=0.5004254919715793,\n",
    "            y=-0.17,\n",
    "            showarrow=False,\n",
    "            text='Inversion Time – TI (ms)',\n",
    "            font=dict(\n",
    "                family='Times New Roman',\n",
    "                size=26\n",
    "            ),\n",
    "            xref='paper',\n",
    "            yref='paper'\n",
    "        ),\n",
    "        dict(\n",
    "            x=-0.15,\n",
    "            y=0.5,\n",
    "            showarrow=False,\n",
    "            text='Signal (magnitude)',\n",
    "            font=dict(\n",
    "                family='Times New Roman',\n",
    "                size=26\n",
    "            ),\n",
    "            textangle=-90,\n",
    "            xref='paper',\n",
    "            yref='paper'\n",
    "        ),\n",
    "        dict(\n",
    "            x=0.76,\n",
    "            y=0.77,\n",
    "            showarrow=False,\n",
    "            text='<b>TR (ms)<b>',\n",
    "            font=dict(\n",
    "                family='Times New Roman',\n",
    "                size=14\n",
    "            ),\n",
    "            xref='paper',\n",
    "            yref='paper'\n",
    "        ),\n",
    "        dict(\n",
    "            x=0.40,\n",
    "            y=0.35,\n",
    "            showarrow=False,\n",
    "            text='<b>Mean T<sub>1</sub> (ms)<b>',\n",
    "            font=dict(\n",
    "                family='Times New Roman',\n",
    "                size=14\n",
    "            ),\n",
    "            textangle=-90,\n",
    "            xref='paper',\n",
    "            yref='paper'\n",
    "        ),\n",
    "        dict(\n",
    "            x=1.00,\n",
    "            y=0.35,\n",
    "            showarrow=False,\n",
    "            text='<b>STD T<sub>1</sub> (ms)<b>',\n",
    "            font=dict(\n",
    "                family='Times New Roman',\n",
    "                size=14\n",
    "            ),\n",
    "            textangle=-90,\n",
    "            xref='paper',\n",
    "            yref='paper'\n",
    "        )\n",
    "    ],\n",
    "    xaxis=dict(\n",
    "        autorange=False,\n",
    "        range=[0, 5000],\n",
    "        showgrid=False,\n",
    "        linecolor='black',\n",
    "        linewidth=2\n",
    "    ),\n",
    "    yaxis=dict(\n",
    "        autorange=False,\n",
    "        range=[0, 1],\n",
    "        showgrid=False,\n",
    "        linecolor='black',\n",
    "        linewidth=2\n",
    "    ),\n",
    "    xaxis2=dict(\n",
    "        domain=[0.5, 0.90],\n",
    "        anchor='y2',\n",
    "        mirror = True,\n",
    "        side='top',\n",
    "        ticks='inside',\n",
    "        showline=True,\n",
    "    ),\n",
    "    yaxis2=dict(\n",
    "        autorange=False,\n",
    "        range=[500, 1300],\n",
    "        domain=[0.05, 0.65],\n",
    "        anchor='x2',\n",
    "        mirror = True,\n",
    "        ticks='inside',\n",
    "        showline=True,\n",
    "    ),\n",
    "    yaxis3=dict(\n",
    "        autorange=False,\n",
    "        range=[0, 190],\n",
    "        domain=[0.05, 0.65],\n",
    "        anchor='x2',\n",
    "        overlaying='y2',\n",
    "        side='right',\n",
    "        ticks='inside',\n",
    "    ),\n",
    "    legend=dict(\n",
    "        x=0.3,\n",
    "        y=1.35,\n",
    "        traceorder='normal',\n",
    "        font=dict(\n",
    "            family='Times New Roman',\n",
    "            size=12,\n",
    "            color='#000'\n",
    "        ),\n",
    "        bordercolor='#000000',\n",
    "        borderwidth=2\n",
    "    ), \n",
    "    sliders=sliders\n",
    ")\n",
    "\n",
    "fig = dict(data=data, layout=layout)\n",
    "\n",
    "plot(fig, filename = 'ir_fig_6.html', config = config)\n",
    "display(HTML('ir_fig_6.html'))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "Python3"
   },
   "source": [
    "<p style=\"text-align:justify;\">\n",
    "Despite a widely acknowledged robustness for measuring accurate T<sub>1</sub> maps, inversion recovery is not often used in studies. An important drawback of this technique is the need for long TR values, generally on the order of a few T<sub>1</sub> for general models (e.g. Eqs. 1 and 4), and up to 5T<sub>1</sub> for long TR approximated models (Eq. 3). It takes about to 10-25 minutes to acquire a single-slice T<sub>1</sub> map using the inversion recovery technique, as only one TI is acquired per TR  (2-5 s) and conventional cartesian gradient readout imaging acquires one phase encode line per excitation (for a total of ~100-200 phase encode lines). The long acquisition time makes it challenging to acquire whole-organ T<sub>1</sub> maps in clinically feasible protocol times. Nonetheless, it is useful as a reference measurement for comparisons against other T<sub>1</sub> mapping methods, or to acquire a single-slice T<sub>1</sub> map of a tissue to get T<sub>1</sub> estimates for optimization of other pulse sequences.\n",
    "</p>"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "SoS",
   "language": "sos",
   "name": "sos"
  },
  "language_info": {
   "codemirror_mode": "sos",
   "file_extension": ".sos",
   "mimetype": "text/x-sos",
   "name": "sos",
   "nbconvert_exporter": "sos_notebook.converter.SoS_Exporter",
   "pygments_lexer": "sos"
  },
  "sos": {
   "kernels": [
    [
     "Octave",
     "octave",
     "Octave",
     "#dff8fb"
    ],
    [
     "Python3",
     "python3",
     "Python3",
     "#FFD91A"
    ],
    [
     "SoS",
     "sos",
     "",
     ""
    ]
   ],
   "panel": {
    "displayed": true,
    "height": 0,
    "style": "side"
   },
   "version": "0.17.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
